(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3298666,      84244]*)
(*NotebookOutlinePosition[   3299429,      84270]*)
(*  CellTagsIndexPosition[   3299385,      84266]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Estimation of Forward Curves", "Title"],

Cell["A First Expedition into the World of Electricity Prices", "Subtitle"],

Cell[CellGroupData[{

Cell["Preparation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(<< MathExcel`\ \  (*\ 
      Allows\ reading\ and\ writing\ to\ Excel\ *) \), "\n", 
    \(<< Graphics`\ \ \ \  (*\ 
      Some\ additional\ graphics\ like\ histogram\ \(\(etc\)\(.\)\)\ *) \), "\
\n", 
    \(<< Statistics`\  (*\ Mean, \ 
      StandardDeviation\ *) \), "\[IndentingNewLine]", 
    \(<< TimeSeries`\  (*\ 
      commerical\ add\ on\ for\ time\ series\ analysis\ *) \), "\
\[IndentingNewLine]", 
    \(<< Finance`\ \ \ \ \ \ \  (*\ inhouse\ developed\ add\ on, \ 
      comes\ as\ part\ of\ our\ trainings\ *) \), "\[IndentingNewLine]", 
    \(\($DefaultFont\  = \ {"\<Arial\>", 14};\)\  (*\ 
      gives\ nicer\ graphics\ if\ the\ graphics\ are\ copied\ to\ Powerpoint\ \
*) \), "\[IndentingNewLine]", 
    \(Off[General::"\<spell1\>"]\ \  (*\ 
      reduces\ the\ output\ *) \), "\[IndentingNewLine]", 
    \(\(SetOptions[ListPlot, PlotJoined \[Rule] True];\)\  (*\ 
      Some\ options\ for\ list\ plotting\ we\ regulary\ use\ *) \)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("MathExcel installed, Version 0.2\n\
"\[InvisibleSpace]"for "\[InvisibleSpace]"WindowsNT"\[InvisibleSpace]" system \
"\[InvisibleSpace]"Microsoft Windows"\[InvisibleSpace]"\n"\[InvisibleSpace]"\
\[Copyright] by Weber & Partner 2000\n"\),
      SequenceForm[ 
      "MathExcel installed, Version 0.2\n", "for ", "WindowsNT", " system ", 
        "Microsoft Windows", "\n", "\[Copyright] by Weber & Partner 2000\n"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  "The prices for electricity we want to analyze are provided from the \
Leipzig Power Exchange (LPX) as an Excel Sheet. The sheet can be downloaded \
from ",
  ButtonBox["http://www.lpx.de/info_center/downloads/dl_general/LPX_Results.\
xls",
    ButtonData:>{
      URL[ 
      "http://www.lpx.de/info_center/downloads/dl_general/LPX_Results.xls"], 
      None},
    ButtonStyle->"Hyperlink"],
  " . To get started the file is opened with Excel and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is linked to the Excel sheet."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xl = \ XLOpenLink[OpenMode \[Rule] omAttach]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A first look at the data", "Section"],

Cell[TextData[{
  "The first column within the Excel sheet contains the dates. These dates \
will come over the link as OLEDate(s). To get the typical ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " representation of dates these OLEDates are transformed to lists. (If we \
find time we should automate the selection of the range. At the moment the \
range is hard coded.)\nIn the Excel sheet the first data row is the most \
recent one. For time series analysis it is more convenient to have the most \
recent observation as the last element. The reordering of the data can be \
achieved with the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " command ",
  StyleBox["Reverse", "MR"],
  ". Since the first day in the historical data set starts with prices of \
zero for some unknown reasons, we just throw away this observation with the \
command ",
  StyleBox["Rest", "MR"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dates\  = \ \(Flatten[XLGetRange["\<A2:A685\>"]]\  /. \ 
              OLEDate \[Rule] List\  // \ Reverse\)\  // \ 
          Rest;\)\), "\[IndentingNewLine]", 
    \(dates\  // \ Shallow\)}], "Input"],

Cell[BoxData[
    \({{2000, 6, 16}, {2000, 6, 17}, {2000, 6, 18}, {2000, 6, 19}, {2000, 6, 
        20}, {2000, 6, 21}, {2000, 6, 22}, {2000, 6, 23}, {2000, 6, 
        24}, {2000, 6, 25}, \[LeftSkeleton]673\[RightSkeleton]}\)], "Output"]
}, Open  ]],

Cell["\<\
In the second column of the Excel sheet are the prices for the base load.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(base\  = \ \(\(XLGetRange["\<B2:B685\>"] // \ Flatten\)\  // \ 
            Reverse\)\  // \ Rest;\)\), "\[IndentingNewLine]", 
    \(base\  // \ Shallow\)}], "Input"],

Cell[BoxData[
    \({17.13`, 13.3`, 11.4`, 17.67`, 18.36`, 17.94`, 13.56`, 14.39`, 12.58`, 
      11.09`, \[LeftSkeleton]673\[RightSkeleton]}\)], "Output"]
}, Open  ]],

Cell["\<\
To get a first impression of the data we plot the data, doing some \
adjustments to the regular plot options and providing non-standard ticks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ticks\  = \ 
        Map[{#, StringForm["\<`3`/`2`/`1`\>", Sequence @@ dates[\([#]\)]]} &, 
          Range[1, Length[dates], 100]];\)\), "\n", 
    \(\(plbase\  = 
        ListPlot[base, PlotJoined \[Rule] True, AspectRatio \[Rule] \ 0.2, 
          Frame \[Rule] True, 
          FrameTicks \[Rule] {ticks, Automatic, None, None}, 
          PlotStyle \[Rule] Green, FrameLabel \[Rule] \ "\<\:f280/MWh\>", 
          Axes \[Rule] None, PlotRange \[Rule] All];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0224131 0.00139645 0.000465327 0.000810675 [
[.02381 -0.0125 -33.7813 -17.75 ]
[.02381 -0.0125 33.7813 0 ]
[.16345 -0.0125 -33.7813 -17.75 ]
[.16345 -0.0125 33.7813 0 ]
[.3031 -0.0125 -29.875 -17.75 ]
[.3031 -0.0125 29.875 0 ]
[.44275 -0.0125 -33.7813 -17.75 ]
[.44275 -0.0125 33.7813 0 ]
[.58239 -0.0125 -33.7813 -17.75 ]
[.58239 -0.0125 33.7813 0 ]
[.72204 -0.0125 -37.6875 -17.75 ]
[.72204 -0.0125 37.6875 0 ]
[.86168 -0.0125 -29.875 -17.75 ]
[.86168 -0.0125 29.875 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00047 -11.8125 -8.875 ]
[-0.0125 .00047 0 8.875 ]
[-0.0125 .041 -19.625 -8.875 ]
[-0.0125 .041 0 8.875 ]
[-0.0125 .08153 -27.4375 -8.875 ]
[-0.0125 .08153 0 8.875 ]
[-0.0125 .12207 -27.4375 -8.875 ]
[-0.0125 .12207 0 8.875 ]
[-0.0125 .1626 -27.4375 -8.875 ]
[-0.0125 .1626 0 8.875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .1 -45.1875 -24.8125 ]
[-0.01875 .1 -27.4375 24.8125 ]
[ 0 .2 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16345 0 m
.16345 .00625 L
s
gsave
.16345 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.3031 0 m
.3031 .00625 L
s
gsave
.3031 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.44275 0 m
.44275 .00625 L
s
gsave
.44275 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.58239 0 m
.58239 .00625 L
s
gsave
.58239 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72204 0 m
.72204 .00625 L
s
gsave
.72204 -0.0125 -98.6875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.688 17.625 moveto
(\\220) show
103.125 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
134.375 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86168 0 m
.86168 .00625 L
s
gsave
.86168 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2002) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .00047 m
.00625 .00047 L
s
gsave
-0.0125 .00047 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .041 m
.00625 .041 L
s
gsave
-0.0125 .041 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
0 .08153 m
.00625 .08153 L
s
gsave
-0.0125 .08153 -88.4375 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .12207 m
.00625 .12207 L
s
gsave
-0.0125 .12207 -88.4375 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
0 .1626 m
.00625 .1626 L
s
gsave
-0.0125 .1626 -88.4375 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .00857 m
.00375 .00857 L
s
0 .01668 m
.00375 .01668 L
s
0 .02479 m
.00375 .02479 L
s
0 .03289 m
.00375 .03289 L
s
0 .04911 m
.00375 .04911 L
s
0 .05721 m
.00375 .05721 L
s
0 .06532 m
.00375 .06532 L
s
0 .07343 m
.00375 .07343 L
s
0 .08964 m
.00375 .08964 L
s
0 .09775 m
.00375 .09775 L
s
0 .10585 m
.00375 .10585 L
s
0 .11396 m
.00375 .11396 L
s
0 .13017 m
.00375 .13017 L
s
0 .13828 m
.00375 .13828 L
s
0 .14639 m
.00375 .14639 L
s
0 .15449 m
.00375 .15449 L
s
0 .17071 m
.00375 .17071 L
s
0 .17881 m
.00375 .17881 L
s
0 .18692 m
.00375 .18692 L
s
0 .19503 m
.00375 .19503 L
s
.25 Mabswid
0 0 m
0 .2 L
s
gsave
-0.01875 .1 -122.125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.8125 12.875 translate
90 rotate
-85.8125 -12.875 translate
0 25.75 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
%%BeginResource: font Arial-MISO
%%BeginFont: Arial-MISO
/Arial /Arial-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
currentpoint currentpoint
newpath
 moveto
 0.813 0.000 rmoveto
 0 -10.063 rlineto
 6.688 0 rlineto
 0 10.063 rlineto
 -6.688 0 rlineto
closepath
fill moveto
8.313 0.000 rmoveto
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.313 17.625 moveto
(\\220) show
75.750 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MWh) show
108.625 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
1 .2 L
s
1 0 m
1 .2 L
s
0 1 0 r
.5 Mabswid
.02381 .01435 m
.02521 .01125 L
.0266 .00971 L
.028 .01479 L
.0294 .01535 L
.03079 .01501 L
.03219 .01146 L
.03358 .01213 L
.03498 .01066 L
.03638 .00946 L
.03777 .0156 L
.03917 .01357 L
.04057 .01408 L
.04196 .01554 L
.04336 .01329 L
.04476 .0095 L
.04615 .00858 L
.04755 .01353 L
.04895 .01494 L
.05034 .01452 L
.05174 .01502 L
.05314 .01394 L
.05453 .01068 L
.05593 .00846 L
.05732 .01417 L
.05872 .01584 L
.06012 .01499 L
.06151 .01381 L
.06291 .01267 L
.06431 .01002 L
.0657 .00882 L
.0671 .01303 L
.0685 .01254 L
.06989 .01266 L
.07129 .01269 L
.07269 .01363 L
.07408 .01139 L
.07548 .00903 L
.07687 .01303 L
.07827 .01286 L
.07967 .01333 L
.08106 .01254 L
.08246 .01276 L
.08386 .01047 L
.08525 .00938 L
.08665 .01304 L
.08805 .01266 L
.08944 .01212 L
.09084 .01306 L
.09224 .01345 L
Mistroke
.09363 .01071 L
.09503 .00872 L
.09643 .01167 L
.09782 .01246 L
.09922 .0122 L
.10061 .01298 L
.10201 .01249 L
.10341 .0107 L
.1048 .00875 L
.1062 .013 L
.1076 .01211 L
.10899 .01447 L
.11039 .01477 L
.11179 .01426 L
.11318 .01211 L
.11458 .00936 L
.11598 .01526 L
.11737 .01801 L
.11877 .01387 L
.12016 .01713 L
.12156 .01546 L
.12296 .01049 L
.12435 .00754 L
.12575 .0157 L
.12715 .0164 L
.12854 .01874 L
.12994 .01706 L
.13134 .01849 L
.13273 .01294 L
.13413 .01107 L
.13553 .01718 L
.13692 .02162 L
.13832 .01914 L
.13972 .02012 L
.14111 .02042 L
.14251 .01203 L
.1439 .00977 L
.1453 .01839 L
.1467 .02067 L
.14809 .02153 L
.14949 .02504 L
.15089 .01892 L
.15228 .01331 L
.15368 .01054 L
.15508 .01848 L
.15647 .01875 L
.15787 .0189 L
.15927 .02368 L
.16066 .01832 L
.16206 .01371 L
Mistroke
.16345 .0104 L
.16485 .01821 L
.16625 .01901 L
.16764 .01849 L
.16904 .01891 L
.17044 .01811 L
.17183 .01343 L
.17323 .00894 L
.17463 .01502 L
.17602 .01276 L
.17742 .01685 L
.17882 .01589 L
.18021 .01546 L
.18161 .01308 L
.18301 .00937 L
.1844 .01751 L
.1858 .01777 L
.18719 .02082 L
.18859 .01793 L
.18999 .01702 L
.19138 .00959 L
.19278 .00674 L
.19418 .01351 L
.19557 .01746 L
.19697 .01621 L
.19837 .0163 L
.19976 .01605 L
.20116 .0123 L
.20256 .00961 L
.20395 .01834 L
.20535 .01873 L
.20674 .01751 L
.20814 .01812 L
.20954 .01809 L
.21093 .01438 L
.21233 .01076 L
.21373 .02153 L
.21512 .019 L
.21652 .01629 L
.21792 .02376 L
.21931 .01648 L
.22071 .01588 L
.22211 .01125 L
.2235 .0177 L
.2249 .01922 L
.2263 .01853 L
.22769 .01545 L
.22909 .01743 L
.23048 .01329 L
.23188 .011 L
Mistroke
.23328 .01939 L
.23467 .01978 L
.23607 .02153 L
.23747 .02038 L
.23886 .02081 L
.24026 .01568 L
.24166 .01418 L
.24305 .02087 L
.24445 .02004 L
.24585 .02224 L
.24724 .0217 L
.24864 .02042 L
.25003 .01849 L
.25143 .0127 L
.25283 .02301 L
.25422 .02109 L
.25562 .02154 L
.25702 .02423 L
.25841 .01923 L
.25981 .01398 L
.26121 .01411 L
.2626 .02204 L
.264 .02056 L
.2654 .02451 L
.26679 .02166 L
.26819 .01567 L
.26959 .01642 L
.27098 .01408 L
.27238 .02088 L
.27377 .02089 L
.27517 .01768 L
.27657 .01946 L
.27796 .02094 L
.27936 .01563 L
.28076 .01365 L
.28215 .02494 L
.28355 .02949 L
.28495 .02706 L
.28634 .0216 L
.28774 .01893 L
.28914 .01638 L
.29053 .01395 L
.29193 .01267 L
.29332 .01272 L
.29472 .01667 L
.29612 .01597 L
.29751 .01499 L
.29891 .01525 L
.30031 .01381 L
.3017 .01071 L
Mistroke
.3031 .01686 L
.3045 .01604 L
.30589 .01757 L
.30729 .0176 L
.30869 .01391 L
.31008 .01289 L
.31148 .01961 L
.31288 .02033 L
.31427 .02091 L
.31567 .02081 L
.31706 .0199 L
.31846 .01832 L
.31986 .01739 L
.32125 .0241 L
.32265 .02448 L
.32405 .02492 L
.32544 .02267 L
.32684 .02472 L
.32824 .01871 L
.32963 .01528 L
.33103 .0238 L
.33243 .02117 L
.33382 .01729 L
.33522 .02131 L
.33661 .01987 L
.33801 .01491 L
.33941 .01315 L
.3408 .01984 L
.3422 .02183 L
.3436 .02083 L
.34499 .02068 L
.34639 .02342 L
.34779 .01837 L
.34918 .01528 L
.35058 .02183 L
.35198 .01754 L
.35337 .01936 L
.35477 .01861 L
.35617 .01847 L
.35756 .01627 L
.35896 .01348 L
.36035 .01836 L
.36175 .01788 L
.36315 .01825 L
.36454 .02184 L
.36594 .01904 L
.36734 .01678 L
.36873 .01331 L
.37013 .01766 L
.37153 .01796 L
Mistroke
.37292 .01808 L
.37432 .01826 L
.37572 .02075 L
.37711 .01914 L
.37851 .0149 L
.37991 .02225 L
.3813 .02586 L
.3827 .02419 L
.38409 .03275 L
.38549 .02287 L
.38689 .02084 L
.38828 .01528 L
.38968 .02179 L
.39108 .0259 L
.39247 .02183 L
.39387 .02109 L
.39527 .01788 L
.39666 .01655 L
.39806 .01318 L
.39946 .01907 L
.40085 .01506 L
.40225 .01832 L
.40364 .01851 L
.40504 .01794 L
.40644 .01567 L
.40783 .01185 L
.40923 .01486 L
.41063 .01834 L
.41202 .0169 L
.41342 .01729 L
.41482 .01657 L
.41621 .0143 L
.41761 .00771 L
.41901 .01518 L
.4204 .01847 L
.4218 .01528 L
.4232 .01751 L
.42459 .01855 L
.42599 .01536 L
.42738 .01347 L
.42878 .02095 L
.43018 .02118 L
.43157 .01708 L
.43297 .01873 L
.43437 .01974 L
.43576 .01764 L
.43716 .01477 L
.43856 .01873 L
.43995 .02239 L
.44135 .02075 L
Mistroke
.44275 .01745 L
.44414 .01402 L
.44554 .01661 L
.44693 .01245 L
.44833 .01026 L
.44973 .02245 L
.45112 .02125 L
.45252 .03423 L
.45392 .02175 L
.45531 .01828 L
.45671 .01678 L
.45811 .02731 L
.4595 .02475 L
.4609 .02117 L
.4623 .02062 L
.46369 .02629 L
.46509 .01806 L
.46649 .01498 L
.46788 .01913 L
.46928 .01309 L
.47067 .02487 L
.47207 .01802 L
.47347 .01768 L
.47486 .01646 L
.47626 .01429 L
.47766 .02061 L
.47905 .01981 L
.48045 .0178 L
.48185 .01965 L
.48324 .01507 L
.48464 .01531 L
.48604 .01158 L
.48743 .0198 L
.48883 .02091 L
.49022 .02098 L
.49162 .0184 L
.49302 .01918 L
.49441 .0147 L
.49581 .01356 L
.49721 .02235 L
.4986 .02315 L
.5 .01984 L
.5014 .01187 L
.50279 .01337 L
.50419 .01228 L
.50559 .00895 L
.50698 .01907 L
.50838 .01821 L
.50978 .01952 L
.51117 .02054 L
Mistroke
.51257 .01567 L
.51396 .01132 L
.51536 .0072 L
.51676 .00843 L
.51815 .01789 L
.51955 .02338 L
.52095 .01651 L
.52234 .01709 L
.52374 .01685 L
.52514 .01146 L
.52653 .01741 L
.52793 .01978 L
.52933 .02493 L
.53072 .01531 L
.53212 .01573 L
.53351 .01554 L
.53491 .01087 L
.53631 .02221 L
.5377 .01996 L
.5391 .02205 L
.5405 .01838 L
.54189 .0159 L
.54329 .01314 L
.54469 .0092 L
.54608 .02033 L
.54748 .02532 L
.54888 .02031 L
.55027 .02522 L
.55167 .0212 L
.55307 .01311 L
.55446 .00838 L
.55586 .02468 L
.55725 .02193 L
.55865 .022 L
.56005 .02475 L
.56144 .02093 L
.56284 .01698 L
.56424 .00886 L
.56563 .02219 L
.56703 .0202 L
.56843 .01997 L
.56982 .01792 L
.57122 .01775 L
.57262 .01264 L
.57401 .00828 L
.57541 .01991 L
.5768 .01866 L
.5782 .01496 L
.5796 .01693 L
.58099 .01668 L
Mistroke
.58239 .01038 L
.58379 .0077 L
.58518 .01403 L
.58658 .01605 L
.58798 .01283 L
.58937 .01595 L
.59077 .01384 L
.59217 .01187 L
.59356 .00754 L
.59496 .01491 L
.59636 .01797 L
.59775 .01511 L
.59915 .01642 L
.60054 .01545 L
.60194 .01063 L
.60334 .00719 L
.60473 .01636 L
.60613 .01596 L
.60753 .01687 L
.60892 .01425 L
.61032 .01739 L
.61172 .00743 L
.61311 .00476 L
.61451 .01219 L
.61591 .01696 L
.6173 .01427 L
.6187 .02098 L
.62009 .02054 L
.62149 .01408 L
.62289 .01001 L
.62428 .01787 L
.62568 .02333 L
.62708 .01958 L
.62847 .02389 L
.62987 .02102 L
.63127 .018 L
.63266 .0132 L
.63406 .02136 L
.63546 .02128 L
.63685 .03652 L
.63825 .02201 L
.63965 .01862 L
.64104 .01597 L
.64244 .0119 L
.64383 .02432 L
.64523 .02031 L
.64663 .01943 L
.64802 .02129 L
.64942 .01854 L
.65082 .0146 L
Mistroke
.65221 .01165 L
.65361 .01948 L
.65501 .01922 L
.6564 .02315 L
.6578 .02069 L
.6592 .02426 L
.66059 .01513 L
.66199 .01184 L
.66339 .01957 L
.66478 .02135 L
.66618 .02108 L
.66757 .02135 L
.66897 .02063 L
.67037 .01729 L
.67176 .01454 L
.67316 .02166 L
.67456 .02143 L
.67595 .02232 L
.67735 .02012 L
.67875 .01977 L
.68014 .01711 L
.68154 .01414 L
.68294 .02542 L
.68433 .02034 L
.68573 .01603 L
.68712 .01779 L
.68852 .01876 L
.68992 .01535 L
.69131 .01121 L
.69271 .0175 L
.69411 .01756 L
.6955 .01823 L
.6969 .02027 L
.6983 .01706 L
.69969 .01443 L
.70109 .01337 L
.70249 .01961 L
.70388 .01965 L
.70528 .02098 L
.70668 .01995 L
.70807 .02016 L
.70947 .01708 L
.71086 .01533 L
.71226 .01985 L
.71366 .02292 L
.71505 .02306 L
.71645 .02379 L
.71785 .01922 L
.71924 .01671 L
.72064 .0128 L
Mistroke
.72204 .02652 L
.72343 .02111 L
.72483 .01748 L
.72623 .01468 L
.72762 .019 L
.72902 .01778 L
.73041 .01419 L
.73181 .02272 L
.73321 .0211 L
.7346 .02327 L
.736 .02209 L
.7374 .02503 L
.73879 .01982 L
.74019 .0161 L
.74159 .02285 L
.74298 .03745 L
.74438 .03419 L
.74578 .02967 L
.74717 .033 L
.74857 .02763 L
.74997 .02013 L
.75136 .02922 L
.75276 .03112 L
.75415 .02961 L
.75555 .02679 L
.75695 .03058 L
.75834 .02105 L
.75974 .01468 L
.76114 .02826 L
.76253 .02729 L
.76393 .02594 L
.76533 .0256 L
.76672 .02207 L
.76812 .01384 L
.76952 .01319 L
.77091 .03055 L
.77231 .02641 L
.7737 .02298 L
.7751 .02177 L
.7765 .02415 L
.77789 .02153 L
.77929 .01727 L
.78069 .05203 L
.78208 .03697 L
.78348 .04733 L
.78488 .04519 L
.78627 .04754 L
.78767 .03005 L
.78907 .02115 L
.79046 .19524 L
Mistroke
.79186 .14069 L
.79326 .0342 L
.79465 .04416 L
.79605 .02463 L
.79744 .02483 L
.79884 .01948 L
.80024 .01828 L
.80163 .01302 L
.80303 .01485 L
.80443 .023 L
.80582 .01234 L
.80722 .01574 L
.80862 .01464 L
.81001 .01836 L
.81141 .01257 L
.81281 .02377 L
.8142 .02582 L
.8156 .0282 L
.81699 .02278 L
.81839 .0172 L
.81979 .03893 L
.82118 .04992 L
.82258 .0426 L
.82398 .04105 L
.82537 .03507 L
.82677 .02706 L
.82817 .02188 L
.82956 .03119 L
.83096 .02807 L
.83236 .02796 L
.83375 .02838 L
.83515 .02614 L
.83655 .01387 L
.83794 .01353 L
.83934 .02286 L
.84073 .02337 L
.84213 .01999 L
.84353 .02106 L
.84492 .0205 L
.84632 .01525 L
.84772 .01328 L
.84911 .02034 L
.85051 .01498 L
.85191 .01943 L
.8533 .01748 L
.8547 .01743 L
.8561 .0128 L
.85749 .00976 L
.85889 .01759 L
.86028 .0176 L
Mistroke
.86168 .01745 L
.86308 .01714 L
.86447 .0158 L
.86587 .01441 L
.86727 .01162 L
.86866 .01575 L
.87006 .01386 L
.87146 .01846 L
.87285 .01995 L
.87425 .01556 L
.87565 .01898 L
.87704 .0153 L
.87844 .01909 L
.87984 .01836 L
.88123 .01904 L
.88263 .0213 L
.88402 .01811 L
.88542 .01578 L
.88682 .01579 L
.88821 .01995 L
.88961 .01878 L
.89101 .01666 L
.8924 .01909 L
.8938 .02303 L
.8952 .01551 L
.89659 .01268 L
.89799 .01968 L
.89939 .02052 L
.90078 .01894 L
.90218 .01787 L
.90357 .01725 L
.90497 .01768 L
.90637 .01438 L
.90776 .01843 L
.90916 .01842 L
.91056 .01665 L
.91195 .01805 L
.91335 .01528 L
.91475 .01468 L
.91614 .01199 L
.91754 .0173 L
.91894 .01601 L
.92033 .0166 L
.92173 .01554 L
.92313 .01599 L
.92452 .01252 L
.92592 .00967 L
.92731 .01761 L
.92871 .02026 L
.93011 .01991 L
Mistroke
.9315 .01853 L
.9329 .01366 L
.9343 .01254 L
.93569 .00778 L
.93709 .0069 L
.93849 .01679 L
.93988 .01583 L
.94128 .01716 L
.94268 .016 L
.94407 .01619 L
.94547 .01288 L
.94686 .02316 L
.94826 .02075 L
.94966 .02131 L
.95105 .024 L
.95245 .0227 L
.95385 .01499 L
.95524 .01304 L
.95664 .02265 L
.95804 .02522 L
.95943 .02511 L
.96083 .02308 L
.96223 .02134 L
.96362 .01898 L
.96502 .01299 L
.96642 .02007 L
.96781 .02216 L
.96921 .02314 L
.9706 .02021 L
.972 .01647 L
.9734 .01227 L
.97479 .0098 L
.97619 .01778 L
Mfstroke
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{787, 157.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<C0000WB000`400?l00000o`00003oo`3ooooo
0?ooool0oooo5P3oool00?l0ooooo`3ooooo0?oooaH0oooo001O0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0Q`3oool005l0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`270?ooo`00G`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08L0oooo001C
0?ooo`030000003oool0oooo00<0oooo100000030?ooo`030000003oool0oooo0080oooo10000003
0?ooo`040000003oool0oooo0?ooo`H000000`3oool4000000@0oooo100000040?ooo`@000007P3o
ool6000000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`<00000103oool010000000oooo
0?ooo`3oool6000000<0oooo100000040?ooo`@00000103oool400000280oooo1P0000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool60000
00<0oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0080oooo1P0000020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`H000000`3oool4000000@0oooo100000060?ooo`030000003oool0oooo01d0oooo1P000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo0?ooo`H000000`3oool4000000@0oooo100000060?ooo`030000003o
ool0oooo01T0oooo1P0000030?ooo`<00000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo100000030?ooo`040000003oool0oooo0?ooo`H000000`3oool4000000@0oooo
100000060?ooo`030000003oool0oooo01h0oooo100000030?ooo`040000003oool0oooo0?ooo`H0
00000P3oool010000000oooo0?ooo`3oool6000000<0oooo100000040?ooo`@000000`3oool60000
06L0oooo001C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
203oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`050000003oool0oooo0?ooo`000000J`3oool005<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`020?ooo`L000000P3oool00`000000oooo0?ooo`060?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0700000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`08
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1X0?ooo`00D`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool07P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo06L0oooo001C0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`050000003oool0oooo
0?ooo`0000000P3oool2000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003o
ool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool07`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000030?ooo`000000oooo0080oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo0P0000030?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1V0?ooo`00D`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000800000103oool01@000000oooo0?ooo`000000oooo00<00000
103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0200oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0`3oool2000000<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0T
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`070?ooo`05
0000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool010000000oooo0?ooo`000003
0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo00000002000000@0oooo00<000000?ooo`3oool01@3oool01@000000
oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0I@3oool005<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000T0oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo06D0oooo001A0?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo000000090?ooo`030000003oool0000000@0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000
oooo000000H0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000002@0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`000000103oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0oooo0000003o
ool0000001l0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
0000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00L00000
0?ooo`3oool0oooo0000003oool0000001/0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo00000004
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool01`000000oooo
0?ooo`3oool000000?ooo`0000007`3oool00`000000oooo0?ooo`070?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo06D0oooo001B0?ooo`8000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo0P0000050?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000001P3oool0
0`000000oooo000000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`020?ooo`8000009@3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000
003oool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0080oooo0P00000O0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool2000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0080oooo0P00000K0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`80
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
0000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3oool200000200oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo06D0oooo001C0?ooo`030000003oool0oooo00@0oooo0`0000060?ooo`03
0000003oool0oooo00<000001P3oool00`000000oooo00000003000000@0oooo100000040?ooo`@0
0000103oool4000001l0oooo100000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
00000`0000060?ooo`030000003oool0000000<00000103oool4000000@0oooo100000040?ooo`@0
00008`3oool4000000H0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool00000
00<00000103oool4000000@0oooo100000060?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool00`3oool4000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0000000<00000103oool4000000@0oooo100000060?ooo`030000003oool0oooo
01h0oooo100000060?ooo`030000003oool0oooo00D0oooo1`0000050?ooo`030000003oool00000
00<00000103oool4000000@0oooo100000060?ooo`030000003oool0oooo01X0oooo100000040?oo
o`@000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo100000060?ooo`030000003oool0
000000<00000103oool4000000@0oooo100000060?ooo`030000003oool0oooo01l0oooo0`000006
0?ooo`030000003oool0000000<000001P3oool00`000000oooo00000003000000@0oooo10000004
0?ooo`@00000103oool4000006P0oooo003o0?ooool0ooooo`3ooolF0?ooo`00o`3ooooo0?ooool0
oooo5P3oool00?l0ooooo`3ooooo0?oooaH0oooo003o0?ooool0ooooo`3ooolF0?ooo`00o`3ooooo
0?ooool0oooo5P3oool00?l0ooooo`3ooooo0?oooaH0oooo003o0?ooool0ooooo`3ooolF0?ooo`00
o`3ooooo0?ooool0oooo5P3oool004l0oooo1000003o0?ooool0oooo`P3oool004h0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooool0oooo_`3oool004h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?ooool0oooo_`3oool004h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`090?ooool00000o`00002?000002L0oooo001>0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool09@3oool004h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0U0?ooo`00CP3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo0140oooo00<00?l00?ooo`3oool0A03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool09@3oool004h0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0@0?ooo`800?l0AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool09@3oool004h0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo04h0oooo00<00?l00?ooo`3oool0:P3oool00`00o`00
oooo0?ooo`2?0?ooo`03003o003oool0oooo03d0oooo00<00?l00?ooo`3oool0:P3oool00`00o`00
oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool2003o0=40
oooo0P00o`0X0?ooo`030000003oool0oooo02D0oooo001?0?ooo`@00000303oool4000000h0oooo
00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`800?l01P3oool00`00o`00oooo
0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo
0?ooo`030?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo
0?ooo`020?ooo`800?l07`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0080oooo
0P00o`050?ooo`03003o003oool0oooo08T0oooo00<00?l00?ooo`3oool0=`3oool00`00o`00oooo
0?ooo`030?ooo`800?l04@3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00<0oooo
00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`800?l01@3oool00`00o`00oooo
0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`00o`00bP3oool00`00o`00oooo
0?ooo`030?ooo`800?l0:03oool00`000000oooo0?ooo`0U0?ooo`00G`3oool00`000000oooo0?oo
o`0>0?ooo`800?l0103oool2003o00@0oooo0P00o`050?ooo`800?l0103oool2003o00D0oooo00<0
0?l00?ooo`3oool00`3oool2003o00@0oooo0P00o`050?ooo`800?l0103oool2003o00@0oooo0P00
o`060?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`040?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?oo
o`020?ooo`800?l0103oool2003o00H0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo02/0oooo00<00?l00?ooo`3oool0B03oool00`00o`00oooo0?oo
o`0A0?ooo`03003o003oool0oooo0280oooo0P00o`040?ooo`03003o003oool00?l000/0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool00P3oool2003o00D0oooo0P00o`040?ooo`800?l01@3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool00?l000@0oooo00<00?l00?ooo`3oool0:P3oool00`00o`00oooo0?oo
o`1Y0?ooo`03003o003oool0oooo02T0oooo0P00o`040?ooo`03003o003oool00?l001P0oooo00<0
0?l00?ooo`3oool03@3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool00`000000oooo0?ooo`0=
0?ooo`03003o003oool00?l00080oooo0P00o`000`3oool00?l00?ooo`030?ooo`03003o003oool0
0?l000<0oooo00@00?l00?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`04003o00030?ooo`00
o`000?l00080oooo0P00o`020?ooo`@00?l00P3oool3003o00030?ooo`00o`00oooo00800?l00`3o
ool2003o00@0oooo00<00?l00?ooo`00o`00103oool2003o00@0oooo0P00o`050?ooo`03003o003o
ool0oooo00<0oooo0P00o`040?ooo`800?l000<0oooo003o003oool00P3oool2003o00@0oooo00<0
0?l00?ooo`00o`000`3oool2003o00H0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`020?ooo`800?l0303oool00`00o`00oooo0?ooo`0H0?ooo`03003o003oool0oooo0080oooo0P00
o`140?ooo`03003o003oool0oooo00<0oooo0P00o`0B0?ooo`03003o003oool0oooo01H0oooo00<0
0?l00?ooo`3oool01`3oool01000o`00oooo003o0000o`040?ooo`03003o003oool00?l000D0oooo
00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`800?l01@3oool2003o00D0oooo
00<00?l00?ooo`3oool00P3oool2003o00D0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo
003o00040?ooo`03003o003oool0oooo0080oooo00@00?l00?ooo`3oool00?l00`3oool2003o00`0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo0100
oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`0d0?ooo`05003o003oool0oooo0?oo
o`00o`00703oool2003o00H0oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`090?oo
o`03003o003oool0oooo00<0oooo0P00o`040?ooo`03003o003oool00?l001L0oooo0P00o`0?0?oo
o`030000003oool0oooo02D0oooo001O0?ooo`030000003oool0oooo00d0oooo00<00?l00?ooo`3o
ool00P00o`040?ooo`<00?l000@0oooo003o003oool00?l00`3oool01P00o`00oooo0?ooo`00o`00
oooo003o00<0oooo00H00?l00?ooo`3oool0oooo003o003oool3003o00@0oooo00@00?l00?ooo`00
o`000?l01@3oool00`00o`00oooo0?ooo`02003o0080oooo00D00?l00?ooo`3oool00?l00?ooo`02
003o0080oooo00<00?l00?ooo`3oool00P3oool2003o00@0oooo0P00o`050?ooo`03003o003oool0
oooo00<0oooo0P00o`040?ooo`04003o003oool00?l0003o00<0oooo0P00o`030?ooo`04003o003o
ool0oooo003o00<0oooo0P00o`050?ooo`800?l0103oool2003o00@0oooo0P00o`060?ooo`03003o
003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool2003o00D0oooo00<00?l00?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`040?ooo`800?l0103oool2003o00<0oooo0P00o`0B0?ooo`03003o
003oool0oooo00X0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0@0?ooo`03003o
003oool0oooo0080oooo0P00o`050?ooo`800?l01@3oool00`00o`00oooo0?ooo`080?ooo`03003o
003oool00?l000d0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`800?l0
1@3oool01000o`00oooo0?ooo`3oool2003o00030?ooo`00o`00oooo0080oooo00@00?l00?ooo`3o
ool00?l01@3oool00`00o`00oooo0?ooo`020?ooo`800?l0103oool2003o00D0oooo0P00o`040?oo
o`800?l0103oool2003o00@0oooo00<00?l00?ooo`3oool00P00o`001@3oool00?l00?ooo`3oool0
0?l000<0oooo00<00?l00?ooo`00o`000P3oool2003o0080oooo00@00?l00?ooo`00o`00oooo0P00
o`060?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool2003o00D0oooo0P00
o`0;0?ooo`03003o003oool0oooo00<0oooo0P00o`050?ooo`03003o003oool0oooo00X0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0F0?ooo`800?l0503oool00`00o`00oooo003o
00030?ooo`03003o003oool0oooo00d0oooo0P00o`060?ooo`03003o003oool0oooo0080oooo0P00
o`050?ooo`<00?l0403oool2003o00X0oooo0P00o`050?ooo`800?l00`3oool01@00o`00oooo0?oo
o`3oool00?l000<0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0oooo00<0oooo0P00o`0?0?ooo`030000003oool0oooo02D0oooo001O0?ooo`030000003o
ool0oooo0100oooo0P00o`040?ooo`04003o003oool0oooo003o00<0oooo0`00o`040?ooo`03003o
003oool0oooo01d0oooo0P00o`030?ooo`04003o003oool00?l0003o0080oooo00<00?l00?ooo`3o
ool00P3oool00`00o`00oooo003o00030?ooo`03003o003oool00?l000@0oooo0P00o`040?ooo`03
003o003oool00?l000<0oooo00T00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000`3o
ool01000o`00oooo0?ooo`00o`020?ooo`04003o003oool0oooo003o00@0oooo0P00o`040?ooo`03
003o003oool00?l00080oooo0`00o`050?ooo`800?l0103oool2003o00D0oooo0P00o`030?ooo`<0
0?l0103oool2003o00D0oooo00D00?l00?ooo`3oool00?l00?ooo`02003o0080oooo00<00?l00?oo
o`3oool00P00o`0<0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0103oool00`00
o`00oooo0?ooo`020?ooo`800?l01@3oool2003o00D0oooo00<00?l00?ooo`3oool00`3oool00`00
o`00oooo0?ooo`030?ooo`800?l000L0oooo003o003oool0oooo003o003oool00?l000<0oooo00D0
0?l00?ooo`00o`00oooo003o00020?ooo`800?l01@3oool00`00o`00oooo0?ooo`020?ooo`<00?l0
2`3oool00`00o`00oooo003o00030?ooo`800?l00`3oool3003o00D0oooo00D00?l00?ooo`3oool0
oooo003o00030?ooo`04003o003oool0oooo003o00<0oooo00@00?l00?ooo`3oool0oooo0P00o`02
0?ooo`@00?l00`3oool01000o`00oooo0?ooo`00o`040?ooo`800?l0103oool2003o00@0oooo00L0
0?l00?ooo`00o`00oooo003o003oool00?l00080oooo0`00o`030?ooo`08003o003oool00?l00?oo
o`00o`00oooo003o003oool3003o00<0oooo0P00o`00103oool00?l00?ooo`00o`050?ooo`03003o
003oool0oooo0080oooo0P00o`040?ooo`800?l01@3oool2003o00D0oooo00<00?l00?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool00?l000<0oooo0P00o`060?ooo`03003o
003oool0oooo0080oooo0P00o`030?ooo`03003o003oool00?l00180oooo00<00?l00?ooo`3oool0
0`3oool2003o01@0oooo1`00o`0?0?ooo`800?l01@3oool2003o00040?ooo`00o`00oooo003o0080
oooo00@00?l00?ooo`3oool0oooo1000o`020?ooo`03003o003oool00?l000@0oooo0P00o`050?oo
o`800?l01@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool00?l00080oooo0P00o`020?oo
o`04003o003oool0oooo003o00<0oooo0P00o`020?ooo`03003o003oool0oooo00<0oooo0P00o`05
0?ooo`03003o003oool0oooo0080oooo00@00?l00?ooo`3oool00?l03P3oool00`000000oooo0?oo
o`0U0?ooo`00G`3oool4000004P0oooo0P00o`000`3oool00?l00?ooo`020?ooo`04003o003oool0
0?l0003o0080oooo00@00?l00?ooo`3oool00?l00P3oool01`00o`00oooo0?ooo`3oool00?l00?oo
o`00o`000`3oool01000o`00oooo0?ooo`00o`020?ooo`03003o003oool0oooo0080oooo0P00o`02
0?ooo`05003o003oool0oooo0?ooo`00o`000`3oool3003o0080oooo00D00?l00?ooo`3oool0oooo
003o00020?ooo`800?l000H0oooo003o003oool0oooo003o003oool3003o00030?ooo`00o`00oooo
00<0oooo0P00o`040?ooo`800?l0103oool00`00o`00oooo003o00030?ooo`<00?l0103oool2003o
00D0oooo00<00?l00?ooo`3oool00P00o`040?ooo`800?l000<0oooo003o0000o`001P3oool00`00
o`00oooo0?ooo`020?ooo`800?l00P3oool01000o`00oooo0?ooo`00o`050?ooo`800?l0103oool0
0`00o`00oooo003o00040?ooo`800?l01@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0
oooo00<0oooo0P00o`00103oool00?l00?ooo`00o`020?ooo`03003o003oool00?l000800?l000P0
oooo003o0000o`000?l00?ooo`00o`00oooo003o0080oooo00@00?l00?ooo`00o`000?l00`3oool0
1000o`00oooo003o0000o`050?ooo`03003o003oool0oooo0080oooo1000o`030?ooo`800?l00`3o
ool01000o`00oooo0?ooo`00o`040?ooo`04003o003oool0oooo003o00@0oooo00@00?l00?ooo`3o
ool00?l00`3oool00`00o`00oooo003o0003003o0080oooo00@00?l00?ooo`3oool00?l00`3oool0
1000o`00oooo0?ooo`00o`040?ooo`800?l0103oool00`00o`00oooo003o00030?ooo`05003o003o
ool00?l0003o003oool00P00o`030?ooo`800?l00`3oool2003o00040?ooo`00o`00oooo0?ooo`<0
0?l000<0oooo003o003oool00P3oool2003o00040?ooo`00o`00oooo003o00@0oooo0P00o`040?oo
o`800?l0103oool00`00o`00oooo003o00040?ooo`03003o003oool00?l000<0oooo0P00o`050?oo
o`06003o003oool0oooo003o003oool00?l00P3oool01P00o`00oooo0?ooo`00o`00oooo003o00D0
oooo0P00o`040?ooo`800?l00P3oool4003o00H0oooo00<00?l00?ooo`3oool02@3oool00`00o`00
oooo0?ooo`030?ooo`800?l01@3oool00`00o`00oooo0?ooo`0;0?ooo`05003o003oool00?l0003o
003oool00`00o`040?ooo`03003o003oool0oooo00P0oooo0P00o`050?ooo`800?l000@0oooo003o
003oool00?l00P3oool01000o`00oooo0?ooo`00o`040?ooo`05003o003oool00?l00?ooo`00o`00
0`3oool00`00o`00oooo003o00020?ooo`06003o003oool0oooo003o003oool00?l00P3oool3003o
0080oooo0P00o`020?ooo`<00?l000L0oooo003o003oool0oooo003o003oool00?l000@0oooo00<0
0?l00?ooo`00o`000P00o`050?ooo`800?l0103oool2003o00@0oooo00@00?l00?ooo`3oool00?l0
3P3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool00`000000oooo0?ooo`1:0?ooo`03003o003o
ool0oooo00@0oooo00<00?l00?ooo`00o`000P3oool01000o`00oooo0?ooo`00o`020?ooo`06003o
003oool0oooo0?ooo`00o`00oooo0`00o`001P3oool00?l00?ooo`3oool00?l00?ooo`800?l0203o
ool2003o00030?ooo`00o`00oooo00<0oooo00<00?l00?ooo`3oool00P3oool5003o0080oooo0P00
o`002`3oool00?l00?ooo`3oool00?l00?ooo`00o`00oooo003o003oool00?l000<0oooo00@00?l0
0?ooo`3oool00?l00`3oool00`00o`00oooo003o00030?ooo`03003o003oool00?l00080oooo00H0
0?l00?ooo`3oool0oooo003o003oool2003o00030?ooo`00o`00oooo00<0oooo00<00?l00?ooo`3o
ool02@3oool2003o00030?ooo`00o`00oooo00<0oooo0P00o`040?ooo`800?l00P3oool01@00o`00
oooo003o003oool00?l000@0oooo0P00o`00103oool00?l0003o0000o`020?ooo`<00?l000<0oooo
003o003oool01000o`000`3oool00?l0003o00040?ooo`800?l0103oool00`00o`00oooo0?ooo`04
003o00<0oooo00<00?l00?ooo`3oool00`3oool01000o`00oooo003o0000o`020?ooo`07003o003o
ool00?l00?ooo`00o`00oooo003o00020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o
00@0oooo00D00?l00?ooo`00o`000?l00?ooo`02003o0080oooo0`00o`030?ooo`03003o003oool0
oooo00<00?l00P3oool00`00o`00oooo0?ooo`020?ooo`<00?l0103oool00`00o`00oooo003o0002
0?ooo`04003o003oool0oooo003o00<0oooo00@00?l00?ooo`3oool00?l00P3oool01@00o`00oooo
0?ooo`3oool00?l00080oooo00L00?l00?ooo`3oool0oooo003o003oool00?l00080oooo0P00o`00
0`3oool00?l0003o000<0?ooo`03003o003oool0oooo00`0oooo00@00?l00?ooo`3oool00?l0103o
ool00`00o`00oooo003o00020?ooo`03003o003oool00?l000@0oooo00<00?l00?ooo`00o`00103o
ool00`00o`00oooo003o00030?ooo`800?l0103oool2003o00030?ooo`00o`00oooo00800?l00P3o
ool3003o00<0oooo00L00?l00?ooo`3oool0oooo003o003oool00?l000<0oooo00<00?l00?ooo`00
o`000P3oool4003o00D0oooo0P00o`0;0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`00
o`001@3oool00`00o`00oooo0?ooo`0;0?ooo`04003o003oool00?l0003o0080oooo0P00o`040?oo
o`03003o003oool0oooo00P0oooo0P00o`040?ooo`05003o003oool0oooo003o003oool00P00o`02
0?ooo`<00?l01@3oool2003o00030?ooo`00o`00oooo00800?l000@0oooo003o003oool0oooo0`00
o`020?ooo`03003o003oool00?l000800?l000<0oooo003o003oool00P00o`000`3oool00?l00?oo
o`080?ooo`03003o003oool00?l000P0oooo00<00?l00?ooo`3oool00`3oool2003o00@0oooo00<0
0?l00?ooo`00o`000P3oool01@00o`00oooo0?ooo`3oool00?l000h0oooo00<000000?ooo`3oool0
9@3oool005l0oooo00<000000?ooo`3oool0E`3oool3003o0080oooo00D00?l00?ooo`3oool0oooo
003o00030?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`3oool02@3oool2003o0140oooo
0P00o`000`3oool00?l00?ooo`020?ooo`03003o003oool0oooo0080oooo0P00o`000`3oool00?l0
003o00020?ooo`800?l000D0oooo003o003oool0oooo003o00030?ooo`03003o003oool00?l00080
oooo00@00?l00?ooo`3oool0oooo0P00o`001@3oool00?l00?ooo`3oool00?l00080oooo00<00?l0
0?ooo`3oool03@3oool2003o0080oooo00<00?l00?ooo`00o`00103oool2003o00030?ooo`00o`00
oooo00800?l000<0oooo003o003oool00`3oool01@00o`00oooo003o003oool00?l000D0oooo00<0
0?l00?ooo`00o`00103oool01@00o`00oooo003o003oool00?l000<0oooo00<00?l00?ooo`00o`00
0P3oool01@00o`00oooo0?ooo`3oool00?l00180oooo0P00o`001`3oool00?l00?ooo`3oool00?l0
0?ooo`00o`00103oool01P00o`00oooo0?ooo`00o`00oooo003o00@0oooo00@00?l00?ooo`00o`00
oooo0P00o`030?ooo`03003o003oool00?l000<0oooo00T00?l00?ooo`00o`00oooo003o003oool0
0?l00?ooo`00o`00103oool00`00o`00oooo003o00040?ooo`800?l0103oool2003o00@0oooo0P00
o`002@3oool00?l00?ooo`3oool00?l00?ooo`00o`00oooo003o00020?ooo`04003o003oool0oooo
003o0080oooo0`00o`030?ooo`03003o003oool0oooo01X0oooo00P00?l00?ooo`3oool00?l00?oo
o`00o`00oooo003o0080oooo00<00?l00?ooo`00o`000`3oool4003o0080oooo0P00o`020?ooo`04
003o003oool0oooo003o0080oooo00@00?l00?ooo`3oool00?l00P3oool3003o00030?ooo`00o`00
oooo00H0oooo00@00?l00?ooo`3oool0oooo0P00o`001@3oool00?l0003o003oool00?l000<0oooo
00<00?l00?ooo`3oool00P00o`001@3oool00?l00?ooo`3oool00?l000@0oooo0P00o`050?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo003o00040?ooo`80
0?l0303oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00<00?l00?ooo`3oool00P00o`0:0?oo
o`07003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`03003o003oool00?l000`0oooo00H0
0?l00?ooo`00o`00oooo003o003oool2003o0080oooo00<00?l00?ooo`3oool00P00o`020?ooo`03
003o003oool0oooo0140oooo00<00?l00?ooo`3oool0203oool01@00o`00oooo0?ooo`3oool00?l0
0080oooo00L00?l00?ooo`3oool0oooo003o003oool00?l00080oooo00<00?l00?ooo`3oool0403o
ool00`000000oooo0?ooo`0U0?ooo`00G`3oool00`000000oooo0?ooo`1G0?ooo`03003o003oool0
oooo00<0oooo0`00o`040?ooo`800?l04@3oool00`00o`00oooo0?ooo`0?0?ooo`03003o003oool0
0?l000/0oooo00<00?l00?ooo`00o`000P3oool3003o00<0oooo0`00o`000`3oool00?l00?ooo`02
003o00030?ooo`00o`00oooo0080oooo0P00o`001@3oool00?l00?ooo`3oool00?l00080oooo00<0
0?l00?ooo`3oool03`3oool2003o00<0oooo00@00?l00?ooo`3oool00?l00P3oool2003o00030?oo
o`00o`00oooo0080oooo1000o`020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0
103oool01000o`00oooo0?ooo`00o`030?ooo`04003o003oool00?l00?ooo`800?l05P3oool2003o
00D0oooo0P00o`040?ooo`800?l000@0oooo003o003oool00?l00P3oool3003o00<0oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`040?ooo`800?l00`3oool2003o00L0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`800?l0103oool3003o00<0oooo00D00?l0
0?ooo`00o`00oooo003o00020?ooo`800?l000D0oooo003o003oool0oooo003o000R0?ooo`04003o
003oool0oooo0?ooo`800?l000L0oooo003o003oool0oooo003o003oool00?l000<0oooo0P00o`00
0`3oool00?l00?ooo`020?ooo`04003o003oool00?l0003o00<0oooo0`00o`020?ooo`<00?l00`3o
ool2003o00d0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`03003o003oool0oooo00800?l0
103oool2003o00<0oooo00<00?l00?ooo`00o`00103oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0oooo0080oooo00<00?l00?ooo`00o`000P3oool01000o`00oooo003o0000o`060?ooo`03
003o003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`03003o003oool0oooo
00800?l01@3oool00`00o`00oooo0?ooo`020?ooo`05003o003oool00?l0003o003oool00P00o`0H
0?ooo`03003o003oool0oooo00<0oooo0P00o`020?ooo`03003o003oool0oooo01`0oooo0`00o`00
1@3oool00?l00?ooo`3oool00?l00080oooo00H00?l00?ooo`3oool00?l00?ooo`00o`0C0?ooo`03
0000003oool0oooo02D0oooo001O0?ooo`030000003oool0oooo05h0oooo0P00o`050?ooo`03003o
003oool0oooo02<0oooo00<00?l00?ooo`3oool03`3oool00`00o`00oooo0?ooo`020?ooo`04003o
003oool00?l0003o0080oooo0`00o`0:0?ooo`04003o003oool0oooo003o01H0oooo00@00?l00?oo
o`00o`000?l00P3oool00`00o`00oooo0?ooo`070?ooo`03003o003oool0oooo01<0oooo00T00?l0
0?ooo`3oool0oooo003o003oool00?l00?ooo`00o`007P3oool00`00o`00oooo0?ooo`030?ooo`80
0?l000@0oooo003o003oool0oooo0P00o`000`3oool00?l00?ooo`030?ooo`03003o003oool0oooo
00h0oooo0P00o`0=0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`00
o`00oooo003o00030?ooo`<00?l000@0oooo003o003oool0oooo0`00o`030?ooo`03003o003oool0
oooo02@0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00030?ooo`03003o003oool0
oooo00D0oooo0`00o`0:0?ooo`05003o003oool0oooo0?ooo`00o`004`3oool3003o00<0oooo0P00
o`040?ooo`03003o003oool00?l000800?l00P3oool00`00o`00oooo0?ooo`020?ooo`03003o003o
ool0oooo00<0oooo0P00o`030?ooo`05003o003oool0oooo003o003oool00P00o`000`3oool00?l0
0?ooo`050?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo
0?ooo`020?ooo`03003o003oool0oooo00800?l01@3oool00`00o`00oooo0?ooo`020?ooo`04003o
003oool00?l0003o0280oooo00<00?l00?ooo`3oool07`3oool01@00o`00oooo003o003oool00?l0
0080oooo00<00?l00?ooo`00o`00103oool2003o01<0oooo00<000000?ooo`3oool09@3oool005l0
oooo1000001N0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool08`3oool00`00o`00
oooo0?ooo`0G0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0203oool00`00o`00
oooo003o000G0?ooo`800?l000D0oooo003o003oool0oooo003o000O0?ooo`05003o003oool00?l0
0?ooo`00o`000P3oool00`00o`00oooo0?ooo`0T0?ooo`03003o003oool00?l00080oooo0P00o`00
0`3oool00?l00?ooo`030?ooo`03003o003oool0oooo02<0oooo00<00?l00?ooo`3oool02@3oool0
0`00o`00oooo003o00030?ooo`03003o003oool00?l002`0oooo00L00?l00?ooo`3oool0oooo003o
003oool00?l000<0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0<0?ooo`03003o
003oool0oooo01<0oooo00D00?l00?ooo`3oool0oooo003o00090?ooo`04003o003oool0oooo003o
00<0oooo0P00o`050?ooo`800?l00P3oool01000o`00oooo0?ooo`3oool2003o00040?ooo`00o`00
oooo003o00H0oooo00@00?l00?ooo`3oool0oooo0P00o`090?ooo`03003o003oool0oooo00800?l0
103oool2003o00@0oooo00<00?l00?ooo`3oool0B03oool01`00o`00oooo0?ooo`3oool00?l00?oo
o`00o`006@3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool00`000000oooo0?ooo`2e0?ooo`03
003o003oool00?l003h0oooo0P00o`001@3oool00?l00?ooo`3oool00?l002H0oooo00<00?l00?oo
o`00o`000P3oool01000o`00oooo0?ooo`00o`0f0?ooo`03003o003oool00?l003H0oooo00<00?l0
0?ooo`00o`00703oool00`00o`00oooo0?ooo`0G0?ooo`03003o003oool0oooo00X0oooo00L00?l0
0?ooo`3oool0oooo003o003oool00?l000<0oooo00@00?l00?ooo`00o`00oooo0P00o`030?ooo`80
0?l00`3oool00`00o`00oooo0?ooo`030?ooo`800?l00`3oool00`00o`00oooo0?ooo`090?ooo`80
0?l000<0oooo003o003oool00`3oool2003o00@0oooo00<00?l00?ooo`3oool0C@3oool2003o01T0
oooo00<000000?ooo`3oool09@3oool005l0oooo00<000000?ooo`3oool0]P3oool2003o03l0oooo
0P00o`0Z0?ooo`800?l00`3oool00`00o`00oooo0?ooo`1`0?ooo`03003o003oool00?l004<0oooo
00L00?l00?ooo`3oool0oooo003o003oool00?l00080oooo0P00o`000`3oool00?l0003o00050?oo
o`800?l00`3oool00`00o`00oooo0?ooo`030?ooo`800?l00`3oool00`00o`00oooo0?ooo`090?oo
o`800?l000<0oooo003o003oool00`3oool00`00o`00oooo003o0003003o06/0oooo00<000000?oo
o`3oool09@3oool005l0oooo00<000000?ooo`3oool0]P3oool00`00o`00oooo0?ooo`0o0?ooo`03
003o003oool0oooo02T0oooo00<00?l00?ooo`3oool0M03oool2003o04@0oooo00P00?l00?ooo`00
o`00oooo003o003oool00?l00?ooo`<00?l000<0oooo003o003oool01@3oool00`00o`00oooo0?oo
o`020?ooo`03003o003oool0oooo00<0oooo0P00o`030?ooo`03003o003oool0oooo00X0oooo00@0
0?l00?ooo`3oool00?l00`3oool00`00o`00oooo003o00020?ooo`03003o003oool0oooo06T0oooo
00<000000?ooo`3oool09@3oool005l0oooo00<000000?ooo`3oool0n03oool00`00o`00oooo0?oo
o`0Y0?ooo`03003o003oool0oooo07D0oooo00<00?l00?ooo`3oool0@P3oool01000o`00oooo003o
0000o`030?ooo`04003o003oool0oooo003o00P0oooo00<00?l00?ooo`3oool00P3oool00`00o`00
oooo0?ooo`030?ooo`800?l00`3oool00`00o`00oooo0?ooo`0=0?ooo`07003o003oool0oooo0?oo
o`00o`00oooo003o001^0?ooo`030000003oool0oooo02D0oooo001O0?ooo`030000003oool0oooo
0?P0oooo00<00?l00?ooo`3oool0:@3oool00`00o`00oooo0?ooo`1e0?ooo`03003o003oool0oooo
04<0oooo00<00?l00?ooo`00o`00503oool00`00o`00oooo0?ooo`030?ooo`800?l00`3oool00`00
o`00oooo0?ooo`0=0?ooo`04003o003oool0oooo003o0740oooo00<000000?ooo`3oool09@3oool0
05l0oooo1000003o0?ooob@0oooo00<00?l00?ooo`3oool0M@3oool00`00o`00oooo0?ooo`130?oo
o`03003o003oool00?l001@0oooo00<00?l00?ooo`3oool00`3oool2003o00040?ooo`00o`00oooo
003o00l0oooo00@00?l00?ooo`3oool00?l0L@3oool00`000000oooo0?ooo`0U0?ooo`00A`3oool4
000000@0oooo1000000<0?ooo`030000003oool0oooo0?l0ooooW@3oool00`00o`00oooo0?ooo`13
0?ooo`03003o003oool0oooo01D0oooo00<00?l00?ooo`3oool00P3oool2003o00030?ooo`00o`00
0?l00100oooo00@00?l00?ooo`3oool00?l0L@3oool00`000000oooo0?ooo`0U0?ooo`00AP3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0?l0ooooW@3oool00`00o`00oooo0?ooo`130?ooo`03003o003o
ool0oooo01D0oooo0P00o`030?ooo`800?l000<0oooo003o0000o`00403oool01000o`00oooo0?oo
o`00o`1a0?ooo`030000003oool0oooo02D0oooo00160?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo
h`3oool00`00o`00oooo0?ooo`0E0?ooo`800?l00`3oool2003o00030?ooo`00o`000?l00100oooo
00<00?l00?ooo`00o`00LP3oool00`000000oooo0?ooo`0U0?ooo`00B`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooook0?ooo`800?l0
0P3oool01000o`00oooo003o003oool2003o0100oooo00<00?l00?ooo`00o`00LP3oool00`000000
oooo0?ooo`0U0?ooo`00B`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00T0
oooo1@00003o0?ooooT0oooo0P00o`020?ooo`04003o003oool00?l00?ooo`800?l0403oool00`00
o`00oooo003o001b0?ooo`030000003oool0oooo02D0oooo00160?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0?l0oooon`3oool3003o00050?ooo`00o`00oooo003o003oool00P00o`0@0?ooo`800?l0L`3oool0
0`000000oooo0?ooo`0U0?ooo`00AP3oool5000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooon`3oool02000o`00oooo003o003oool0
0?l00?ooo`00o`00oooo0P00o`0@0?ooo`800?l0L`3oool00`000000oooo0?ooo`0U0?ooo`00AP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`3o0?oooo/0oooo00<00?l00?ooo`00o`000P00o`00103oool00?l00?oo
o`00o`0A0?ooo`800?l0L`3oool00`000000oooo0?ooo`0U0?ooo`00A`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`3o0?oooo/0oooo00T00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`004@3oool00`00
o`00oooo0?ooo`1b0?ooo`030000003oool0oooo02D0oooo00170?ooo`D000000`3oool4000000`0
oooo1000003o0?ooooX0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo003o000A0?ooo`03
003o003oool0oooo0780oooo00<000000?ooo`3oool09@3oool005l0oooo00<000000?ooo`3oool0
o`3ooook0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`00o`004@3oool00`00o`00oooo
0?ooo`1b0?ooo`030000003oool0oooo02D0oooo001O0?ooo`030000003oool0oooo0?l0oooon`3o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool00?l008H0oooo00<000000?ooo`3oool09@3o
ool005l0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo00<00?l00?ooo`00o`00QP3oool0
0`000000oooo0?ooo`0U0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool00`00
o`00oooo003o00260?ooo`030000003oool0oooo02D0oooo001O0?ooo`@00000o`3ooooo0?ooo`40
oooo00<00?l00?ooo`00o`00QP3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool00`000000oooo
0?ooo`3o0?ooool0oooo0P3oool00`00o`00oooo003o00260?ooo`030000003oool0oooo02D0oooo
001O0?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`03003o003oool00?l008H0oooo00<0
00000?ooo`3oool09@3oool005l0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo00<00?l0
0?ooo`00o`00QP3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo0P3oool00`00o`00oooo003o00260?ooo`030000003oool0oooo02D0oooo001O0?ooo`03
0000003oool0oooo0?l0ooooo`3oool20?ooo`03003o003oool00?l008H0oooo00<000000?ooo`3o
ool09@3oool005l0oooo1000003o0?ooool0oooo0@3oool00`00o`00oooo003o00260?ooo`030000
003oool0oooo02D0oooo000Y0?ooo`/00000:`3oool00`000000oooo0?ooo`3o0?ooool0oooo0P3o
ool00`00o`00oooo003o00260?ooo`030000003oool0oooo02D0oooo000Y0?ooo`/00000:`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo0P3oool00`00o`00oooo003o00260?ooo`030000003oool0
oooo02D0oooo000Y0?ooo`/00000:`3oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool00`00
o`00oooo003o00260?ooo`030000003oool0oooo02D0oooo000Y0?ooo`/00000:`3oool00`000000
oooo0?ooo`3o0?ooool0oooo0P3oool00`00o`00oooo003o00260?ooo`030000003oool0oooo02D0
oooo000Y0?ooo`/00000:`3oool400000?l0ooooo`3oool10?ooo`03003o003oool00?l008H0oooo
00<000000?ooo`3oool09@3oool002T0oooo2`00000[0?ooo`030000003oool0oooo0?l0ooooo`3o
ool20?ooo`03003o003oool00?l008H0oooo00<000000?ooo`3oool09@3oool002T0oooo2`00000>
0?ooo`030000003oool0oooo00<0oooo100000040?ooo`@000002`3oool00`000000oooo0?ooo`3o
0?ooool0oooo0P3oool00`00o`00oooo003o00260?ooo`030000003oool0oooo02D0oooo00120?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo00<00?l0
0?ooo`00o`00QP3oool00`000000oooo0?ooo`0U0?ooo`00=03oool3000000/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool00`00o`00oooo003o0026
0?ooo`030000003oool0oooo02D0oooo000a0?ooo`<000003P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`08
0?ooo`D00000o`3ooooo0?ooo`03003o003oool00?l008H0oooo00<000000?ooo`3oool09@3oool0
02h0oooo0`00000A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`80oooo00<00?l00?ooo`00o`00QP3oool00`000000oooo0?ooo`0U0?ooo`00:`3oool30000
01@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool0
0`00o`00oooo003o00260?ooo`030000003oool0oooo02D0oooo000Z0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool0
0`00o`00oooo003o00260?ooo`030000003oool0oooo02D0oooo000Z0?ooo`X00000303oool00`00
0000oooo000000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`800?l0Q`3oool0
0`000000oooo0?ooo`0U0?ooo`00:`3oool2000001@0oooo0P0000040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0?l0ooooo`3oool20?ooo`800?l0Q`3oool00`000000oooo0?ooo`0U0?ooo`00;@3oool20000
01<0oooo00<000000?ooo`3oool00`3oool4000000@0oooo1000000;0?ooo`@00000o`3ooooo0?oo
o`40oooo0P00o`270?ooo`030000003oool0oooo02D0oooo000_0?ooo`<00000;@3oool00`000000
oooo0?ooo`3o0?ooool0oooo0P3oool2003o08L0oooo00<000000?ooo`3oool09@3oool00380oooo
0P00000[0?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`800?l0Q`3oool00`000000oooo
0?ooo`0U0?ooo`00;`3oool3000002d0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo0P00
o`270?ooo`030000003oool0oooo02D0oooo000]0?ooo`800000<03oool00`000000oooo0?ooo`3o
0?ooool0oooo0P3oool2003o08L0oooo00<000000?ooo`3oool09@3oool002/0oooo0P00000b0?oo
o`@00000o`3ooooo0?ooo`40oooo0P00o`270?ooo`030000003oool0oooo02D0oooo000Z0?ooo`X0
0000:`3oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool2003o08L0oooo00<000000?ooo`3o
ool09@3oool005l0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo0P00o`270?ooo`030000
003oool0oooo02D0oooo001O0?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`800?l0Q`3o
ool00`000000oooo0?ooo`0U0?ooo`00:P3oool2000003<0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`80oooo0P00o`270?ooo`030000003oool0oooo02D0oooo000/0?ooo`<00000<03oool40000
0?l0ooooo`3oool10?ooo`800?l0Q`3oool00`000000oooo0?ooo`0U0?ooo`00;`3oool3000002d0
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo0P00o`270?ooo`030000003oool0oooo02D0
oooo000b0?ooo`800000:`3oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool2003o08L0oooo
00<000000?ooo`3oool09@3oool002l0oooo0`00000]0?ooo`030000003oool0oooo0?l0ooooo`3o
ool20?ooo`800?l0Q`3oool00`000000oooo0?ooo`0U0?ooo`00:`3oool400000300oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`80oooo0P00o`270?ooo`030000003oool0oooo02D0oooo000Z0?oo
o`030000003oool0oooo0380oooo1000003o0?ooool0oooo0@3oool2003o08L0oooo00<000000?oo
o`3oool09@3oool002/0oooo1000000`0?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`80
0?l0Q`3oool00`000000oooo0?ooo`0U0?ooo`00;`3oool300000100oooo00<000000?ooo`3oool0
0`3oool4000000@0oooo1000000;0?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`800?l0
Q`3oool00`000000oooo0?ooo`0U0?ooo`00<P3oool2000000h0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`800?l0Q`3oool00`000000oooo
0?ooo`0U0?ooo`00;`3oool300000100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3o0?ooool0oooo0P3oool2003o08L0oooo00<000000?ooo`3oool09@3oool002`0oooo0`00
000C0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`800?l0Q`3oool00`000000oooo
0?ooo`0U0?ooo`00:P3oool2000001H0oooo00<000000?ooo`3oool01`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00P0oooo1@00003o0?ooool0oooo0P00o`270?ooo`030000
003oool0oooo02D0oooo00120?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`80oooo0P00o`270?ooo`030000003oool0oooo02D0oooo000Z0?ooo`X000003P3o
ool00`000000oooo0?ooo`020?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo0P00o`270?ooo`030000003o
ool0oooo02D0oooo000]0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`3o0?ooool0oooo0P3oool2003o08L0oooo00<000000?ooo`3oool09@3oool0
02`0oooo00<000000?ooo`3oool04P3oool2000000D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`80oooo0P00o`270?ooo`030000003oool0oooo02D0oooo000/0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool00`3oool5000000<0oooo1000000;0?ooo`@00000o`3ooooo0?ooo`40
oooo0P00o`270?ooo`030000003oool0oooo02D0oooo000/0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo0P00o`270?ooo`030000003oool0oooo02D0oooo
000]0?ooo`L00000:`3oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool2003o08L0oooo00<0
00000?ooo`3oool09@3oool005l0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo0P00o`27
0?ooo`030000003oool0oooo02D0oooo001O0?ooo`030000003oool0oooo0?l0ooooo`3oool20?oo
o`800?l0Q`3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool400000?l0ooooo`3oool10?ooo`80
0?l0Q`3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooool0oooo
0P3oool2003o08L0oooo00<000000?ooo`3oool09@3oool005l0oooo00<000000?ooo`3oool0o`3o
oooo0?ooo`80oooo0P00o`270?ooo`030000003oool0oooo02D0oooo001O0?ooo`030000003oool0
oooo0?l0ooooo`3oool20?ooo`800?l0Q`3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool00`00
0000oooo0?ooo`3o0?ooool0oooo0P3oool2003o08L0oooo00<000000?ooo`3oool09@3oool005l0
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo0P00o`270?ooo`030000003oool0oooo02D0
oooo001O0?ooo`@00000o`3ooooo0?ooo`40oooo0P00o`270?ooo`030000003oool0oooo02D0oooo
001O0?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`800?l0Q`3oool00`000000oooo0?oo
o`0U0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool2003o08L0oooo00<00000
0?ooo`3oool09@3oool005l0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo0P00o`270?oo
o`030000003oool0oooo02D0oooo001O0?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`80
0?l0Q`3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool400000?l0ooooo`3oool10?ooo`800?l0
Q`3oool00`000000oooo0?ooo`0U0?ooo`00?`3oool6000000<0oooo100000040?ooo`@000002`3o
ool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool2003o08L0oooo00<000000?ooo`3oool09@3o
ool00400oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooool0oooo0P3o
ool2003o08L0oooo00<000000?ooo`3oool09@3oool00440oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool2003o08L0oooo00<000000?ooo`3oool09@3o
ool00480oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooool0oooo0P3o
ool2003o08L0oooo00<000000?ooo`3oool09@3oool004<0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool500000?l0oooo
o`3oool2003o08L0oooo00<000000?ooo`3oool09@3oool004@0oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`80oooo0P00o`270?ooo`030000003oool0oooo02D0oooo00140?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0?l0ooooo`3oool20?ooo`800?l0Q`3oool00`000000oooo0?ooo`0U0?oo
o`00?`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooo`3oool2
0?ooo`800?l0Q`3oool00`000000oooo0?ooo`0U0?ooo`00?`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`03003o003oool0oooo08H0oooo00<0
00000?ooo`3oool09@3oool00400oooo100000040?ooo`@00000103oool4000000/0oooo1000003o
0?ooool0oooo0@3oool00`00o`00oooo0?ooo`260?ooo`030000003oool0oooo02D0oooo001O0?oo
o`030000003oool0oooo0?l0ooooo`3oool20?ooo`03003o003oool0oooo08H0oooo00<000000?oo
o`3oool09@3oool005l0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo00<00?l00?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooool0oooo
0P3oool00`00o`00oooo0?ooo`260?ooo`030000003oool0oooo02D0oooo001O0?ooo`030000003o
ool0oooo0?l0ooooo`3oool20?ooo`03003o003oool0oooo08H0oooo00<000000?ooo`3oool09@3o
ool005l0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo00<00?l00?ooo`3oool0QP3oool0
0`000000oooo0?ooo`0U0?ooo`00G`3oool400000?l0ooooo`3oool10?ooo`03003o003oool0oooo
08H0oooo00<000000?ooo`3oool09@3oool005l0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80
oooo00<00?l00?ooo`3oool0QP3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool00`000000oooo
0?ooo`3o0?ooool0oooo0P3oool00`00o`00oooo0?ooo`260?ooo`030000003oool0oooo02D0oooo
001O0?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`03003o003oool0oooo08H0oooo00<0
00000?ooo`3oool09@3oool005l0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo00<00?l0
0?ooo`3oool0QP3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool400000?l0ooooo`3oool10?oo
o`03003o003oool0oooo08H0oooo00<000000?ooo`3oool09@3oool005l0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`80oooo00<00?l00?ooo`3oool0QP3oool00`000000oooo0?ooo`0U0?ooo`00
G`3oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool00`00o`00oooo0?ooo`260?ooo`030000
003oool0oooo02D0oooo001O0?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`03003o003o
ool0oooo08H0oooo00<000000?ooo`3oool09@3oool005l0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`80oooo00<00?l00?ooo`3oool0QP3oool00`000000oooo0?ooo`0U0?ooo`00G`3oool40000
0?l0ooooo`3oool10?ooo`03003o003oool0oooo08H0oooo00<000000?ooo`3oool09@3oool005l0
oooo00<000000?ooo`3oool0o`3ooooo0?oooh/0oooo00<000000?ooo`3oool09@3oool005l0oooo
00<000000?ooo`3oool0o`3ooooo0?oooh/0oooo00<000000?ooo`3oool09@3oool005l0ooooo`00
003o000008l000009`3oool00001\
\>"],
  ImageRangeCache->{{{0, 786}, {156.25, 0}} -> {-121.266, -49.5888, 1.09872, \
1.89263}}]
}, Open  ]],

Cell["\<\
Ther are large jumps observable in December 2001. At the moment we are not \
interested in these jumps therefore we use another scale in the plotting.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plbase\  = 
        ListPlot[base, PlotJoined \[Rule] True, AspectRatio \[Rule] \ 0.2, 
          Frame \[Rule] True, 
          FrameTicks \[Rule] {ticks, Automatic, None, None}, 
          PlotStyle \[Rule] Green, FrameLabel \[Rule] \ "\<\:f280/MWh\>", 
          Axes \[Rule] None];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0238095 0.00139441 0.0047619 0.0044271 [
[.0252 -0.0125 -33.7813 -17.75 ]
[.0252 -0.0125 33.7813 0 ]
[.16464 -0.0125 -33.7813 -17.75 ]
[.16464 -0.0125 33.7813 0 ]
[.30409 -0.0125 -29.875 -17.75 ]
[.30409 -0.0125 29.875 0 ]
[.44353 -0.0125 -33.7813 -17.75 ]
[.44353 -0.0125 33.7813 0 ]
[.58297 -0.0125 -33.7813 -17.75 ]
[.58297 -0.0125 33.7813 0 ]
[.72241 -0.0125 -37.6875 -17.75 ]
[.72241 -0.0125 37.6875 0 ]
[.86185 -0.0125 -29.875 -17.75 ]
[.86185 -0.0125 29.875 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00476 -11.8125 -8.875 ]
[-0.0125 .00476 0 8.875 ]
[-0.0125 .04903 -19.625 -8.875 ]
[-0.0125 .04903 0 8.875 ]
[-0.0125 .0933 -19.625 -8.875 ]
[-0.0125 .0933 0 8.875 ]
[-0.0125 .13758 -19.625 -8.875 ]
[-0.0125 .13758 0 8.875 ]
[-0.0125 .18185 -19.625 -8.875 ]
[-0.0125 .18185 0 8.875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .1 -37.375 -24.8125 ]
[-0.01875 .1 -19.625 24.8125 ]
[ 0 .2 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0252 0 m
.0252 .00625 L
s
gsave
.0252 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16464 0 m
.16464 .00625 L
s
gsave
.16464 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.30409 0 m
.30409 .00625 L
s
gsave
.30409 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.44353 0 m
.44353 .00625 L
s
gsave
.44353 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.58297 0 m
.58297 .00625 L
s
gsave
.58297 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72241 0 m
.72241 .00625 L
s
gsave
.72241 -0.0125 -98.6875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.688 17.625 moveto
(\\220) show
103.125 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
134.375 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86185 0 m
.86185 .00625 L
s
gsave
.86185 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2002) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .00476 m
.00625 .00476 L
s
gsave
-0.0125 .00476 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .04903 m
.00625 .04903 L
s
gsave
-0.0125 .04903 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .0933 m
.00625 .0933 L
s
gsave
-0.0125 .0933 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .13758 m
.00625 .13758 L
s
gsave
-0.0125 .13758 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .18185 m
.00625 .18185 L
s
gsave
-0.0125 .18185 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01362 m
.00375 .01362 L
s
0 .02247 m
.00375 .02247 L
s
0 .03132 m
.00375 .03132 L
s
0 .04018 m
.00375 .04018 L
s
0 .05789 m
.00375 .05789 L
s
0 .06674 m
.00375 .06674 L
s
0 .0756 m
.00375 .0756 L
s
0 .08445 m
.00375 .08445 L
s
0 .10216 m
.00375 .10216 L
s
0 .11101 m
.00375 .11101 L
s
0 .11987 m
.00375 .11987 L
s
0 .12872 m
.00375 .12872 L
s
0 .14643 m
.00375 .14643 L
s
0 .15528 m
.00375 .15528 L
s
0 .16414 m
.00375 .16414 L
s
0 .17299 m
.00375 .17299 L
s
0 .1907 m
.00375 .1907 L
s
0 .19955 m
.00375 .19955 L
s
.25 Mabswid
0 0 m
0 .2 L
s
gsave
-0.01875 .1 -114.313 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.8125 12.875 translate
90 rotate
-85.8125 -12.875 translate
0 25.75 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
%%BeginResource: font Arial-MISO
%%BeginFont: Arial-MISO
/Arial /Arial-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
currentpoint currentpoint
newpath
 moveto
 0.813 0.000 rmoveto
 0 -10.063 rlineto
 6.688 0 rlineto
 0 10.063 rlineto
 -6.688 0 rlineto
closepath
fill moveto
8.313 0.000 rmoveto
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.313 17.625 moveto
(\\220) show
75.750 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MWh) show
108.625 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
1 .2 L
s
1 0 m
1 .2 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.0252 .0806 m
.0266 .06364 L
.02799 .05523 L
.02939 .08299 L
.03078 .08604 L
.03218 .08418 L
.03357 .06479 L
.03496 .06847 L
.03636 .06045 L
.03775 .05386 L
.03915 .08742 L
.04054 .07635 L
.04194 .07909 L
.04333 .08706 L
.04473 .0748 L
.04612 .05408 L
.04751 .04908 L
.04891 .07608 L
.0503 .08379 L
.0517 .08153 L
.05309 .08423 L
.05449 .07834 L
.05588 .06054 L
.05728 .04841 L
.05867 .07958 L
.06006 .08874 L
.06146 .0841 L
.06285 .07763 L
.06425 .07139 L
.06564 .05691 L
.06704 .05036 L
.06843 .07338 L
.06983 .07068 L
.07122 .07135 L
.07261 .07152 L
.07401 .07666 L
.0754 .06444 L
.0768 .05151 L
.07819 .07338 L
.07959 .07245 L
.08098 .07502 L
.08237 .07068 L
.08377 .07188 L
.08516 .05939 L
.08656 .05346 L
.08795 .07343 L
.08935 .07135 L
.09074 .06842 L
.09214 .07356 L
.09353 .07568 L
Mistroke
.09492 .06072 L
.09632 .04983 L
.09771 .06594 L
.09911 .07028 L
.1005 .06887 L
.1019 .07312 L
.10329 .07042 L
.10469 .06068 L
.10608 .05001 L
.10747 .0732 L
.10887 .06838 L
.11026 .08126 L
.11166 .0829 L
.11305 .08011 L
.11445 .06834 L
.11584 .05333 L
.11723 .08556 L
.11863 .10056 L
.12002 .07794 L
.12142 .09578 L
.12281 .08666 L
.12421 .05948 L
.1256 .04341 L
.127 .08795 L
.12839 .0918 L
.12978 .10455 L
.13118 .09538 L
.13257 .10322 L
.13397 .0729 L
.13536 .06267 L
.13676 .09605 L
.13815 .12031 L
.13955 .10676 L
.14094 .11207 L
.14233 .11376 L
.14373 .06789 L
.14512 .05559 L
.14652 .10265 L
.14791 .11509 L
.14931 .11982 L
.1507 .13899 L
.1521 .10557 L
.15349 .07493 L
.15488 .05979 L
.15628 .10313 L
.15767 .10459 L
.15907 .10543 L
.16046 .13155 L
.16186 .10225 L
.16325 .0771 L
Mistroke
.16464 .05904 L
.16604 .10167 L
.16743 .10605 L
.16883 .10322 L
.17022 .10548 L
.17162 .10114 L
.17301 .07555 L
.17441 .05107 L
.1758 .08423 L
.17719 .07188 L
.17859 .09423 L
.17998 .08901 L
.18138 .08666 L
.18277 .07365 L
.18417 .05337 L
.18556 .09786 L
.18696 .09928 L
.18835 .11593 L
.18974 .10012 L
.19114 .09516 L
.19253 .05457 L
.19393 .03903 L
.19532 .07599 L
.19672 .09755 L
.19811 .09074 L
.1995 .09122 L
.2009 .08985 L
.20229 .0694 L
.20369 .0547 L
.20508 .10238 L
.20648 .1045 L
.20787 .09786 L
.20927 .10118 L
.21066 .10101 L
.21205 .08078 L
.21345 .06099 L
.21484 .11982 L
.21624 .10597 L
.21763 .09118 L
.21903 .13195 L
.22042 .09224 L
.22182 .08897 L
.22321 .06364 L
.2246 .09888 L
.226 .10716 L
.22739 .1034 L
.22879 .08657 L
.23018 .09742 L
.23158 .0748 L
.23297 .06231 L
Mistroke
.23437 .10813 L
.23576 .11022 L
.23715 .11982 L
.23855 .11349 L
.23994 .11588 L
.24134 .08786 L
.24273 .07967 L
.24413 .11619 L
.24552 .11168 L
.24691 .12367 L
.24831 .12071 L
.2497 .11371 L
.2511 .10322 L
.25249 .07157 L
.25389 .12788 L
.25528 .11739 L
.25668 .11987 L
.25807 .13456 L
.25946 .10725 L
.26086 .07856 L
.26225 .07927 L
.26365 .12257 L
.26504 .11451 L
.26644 .13607 L
.26783 .12053 L
.26923 .08777 L
.27062 .09189 L
.27201 .07909 L
.27341 .11624 L
.2748 .11632 L
.2762 .09875 L
.27759 .10849 L
.27899 .11659 L
.28038 .08759 L
.28178 .07675 L
.28317 .13842 L
.28456 .16325 L
.28596 .14997 L
.28735 .12018 L
.28875 .10561 L
.29014 .09167 L
.29154 .07843 L
.29293 .07143 L
.29432 .0717 L
.29572 .09326 L
.29711 .08941 L
.29851 .0841 L
.2999 .08551 L
.3013 .07763 L
.30269 .06072 L
Mistroke
.30409 .09428 L
.30548 .08981 L
.30687 .09817 L
.30827 .09835 L
.30966 .07821 L
.31106 .07263 L
.31245 .10929 L
.31385 .11323 L
.31524 .11641 L
.31664 .11588 L
.31803 .11088 L
.31942 .10225 L
.32082 .0972 L
.32221 .13381 L
.32361 .13589 L
.325 .13833 L
.3264 .12602 L
.32779 .13722 L
.32918 .10442 L
.33058 .08569 L
.33197 .13217 L
.33337 .11783 L
.33476 .09662 L
.33616 .11858 L
.33755 .11075 L
.33895 .08365 L
.34034 .07405 L
.34173 .11057 L
.34313 .12146 L
.34452 .11597 L
.34592 .11513 L
.34731 .13009 L
.34871 .10256 L
.3501 .08565 L
.3515 .12142 L
.35289 .098 L
.35428 .10796 L
.35568 .10384 L
.35707 .10309 L
.35847 .09105 L
.35986 .07586 L
.36126 .10247 L
.36265 .09986 L
.36405 .10189 L
.36544 .1215 L
.36683 .10619 L
.36823 .09388 L
.36962 .07489 L
.37102 .09866 L
.37241 .1003 L
Mistroke
.37381 .10096 L
.3752 .10194 L
.37659 .11553 L
.37799 .10676 L
.37938 .08361 L
.38078 .12372 L
.38217 .14342 L
.38357 .1343 L
.38496 .18105 L
.38636 .12713 L
.38775 .11602 L
.38914 .08569 L
.39054 .12124 L
.39193 .14368 L
.39333 .12146 L
.39472 .11739 L
.39612 .09986 L
.39751 .0926 L
.39891 .07418 L
.4003 .10636 L
.40169 .08445 L
.40309 .10229 L
.40448 .10331 L
.40588 .10017 L
.40727 .08781 L
.40867 .06692 L
.41006 .08339 L
.41146 .10238 L
.41285 .0945 L
.41424 .09662 L
.41564 .09273 L
.41703 .08029 L
.41843 .04434 L
.41982 .08511 L
.42122 .10309 L
.42261 .08565 L
.424 .09786 L
.4254 .10353 L
.42679 .08609 L
.42819 .07577 L
.42958 .11663 L
.43098 .11787 L
.43237 .09552 L
.43377 .1045 L
.43516 .10999 L
.43655 .09857 L
.43795 .0829 L
.43934 .1045 L
.44074 .12452 L
.44213 .11553 L
Mistroke
.44353 .09751 L
.44492 .07878 L
.44632 .09295 L
.44771 .07019 L
.4491 .05824 L
.4505 .12482 L
.45189 .11827 L
.45329 .18915 L
.45468 .12097 L
.45608 .10203 L
.45747 .09384 L
.45886 .15134 L
.46026 .13735 L
.46165 .11783 L
.46305 .11482 L
.46444 .14581 L
.46584 .10083 L
.46723 .08405 L
.46863 .10667 L
.47002 .07369 L
.47141 .13802 L
.47281 .10061 L
.4742 .09875 L
.4756 .09211 L
.47699 .08024 L
.47839 .11478 L
.47978 .11039 L
.48118 .09941 L
.48257 .10955 L
.48396 .08454 L
.48536 .08582 L
.48675 .06546 L
.48815 .11035 L
.48954 .11641 L
.49094 .11681 L
.49233 .10269 L
.49373 .10698 L
.49512 .0825 L
.49651 .07626 L
.49791 .12429 L
.4993 .12863 L
.5007 .11057 L
.50209 .06705 L
.50349 .07524 L
.50488 .06931 L
.50627 .05111 L
.50767 .10636 L
.50906 .10167 L
.51046 .10884 L
.51185 .11438 L
Mistroke
.51325 .08777 L
.51464 .06404 L
.51604 .04155 L
.51743 .04828 L
.51882 .09994 L
.52022 .12992 L
.52161 .09237 L
.52301 .09556 L
.5244 .09423 L
.5258 .06479 L
.52719 .09729 L
.52859 .11026 L
.52998 .13837 L
.53137 .08582 L
.53277 .08812 L
.53416 .08706 L
.53556 .06161 L
.53695 .1235 L
.53835 .11123 L
.53974 .12261 L
.54114 .1026 L
.54253 .08905 L
.54392 .07396 L
.54532 .05249 L
.54671 .11323 L
.54811 .1405 L
.5495 .11314 L
.5509 .13992 L
.55229 .11801 L
.55368 .07382 L
.55508 .04797 L
.55647 .137 L
.55787 .12199 L
.55926 .12239 L
.56066 .1374 L
.56205 .1165 L
.56345 .09494 L
.56484 .05058 L
.56623 .12341 L
.56763 .11252 L
.56902 .11128 L
.57042 .10008 L
.57181 .09915 L
.57321 .07126 L
.5746 .04744 L
.576 .11097 L
.57739 .10411 L
.57878 .08392 L
.58018 .09468 L
.58157 .0933 L
Mistroke
.58297 .05891 L
.58436 .04425 L
.58576 .07883 L
.58715 .0899 L
.58854 .07228 L
.58994 .08932 L
.59133 .07781 L
.59273 .06705 L
.59412 .04341 L
.59552 .08365 L
.59691 .10034 L
.59831 .08476 L
.5997 .09189 L
.60109 .08662 L
.60249 .06028 L
.60388 .04151 L
.60528 .09158 L
.60667 .08936 L
.60807 .09432 L
.60946 .08007 L
.61086 .0972 L
.61225 .04279 L
.61364 .02823 L
.61504 .06878 L
.61643 .09485 L
.61783 .08016 L
.61922 .11681 L
.62062 .11438 L
.62201 .07909 L
.62341 .05687 L
.6248 .09981 L
.62619 .12965 L
.62759 .10915 L
.62898 .13266 L
.63038 .11699 L
.63177 .10052 L
.63317 .07431 L
.63456 .11889 L
.63595 .11845 L
Mfstroke
.63595 .11845 m
.63732 .2 L
s
.63738 .2 m
.63874 .12243 L
.64014 .10393 L
.64153 .08945 L
.64293 .06718 L
.64432 .13505 L
.64572 .11314 L
.64711 .10831 L
.6485 .11849 L
.6499 .10349 L
.65129 .08193 L
.65269 .06586 L
.65408 .10858 L
.65548 .10721 L
.65687 .12863 L
.65827 .11522 L
.65966 .1347 L
.66105 .08485 L
.66245 .06687 L
.66384 .10911 L
.66524 .1188 L
.66663 .11734 L
.66803 .1188 L
.66942 .11491 L
.67082 .09667 L
.67221 .08162 L
.6736 .12049 L
.675 .11925 L
.67639 .12412 L
.67779 .11212 L
.67918 .11017 L
.68058 .09565 L
.68197 .07945 L
.68336 .14103 L
.68476 .11331 L
.68615 .08976 L
.68755 .09937 L
.68894 .10468 L
.69034 .08604 L
.69173 .06347 L
.69313 .09778 L
.69452 .09813 L
.69591 .10176 L
.69731 .11292 L
.6987 .09538 L
.7001 .081 L
.70149 .07524 L
.70289 .10929 L
.70428 .10955 L
.70568 .11681 L
Mistroke
.70707 .11119 L
.70846 .11234 L
.70986 .09547 L
.71125 .08596 L
.71265 .11061 L
.71404 .12739 L
.71544 .12815 L
.71683 .13213 L
.71822 .10721 L
.71962 .09348 L
.72101 .0721 L
.72241 .14705 L
.7238 .11748 L
.7252 .09769 L
.72659 .08237 L
.72799 .10597 L
.72938 .09932 L
.73077 .07971 L
.73217 .12629 L
.73356 .11743 L
.73496 .1293 L
.73635 .12283 L
.73775 .1389 L
.73914 .11048 L
.74054 .09012 L
.74193 .12699 L
Mfstroke
.74193 .12699 m
.74321 .2 L
s
.74385 .2 m
.74472 .18893 L
.74611 .16423 L
.74751 .18242 L
.7489 .15311 L
.7503 .11216 L
.75169 .16179 L
.75309 .17215 L
.75448 .16392 L
.75587 .14851 L
.75727 .16923 L
.75866 .11717 L
.76006 .08241 L
.76145 .15652 L
.76285 .15125 L
.76424 .14386 L
.76563 .14205 L
.76703 .12274 L
.76842 .07781 L
.76982 .07427 L
.77121 .16905 L
.77261 .14643 L
.774 .1277 L
.7754 .12111 L
.77679 .13412 L
.77818 .11982 L
.77958 .09654 L
s
.77958 .09654 m
.78034 .2 L
s
.78745 .2 m
.78795 .16631 L
.78934 .1177 L
s
.78934 .1177 m
.78946 .2 L
s
.7935 .2 m
.79352 .18897 L
s
.79352 .18897 m
.79381 .2 L
s
.79548 .2 m
.79631 .13673 L
.79771 .1378 L
.7991 .10862 L
.8005 .10207 L
.80189 .07334 L
.80328 .08334 L
.80468 .12784 L
.80607 .06962 L
.80747 .08817 L
.80886 .08219 L
.81026 .10247 L
.81165 .07086 L
.81304 .13204 L
.81444 .1432 L
.81583 .15621 L
.81723 .12664 L
.81862 .09614 L
s
.81862 .09614 m
.81984 .2 L
s
.82533 .2 m
.82559 .19376 L
.82699 .14997 L
.82838 .12173 L
.82978 .17255 L
.83117 .1555 L
.83257 .15493 L
.83396 .15719 L
.83536 .14497 L
.83675 .07794 L
.83814 .07608 L
.83954 .12708 L
.84093 .12983 L
.84233 .11137 L
.84372 .11725 L
.84512 .11416 L
.84651 .08551 L
.8479 .07475 L
.8493 .11331 L
.85069 .08401 L
.85209 .10831 L
.85348 .09769 L
.85488 .09742 L
.85627 .07214 L
.85767 .0555 L
.85906 .09831 L
.86045 .09835 L
.86185 .09751 L
.86324 .09583 L
.86464 .08852 L
.86603 .08091 L
.86743 .06568 L
.86882 .08826 L
.87022 .0779 L
.87161 .10304 L
.873 .11115 L
.8744 .08719 L
.87579 .10588 L
.87719 .08578 L
.87858 .1065 L
.87998 .10247 L
.88137 .10619 L
.88277 .11854 L
.88416 .1011 L
.88555 .08839 L
.88695 .08843 L
.88834 .11119 L
.88974 .10477 L
.89113 .09322 L
.89253 .10645 L
Mistroke
.89392 .12797 L
.89531 .08693 L
.89671 .07148 L
.8981 .10968 L
.8995 .11429 L
.90089 .10566 L
.90229 .09981 L
.90368 .0964 L
.90508 .09875 L
.90647 .08073 L
.90786 .10287 L
.90926 .10282 L
.91065 .09313 L
.91205 .10079 L
.91344 .08569 L
.91484 .08237 L
.91623 .06772 L
.91763 .09671 L
.91902 .08967 L
.92041 .09286 L
.92181 .08706 L
.9232 .08954 L
.9246 .07059 L
.92599 .05505 L
.92739 .0984 L
.92878 .11287 L
.93017 .11092 L
.93157 .1034 L
.93296 .07679 L
.93436 .07068 L
.93575 .04469 L
.93715 .03991 L
.93854 .09392 L
.93994 .08866 L
.94133 .09592 L
.94272 .08959 L
.94412 .09065 L
.94551 .07254 L
.94691 .12868 L
.9483 .11553 L
.9497 .11858 L
.95109 .13328 L
.95249 .1262 L
.95388 .0841 L
.95527 .07343 L
.95667 .12593 L
.95806 .13997 L
.95946 .13935 L
.96085 .12823 L
.96225 .11876 L
Mistroke
.96364 .10588 L
.96504 .07316 L
.96643 .11181 L
.96782 .12323 L
.96922 .12859 L
.97061 .11256 L
.97201 .09215 L
.9734 .06922 L
.9748 .05576 L
.97619 .09932 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{754, 150.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;b0000UR000`400?l00000o`00003oo`3ooooo
0?oooo@0oooo003o0?ooool0oooom03oool005T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`260?ooo`00F@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08H0oooo
001I0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0QP3oool004h0oooo00<00000
0?ooo`3oool00`3oool400000080oooo00<000000?ooo`3oool00`3oool4000000<0oooo00@00000
0?ooo`3oool0oooo1P0000030?ooo`@00000103oool4000000@0oooo1000000I0?ooo`H000001P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo0`0000030?ooo`030000003oool0oooo0080oooo
1P0000030?ooo`@00000103oool4000000@0oooo1000000M0?ooo`H000000P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo1P0000030?ooo`@0
0000103oool4000000H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`020?ooo`H0
000000<0oooo0000003oool01`3oool010000000oooo0?ooo`0000040?ooo`H000000`3oool40000
00@0oooo100000060?ooo`030000003oool0oooo01P0oooo1P0000050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
0?ooo`H000000`3oool4000000@0oooo100000060?ooo`030000003oool0oooo01D0oooo1P000003
0?ooo`<000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo10000003
0?ooo`040000003oool0oooo0?ooo`H000000`3oool4000000@0oooo100000060?ooo`030000003o
ool0oooo01T0oooo100000030?ooo`040000003oool0oooo0?ooo`H000000P3oool00`000000oooo
0?ooo`020?ooo`H000000`3oool4000000@0oooo100000030?ooo`H00000I@3oool004h0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`00
0000J@3oool004h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`02
0?ooo`L000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool7000000030?ooo`000000oooo
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0203oool00`000000oooo000000070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0IP3oool004h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`1U0?ooo`00CP3oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000oooo0?oo
o`0000030?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo0`0000001@3oool000000?ooo`3oool0000000L0
oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`05
0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0080oooo0`0000001@3oool000000?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01P0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1T0?ooo`00CP3oool00`000000oooo0?ooo`020?ooo`030000003oool00000008000000`3oool0
1P000000oooo0?ooo`3oool000000?ooo`<00000103oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`8000000P3oool00`000000oooo
0?ooo`060?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo01l0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool06P3oool010000000oooo0?ooo`0000030?ooo`8000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000L0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool00`000000oooo00000002000000@0
oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000P0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0H`3oool004h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000070?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000030?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0J0?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo06<0oooo001<0?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000090?ooo`030000003oool00000
00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000
003oool0oooo0000003oool000001P3oool00`000000oooo000000040?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool01`000000oooo0?ooo`3oool000000?ooo`00
0000803oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000001X0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0
oooo00L000000?ooo`3oool0oooo0000003oool0000001L0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool01`00
0000oooo0?ooo`3oool000000?ooo`0000006P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo06<0oooo001=0?ooo`8000001@3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00@000000?ooo`3oool00000103oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool200000240oooo
0P0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000050?ooo`80
0000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`8000006P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`8000005`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool2000001/0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo06<0oooo001>0?ooo`030000003oool0oooo00@0oooo0`00
00050?ooo`040000003oool0oooo0?ooo`<000001P3oool00`000000oooo00000003000000@0oooo
100000040?ooo`@00000103oool4000001X0oooo100000070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0100000050?ooo`030000003oool0oooo00@00000103oool4000000@0oooo
100000040?ooo`@000007P3oool4000000H0oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0000000<00000103oool4000000@0oooo100000060?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool00`3oool4000000D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@00000103oool4000000@0oooo100000060?ooo`03
0000003oool0oooo01T0oooo100000060?ooo`030000003oool0oooo00D0oooo1`0000050?ooo`03
0000003oool0000000<00000103oool4000000@0oooo100000060?ooo`030000003oool0oooo01H0
oooo100000040?ooo`@000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo100000060?ooo`030000003oool0000000<00000103oool4000000@0oooo100000060?ooo`03
0000003oool0oooo01X0oooo0`0000060?ooo`030000003oool0000000<000001P3oool00`000000
oooo0?ooo`04000000@0oooo100000040?ooo`@00000103oool4000006H0oooo003o0?ooool0oooo
m03oool00?l0ooooo`3ooood0?ooo`00o`3ooooo0?oooo@0oooo003o0?ooool0oooom03oool00?l0
ooooo`3ooood0?ooo`00o`3ooooo0?oooo@0oooo003o0?ooool0oooom03oool00?l0ooooo`3ooood
0?ooo`00o`3ooooo0?oooo@0oooo003o0?ooool0oooom03oool004X0oooo1000000<0?ooool00000
o`00001`000002X0oooo00190?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0:03o
ool004T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0X0?ooo`00B@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo1@00000;0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0:03oool004T0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0X0?ooo`00B@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0o`3ooooo0?ooof`0oooo00<000000?ooo`3oool0:03oool004T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooo`3o
oom/0?ooo`030000003oool0oooo02P0oooo00190?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooool0ooooK03oool00`000000oooo0?ooo`0X
0?ooo`00B@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0o`3ooooo0?ooof`0oooo00<000000?ooo`3oool0:03oool004X0oooo1000000<0?ooo`<0
0000o`3ooooo0?ooof`0oooo00<000000?ooo`3oool0:03oool005X0oooo00<000000?ooo`3oool0
o`3ooooo0?ooof`0oooo00<000000?ooo`3oool0:03oool005X0oooo00<000000?ooo`3oool0o`3o
oooo0?ooof`0oooo00<000000?ooo`3oool0:03oool005X0oooo00<000000?ooo`3oool0o`3ooooo
0?ooof`0oooo00<000000?ooo`3oool0:03oool005X0oooo00<000000?ooo`3oool0o`3ooooo0?oo
of`0oooo00<000000?ooo`3oool0:03oool005X0oooo0`00003o0?ooool0ooooK03oool00`000000
oooo0?ooo`0X0?ooo`00FP3oool00`000000oooo0?ooo`3o0?ooool0ooooK03oool00`000000oooo
0?ooo`0X0?ooo`00FP3oool00`000000oooo0?ooo`3o0?ooool0ooooK03oool00`000000oooo0?oo
o`0X0?ooo`00FP3oool00`000000oooo0?ooo`3o0?ooool0ooooK03oool00`000000oooo0?ooo`0X
0?ooo`00FP3oool00`000000oooo0?ooo`3o0?ooog/0oooo00<00?l00?ooo`3oool0k@3oool00`00
0000oooo0?ooo`0X0?ooo`00FP3oool00`000000oooo0?ooo`3o0?ooog/0oooo00<00?l00?ooo`3o
ool0k@3oool00`000000oooo0?ooo`0X0?ooo`00FP3oool300000?l0ooooN`3oool00`00o`00oooo
0?ooo`3]0?ooo`030000003oool0oooo02P0oooo001J0?ooo`030000003oool0oooo0?l0ooooN`3o
ool00`00o`00oooo0?ooo`3]0?ooo`030000003oool0oooo02P0oooo001J0?ooo`030000003oool0
oooo0?l0ooooN`3oool00`00o`00oooo0?ooo`3]0?ooo`030000003oool0oooo02P0oooo001J0?oo
o`030000003oool0oooo0?l0ooooNP3oool2003o0>l0oooo00<000000?ooo`3oool0:03oool005X0
oooo00<000000?ooo`3oool0o`3ooomj0?ooo`800?l0k`3oool00`000000oooo0?ooo`0X0?ooo`00
FP3oool3000007D0oooo00<00?l00?ooo`3oool0o`3oool20?ooo`800?l0b03oool00`00o`00oooo
0?ooo`0T0?ooo`030000003oool0oooo02P0oooo001J0?ooo`030000003oool0oooo07D0oooo00<0
0?l00?ooo`3oool0a@3oool00`00o`00oooo0?ooo`0d0?ooo`03003o003oool0oooo0080oooo0P00
o`380?ooo`03003o003oool0oooo02@0oooo00<000000?ooo`3oool0:03oool004D0oooo00<00000
0?ooo`3oool00`3oool4000000/0oooo00<000000?ooo`3oool0B`3oool00`00o`00oooo0?ooo`0W
0?ooo`03003o003oool0oooo0<D0oooo00<00?l00?ooo`3oool0;P3oool00`00o`00oooo0?ooo`03
0?ooo`03003o003oool0oooo0080oooo0P00o`370?ooo`800?l09P3oool00`000000oooo0?ooo`0X
0?ooo`00A@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1;0?ooo`03003o003oool0oooo02L0oooo00<00?l00?oo
o`3oool0R@3oool00`00o`00oooo0?ooo`0i0?ooo`03003o003oool0oooo02P0oooo00<00?l00?oo
o`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo0P00o`370?oo
o`800?l09P3oool00`000000oooo0?ooo`0X0?ooo`00A@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1;0?ooo`03
003o003oool0oooo02L0oooo00<00?l00?ooo`3oool0R@3oool00`00o`00oooo0?ooo`0i0?ooo`80
0?l0:@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3o
ool00P3oool2003o0<L0oooo0P00o`0V0?ooo`030000003oool0oooo02P0oooo00150?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0240oooo00<00?l00?ooo`3oool09`3oool00`00o`00oooo0?ooo`0W0?ooo`03003o
003oool0oooo08T0oooo00<00?l00?ooo`3oool0>@3oool2003o01L0oooo00<00?l00?ooo`3oool0
2@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`020?ooo`800?l0a`3oool2003o02H0oooo00<000000?ooo`3oool0
:03oool004D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo1@00000I0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool05@3o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool09`3o
ool00`00o`00oooo0?ooo`290?ooo`03003o003oool0oooo03T0oooo0P00o`0G0?ooo`03003o003o
ool0oooo00T0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003o
ool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo003o00360?ooo`800?l09P3o
ool00`000000oooo0?ooo`0X0?ooo`00A@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0
oooo00T0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`080?ooo`800?l07@3oool0
0`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo08T0oooo00<00?l00?ooo`3oool0<`3oool0
0`00o`00oooo0?ooo`030?ooo`800?l05`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0
oooo0080oooo0P00o`040?ooo`03003o003oool00?l00<H0oooo0P00o`0V0?ooo`030000003oool0
oooo02P0oooo00150?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo0P00o`050?ooo`03003o003oool0oooo
00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo
00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`800?l07@3oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0R@3oool00`00
o`00oooo0?ooo`0c0?ooo`03003o003oool0oooo00<0oooo0P00o`0A0?ooo`03003o003oool0oooo
00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo
0080oooo0P00o`050?ooo`03003o003oool0oooo0080oooo0P00o`040?ooo`03003o003oool00?l0
0<H0oooo0P00o`0V0?ooo`030000003oool0oooo02P0oooo00130?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0
oooo00<00?l00?ooo`3oool00`3oool2003o00@0oooo0P00o`040?ooo`800?l01@3oool00`00o`00
oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo0P00o`0M0?ooo`03003o003oool0oooo00<0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo08<0
oooo00<00?l00?ooo`3oool0<`3oool00`00o`00oooo0?ooo`030?ooo`800?l04@3oool00`00o`00
oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00
oooo0?ooo`020?ooo`800?l01@3oool00`00o`00oooo0?ooo`020?ooo`800?l0103oool00`00o`00
oooo003o00360?ooo`800?l09P3oool00`000000oooo0?ooo`0X0?ooo`00A03oool2000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo
00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`800?l0103oool2003o00@0oooo
0P00o`050?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool2003o00@0oooo
0P00o`050?ooo`03003o003oool0oooo0080oooo0P00o`0;0?ooo`03003o003oool0oooo00l0oooo
00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo
00<00?l00?ooo`3oool0P`3oool00`00o`00oooo0?ooo`0c0?ooo`03003o003oool0oooo00<0oooo
0P00o`0A0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo
0?ooo`030?ooo`03003o003oool0oooo0080oooo0P00o`040?ooo`800?l0103oool2003o00@0oooo
00<00?l00?ooo`00o`00UP3oool00`00o`00oooo0?ooo`0W0?ooo`03003o003oool0oooo00<0oooo
0P00o`0F0?ooo`03003o003oool0oooo00d0oooo00<000000?ooo`3oool0:03oool004D0oooo00<0
00000?ooo`3oool00`3oool4000000/0oooo0`00000>0?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool00`3oool2003o00@0oooo0P00o`040?ooo`800?l0103oool2003o00@0oooo0P00
o`040?ooo`800?l0103oool2003o00D0oooo00<00?l00?ooo`3oool00P3oool2003o00/0oooo00<0
0?l00?ooo`3oool03`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`230?ooo`03003o003oool0oooo0100oooo00<0
0?l00?ooo`3oool0803oool00`00o`00oooo0?ooo`030?ooo`800?l04@3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?oo
o`020?ooo`800?l0103oool2003o00@0oooo0P00o`040?ooo`03003o003oool00?l000@0oooo00<0
0?l00?ooo`3oool0S`3oool00`00o`00oooo0?ooo`0W0?ooo`03003o003oool0oooo0080oooo00<0
0?l00?ooo`00o`005P3oool00`00o`00oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo001J
0?ooo`030000003oool0oooo00h0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`03
0?ooo`800?l0103oool2003o00@0oooo0P00o`040?ooo`800?l0103oool2003o00@0oooo00<00?l0
0?ooo`00o`000`3oool2003o00D0oooo00<00?l00?ooo`3oool00P3oool2003o00/0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`800?l0103oool00`00o`00oooo0?ooo`23
0?ooo`03003o003oool0oooo0100oooo00<00?l00?ooo`3oool0803oool00`00o`00oooo0?ooo`03
0?ooo`800?l04@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`800?l0103oool2003o00@0oooo0P00o`04
0?ooo`03003o003oool00?l000@0oooo00<00?l00?ooo`3oool0S`3oool00`00o`00oooo0?ooo`0W
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`00o`005P3oool00`00o`00oooo0?ooo`0=
0?ooo`030000003oool0oooo02P0oooo001J0?ooo`030000003oool0oooo00h0oooo00<00?l00?oo
o`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`800?l0103oool2003o00@0oooo0P00o`040?oo
o`800?l0103oool2003o00@0oooo00<00?l00?ooo`00o`000`3oool2003o00@0oooo0P00o`040?oo
o`800?l02`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?oo
o`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo0P00o`040?oo
o`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0=03oool00`00o`00oooo0?ooo`150?oo
o`03003o003oool0oooo0100oooo00<00?l00?ooo`3oool07`3oool2003o00D0oooo0P00o`0A0?oo
o`03003o003oool0oooo0080oooo0P00o`050?ooo`03003o003oool0oooo0080oooo0P00o`040?oo
o`800?l0103oool2003o00@0oooo0P00o`040?ooo`03003o003oool00?l000@0oooo00<00?l00?oo
o`3oool0S`3oool00`00o`00oooo0?ooo`0W0?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`00o`005P3oool00`00o`00oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo001J0?ooo`03
0000003oool0oooo00h0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`80
0?l0103oool2003o00@0oooo0P00o`040?ooo`800?l0103oool2003o00@0oooo00<00?l00?ooo`00
o`000`3oool00`00o`00oooo003o00030?ooo`800?l0103oool2003o00D0oooo00<00?l00?ooo`3o
ool00P3oool2003o00D0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool2003o00@0oooo00<00?l00?ooo`3o
ool0103oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo02P0oooo00<00?l00?ooo`3o
ool0A03oool2003o0180oooo00<00?l00?ooo`3oool07`3oool2003o00D0oooo0P00o`0;0?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool2003o00D0oooo00<00?l00?ooo`3o
ool00P3oool2003o00@0oooo00<00?l00?ooo`00o`000`3oool2003o00@0oooo0P00o`040?ooo`03
003o003oool00?l000@0oooo00<00?l00?ooo`3oool0S`3oool00`00o`00oooo0?ooo`0W0?ooo`03
003o003oool0oooo0080oooo00<00?l00?ooo`00o`005@3oool2003o00l0oooo00<000000?ooo`3o
ool0:03oool005X0oooo00<000000?ooo`3oool03P3oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0oooo00<0oooo0P00o`040?ooo`800?l0103oool2003o00@0oooo00<00?l00?ooo`00o`00
0`3oool2003o00@0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00030?ooo`800?l0
103oool2003o00D0oooo00<00?l00?ooo`3oool00P3oool2003o00D0oooo00<00?l00?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`020?ooo`800?l0103oool2003o00D0oooo0P00o`040?ooo`03003o
003oool0oooo00@0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0oooo02P0oooo00<00?l00?ooo`3oool0A03oool2003o0140oooo0P00o`0Q0?ooo`800?l0
1@3oool2003o00/0oooo00<00?l00?ooo`3oool00P3oool2003o00@0oooo0P00o`050?ooo`03003o
003oool0oooo0080oooo0P00o`040?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`00
0`3oool2003o00@0oooo00<00?l00?ooo`00o`00103oool00`00o`00oooo0?ooo`0W0?ooo`03003o
003oool0oooo06@0oooo0P00o`0X0?ooo`800?l0103oool00`00o`00oooo003o000E0?ooo`800?l0
3`3oool00`000000oooo0?ooo`0X0?ooo`00;@3oool:000002<0oooo00<000000?ooo`3oool03P3o
ool01000o`00oooo0?ooo`3oool3003o00@0oooo00<00?l00?ooo`00o`00103oool2003o00<0oooo
00<00?l00?ooo`00o`00103oool00`00o`00oooo003o00020?ooo`04003o003oool0oooo003o00<0
oooo00<00?l00?ooo`00o`000P3oool01000o`00oooo0?ooo`00o`030?ooo`800?l0103oool2003o
00D0oooo00<00?l00?ooo`3oool00P3oool2003o00D0oooo00<00?l00?ooo`3oool00`3oool00`00
o`00oooo0?ooo`020?ooo`800?l0103oool2003o00D0oooo0P00o`040?ooo`03003o003oool0oooo
00@0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo
02P0oooo00<00?l00?ooo`3oool0A03oool00`00o`00oooo003o000@0?ooo`800?l05P3oool00`00
o`00oooo0?ooo`080?ooo`800?l01@3oool2003o00@0oooo00<00?l00?ooo`3oool0103oool00`00
o`00oooo0?ooo`020?ooo`800?l0103oool2003o00D0oooo00<00?l00?ooo`3oool00P3oool2003o
00@0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00030?ooo`800?l0103oool00`00
o`00oooo003o00040?ooo`03003o003oool0oooo00l0oooo00<00?l00?ooo`3oool05@3oool00`00
o`00oooo0?ooo`1T0?ooo`800?l01@3oool00`00o`00oooo0?ooo`0P0?ooo`800?l0103oool00`00
o`00oooo003o000E0?ooo`800?l03`3oool00`000000oooo0?ooo`0X0?ooo`00;@3oool:000002<0
oooo0`00000>0?ooo`04003o003oool0oooo0?ooo`<00?l0103oool00`00o`00oooo003o00040?oo
o`800?l00`3oool00`00o`00oooo003o00040?ooo`03003o003oool00?l00080oooo00@00?l00?oo
o`3oool00?l00`3oool00`00o`00oooo003o00020?ooo`04003o003oool0oooo003o00<0oooo0P00
o`040?ooo`03003o003oool00?l000@0oooo00<00?l00?ooo`3oool00P3oool2003o00@0oooo0P00
o`050?ooo`03003o003oool0oooo0080oooo0P00o`040?ooo`800?l01@3oool2003o00@0oooo00<0
0?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool0:03oool00`00o`00oooo0?ooo`0o0?ooo`03003o003oool0oooo0080oooo00<0
0?l00?ooo`00o`00403oool2003o01H0oooo00<00?l00?ooo`3oool01`3oool3003o00D0oooo0P00
o`040?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool2003o00@0oooo0P00
o`050?ooo`03003o003oool0oooo0080oooo0P00o`040?ooo`03003o003oool00?l000<0oooo00<0
0?l00?ooo`00o`000`3oool00`00o`00oooo003o00030?ooo`03003o003oool00?l000@0oooo00<0
0?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool03`3oool00`00o`00oooo0?ooo`1T0?ooo`800?l01@3oool00`00o`00oooo0?oo
o`0K0?ooo`03003o003oool0oooo0080oooo0P00o`040?ooo`03003o003oool00?l001D0oooo0P00
o`0?0?ooo`030000003oool0oooo02P0oooo000]0?ooo`X000008`3oool00`000000oooo0?ooo`0>
0?ooo`04003o003oool0oooo0?ooo`<00?l0103oool00`00o`00oooo003o00040?ooo`800?l00`3o
ool00`00o`00oooo003o00040?ooo`03003o003oool00?l00080oooo00<00?l00?ooo`3oool00P00
o`000`3oool00?l00?ooo`020?ooo`03003o003oool00?l00080oooo0P00o`020?ooo`800?l0103o
ool00`00o`00oooo003o00030?ooo`800?l0103oool2003o00@0oooo0P00o`040?ooo`800?l0103o
ool00`00o`00oooo003o00030?ooo`800?l01@3oool2003o00@0oooo00<00?l00?ooo`3oool0103o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo0P00o`0Z0?ooo`03003o003o
ool0oooo03l0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo003o000@0?ooo`800?l05P3o
ool00`00o`00oooo0?ooo`070?ooo`<00?l01@3oool2003o00@0oooo00<00?l00?ooo`3oool0103o
ool00`00o`00oooo0?ooo`020?ooo`800?l0103oool2003o00D0oooo00<00?l00?ooo`3oool00P3o
ool2003o00@0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00030?ooo`03003o003o
ool00?l000<0oooo00<00?l00?ooo`00o`000`3oool2003o00/0oooo00<00?l00?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00l0oooo00<00?l00?ooo`3oool0I03o
ool2003o00D0oooo00<00?l00?ooo`3oool06`3oool00`00o`00oooo0?ooo`020?ooo`800?l0103o
ool01000o`00oooo0?ooo`00o`0D0?ooo`800?l03`3oool00`000000oooo0?ooo`0X0?ooo`00;@3o
ool:000002<0oooo00<000000?ooo`3oool03P3oool2003o0080oooo00<00?l00?ooo`00o`00103o
ool00`00o`00oooo003o00030?ooo`03003o003oool00?l000<0oooo00@00?l00?ooo`00o`000?l0
0P3oool01@00o`00oooo0?ooo`00o`00oooo00800?l00P3oool2003o00030?ooo`00o`00oooo0080
oooo00<00?l00?ooo`00o`000P3oool2003o0080oooo00<00?l00?ooo`00o`000`3oool00`00o`00
oooo003o00030?ooo`800?l0103oool2003o00@0oooo0P00o`040?ooo`800?l0103oool00`00o`00
oooo003o00030?ooo`800?l01@3oool2003o00@0oooo00<00?l00?ooo`3oool00`3oool2003o00D0
oooo00<00?l00?ooo`3oool00P3oool2003o02T0oooo0P00o`110?ooo`03003o003oool0oooo0080
oooo00<00?l00?ooo`00o`00403oool2003o01H0oooo00<00?l00?ooo`3oool01`3oool3003o00D0
oooo0P00o`040?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00P3oool2003o00@0
oooo0P00o`050?ooo`03003o003oool0oooo0080oooo0P00o`040?ooo`03003o003oool00?l000<0
oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00020?ooo`04003o003oool0oooo003o
00<0oooo0P00o`0;0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00
o`00oooo0?ooo`0?0?ooo`03003o003oool0oooo04@0oooo00D00?l00?ooo`3oool0oooo003o000K
0?ooo`800?l01@3oool00`00o`00oooo0?ooo`0K0?ooo`03003o003oool0oooo0080oooo0P00o`04
0?ooo`04003o003oool0oooo003o01@0oooo0P00o`0?0?ooo`030000003oool0oooo02P0oooo000]
0?ooo`X000008`3oool00`000000oooo0?ooo`0=0?ooo`03003o003oool00?l00080oooo00@00?l0
0?ooo`3oool00?l00`3oool00`00o`00oooo003o00030?ooo`03003o003oool00?l000<0oooo00@0
0?l00?ooo`00o`00oooo0`00o`020?ooo`04003o003oool00?l0003o0080oooo00@00?l00?ooo`00
o`000?l0103oool01000o`00oooo0?ooo`3oool2003o0080oooo00<00?l00?ooo`00o`000`3oool0
0`00o`00oooo003o00030?ooo`800?l0103oool2003o00@0oooo0P00o`040?ooo`800?l0103oool0
1000o`00oooo003o0000o`020?ooo`800?l01@3oool2003o00@0oooo00<00?l00?ooo`3oool00`3o
ool2003o00D0oooo00<00?l00?ooo`3oool00P3oool2003o00/0oooo00<00?l00?ooo`3oool05P3o
ool2003o00<0oooo0P00o`040?ooo`03003o003oool0oooo03X0oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo003o000@0?ooo`800?l05P3oool00`00o`00oooo0?ooo`070?ooo`<00?l01@3o
ool2003o00@0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`800?l0103o
ool2003o00D0oooo00<00?l00?ooo`3oool00P3oool2003o00@0oooo00@00?l00?ooo`00o`000?l0
0P3oool00`00o`00oooo003o00030?ooo`03003o003oool00?l00080oooo00@00?l00?ooo`3oool0
0?l00`3oool2003o00/0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03
003o003oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`0a0?ooo`05
003o003oool0oooo0?ooo`00o`006`3oool2003o00D0oooo00<00?l00?ooo`3oool03`3oool00`00
o`00oooo0?ooo`090?ooo`03003o003oool0oooo0080oooo0P00o`040?ooo`04003o003oool0oooo
003o00<0oooo00<00?l00?ooo`3oool03P3oool2003o00l0oooo00<000000?ooo`3oool0:03oool0
02d0oooo2P00000S0?ooo`030000003oool0oooo00d0oooo00<00?l00?ooo`00o`000P3oool01000
o`00oooo0?ooo`00o`030?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`000`3oool0
0`00o`00oooo003o00020?ooo`800?l00P3oool2003o00@0oooo00@00?l00?ooo`00o`000?l0103o
ool01000o`00oooo0?ooo`3oool2003o0080oooo00<00?l00?ooo`00o`000P3oool01000o`00oooo
0?ooo`00o`030?ooo`800?l0103oool2003o00@0oooo0P00o`040?ooo`800?l0103oool01000o`00
oooo003o0000o`020?ooo`800?l01@3oool2003o00@0oooo00<00?l00?ooo`3oool00`3oool2003o
00D0oooo00<00?l00?ooo`3oool00P3oool2003o00/0oooo00<00?l00?ooo`3oool05P3oool2003o
00<0oooo0P00o`040?ooo`03003o003oool0oooo00l0oooo00<00?l00?ooo`3oool08P3oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`00o`00403oool2003o
00`0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`070?ooo`<00?l01@3oool2003o
00@0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`800?l0103oool2003o
00@0oooo0P00o`040?ooo`800?l0103oool01P00o`00oooo003o0000o`00oooo003o0080oooo00@0
0?l00?ooo`3oool00?l00P3oool01000o`00oooo0?ooo`00o`020?ooo`04003o003oool0oooo0?oo
o`800?l01@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo0P00o`050?oo
o`03003o003oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`0K0?oo
o`03003o003oool0oooo0140oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo0?ooo`0I0?oo
o`800?l0103oool2003o0140oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`020?oo
o`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo0P00o`0?0?ooo`030000003oool0
oooo02P0oooo000]0?ooo`X000008`3oool3000000d0oooo00D00?l00?ooo`00o`00oooo003o0003
0?ooo`07003o003oool0oooo0?ooo`00o`00oooo003o00030?ooo`03003o003oool00?l00080oooo
00<00?l00?ooo`3oool0103oool01@00o`00oooo0?ooo`3oool00?l000L0oooo00<00?l00?ooo`3o
ool01`3oool00`00o`00oooo003o00020?ooo`04003o003oool0oooo003o0080oooo00@00?l00?oo
o`3oool0oooo0P00o`040?ooo`800?l0103oool2003o00@0oooo0P00o`040?ooo`04003o003oool0
0?l0003o0080oooo0P00o`040?ooo`03003o003oool00?l000@0oooo00<00?l00?ooo`3oool00`3o
ool2003o00D0oooo00<00?l00?ooo`3oool00P3oool2003o00/0oooo00<00?l00?ooo`3oool05@3o
ool00`00o`00oooo003o00030?ooo`800?l00`3oool2003o0140oooo00<00?l00?ooo`3oool02@3o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0100oooo00<00?l00?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`020?ooo`03003o003oool00?l000@0oooo00<00?l00?ooo`3oool02@3o
ool2003o00`0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`070?ooo`<00?l01@3o
ool00`00o`00oooo003o00030?ooo`03003o003oool0oooo00<0oooo0P00o`040?ooo`800?l0103o
ool2003o00@0oooo0P00o`040?ooo`800?l0103oool01P00o`00oooo003o0000o`00oooo003o0080
oooo00@00?l00?ooo`3oool00?l00P3oool01000o`00oooo0?ooo`00o`020?ooo`04003o003oool0
oooo0?ooo`800?l01@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo0P00
o`050?ooo`03003o003oool0oooo00l0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?oo
o`090?ooo`03003o003oool0oooo01/0oooo00<00?l00?ooo`3oool04@3oool00`00o`00oooo003o
00030?ooo`03003o003oool0oooo01<0oooo00<00?l00?ooo`3oool00`3oool2003o00@0oooo0P00
o`0A0?ooo`03003o003oool0oooo00P0oooo0P00o`040?ooo`800?l00`3oool01@00o`00oooo0?oo
o`3oool00?l000<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0oooo0080oooo0P00o`0?0?ooo`030000003oool0oooo02P0oooo001J0?ooo`030000003o
ool0oooo00d0oooo00D00?l00?ooo`00o`00oooo003o00030?ooo`800?l00P3oool00`00o`00oooo
003o00030?ooo`03003o003oool00?l00080oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo
0?ooo`0C0?ooo`03003o003oool00?l00080oooo00@00?l00?ooo`3oool00?l00P3oool01000o`00
oooo0?ooo`3oool2003o00@0oooo0P00o`040?ooo`800?l0103oool2003o00@0oooo00@00?l00?oo
o`00o`000?l00P3oool00`00o`00oooo003o00030?ooo`03003o003oool00?l000@0oooo00<00?l0
0?ooo`3oool00`3oool2003o00@0oooo0P00o`040?ooo`800?l02`3oool00`00o`00oooo0?ooo`0?
0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`00o`000`3oool2003o00<0oooo0P00o`0A
0?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0@
0?ooo`03003o003oool0oooo00<0oooo0P00o`030?ooo`03003o003oool00?l000@0oooo00<00?l0
0?ooo`3oool02@3oool2003o00`0oooo00<00?l00?ooo`3oool01P3oool2003o00D0oooo00L00?l0
0?ooo`3oool0oooo003o003oool00?l000@0oooo00@00?l00?ooo`3oool00?l00`3oool00`00o`00
oooo0?ooo`030?ooo`800?l0103oool2003o00@0oooo0P00o`040?ooo`800?l0103oool2003o00<0
oooo00<00?l00?ooo`3oool00P00o`001@3oool00?l00?ooo`3oool00?l00080oooo00@00?l00?oo
o`3oool00?l00P3oool01000o`00oooo0?ooo`00o`030?ooo`800?l01@3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool0oooo0080oooo0P00o`040?ooo`800?l04@3oool00`00o`00oooo0?oo
o`040?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool06P3oool2003o01<0oooo00<0
0?l00?ooo`00o`000`3oool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool00`3oool2003o00@0oooo0P00o`0A0?ooo`03003o003oool0oooo00P0oooo0P00
o`040?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo0P00o`0?0?ooo`030000
003oool0oooo02P0oooo000g0?ooo`<00000803oool00`000000oooo0?ooo`0=0?ooo`05003o003o
ool00?l00?ooo`00o`000`3oool3003o00040?ooo`00o`00oooo003o00<0oooo00<00?l00?ooo`00
o`000P3oool00`00o`00oooo0?ooo`0J0?ooo`03003o003oool00?l00080oooo00@00?l00?ooo`00
o`000?l00P3oool01000o`00oooo0?ooo`3oool2003o00@0oooo0P00o`040?ooo`800?l0103oool2
003o00@0oooo00@00?l00?ooo`00o`000?l00P3oool00`00o`00oooo003o00030?ooo`03003o003o
ool00?l000@0oooo00<00?l00?ooo`3oool00`3oool2003o00@0oooo0P00o`040?ooo`800?l02`3o
ool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`000P3o
ool2003o0100oooo0P00o`0;0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0403o
ool00`00o`00oooo0?ooo`020?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`00103o
ool00`00o`00oooo0?ooo`070?ooo`04003o003oool00?l0003o00`0oooo00<00?l00?ooo`3oool0
1P3oool2003o00D0oooo00L00?l00?ooo`3oool0oooo003o003oool00?l000@0oooo00@00?l00?oo
o`3oool00?l00`3oool00`00o`00oooo0?ooo`030?ooo`800?l0103oool2003o00@0oooo0P00o`04
0?ooo`800?l0103oool2003o00<0oooo00<00?l00?ooo`3oool00P00o`001@3oool00?l00?ooo`3o
ool00?l00080oooo00@00?l00?ooo`3oool00?l00P3oool01000o`00oooo0?ooo`00o`030?ooo`80
0?l01@3oool00`00o`00oooo0?ooo`020?ooo`800?l0103oool2003o00@0oooo0P00o`0A0?ooo`03
003o003oool0oooo00<0oooo0P00o`0;0?ooo`03003o003oool0oooo01X0oooo0P00o`0C0?ooo`03
003o003oool00?l000<0oooo00<00?l00?ooo`3oool03@3oool00`00o`00oooo0?ooo`030?ooo`03
003o003oool0oooo00<0oooo0P00o`040?ooo`<00?l0403oool00`00o`00oooo0?ooo`080?ooo`80
0?l0103oool00`00o`00oooo003o00020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`00
o`00oooo003o000>0?ooo`030000003oool0oooo02P0oooo000d0?ooo`<000008`3oool00`000000
oooo0?ooo`0=0?ooo`05003o003oool00?l00?ooo`00o`000`3oool3003o00040?ooo`00o`00oooo
003o00<0oooo00<00?l00?ooo`00o`000P3oool00`00o`00oooo0?ooo`0J0?ooo`03003o003oool0
0?l00080oooo00@00?l00?ooo`00o`000?l00P3oool01`00o`00oooo0?ooo`3oool00?l00?ooo`00
o`000`3oool00`00o`00oooo003o00030?ooo`800?l0103oool2003o00@0oooo00@00?l00?ooo`00
o`000?l00P3oool00`00o`00oooo003o00030?ooo`03003o003oool00?l000<0oooo00<00?l00?oo
o`00o`00103oool2003o00@0oooo0P00o`040?ooo`800?l01@3oool00`00o`00oooo0?ooo`030?oo
o`03003o003oool0oooo0080oooo0P00o`050?ooo`03003o003oool0oooo00<0oooo00<00?l00?oo
o`3oool00`3oool00`00o`00oooo003o00030?ooo`03003o003oool00?l00080oooo0P00o`0@0?oo
o`800?l02`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0100oooo00<00?l00?oo
o`3oool00P3oool00`00o`00oooo003o00030?ooo`03003o003oool00?l000@0oooo00<00?l00?oo
o`3oool01`3oool01000o`00oooo003o0000o`0<0?ooo`05003o003oool0oooo0?ooo`00o`00103o
ool2003o00@0oooo0P00o`030?ooo`04003o003oool0oooo003o00<0oooo00@00?l00?ooo`3oool0
0?l00`3oool00`00o`00oooo0?ooo`030?ooo`800?l0103oool2003o00@0oooo0P00o`040?ooo`80
0?l0103oool00`00o`00oooo003o00020?ooo`03003o003oool0oooo00800?l000D0oooo003o003o
ool0oooo003o00020?ooo`05003o003oool0oooo003o003oool00P00o`020?ooo`07003o003oool0
0?l00?ooo`00o`00oooo003o00040?ooo`03003o003oool0oooo0080oooo0P00o`040?ooo`800?l0
103oool2003o00/0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`800?l0
2`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo01@0oooo0P00o`0C0?ooo`@00?l0
0P3oool00`00o`00oooo0?ooo`0=0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0
0`3oool2003o00@0oooo0`00o`0?0?ooo`800?l01@3oool00`00o`00oooo0?ooo`020?ooo`800?l0
0`3oool01000o`00oooo0?ooo`00o`020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`00
o`00oooo0?ooo`020?ooo`800?l01@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool00?l0
00h0oooo00<000000?ooo`3oool0:03oool00340oooo0`00000V0?ooo`030000003oool0oooo00l0
oooo00<00?l00?ooo`00o`000`3oool4003o00<0oooo0`00o`020?ooo`03003o003oool00?l001d0
oooo0P00o`030?ooo`04003o003oool00?l0003o0080oooo00L00?l00?ooo`3oool0oooo003o003o
ool00?l000<0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00030?ooo`03003o003o
ool00?l000<0oooo00@00?l00?ooo`00o`000?l00P3oool00`00o`00oooo003o00030?ooo`03003o
003oool00?l000<0oooo00<00?l00?ooo`00o`00103oool2003o00@0oooo0P00o`040?ooo`800?l0
1@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo0P00o`050?ooo`03003o
003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo003o00020?ooo`04003o
003oool0oooo003o0080oooo0P00o`0@0?ooo`800?l02`3oool00`00o`00oooo0?ooo`030?ooo`03
003o003oool0oooo0100oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo003o00030?ooo`03
003o003oool00?l000<0oooo0P00o`090?ooo`800?l000<0oooo003o003oool02`3oool01@00o`00
oooo0?ooo`3oool00?l000@0oooo0P00o`040?ooo`800?l00`3oool01000o`00oooo0?ooo`00o`03
0?ooo`04003o003oool0oooo003o00<0oooo00<00?l00?ooo`3oool00`3oool2003o00<0oooo00<0
0?l00?ooo`00o`00103oool2003o00@0oooo0P00o`040?ooo`03003o003oool00?l00080oooo00<0
0?l00?ooo`3oool01000o`020?ooo`04003o003oool0oooo003o0080oooo00@00?l00?ooo`00o`00
0?l00P3oool01`00o`00oooo003o003oool00?l00?ooo`00o`00103oool00`00o`00oooo0?ooo`02
0?ooo`800?l0103oool2003o00@0oooo0P00o`050?ooo`03003o003oool0oooo00<0oooo00<00?l0
0?ooo`3oool00`3oool2003o00@0oooo0P00o`0;0?ooo`04003o003oool0oooo003o0080oooo00<0
0?l00?ooo`3oool03`3oool00`00o`00oooo0?ooo`020?ooo`800?l04`3oool5003o00030?ooo`00
o`00oooo00h0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?ooo`800?l0103o
ool3003o00l0oooo0P00o`050?ooo`03003o003oool0oooo0080oooo0P00o`030?ooo`04003o003o
ool0oooo003o0080oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`800?l0103oool2003o00D0
oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo003o000>0?ooo`030000003oool0oooo02P0
oooo000^0?ooo`<00000:@3oool00`000000oooo0?ooo`0?0?ooo`03003o003oool00?l000<0oooo
00@00?l00?ooo`3oool00?l00`3oool3003o0080oooo00<00?l00?ooo`00o`007P3oool01P00o`00
oooo0?ooo`3oool00?l00?ooo`800?l00P3oool01`00o`00oooo0?ooo`3oool00?l00?ooo`00o`00
0`3oool00`00o`00oooo003o00030?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`00
0`3oool01000o`00oooo003o0000o`020?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00
o`000`3oool00`00o`00oooo003o00040?ooo`800?l0103oool2003o00@0oooo0P00o`050?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool2003o00D0oooo00<00?l00?ooo`3o
ool00P3oool2003o00D0oooo00H00?l00?ooo`3oool00?l00?ooo`00o`020?ooo`03003o003oool0
oooo00800?l0403oool2003o00/0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`04
0?ooo`03003o003oool0oooo00P0oooo0P00o`040?ooo`03003o003oool00?l000<0oooo00<00?l0
0?ooo`00o`000`3oool2003o00D0oooo00@00?l00?ooo`3oool0oooo0P00o`000`3oool00?l00?oo
o`0;0?ooo`05003o003oool0oooo0?ooo`00o`00103oool2003o00@0oooo0P00o`030?ooo`04003o
003oool0oooo003o00<0oooo00@00?l00?ooo`3oool00?l00`3oool2003o00@0oooo0P00o`030?oo
o`03003o003oool00?l000@0oooo0P00o`040?ooo`800?l0103oool01P00o`00oooo003o0000o`00
oooo003o0080oooo1000o`020?ooo`04003o003oool0oooo003o0080oooo00@00?l00?ooo`00o`00
0?l00`3oool2003o00040?ooo`00o`00oooo003o00@0oooo00<00?l00?ooo`3oool00P3oool2003o
00@0oooo0P00o`040?ooo`800?l01@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo
00<0oooo0P00o`040?ooo`800?l02P3oool2003o0080oooo00@00?l00?ooo`3oool00?l04@3oool0
0`00o`00oooo0?ooo`020?ooo`800?l04`3oool5003o00030?ooo`00o`00oooo00h0oooo00<00?l0
0?ooo`3oool00`3oool00`00o`00oooo003o00030?ooo`800?l0103oool3003o00l0oooo0P00o`05
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`00o`000P3oool01000o`00oooo0?ooo`00
o`020?ooo`05003o003oool0oooo0?ooo`00o`000P3oool2003o00@0oooo0P00o`050?ooo`03003o
003oool0oooo0080oooo00<00?l00?ooo`00o`003P3oool00`000000oooo0?ooo`0X0?ooo`00;@3o
ool00`000000oooo0?ooo`0Z0?ooo`<000003`3oool00`00o`00oooo003o00030?ooo`04003o003o
ool0oooo003o00D0oooo00@00?l00?ooo`3oool0oooo0P00o`0R0?ooo`04003o003oool00?l0003o
0080oooo00L00?l00?ooo`3oool0oooo003o003oool00?l000<0oooo00<00?l00?ooo`00o`000`3o
ool00`00o`00oooo003o00030?ooo`03003o003oool00?l000<0oooo00T00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`000`3oool00`00o`00oooo003o00030?ooo`03003o003oool00?l0
00@0oooo0P00o`040?ooo`800?l0103oool2003o00@0oooo0P00o`050?ooo`03003o003oool0oooo
0080oooo0P00o`040?ooo`800?l0103oool2003o00@0oooo00@00?l00?ooo`3oool0oooo0`00o`02
0?ooo`03003o003oool0oooo00800?l0403oool2003o00/0oooo00<00?l00?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo00P0oooo0`00o`030?ooo`03003o003oool0
0?l000<0oooo00<00?l00?ooo`00o`000`3oool2003o00D0oooo00@00?l00?ooo`3oool0oooo0P00
o`000`3oool00?l00?ooo`090?ooo`03003o003oool00?l000<0oooo00@00?l00?ooo`3oool0oooo
0`00o`040?ooo`800?l00`3oool01000o`00oooo0?ooo`00o`030?ooo`04003o003oool0oooo003o
00<0oooo0P00o`040?ooo`800?l00`3oool00`00o`00oooo003o00040?ooo`800?l0103oool2003o
00@0oooo00H00?l00?ooo`00o`000?l00?ooo`00o`030?ooo`800?l00`3oool2003o00060?ooo`00
o`00oooo0?ooo`00o`00oooo0P00o`030?ooo`800?l000@0oooo003o003oool00?l0103oool00`00
o`00oooo0?ooo`020?ooo`800?l0103oool2003o00@0oooo0P00o`050?ooo`03003o003oool0oooo
00<0oooo00<00?l00?ooo`3oool00`3oool2003o00@0oooo0P00o`0:0?ooo`800?l00P3oool01000
o`00oooo0?ooo`00o`0A0?ooo`03003o003oool0oooo0080oooo0P00o`0C0?ooo`D00?l000<0oooo
003o003oool03P3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool00?l00080oooo00<00?l0
0?ooo`00o`000`3oool01000o`00oooo003o0000o`0?0?ooo`800?l01@3oool01@00o`00oooo0?oo
o`3oool00?l00080oooo00@00?l00?ooo`3oool00?l00P3oool01000o`00oooo0?ooo`00o`030?oo
o`03003o003oool0oooo00800?l0103oool2003o00D0oooo00<00?l00?ooo`3oool00P3oool00`00
o`00oooo003o000>0?ooo`030000003oool0oooo02P0oooo000]0?ooo`X000002`3oool6000000<0
oooo1000000;0?ooo`030000003oool0oooo0100oooo00<00?l00?ooo`3oool00P3oool01000o`00
oooo0?ooo`00o`090?ooo`03003o003oool0oooo0240oooo00@00?l00?ooo`00o`000?l00P3oool0
1`00o`00oooo0?ooo`3oool00?l00?ooo`00o`000`3oool00`00o`00oooo003o00030?ooo`03003o
003oool00?l000<0oooo00<00?l00?ooo`00o`000`3oool02@00o`00oooo0?ooo`3oool00?l00?oo
o`00o`00oooo003o00030?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`00103oool2
003o00@0oooo0P00o`020?ooo`800?l00P3oool01000o`00oooo0?ooo`3oool2003o00D0oooo00<0
0?l00?ooo`3oool00P3oool2003o00@0oooo0P00o`040?ooo`800?l0103oool01000o`00oooo0?oo
o`3oool2003o00<0oooo00<00?l00?ooo`3oool00P00o`0;0?ooo`03003o003oool0oooo0080oooo
0P00o`050?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo
0?ooo`040?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool3003o00<0oooo
00<00?l00?ooo`00o`000P3oool00`00o`00oooo0?ooo`02003o0080oooo0P00o`050?ooo`04003o
003oool0oooo0?ooo`800?l000<0oooo003o003oool02@3oool00`00o`00oooo003o00020?ooo`80
0?l00`3oool3003o00@0oooo0P00o`030?ooo`04003o003oool0oooo003o00<0oooo00@00?l00?oo
o`3oool00?l00`3oool2003o0080oooo00@00?l00?ooo`00o`000?l00`3oool00`00o`00oooo003o
00040?ooo`800?l0103oool2003o00<0oooo00<00?l00?ooo`3oool00P00o`000`3oool00?l00?oo
o`020?ooo`800?l00`3oool2003o00060?ooo`00o`00oooo0?ooo`00o`00oooo0P00o`030?ooo`80
0?l000@0oooo003o003oool00?l0103oool00`00o`00oooo0?ooo`020?ooo`800?l0103oool2003o
00@0oooo0P00o`050?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`3oool2003o
00@0oooo0P00o`050?ooo`03003o003oool0oooo0080oooo0P00o`020?ooo`04003o003oool0oooo
003o0140oooo00<00?l00?ooo`3oool00P3oool2003o01<0oooo1`00o`0?0?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`00o`000P3oool00`00o`00oooo003o00030?ooo`04003o003oool0
0?l0003o0080oooo00<00?l00?ooo`00o`002P3oool2003o00D0oooo00D00?l00?ooo`3oool0oooo
003o00020?ooo`04003o003oool00?l0003o0080oooo00@00?l00?ooo`3oool00?l00`3oool00`00
o`00oooo0?ooo`02003o00@0oooo0P00o`050?ooo`03003o003oool0oooo0080oooo00<00?l00?oo
o`00o`003P3oool00`000000oooo0?ooo`0X0?ooo`00;P3oool2000001<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool05@3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool0oooo0240oooo00@00?l00?ooo`00
o`000?l00P3oool01000o`00oooo0?ooo`00o`020?ooo`07003o003oool0oooo0?ooo`00o`00oooo
003o00030?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`000`3oool01000o`00oooo
0?ooo`3oool2003o0080oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`06003o003oool0oooo
003o003oool00?l0103oool2003o00@0oooo0P00o`020?ooo`800?l00P3oool01000o`00oooo0?oo
o`3oool2003o00@0oooo0P00o`040?ooo`800?l00`3oool3003o00@0oooo0P00o`040?ooo`05003o
003oool0oooo0?ooo`00o`00103oool01@00o`00oooo003o003oool00?l000/0oooo00<00?l00?oo
o`3oool00P3oool2003o00D0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`030?oo
o`800?l01@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo0`00o`030?oo
o`03003o003oool00?l00080oooo00<00?l00?ooo`3oool00P00o`020?ooo`800?l01@3oool02000
o`00oooo0?ooo`00o`00oooo003o003oool00?l02P3oool00`00o`00oooo003o00020?ooo`800?l0
0`3oool00`00o`00oooo003o00040?ooo`800?l00`3oool01000o`00oooo0?ooo`00o`030?ooo`04
003o003oool0oooo003o00<0oooo0P00o`020?ooo`800?l000<0oooo003o003oool00P3oool00`00
o`00oooo003o00040?ooo`800?l0103oool00`00o`00oooo003o00020?ooo`03003o003oool0oooo
00800?l000<0oooo003o003oool00P3oool2003o00<0oooo0P00o`001P3oool00?l00?ooo`3oool0
0?l00?ooo`800?l00`3oool2003o00040?ooo`00o`00oooo003o00<0oooo0P00o`040?ooo`800?l0
103oool00`00o`00oooo003o00030?ooo`800?l01@3oool00`00o`00oooo0?ooo`030?ooo`03003o
003oool0oooo00<0oooo0P00o`040?ooo`800?l01@3oool00`00o`00oooo0?ooo`020?ooo`800?l0
0P3oool01000o`00oooo0?ooo`00o`0A0?ooo`03003o003oool0oooo0080oooo0P00o`0B0?ooo`03
003o003oool00?l000D00?l03`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool00?l00080
oooo00<00?l00?ooo`00o`000`3oool01000o`00oooo003o0000o`020?ooo`03003o003oool00?l0
00@0oooo0P00o`040?ooo`800?l01@3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00@00?l0
0?ooo`00o`000?l00P3oool01000o`00oooo0?ooo`00o`030?ooo`800?l000<0oooo003o0000o`00
103oool2003o00D0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo003o000>0?ooo`030000
003oool0oooo02P0oooo000`0?ooo`8000004P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`160?ooo`@00?l00P3o
ool01000o`00oooo0?ooo`00o`020?ooo`07003o003oool0oooo0?ooo`00o`00oooo003o00030?oo
o`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`000`3oool01000o`00oooo0?ooo`3oool2
003o0080oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`06003o003oool0oooo003o003oool0
0?l0103oool2003o00@0oooo0P00o`020?ooo`800?l00P3oool01000o`00oooo0?ooo`3oool2003o
00@0oooo0P00o`040?ooo`800?l00`3oool3003o00@0oooo0P00o`040?ooo`05003o003oool0oooo
0?ooo`00o`00103oool3003o00030?ooo`00o`00oooo00X0oooo00<00?l00?ooo`3oool00P3oool2
003o00D0oooo00<00?l00?ooo`3oool00`3oool2003o00@0oooo0P00o`050?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool00P3oool3003o00<0oooo00<00?l00?ooo`00o`000P3oool0
0`00o`00oooo0?ooo`02003o0080oooo0P00o`050?ooo`08003o003oool0oooo003o003oool00?l0
0?ooo`00o`0:0?ooo`03003o003oool00?l00080oooo0P00o`030?ooo`04003o003oool0oooo003o
00<0oooo0P00o`020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`00
o`030?ooo`800?l00P3oool01000o`00oooo0?ooo`00o`030?ooo`03003o003oool00?l000@0oooo
0P00o`040?ooo`03003o003oool00?l00080oooo00<00?l00?ooo`3oool01000o`030?ooo`800?l0
0`3oool3003o00<0oooo1000o`030?ooo`800?l000@0oooo003o003oool00?l00`3oool2003o00@0
oooo0P00o`040?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`00103oool00`00o`00
oooo0?ooo`030?ooo`04003o003oool0oooo003o0080oooo0P00o`030?ooo`03003o003oool00?l0
00D0oooo00<00?l00?ooo`3oool00P3oool2003o00040?ooo`00o`000?l00?ooo`800?l01@3oool0
0`00o`00oooo0?ooo`090?ooo`03003o003oool0oooo0080oooo0P00o`0B0?ooo`05003o003oool0
0?l0003o003oool00`00o`0?0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`00o`000P3o
ool00`00o`00oooo003o00030?ooo`04003o003oool0oooo003o0080oooo00<00?l00?ooo`00o`00
103oool2003o00@0oooo0P00o`040?ooo`800?l00`3oool00`00o`00oooo0?ooo`02003o00050?oo
o`00o`00oooo0?ooo`00o`000P3oool01000o`00oooo0?ooo`3oool5003o00@0oooo0P00o`040?oo
o`800?l0103oool00`00o`00oooo003o000>0?ooo`030000003oool0oooo02P0oooo000b0?ooo`<0
0000403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`160?ooo`<00?l0103oool00`00o`00oooo003o00020?ooo`04
003o003oool0oooo003o0080oooo00@00?l00?ooo`3oool00?l00P3oool01`00o`00oooo0?ooo`3o
ool00?l00?ooo`00o`000`3oool01000o`00oooo0?ooo`3oool2003o0080oooo00D00?l00?ooo`3o
ool0oooo003o00020?ooo`<00?l00P3oool03@00o`00oooo0?ooo`3oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo00@00?l00?ooo`3oool0oooo0P00o`04
0?ooo`800?l0103oool2003o00<0oooo0`00o`040?ooo`800?l0103oool01@00o`00oooo0?ooo`3o
ool00?l000@0oooo0`00o`020?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool00P3o
ool2003o00D0oooo00<00?l00?ooo`3oool00`3oool2003o00@0oooo0P00o`050?ooo`03003o003o
ool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo003o00030?ooo`03003o003o
ool00?l00080oooo00<00?l00?ooo`3oool00P00o`020?ooo`800?l0103oool2003o0080oooo00D0
0?l00?ooo`00o`00oooo003o000:0?ooo`<00?l00P3oool2003o00<0oooo00@00?l00?ooo`3oool0
0?l00`3oool2003o0080oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`04003o003oool0oooo
003o00<0oooo0P00o`020?ooo`04003o003oool0oooo003o00<0oooo00<00?l00?ooo`00o`00103o
ool2003o00@0oooo00<00?l00?ooo`00o`000P3oool00`00o`00oooo0?ooo`04003o00P0oooo0`00
o`030?ooo`@00?l00`3oool2003o00040?ooo`00o`00oooo003o00<0oooo0P00o`040?ooo`800?l0
103oool00`00o`00oooo003o00030?ooo`03003o003oool00?l000@0oooo00<00?l00?ooo`3oool0
0`3oool01000o`00oooo0?ooo`00o`020?ooo`800?l00`3oool00`00o`00oooo003o00040?ooo`80
0?l0103oool2003o00040?ooo`00o`000?l00?ooo`800?l01@3oool00`00o`00oooo0?ooo`090?oo
o`03003o003oool0oooo0080oooo0P00o`0B0?ooo`05003o003oool00?l0003o003oool00`00o`0?
0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`00o`000P3oool00`00o`00oooo003o0003
0?ooo`09003o003oool0oooo0?ooo`00o`00oooo003o003oool00?l000@0oooo0P00o`040?ooo`03
003o003oool00?l000<0oooo0P00o`030?ooo`03003o003oool0oooo00800?l0103oool00`00o`00
oooo003o00040?ooo`D00?l0103oool2003o00@0oooo0P00o`040?ooo`03003o003oool00?l000h0
oooo00<000000?ooo`3oool0:03oool003D0oooo0P00000?0?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`080?ooo`D00000A03oool3003o00@0oooo00<00?l00?ooo`00
o`000P3oool01000o`00oooo0?ooo`00o`020?ooo`04003o003oool0oooo003o0080oooo00L00?l0
0?ooo`3oool0oooo003o003oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05
003o003oool0oooo0?ooo`00o`000P3oool2003o00<0oooo00d00?l00?ooo`3oool0oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`04003o003oool0oooo
0?ooo`800?l0103oool2003o00<0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o0004
0?ooo`800?l0103oool01@00o`00oooo0?ooo`3oool00?l000@0oooo0`00o`020?ooo`03003o003o
ool0oooo00P0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo003o00040?ooo`03003o003o
ool0oooo00<0oooo0P00o`040?ooo`800?l01@3oool00`00o`00oooo0?ooo`030?ooo`03003o003o
ool0oooo0080oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00020?ooo`03003o003o
ool0oooo00<00?l000<0oooo003o0000o`00103oool2003o0080oooo00<00?l00?ooo`00o`000P3o
ool00`00o`00oooo0?ooo`060?ooo`@00?l00P3oool2003o00<0oooo00@00?l00?ooo`3oool00?l0
0`3oool2003o0080oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`07003o003oool0oooo003o
003oool00?l00?ooo`02003o0080oooo00@00?l00?ooo`3oool00?l00`3oool00`00o`00oooo003o
00040?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`000P3oool00`00o`00oooo0?oo
o`04003o00T0oooo00<00?l00?ooo`3oool0103oool2003o00<0oooo0P00o`00103oool00?l00?oo
o`00o`030?ooo`800?l0103oool2003o00@0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo
003o00040?ooo`03003o003oool0oooo00<0oooo00@00?l00?ooo`3oool00?l00P3oool2003o00<0
oooo00<00?l00?ooo`00o`00103oool2003o00@0oooo0P00o`00103oool00?l0003o003oool2003o
00D0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`020?ooo`800?l04P3oool01000
o`00oooo003o0000o`020?ooo`800?l03`3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0
0?l00080oooo00<00?l00?ooo`00o`000P3oool00`00o`00oooo0?ooo`020?ooo`05003o003oool0
0?l00?ooo`00o`00103oool2003o00070?ooo`00o`00oooo0?ooo`00o`00oooo003o00030?ooo`06
003o003oool00?l0003o003oool00?l00P3oool2003o00@0oooo00<00?l00?ooo`00o`00103oool2
003o0080oooo00<00?l00?ooo`3oool00P3oool2003o00@0oooo0P00o`040?ooo`03003o003oool0
0?l000h0oooo00<000000?ooo`3oool0:03oool00380oooo0`00000B0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`170?ooo`800?l0103oool0
0`00o`00oooo003o00020?ooo`04003o003oool0oooo003o0080oooo00@00?l00?ooo`3oool00?l0
0P3oool01`00o`00oooo0?ooo`3oool00?l00?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool0
0?l000<0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`03003o003oool0oooo0080oooo00d0
0?l00?ooo`3oool0oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00
o`020?ooo`04003o003oool0oooo0?ooo`800?l0103oool2003o00<0oooo00<00?l00?ooo`00o`00
0`3oool00`00o`00oooo003o00040?ooo`800?l0103oool00`00o`00oooo0?ooo`060?ooo`03003o
003oool00?l00080oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool00?l000@0oooo00<00?l00?ooo`3oool00`3oool2003o00@0oooo0P00o`050?ooo`03003o
003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool01P00o`00oooo003o0000o`00oooo003o
0080oooo0`00o`040?ooo`800?l000<0oooo003o0000o`00103oool01@00o`00oooo003o003oool0
0?l000@0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`@00?l00P3oool2003o00<0oooo00@0
0?l00?ooo`3oool00?l00`3oool2003o0080oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`07
003o003oool0oooo003o003oool00?l00?ooo`02003o0080oooo00@00?l00?ooo`3oool00?l00`3o
ool00`00o`00oooo003o00040?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`000P3o
ool01P00o`00oooo0?ooo`00o`00oooo003o00X0oooo00<00?l00?ooo`3oool0103oool2003o00<0
oooo0P00o`00103oool00?l00?ooo`00o`030?ooo`800?l0103oool2003o00@0oooo00<00?l00?oo
o`00o`000`3oool00`00o`00oooo003o00040?ooo`03003o003oool0oooo00<0oooo00@00?l00?oo
o`3oool00?l00P3oool2003o00<0oooo00<00?l00?ooo`00o`00103oool2003o00@0oooo0P00o`00
0`3oool00?l00?ooo`03003o00D0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`02
0?ooo`800?l04P3oool01000o`00oooo003o0000o`020?ooo`800?l03`3oool00`00o`00oooo0?oo
o`030?ooo`03003o003oool00?l00080oooo00<00?l00?ooo`00o`000P3oool00`00o`00oooo0?oo
o`020?ooo`05003o003oool00?l00?ooo`00o`000`3oool01@00o`00oooo003o003oool00?l00080
oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o0002003o00<0oooo00<00?l00?ooo`3o
ool00`3oool00`00o`00oooo003o00040?ooo`800?l00P3oool00`00o`00oooo0?ooo`020?ooo`80
0?l0103oool00`00o`00oooo003o00030?ooo`03003o003oool00?l000h0oooo00<000000?ooo`3o
ool0:03oool00300oooo0P00000E0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`170?ooo`800?l0103oool3003o0080oooo00@00?l00?ooo`3o
ool00?l00P3oool01000o`00oooo0?ooo`00o`020?ooo`07003o003oool0oooo0?ooo`00o`00oooo
003o00030?ooo`03003o003oool0oooo00D0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`03
003o003oool0oooo0080oooo01400?l00?ooo`3oool0oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`04003o003oool0oooo0?ooo`800?l0103o
ool2003o00<0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00040?ooo`800?l0103o
ool00`00o`00oooo0?ooo`080?ooo`04003o003oool0oooo003o00T0oooo0P00o`020?ooo`05003o
003oool00?l00?ooo`00o`00103oool00`00o`00oooo0?ooo`030?ooo`800?l0103oool2003o00@0
oooo0P00o`050?ooo`05003o003oool0oooo0?ooo`00o`000P3oool2003o00040?ooo`00o`00oooo
0?ooo`<00?l0103oool3003o00040?ooo`00o`00oooo003o0080oooo00D00?l00?ooo`00o`00oooo
003o00040?ooo`05003o003oool0oooo0?ooo`00o`00103oool4003o00040?ooo`00o`00oooo003o
00<0oooo00@00?l00?ooo`3oool00?l00`3oool2003o0080oooo00D00?l00?ooo`3oool0oooo003o
00030?ooo`05003o003oool0oooo003o003oool00P00o`001@3oool00?l00?ooo`3oool00?l00080
oooo00@00?l00?ooo`3oool00?l00P3oool01@00o`00oooo0?ooo`3oool00?l00080oooo00L00?l0
0?ooo`3oool0oooo003o003oool00?l00080oooo00@00?l00?ooo`3oool00?l0303oool00`00o`00
oooo0?ooo`050?ooo`03003o003oool0oooo0080oooo0P00o`020?ooo`04003o003oool0oooo0?oo
o`800?l0103oool2003o00@0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00040?oo
o`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`00o`000`3oool00?l00?ooo`020?oo
o`03003o003oool00?l000@0oooo0P00o`040?ooo`800?l000<0oooo003o003oool00`00o`050?oo
o`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool00P3oool2003o00D0oooo00<00?l00?oo
o`3oool02P3oool01000o`00oooo003o0000o`020?ooo`800?l00`3oool00`00o`00oooo0?ooo`09
0?ooo`03003o003oool0oooo00<0oooo0`00o`020?ooo`03003o003oool00?l00080oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo003o0002003o00<0oooo00D00?l00?ooo`00o`00oooo003o
00020?ooo`03003o003oool00?l00080oooo0P00o`00103oool00?l0003o0000o`030?ooo`03003o
003oool0oooo00<0oooo00<00?l00?ooo`00o`001@3oool01000o`00oooo0?ooo`00o`040?ooo`80
0?l0103oool00`00o`00oooo003o00030?ooo`03003o003oool00?l000h0oooo00<000000?ooo`3o
ool0:03oool002h0oooo0P00000B0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04L0oooo00<00?l00?ooo`3o
ool00`3oool3003o0080oooo00@00?l00?ooo`3oool00?l00P3oool01000o`00oooo0?ooo`00o`02
0?ooo`07003o003oool0oooo0?ooo`00o`00oooo003o00030?ooo`03003o003oool0oooo00D0oooo
00@00?l00?ooo`3oool00?l00`3oool00`00o`00oooo0?ooo`020?ooo`0A003o003oool00?l00?oo
o`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool0
1000o`00oooo0?ooo`3oool2003o00@0oooo0P00o`030?ooo`03003o003oool00?l000<0oooo00@0
0?l00?ooo`3oool00?l00`3oool2003o00@0oooo00<00?l00?ooo`3oool0203oool01000o`00oooo
0?ooo`00o`040?ooo`03003o003oool0oooo0080oooo0P00o`020?ooo`05003o003oool00?l00?oo
o`00o`00103oool00`00o`00oooo003o00020?ooo`03003o003oool00?l000@0oooo0P00o`040?oo
o`800?l01@3oool01@00o`00oooo0?ooo`3oool00?l00080oooo0P00o`00103oool00?l00?ooo`3o
ool2003o00D0oooo0`00o`020?ooo`800?l00P3oool01@00o`00oooo003o003oool00?l000@0oooo
00D00?l00?ooo`3oool0oooo003o00040?ooo`08003o003oool00?l0003o003oool00?l00?ooo`00
o`030?ooo`04003o003oool0oooo003o00<0oooo0P00o`020?ooo`05003o003oool0oooo0?ooo`00
o`000`3oool01P00o`00oooo0?ooo`00o`00oooo003o0080oooo00@00?l00?ooo`3oool00?l00P3o
ool01000o`00oooo0?ooo`00o`020?ooo`05003o003oool0oooo0?ooo`00o`000P3oool01`00o`00
oooo0?ooo`3oool00?l00?ooo`00o`000P3oool01000o`00oooo0?ooo`00o`0<0?ooo`03003o003o
ool0oooo00D0oooo00<00?l00?ooo`3oool00P3oool2003o0080oooo00L00?l00?ooo`3oool0oooo
003o003oool00?l00080oooo00<00?l00?ooo`00o`00103oool00`00o`00oooo003o00030?ooo`03
003o003oool00?l000@0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`03003o0003
0?ooo`00o`000?l00080oooo00<00?l00?ooo`00o`00103oool2003o00@0oooo0P00o`000`3oool0
0?l00?ooo`03003o00D0oooo00<00?l00?ooo`3oool02@3oool00`00o`00oooo0?ooo`020?ooo`80
0?l01@3oool00`00o`00oooo0?ooo`0:0?ooo`04003o003oool00?l0003o0080oooo0P00o`030?oo
o`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool00`3oool6003o00040?ooo`00o`000?l0
003o00D0oooo00<00?l00?ooo`00o`000P00o`030?ooo`05003o003oool00?l00?ooo`00o`000P3o
ool01000o`00oooo003o003oool3003o00040?ooo`00o`000?l0003o00T0oooo00<00?l00?ooo`00
o`00203oool00`00o`00oooo0?ooo`020?ooo`800?l0103oool00`00o`00oooo003o00030?ooo`03
003o003oool00?l000h0oooo00<000000?ooo`3oool0:03oool002d0oooo2P00000;0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo04L0oooo00<00?l00?ooo`3oool0103oool2003o0080oooo00@00?l00?ooo`3o
ool00?l00P3oool01000o`00oooo0?ooo`00o`020?ooo`07003o003oool0oooo0?ooo`00o`00oooo
003o00030?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`00o`00203oool01P00o`00oooo
003o003oool00?l00?ooo`<00?l000H0oooo003o003oool00?l00?ooo`00o`040?ooo`07003o003o
ool0oooo0?ooo`00o`00oooo003o00030?ooo`800?l00`3oool00`00o`00oooo003o00030?ooo`03
003o003oool0oooo00800?l00P3oool2003o00<0oooo00<00?l00?ooo`3oool0303oool00`00o`00
oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo0P00o`020?ooo`05003o003oool00?l00?oo
o`00o`00103oool00`00o`00oooo003o00020?ooo`04003o003oool00?l0003o00<0oooo0P00o`04
0?ooo`800?l01@3oool01@00o`00oooo0?ooo`3oool00?l00080oooo0P00o`001@3oool00?l00?oo
o`3oool00?l000H0oooo0`00o`020?ooo`800?l00P3oool01@00o`00oooo003o003oool00?l000@0
oooo00<00?l00?ooo`3oool00P00o`040?ooo`06003o003oool00?l0003o003oool00?l00P3oool0
1000o`00oooo003o0000o`020?ooo`04003o003oool0oooo0?ooo`800?l00P3oool01@00o`00oooo
0?ooo`3oool00?l000<0oooo00H00?l00?ooo`3oool00?l00?ooo`00o`020?ooo`04003o003oool0
oooo003o0080oooo00@00?l00?ooo`3oool00?l00P3oool01@00o`00oooo0?ooo`3oool00?l00080
oooo00P00?l00?ooo`3oool0oooo003o003oool00?l00?ooo`800?l00P3oool00`00o`00oooo0?oo
o`0:0?ooo`03003o003oool0oooo00X0oooo0P00o`020?ooo`07003o003oool0oooo0?ooo`00o`00
oooo003o00020?ooo`03003o003oool00?l000@0oooo00<00?l00?ooo`00o`000`3oool00`00o`00
oooo003o00040?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00`00o`020?ooo`06
003o003oool0oooo003o003oool00?l0103oool2003o00@0oooo0P00o`000`3oool00?l00?ooo`03
003o00D0oooo00<00?l00?ooo`3oool0203oool2003o00@0oooo0P00o`050?ooo`03003o003oool0
oooo00X0oooo00@00?l00?ooo`00o`000?l00P3oool2003o00<0oooo00<00?l00?ooo`3oool02@3o
ool00`00o`00oooo0?ooo`020?ooo`04003o003oool00?l00?ooo`800?l02P3oool2003o00030?oo
o`00o`000?l000<0oooo00<00?l00?ooo`00o`000P00o`020?ooo`08003o003oool00?l00?ooo`00
o`00oooo003o003oool3003o00T0oooo00<00?l00?ooo`00o`00203oool00`00o`00oooo0?ooo`02
0?ooo`800?l0103oool00`00o`00oooo003o00030?ooo`03003o003oool00?l000h0oooo00<00000
0?ooo`3oool0:03oool004<0oooo100000040?ooo`@000002`3oool00`000000oooo0?ooo`170?oo
o`03003o003oool0oooo00@0oooo0P00o`020?ooo`04003o003oool0oooo003o0080oooo00@00?l0
0?ooo`3oool00?l00P3oool01`00o`00oooo0?ooo`3oool00?l00?ooo`00o`000`3oool00`00o`00
oooo0?ooo`060?ooo`03003o003oool00?l000P0oooo0P00o`00103oool00?l0003o003oool3003o
00060?ooo`00o`00oooo003o003oool00?l0103oool01`00o`00oooo0?ooo`3oool00?l00?ooo`00
o`000`3oool00`00o`00oooo003o00020?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`3o
ool00P00o`020?ooo`800?l00`3oool00`00o`00oooo0?ooo`0<0?ooo`04003o003oool0oooo0?oo
o`800?l0103oool2003o0080oooo00D00?l00?ooo`00o`00oooo003o00040?ooo`03003o003oool0
0?l00080oooo00@00?l00?ooo`00o`000?l00P3oool00`00o`00oooo0?ooo`02003o0080oooo0P00
o`040?ooo`800?l00`3oool00`00o`00oooo0?ooo`02003o00050?ooo`00o`00oooo0?ooo`00o`00
1P3oool3003o0080oooo0`00o`001P3oool00?l00?ooo`00o`00oooo003o00@0oooo00<00?l00?oo
o`3oool00P00o`040?ooo`06003o003oool00?l0003o003oool00?l00P3oool01000o`00oooo003o
0000o`020?ooo`09003o003oool0oooo0?ooo`00o`00oooo003o003oool00?l000<0oooo0P00o`00
0`3oool00?l00?ooo`020?ooo`03003o003oool00?l00080oooo00@00?l00?ooo`3oool00?l00P3o
ool01000o`00oooo0?ooo`00o`020?ooo`05003o003oool0oooo0?ooo`00o`000P3oool02@00o`00
oooo0?ooo`3oool00?l00?ooo`00o`00oooo003o00030?ooo`03003o003oool0oooo00X0oooo00<0
0?l00?ooo`3oool02P3oool2003o0080oooo00L00?l00?ooo`3oool0oooo003o003oool00?l00080
oooo00<00?l00?ooo`00o`00103oool00`00o`00oooo003o00030?ooo`03003o003oool00?l000@0
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`03003o00<0oooo00D00?l00?ooo`00
o`00oooo003o00040?ooo`800?l00`3oool01P00o`00oooo003o003oool00?l00?ooo`<00?l0103o
ool2003o00X0oooo0P00o`030?ooo`03003o003oool00?l000D0oooo00<00?l00?ooo`3oool02P3o
ool01000o`00oooo003o0000o`020?ooo`800?l00`3oool00`00o`00oooo0?ooo`090?ooo`03003o
003oool0oooo0080oooo00@00?l00?ooo`00o`00oooo0P00o`0:0?ooo`800?l000<0oooo003o0000
o`000`3oool03000o`00oooo0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o00<0
oooo0`00o`090?ooo`03003o003oool00?l000T0oooo00L00?l00?ooo`3oool0oooo003o003oool0
0?l000<0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo0?ooo`0>0?ooo`030000003oool0
oooo02P0oooo001J0?ooo`<00000CP3oool2003o0080oooo00@00?l00?ooo`3oool00?l00P3oool0
1000o`00oooo0?ooo`00o`020?ooo`0;003o003oool0oooo0?ooo`00o`00oooo003o003oool00?l0
0?ooo`00o`00203oool00`00o`00oooo003o00080?ooo`800?l0103oool3003o00060?ooo`00o`00
oooo003o003oool00?l0103oool01000o`00oooo0?ooo`00o`020?ooo`07003o003oool0oooo0?oo
o`00o`00oooo003o00020?ooo`04003o003oool0oooo003o0080oooo00<00?l00?ooo`3oool00P00
o`00103oool00?l00?ooo`00o`030?ooo`03003o003oool0oooo00`0oooo00@00?l00?ooo`3oool0
oooo0P00o`040?ooo`800?l00P3oool01@00o`00oooo003o003oool00?l000@0oooo00<00?l00?oo
o`00o`000P3oool01`00o`00oooo003o003oool00?l00?ooo`00o`00103oool01000o`00oooo003o
0000o`040?ooo`800?l00`3oool00`00o`00oooo0?ooo`03003o00<0oooo00<00?l00?ooo`3oool0
103oool00`00o`00oooo003o00020?ooo`<00?l000H0oooo003o003oool00?l00?ooo`00o`040?oo
o`03003o003oool0oooo00800?l0103oool01P00o`00oooo003o0000o`00oooo003o0080oooo00@0
0?l00?ooo`00o`000?l00P3oool00`00o`00oooo0?ooo`02003o00040?ooo`00o`00oooo003o00<0
oooo0P00o`000`3oool00?l00?ooo`020?ooo`03003o003oool00?l00080oooo00@00?l00?ooo`3o
ool00?l00P3oool01000o`00oooo0?ooo`00o`020?ooo`05003o003oool0oooo0?ooo`00o`000P3o
ool02@00o`00oooo0?ooo`3oool00?l00?ooo`00o`00oooo003o00030?ooo`03003o003oool0oooo
01L0oooo0P00o`020?ooo`07003o003oool0oooo0?ooo`00o`00oooo003o00020?ooo`04003o003o
ool0oooo003o00<0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00040?ooo`800?l0
103oool00`00o`00oooo003o00020?ooo`09003o003oool0oooo0?ooo`00o`00oooo003o003oool0
0?l000@0oooo0P00o`030?ooo`09003o003oool00?l00?ooo`00o`00oooo003o003oool00?l000@0
oooo0P00o`0:0?ooo`800?l00`3oool00`00o`00oooo003o00050?ooo`03003o003oool0oooo00X0
oooo00@00?l00?ooo`00o`000?l00P3oool00`00o`00oooo003o00020?ooo`03003o003oool0oooo
00T0oooo0P00o`030?ooo`04003o003oool00?l00?ooo`800?l02P3oool2003o00040?ooo`00o`00
0?l0003o0080oooo00T00?l00?ooo`3oool00?l00?ooo`00o`00oooo003o003oool00P00o`040?oo
o`800?l02P3oool00`00o`00oooo003o00090?ooo`07003o003oool0oooo0?ooo`00o`00oooo003o
00030?ooo`03003o003oool00?l00080oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?oo
o`0X0?ooo`00;@3oool2000002/0oooo00<000000?ooo`3oool0CP3oool01@00o`00oooo0?ooo`3o
ool00?l00080oooo00@00?l00?ooo`3oool00?l00P3oool01@00o`00oooo0?ooo`3oool00?l00080
oooo00<00?l00?ooo`3oool00`00o`090?ooo`03003o003oool00?l000T0oooo00<00?l00?ooo`3o
ool00P3oool3003o00040?ooo`00o`00oooo0?ooo`800?l0103oool01000o`00oooo0?ooo`00o`02
0?ooo`07003o003oool0oooo0?ooo`00o`00oooo003o00020?ooo`06003o003oool0oooo003o003o
ool00?l00`3oool2003o00040?ooo`00o`00oooo003o00<0oooo00<00?l00?ooo`3oool0303oool0
1000o`00oooo0?ooo`3oool2003o00@0oooo0P00o`020?ooo`05003o003oool00?l00?ooo`00o`00
103oool00`00o`00oooo003o0002003o00@0oooo00<00?l00?ooo`00o`00103oool01000o`00oooo
003o0000o`040?ooo`800?l00`3oool01000o`00oooo0?ooo`00o`0>0?ooo`03003o003oool0oooo
00<00?l000H0oooo003o003oool00?l00?ooo`00o`040?ooo`03003o003oool0oooo00800?l0103o
ool01P00o`00oooo003o0000o`00oooo003o0080oooo00@00?l00?ooo`00o`000?l00P3oool00`00
o`00oooo0?ooo`02003o00040?ooo`00o`00oooo003o00<0oooo0P00o`000`3oool00?l00?ooo`02
0?ooo`03003o003oool00?l00080oooo00@00?l00?ooo`3oool00?l00P3oool01000o`00oooo0?oo
o`00o`020?ooo`05003o003oool0oooo0?ooo`00o`000P3oool02@00o`00oooo0?ooo`3oool00?l0
0?ooo`00o`00oooo003o00030?ooo`03003o003oool0oooo01L0oooo0P00o`020?ooo`07003o003o
ool0oooo0?ooo`00o`00oooo003o00020?ooo`04003o003oool0oooo003o00<0oooo00<00?l00?oo
o`00o`000`3oool00`00o`00oooo003o00040?ooo`800?l00`3oool2003o00050?ooo`00o`00oooo
0?ooo`00o`000`3oool2003o0080oooo00L00?l00?ooo`3oool0oooo003o003oool00?l000<0oooo
00L00?l00?ooo`00o`00oooo003o003oool00?l00080oooo00@00?l00?ooo`3oool0oooo0P00o`0:
0?ooo`800?l00`3oool00`00o`00oooo003o00050?ooo`03003o003oool0oooo00X0oooo00@00?l0
0?ooo`00o`000?l0103oool01000o`00oooo0?ooo`00o`0;0?ooo`800?l00`3oool01@00o`00oooo
003o003oool00?l000/0oooo0P00o`00103oool00?l0003o0000o`020?ooo`09003o003oool0oooo
003o003oool00?l00?ooo`00o`00oooo00800?l0403oool00`00o`00oooo003o00090?ooo`07003o
003oool0oooo0?ooo`00o`00oooo003o00030?ooo`03003o003oool00?l00080oooo00<00?l00?oo
o`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`00;`3oool3000002P0oooo00<000000?ooo`3o
ool0DP3oool01000o`00oooo0?ooo`00o`020?ooo`04003o003oool0oooo003o00@0oooo00<00?l0
0?ooo`00o`000P3oool00`00o`00oooo003o00090?ooo`03003o003oool00?l000h0oooo0`00o`00
1@3oool00?l00?ooo`3oool00?l000D0oooo00@00?l00?ooo`3oool00?l00P3oool01`00o`00oooo
0?ooo`3oool00?l00?ooo`00o`000P3oool01P00o`00oooo0?ooo`00o`00oooo003o00<0oooo1000
o`000`3oool00?l00?ooo`020?ooo`03003o003oool0oooo00`0oooo00@00?l00?ooo`3oool0oooo
0P00o`040?ooo`800?l00P3oool01@00o`00oooo003o003oool00?l000@0oooo1000o`050?ooo`03
003o003oool00?l000@0oooo00@00?l00?ooo`00o`000?l0103oool2003o00<0oooo00@00?l00?oo
o`3oool00?l04@3oool4003o0080oooo00<00?l00?ooo`00o`00103oool00`00o`00oooo0?ooo`02
003o00@0oooo00H00?l00?ooo`00o`000?l00?ooo`00o`020?ooo`800?l000D0oooo003o003oool0
oooo003o00020?ooo`800?l000@0oooo003o003oool00?l00`3oool01000o`00oooo003o0000o`03
0?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`000P3oool01000o`00oooo0?ooo`00
o`020?ooo`05003o003oool0oooo0?ooo`00o`000P3oool01000o`00oooo0?ooo`00o`020?ooo`80
0?l0103oool00`00o`00oooo0?ooo`0G0?ooo`800?l00P3oool01`00o`00oooo0?ooo`3oool00?l0
0?ooo`00o`000P3oool01000o`00oooo0?ooo`00o`030?ooo`03003o003oool00?l000<0oooo00<0
0?l00?ooo`00o`000`3oool00`00o`00oooo003o00030?ooo`800?l000<0oooo003o003oool01@3o
ool2003o0080oooo00L00?l00?ooo`3oool0oooo003o003oool00?l000<0oooo00L00?l00?ooo`00
o`00oooo003o003oool00?l00080oooo00@00?l00?ooo`3oool0oooo0P00o`0:0?ooo`800?l00`3o
ool00`00o`00oooo003o00050?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool00P00
o`040?ooo`04003o003oool0oooo003o00/0oooo0P00o`030?ooo`05003o003oool00?l00?ooo`00
o`002`3oool2003o00070?ooo`00o`000?l00?ooo`00o`00oooo003o00020?ooo`06003o003oool0
0?l00?ooo`00o`00oooo0P00o`0A0?ooo`800?l02@3oool01000o`00oooo0?ooo`00o`020?ooo`07
003o003oool0oooo0?ooo`00o`00oooo003o00020?ooo`03003o003oool0oooo00l0oooo00<00000
0?ooo`3oool0:03oool00380oooo0`00000U0?ooo`030000003oool0oooo0580oooo00@00?l00?oo
o`00o`000?l00P3oool01000o`00oooo0?ooo`00o`040?ooo`03003o003oool00?l000h0oooo0P00
o`0?0?ooo`<00?l000D0oooo003o003oool0oooo003o00050?ooo`04003o003oool0oooo003o0080
oooo00L00?l00?ooo`3oool0oooo003o003oool00?l00080oooo00H00?l00?ooo`3oool00?l00?oo
o`00o`030?ooo`@00?l000<0oooo003o003oool00P3oool00`00o`00oooo0?ooo`0<0?ooo`06003o
003oool0oooo003o003oool00?l0103oool2003o00070?ooo`00o`000?l00?ooo`00o`00oooo003o
00040?ooo`@00?l01@3oool00`00o`00oooo003o00040?ooo`04003o003oool00?l0003o00@0oooo
0P00o`030?ooo`03003o003oool0oooo0180oooo1000o`020?ooo`03003o003oool00?l000@0oooo
00<00?l00?ooo`3oool00P00o`040?ooo`04003o003oool00?l00?ooo`800?l00P3oool2003o0005
0?ooo`00o`00oooo0?ooo`00o`000P3oool2003o00040?ooo`00o`00oooo003o00D0oooo0P00o`03
0?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`000P3oool01000o`00oooo0?ooo`00
o`020?ooo`05003o003oool0oooo0?ooo`00o`000P3oool01000o`00oooo0?ooo`00o`020?ooo`80
0?l0103oool00`00o`00oooo0?ooo`0G0?ooo`800?l00P3oool01`00o`00oooo0?ooo`3oool00?l0
0?ooo`00o`000P3oool01000o`00oooo0?ooo`00o`030?ooo`04003o003oool00?l0003o0080oooo
00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00030?ooo`800?l000<0oooo003o003oool0
1@3oool2003o0080oooo00L00?l00?ooo`3oool0oooo003o003oool00?l000<0oooo00@00?l00?oo
o`00o`000?l01@3oool01000o`00oooo0?ooo`3oool2003o00X0oooo0P00o`030?ooo`03003o003o
ool00?l000D0oooo00<00?l00?ooo`3oool02@3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo
00@00?l00?ooo`3oool00?l02`3oool2003o00<0oooo00D00?l00?ooo`00o`00oooo003o000<0?oo
o`03003o003oool0oooo0080oooo00<00?l00?ooo`00o`000P3oool01000o`00oooo003o0000o`02
0?ooo`800?l04@3oool2003o00T0oooo00@00?l00?ooo`3oool00?l00P3oool01`00o`00oooo0?oo
o`3oool00?l00?ooo`00o`000P3oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo02P0
oooo000e0?ooo`8000008`3oool00`000000oooo0?ooo`1C0?ooo`<00?l00P3oool01000o`00oooo
0?ooo`00o`040?ooo`03003o003oool00?l000l0oooo00<00?l00?ooo`3oool03@3oool3003o0003
0?ooo`00o`00oooo00L0oooo00@00?l00?ooo`3oool00?l00P3oool01000o`00oooo0?ooo`00o`02
0?ooo`04003o003oool0oooo003o0080oooo00<00?l00?ooo`00o`000`3oool4003o0080oooo00@0
0?l00?ooo`3oool00?l03P3oool01P00o`00oooo0?ooo`00o`00oooo003o00@0oooo0P00o`000`3o
ool00?l00?ooo`02003o00030?ooo`00o`00oooo00<0oooo0`00o`060?ooo`03003o003oool00?l0
00@0oooo00@00?l00?ooo`00o`000?l0103oool2003o0080oooo00<00?l00?ooo`3oool04`3oool2
003o00070?ooo`00o`00oooo0?ooo`00o`00oooo003o00040?ooo`03003o003oool0oooo00800?l0
103oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`001@3oool00?l00?ooo`3oool00?l0
0080oooo00H00?l00?ooo`3oool00?l00?ooo`00o`050?ooo`800?l00`3oool00`00o`00oooo003o
00030?ooo`03003o003oool00?l00080oooo00@00?l00?ooo`3oool00?l00P3oool01@00o`00oooo
0?ooo`3oool00?l00080oooo00@00?l00?ooo`3oool00?l00P3oool2003o00@0oooo00<00?l00?oo
o`3oool05`3oool2003o0080oooo00@00?l00?ooo`00o`000?l00P3oool01000o`00oooo0?ooo`00
o`020?ooo`06003o003oool00?l00?ooo`00o`00oooo0P00o`020?ooo`03003o003oool00?l000<0
oooo00<00?l00?ooo`00o`000`3oool2003o00030?ooo`00o`00oooo00H0oooo00<00?l00?ooo`3o
ool00P00o`020?ooo`03003o003oool00?l000<0oooo00@00?l00?ooo`00o`000?l01@3oool01`00
o`00oooo0?ooo`3oool00?l00?ooo`00o`002@3oool2003o00<0oooo00<00?l00?ooo`00o`00103o
ool2003o00/0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`04003o003oool0oooo003o00/0
oooo0P00o`030?ooo`05003o003oool00?l00?ooo`00o`00303oool00`00o`00oooo0?ooo`020?oo
o`03003o003oool00?l00080oooo00@00?l00?ooo`00o`000?l00P3oool2003o0140oooo0P00o`09
0?ooo`04003o003oool0oooo003o0080oooo00L00?l00?ooo`3oool0oooo003o003oool00?l00080
oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`00<P3oool3000002D0oooo
0`00001C0?ooo`<00?l00`3oool00`00o`00oooo003o00040?ooo`03003o003oool00?l000l0oooo
00<00?l00?ooo`3oool03@3oool3003o00030?ooo`00o`00oooo00L0oooo00@00?l00?ooo`3oool0
0?l00P3oool01000o`00oooo0?ooo`00o`020?ooo`04003o003oool0oooo003o0080oooo00<00?l0
0?ooo`00o`000`3oool4003o0080oooo00@00?l00?ooo`3oool00?l03P3oool01P00o`00oooo0?oo
o`00o`00oooo003o00@0oooo00D00?l00?ooo`00o`000?l00?ooo`02003o00030?ooo`00o`00oooo
00<0oooo0P00o`070?ooo`03003o003oool00?l000D0oooo0`00o`040?ooo`800?l00P3oool00`00
o`00oooo0?ooo`0C0?ooo`800?l000L0oooo003o003oool0oooo003o003oool00?l000@0oooo00<0
0?l00?ooo`3oool00P00o`040?ooo`04003o003oool0oooo0?ooo`800?l00P3oool2003o00@0oooo
00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00050?ooo`800?l00`3oool00`00o`00oooo
003o00030?ooo`03003o003oool00?l00080oooo0P00o`001@3oool00?l00?ooo`3oool00?l000<0
oooo00@00?l00?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`02003o00@0oooo00<00?l00?oo
o`3oool05`3oool2003o0080oooo00@00?l00?ooo`00o`000?l00P3oool01000o`00oooo0?ooo`00
o`020?ooo`05003o003oool00?l00?ooo`00o`000P3oool01P00o`00oooo0?ooo`00o`00oooo003o
00<0oooo00<00?l00?ooo`00o`000`3oool2003o00030?ooo`00o`00oooo00H0oooo00H00?l00?oo
o`3oool0oooo003o003oool2003o00030?ooo`00o`00oooo0080oooo00@00?l00?ooo`3oool00?l0
1@3oool01`00o`00oooo0?ooo`3oool00?l00?ooo`00o`002@3oool2003o00<0oooo00<00?l00?oo
o`00o`00103oool2003o00/0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`04003o003oool0
oooo003o00/0oooo0P00o`001P3oool00?l00?ooo`00o`00oooo003o00h0oooo00<00?l00?ooo`3o
ool00P3oool2003o00<0oooo00@00?l00?ooo`00o`000?l00P3oool00`00o`00oooo0?ooo`0@0?oo
o`800?l02@3oool01000o`00oooo0?ooo`00o`020?ooo`07003o003oool0oooo0?ooo`00o`00oooo
003o00020?ooo`03003o003oool0oooo00l0oooo00<000000?ooo`3oool0:03oool002h0oooo1000
000X0?ooo`030000003oool0oooo05<0oooo0`00o`030?ooo`03003o003oool00?l000@0oooo00<0
0?l00?ooo`00o`003`3oool00`00o`00oooo0?ooo`0=0?ooo`800?l000<0oooo003o003oool0203o
ool01000o`00oooo0?ooo`00o`020?ooo`04003o003oool0oooo003o0080oooo00@00?l00?ooo`3o
ool00?l00P3oool00`00o`00oooo003o00030?ooo`@00?l00P3oool01000o`00oooo0?ooo`00o`0?
0?ooo`05003o003oool00?l00?ooo`00o`00103oool01@00o`00oooo003o0000o`00oooo00800?l0
00<0oooo003o003oool00`3oool2003o00L0oooo00<00?l00?ooo`00o`001@3oool00`00o`00oooo
003o00040?ooo`800?l00P3oool00`00o`00oooo0?ooo`0C0?ooo`800?l0103oool00`00o`00oooo
003o00040?ooo`05003o003oool00?l00?ooo`00o`00103oool01000o`00oooo0?ooo`3oool2003o
0080oooo0P00o`040?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`001P3oool01000
o`00oooo0?ooo`3oool2003o00@0oooo0P00o`030?ooo`<00?l00`3oool01@00o`00oooo0?ooo`3o
ool00?l00080oooo00@00?l00?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`0M0?ooo`800?l0
0P3oool01000o`00oooo003o0000o`020?ooo`04003o003oool0oooo003o0080oooo1000o`030?oo
o`06003o003oool0oooo003o003oool00?l00`3oool00`00o`00oooo003o00020?ooo`03003o003o
ool0oooo00800?l01`3oool01P00o`00oooo0?ooo`3oool00?l00?ooo`800?l000<0oooo003o003o
ool00P3oool01000o`00oooo0?ooo`00o`050?ooo`07003o003oool0oooo0?ooo`00o`00oooo003o
00040?ooo`03003o003oool0oooo0080oooo0P00o`030?ooo`03003o003oool00?l000@0oooo0P00
o`0;0?ooo`05003o003oool0oooo0?ooo`00o`00103oool01000o`00oooo003o0000o`0:0?ooo`09
003o003oool00?l00?ooo`00o`00oooo003o003oool00?l001<0oooo0P00o`050?ooo`800?l00P3o
ool00`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo00P0oooo00@00?l00?ooo`3oool00?l0
0P3oool01000o`00oooo0?ooo`00o`020?ooo`04003o003oool0oooo003o0140oooo00<000000?oo
o`3oool0:03oool002d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1C0?ooo`03
003o003oool00?l000<0oooo00<00?l00?ooo`00o`00103oool00`00o`00oooo003o000?0?ooo`03
003o003oool0oooo00d0oooo00@00?l00?ooo`3oool00?l02@3oool01000o`00oooo003o0000o`02
0?ooo`04003o003oool0oooo003o0080oooo00@00?l00?ooo`3oool00?l00P3oool3003o00<0oooo
0P00o`001`3oool00?l00?ooo`3oool00?l00?ooo`00o`00403oool01@00o`00oooo003o003oool0
0?l000@0oooo00D00?l00?ooo`00o`000?l00?ooo`02003o00030?ooo`00o`00oooo00<0oooo0P00
o`080?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`00o`00103oool2003o0080oooo00<0
0?l00?ooo`3oool04`3oool2003o00@0oooo00<00?l00?ooo`00o`00103oool01@00o`00oooo003o
003oool00?l000@0oooo00@00?l00?ooo`3oool0oooo0P00o`020?ooo`03003o003oool0oooo00<0
oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00060?ooo`04003o003oool0oooo0?oo
o`800?l0103oool2003o00<0oooo0`00o`030?ooo`05003o003oool00?l00?ooo`00o`000P3oool0
1000o`00oooo0?ooo`00o`020?ooo`03003o003oool0oooo01d0oooo0P00o`020?ooo`04003o003o
ool00?l0003o0080oooo00@00?l00?ooo`3oool00?l00P3oool4003o00<0oooo00H00?l00?ooo`3o
ool00?l00?ooo`00o`030?ooo`03003o003oool00?l00080oooo00<00?l00?ooo`3oool00P00o`0<
0?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`00o`050?ooo`07003o
003oool0oooo0?ooo`00o`00oooo003o00040?ooo`03003o003oool0oooo0080oooo0P00o`030?oo
o`03003o003oool00?l000@0oooo0P00o`0;0?ooo`05003o003oool0oooo0?ooo`00o`00103oool0
1000o`00oooo003o0000o`0:0?ooo`09003o003oool00?l00?ooo`00o`00oooo003o003oool00?l0
01@0oooo00<00?l00?ooo`3oool00`3oool2003o0080oooo00<00?l00?ooo`3oool06`3oool01000
o`00oooo0?ooo`00o`020?ooo`04003o003oool0oooo003o0080oooo00@00?l00?ooo`3oool00?l0
4@3oool00`000000oooo0?ooo`0X0?ooo`00;P3oool4000002P0oooo00<000000?ooo`3oool0D`3o
ool00`00o`00oooo0?ooo`030?ooo`03003o003oool00?l000@0oooo00<00?l00?ooo`00o`003`3o
ool00`00o`00oooo0?ooo`0=0?ooo`04003o003oool0oooo003o00T0oooo00@00?l00?ooo`00o`00
0?l00P3oool01000o`00oooo0?ooo`00o`020?ooo`04003o003oool0oooo003o0080oooo0`00o`03
0?ooo`800?l000L0oooo003o003oool0oooo003o003oool00?l00100oooo00D00?l00?ooo`00o`00
oooo003o00040?ooo`06003o003oool00?l0003o003oool00?l00P3oool01@00o`00oooo003o0000
o`00oooo00800?l0203oool00`00o`00oooo0?ooo`040?ooo`03003o003oool00?l000@0oooo0P00
o`020?ooo`03003o003oool0oooo01<0oooo0P00o`050?ooo`800?l0103oool01@00o`00oooo003o
003oool00?l000<0oooo0P00o`030?ooo`800?l00P3oool00`00o`00oooo0?ooo`040?ooo`800?l0
0`3oool00`00o`00oooo003o000;0?ooo`03003o003oool0oooo0080oooo0P00o`030?ooo`<00?l0
0`3oool01@00o`00oooo003o003oool00?l00080oooo00@00?l00?ooo`3oool00?l00P3oool00`00
o`00oooo0?ooo`0M0?ooo`03003o003oool0oooo0080oooo0`00o`020?ooo`04003o003oool0oooo
003o0080oooo0P00o`000`3oool00?l00?ooo`020?ooo`04003o003oool00?l0003o0080oooo00H0
0?l00?ooo`3oool00?l00?ooo`00o`020?ooo`03003o003oool0oooo00800?l0303oool01@00o`00
oooo0?ooo`3oool00?l000<0oooo00@00?l00?ooo`3oool00?l01@3oool01`00o`00oooo0?ooo`3o
ool00?l00?ooo`00o`00103oool00`00o`00oooo0?ooo`020?ooo`800?l00`3oool00`00o`00oooo
003o00040?ooo`800?l02`3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00@00?l00?ooo`00
o`000?l02P3oool01000o`00oooo003o003oool2003o01L0oooo00<00?l00?ooo`3oool00`3oool2
003o0200oooo0P00o`001@3oool00?l00?ooo`3oool00?l00080oooo00@00?l00?ooo`3oool00?l0
0P3oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo02P0oooo000b0?ooo`<000009@3o
ool00`000000oooo0?ooo`1C0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`00o`00103o
ool2003o0200oooo00@00?l00?ooo`3oool00?l02P3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool00?l000<0oooo0P00o`00103oool00?l00?ooo`3oool3003o00@0oooo00<00?l00?ooo`00
o`000P3oool00`00o`00oooo003o000A0?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01P00
o`00oooo003o0000o`00oooo003o00<0oooo1000o`000`3oool00?l00?ooo`070?ooo`03003o003o
ool0oooo00H0oooo00<00?l00?ooo`3oool00P3oool2003o0080oooo00<00?l00?ooo`3oool04`3o
ool2003o00D0oooo0P00o`040?ooo`05003o003oool00?l00?ooo`00o`000P3oool3003o00<0oooo
0P00o`090?ooo`800?l00`3oool00`00o`00oooo003o000;0?ooo`03003o003oool0oooo0080oooo
0P00o`030?ooo`03003o003oool00?l000<0oooo00D00?l00?ooo`00o`00oooo003o00020?ooo`04
003o003oool0oooo003o0080oooo00<00?l00?ooo`3oool07@3oool00`00o`00oooo0?ooo`020?oo
o`<00?l00P3oool01000o`00oooo0?ooo`00o`020?ooo`800?l000<0oooo003o003oool00P3oool0
1000o`00oooo003o0000o`020?ooo`<00?l00P3oool01000o`00oooo0?ooo`00o`020?ooo`800?l0
303oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00@00?l00?ooo`3oool00?l01@3oool01`00
o`00oooo0?ooo`3oool00?l00?ooo`00o`00103oool00`00o`00oooo0?ooo`020?ooo`800?l00`3o
ool00`00o`00oooo003o00040?ooo`800?l01@3oool00`00o`00oooo0?ooo`030?ooo`05003o003o
ool0oooo0?ooo`00o`00103oool01000o`00oooo003o0000o`0:0?ooo`04003o003oool00?l00?oo
o`800?l05`3oool00`00o`00oooo0?ooo`030?ooo`800?l0803oool2003o00050?ooo`00o`00oooo
0?ooo`00o`000P3oool01000o`00oooo0?ooo`00o`020?ooo`03003o003oool0oooo00l0oooo00<0
00000?ooo`3oool0:03oool003D0oooo0P00000S0?ooo`030000003oool0oooo05<0oooo00<00?l0
0?ooo`3oool0103oool2003o00@0oooo0P00o`0P0?ooo`04003o003oool0oooo003o00X0oooo00<0
0?l00?ooo`3oool00`3oool2003o00<0oooo0P00o`00103oool00?l00?ooo`3oool3003o00T0oooo
00<00?l00?ooo`00o`005@3oool01P00o`00oooo0?ooo`3oool00?l00?ooo`800?l000<0oooo003o
003oool00P3oool01P00o`00oooo003o0000o`00oooo003o00P0oooo00<00?l00?ooo`3oool01P3o
ool00`00o`00oooo0?ooo`020?ooo`800?l00P3oool00`00o`00oooo0?ooo`0D0?ooo`03003o003o
ool0oooo00<0oooo0P00o`040?ooo`<00?l000@0oooo003o003oool0oooo0`00o`030?ooo`800?l0
3P3oool00`00o`00oooo003o000;0?ooo`03003o003oool0oooo0080oooo0P00o`030?ooo`03003o
003oool00?l000<0oooo00D00?l00?ooo`00o`00oooo003o00020?ooo`04003o003oool0oooo003o
0080oooo00<00?l00?ooo`3oool08P3oool3003o0080oooo0P00o`00103oool00?l00?ooo`3oool2
003o00030?ooo`00o`00oooo00<0oooo0`00o`020?ooo`03003o003oool00?l00080oooo0`00o`03
0?ooo`800?l0403oool01@00o`00oooo0?ooo`3oool00?l00080oooo00<00?l00?ooo`3oool00`3o
ool01`00o`00oooo0?ooo`3oool00?l00?ooo`00o`00103oool00`00o`00oooo0?ooo`020?ooo`80
0?l00`3oool00`00o`00oooo003o00040?ooo`800?l01@3oool00`00o`00oooo0?ooo`030?ooo`05
003o003oool0oooo0?ooo`00o`00103oool01000o`00oooo003o0000o`0:0?ooo`05003o003oool0
0?l00?ooo`00o`00603oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0oooo01h0oooo1000
o`020?ooo`04003o003oool0oooo003o00<0oooo00<00?l00?ooo`00o`004@3oool00`000000oooo
0?ooo`0X0?ooo`00<P3oool3000002D0oooo0`00001C0?ooo`03003o003oool0oooo00@0oooo0P00
o`050?ooo`03003o003oool0oooo01h0oooo00@00?l00?ooo`3oool00?l02P3oool00`00o`00oooo
0?ooo`030?ooo`800?l00`3oool2003o00040?ooo`00o`00oooo0?ooo`<00?l02@3oool00`00o`00
oooo003o000E0?ooo`06003o003oool0oooo0?ooo`00o`00oooo0P00o`050?ooo`06003o003oool0
0?l0003o003oool00?l0203oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo0080oooo
0P00o`000`3oool00?l00?ooo`0L0?ooo`03003o003oool0oooo00<0oooo0`00o`00103oool00?l0
0?ooo`3oool3003o00<0oooo00<00?l00?ooo`3oool03@3oool2003o00`0oooo00<00?l00?ooo`3o
ool00P3oool2003o00<0oooo00<00?l00?ooo`00o`000`3oool01@00o`00oooo003o003oool00?l0
0080oooo00@00?l00?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`0R0?ooo`<00?l00`3oool0
0`00o`00oooo003o00020?ooo`800?l01P3oool3003o00L0oooo0`00o`030?ooo`800?l04@3oool0
0`00o`00oooo003o00030?ooo`03003o003oool0oooo00<0oooo00L00?l00?ooo`3oool0oooo003o
003oool00?l000@0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo003o00020?ooo`03003o
003oool00?l000@0oooo0P00o`050?ooo`03003o003oool0oooo00<0oooo00D00?l00?ooo`3oool0
oooo003o00040?ooo`04003o003oool00?l0003o00X0oooo00@00?l00?ooo`00o`000?l0803oool0
0`00o`00oooo0?ooo`0N0?ooo`@00?l00P3oool01000o`00oooo0?ooo`00o`030?ooo`800?l04P3o
ool00`000000oooo0?ooo`0X0?ooo`00;`3oool3000002P0oooo00<000000?ooo`3oool0FP3oool2
003o00D0oooo00<00?l00?ooo`3oool08@3oool00`00o`00oooo0?ooo`0>0?ooo`03003o003oool0
oooo0080oooo0`00o`030?ooo`<00?l02@3oool00`00o`00oooo003o000E0?ooo`06003o003oool0
oooo0?ooo`00o`00oooo0P00o`050?ooo`06003o003oool00?l0003o003oool00?l0203oool00`00
o`00oooo0?ooo`060?ooo`09003o003oool0oooo0?ooo`00o`00oooo003o003oool00?l001d0oooo
00<00?l00?ooo`3oool00`3oool3003o00040?ooo`00o`00oooo0?ooo`<00?l00`3oool00`00o`00
oooo0?ooo`0=0?ooo`800?l0303oool00`00o`00oooo0?ooo`020?ooo`800?l00`3oool00`00o`00
oooo003o00030?ooo`05003o003oool00?l00?ooo`00o`000P3oool2003o00050?ooo`00o`00oooo
0?ooo`00o`00903oool00`00o`00oooo003o00030?ooo`03003o003oool00?l00080oooo0P00o`06
0?ooo`<00?l02@3oool01000o`00oooo0?ooo`3oool2003o0140oooo00<00?l00?ooo`00o`000`3o
ool00`00o`00oooo0?ooo`030?ooo`07003o003oool0oooo0?ooo`00o`00oooo003o00040?ooo`03
003o003oool0oooo0080oooo00<00?l00?ooo`00o`000P3oool01`00o`00oooo0?ooo`00o`00oooo
003o003oool00P00o`050?ooo`03003o003oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo003o
00040?ooo`04003o003oool00?l0003o00D0oooo00<00?l00?ooo`3oool00P3oool01000o`00oooo
003o0000o`0P0?ooo`03003o003oool0oooo01h0oooo00@00?l00?ooo`00o`000?l00P3oool01000
o`00oooo0?ooo`00o`030?ooo`800?l04P3oool00`000000oooo0?ooo`0X0?ooo`00;@3oool20000
02/0oooo00<000000?ooo`3oool0FP3oool2003o00D0oooo00<00?l00?ooo`3oool08@3oool00`00
o`00oooo0?ooo`0>0?ooo`03003o003oool0oooo0080oooo0`00o`040?ooo`800?l02@3oool00`00
o`00oooo003o000E0?ooo`06003o003oool0oooo0?ooo`00o`00oooo0P00o`080?ooo`03003o003o
ool0oooo0140oooo00T00?l00?ooo`3oool0oooo003o003oool00?l00?ooo`00o`007@3oool00`00
o`00oooo0?ooo`030?ooo`<00?l00P3oool01000o`00oooo003o0000o`040?ooo`03003o003oool0
oooo00d0oooo0P00o`0<0?ooo`03003o003oool0oooo0080oooo0P00o`030?ooo`03003o003oool0
oooo00<0oooo00D00?l00?ooo`00o`00oooo003o00020?ooo`800?l000D0oooo003o003oool0oooo
003o000T0?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`000P3oool2003o00H0oooo
0`00o`090?ooo`04003o003oool0oooo0?ooo`800?l04@3oool00`00o`00oooo003o00030?ooo`03
003o003oool0oooo00<0oooo00L00?l00?ooo`00o`00oooo003o003oool00?l000@0oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo003o00020?ooo`07003o003oool0oooo003o003oool00?l0
0?ooo`02003o00D0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool0oooo0080oooo00@00?l00?ooo`00o`000?l01@3oool00`00o`00oooo0?ooo`020?ooo`04
003o003oool00?l0003o0200oooo00<00?l00?ooo`3oool07P3oool01000o`00oooo003o0000o`02
0?ooo`04003o003oool0oooo003o00<0oooo0P00o`0B0?ooo`030000003oool0oooo02P0oooo001J
0?ooo`030000003oool0oooo05X0oooo0P00o`050?ooo`03003o003oool0oooo0240oooo00<00?l0
0?ooo`3oool04`3oool3003o00@0oooo0P00o`090?ooo`03003o003oool00?l001D0oooo00L00?l0
0?ooo`3oool0oooo003o003oool00?l000T0oooo00<00?l00?ooo`3oool04@3oool02@00o`00oooo
0?ooo`3oool00?l00?ooo`00o`00oooo003o000M0?ooo`03003o003oool0oooo00<0oooo0`00o`02
0?ooo`04003o003oool00?l0003o00@0oooo00<00?l00?ooo`3oool03@3oool2003o00`0oooo00<0
0?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`070?ooo`05003o003oool00?l00?ooo`00o`00
0P3oool2003o00030?ooo`00o`00oooo02H0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo
003o00020?ooo`03003o003oool0oooo00D0oooo0`00o`0=0?ooo`800?l04@3oool00`00o`00oooo
003o00030?ooo`03003o003oool0oooo00<0oooo1000o`020?ooo`03003o003oool0oooo0080oooo
00<00?l00?ooo`3oool00P3oool00`00o`00oooo003o00020?ooo`07003o003oool0oooo003o003o
ool00?l00?ooo`02003o00D0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?oo
o`03003o003oool0oooo0080oooo00@00?l00?ooo`00o`000?l01@3oool00`00o`00oooo0?ooo`02
0?ooo`04003o003oool00?l0003o0200oooo00<00?l00?ooo`3oool07P3oool01000o`00oooo003o
0000o`020?ooo`04003o003oool0oooo003o00<0oooo0P00o`0B0?ooo`030000003oool0oooo02P0
oooo000]0?ooo`X000008`3oool00`000000oooo0?ooo`1J0?ooo`800?l01@3oool00`00o`00oooo
0?ooo`0Q0?ooo`03003o003oool0oooo01<0oooo0`00o`040?ooo`800?l02@3oool00`00o`00oooo
003o000E0?ooo`03003o003oool0oooo00800?l000<0oooo003o003oool0203oool00`00o`00oooo
0?ooo`0A0?ooo`09003o003oool0oooo0?ooo`00o`00oooo003o003oool00?l002@0oooo0P00o`02
0?ooo`04003o003oool00?l0003o00@0oooo00<00?l00?ooo`3oool03P3oool00`00o`00oooo0?oo
o`0:0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool01`3oool01@00o`00oooo003o
003oool00?l00080oooo0P00o`000`3oool00?l00?ooo`0V0?ooo`03003o003oool00?l000<0oooo
00<00?l00?ooo`00o`000P3oool00`00o`00oooo0?ooo`050?ooo`03003o003oool00?l000d0oooo
0P00o`0A0?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`3oool00`3oool4003o0080oooo
00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool00?l00080oooo
00L00?l00?ooo`3oool00?l00?ooo`00o`00oooo00800?l01@3oool00`00o`00oooo0?ooo`020?oo
o`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool01000o`00oooo003o0000o`05
0?ooo`03003o003oool0oooo0080oooo00@00?l00?ooo`00o`000?l0803oool00`00o`00oooo0?oo
o`0N0?ooo`04003o003oool0oooo003o0080oooo00@00?l00?ooo`3oool00?l0103oool00`00o`00
oooo0?ooo`0@0?ooo`030000003oool0oooo02P0oooo000`0?ooo`030000003oool0oooo02L0oooo
0`00001J0?ooo`800?l01@3oool00`00o`00oooo0?ooo`0Q0?ooo`03003o003oool0oooo01<0oooo
00<00?l00?ooo`00o`00103oool00`00o`00oooo0?ooo`080?ooo`03003o003oool00?l001D0oooo
00<00?l00?ooo`3oool00P00o`000`3oool00?l00?ooo`080?ooo`03003o003oool0oooo0140oooo
00T00?l00?ooo`3oool0oooo003o003oool00?l00?ooo`00o`00903oool2003o0080oooo0P00o`00
0`3oool00?l00?ooo`030?ooo`03003o003oool0oooo00h0oooo00<00?l00?ooo`3oool02P3oool0
0`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00P0oooo00@00?l00?ooo`00o`000?l00P3o
ool3003o02P0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o00020?ooo`03003o003o
ool0oooo00D0oooo00<00?l00?ooo`00o`003@3oool00`00o`00oooo0?ooo`0A0?ooo`800?l00`3o
ool00`00o`00oooo0?ooo`040?ooo`<00?l00P3oool00`00o`00oooo0?ooo`020?ooo`03003o003o
ool0oooo0080oooo00<00?l00?ooo`00o`000P3oool01@00o`00oooo0?ooo`00o`00oooo00800?l0
00<0oooo003o003oool0103oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo
00<00?l00?ooo`3oool00P3oool01000o`00oooo003o0000o`050?ooo`03003o003oool0oooo0080
oooo00@00?l00?ooo`00o`000?l0803oool00`00o`00oooo0?ooo`0N0?ooo`04003o003oool0oooo
003o0080oooo00@00?l00?ooo`3oool00?l0103oool00`00o`00oooo0?ooo`0@0?ooo`030000003o
ool0oooo02P0oooo000_0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0FP3oool2
003o00D0oooo00<00?l00?ooo`3oool08@3oool00`00o`00oooo0?ooo`0E0?ooo`03003o003oool0
oooo0080oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo003o000E0?ooo`03003o003oool0
oooo00800?l000<0oooo003o003oool0203oool00`00o`00oooo0?ooo`0A0?ooo`09003o003oool0
oooo0?ooo`00o`00oooo003o003oool00?l002@0oooo0P00o`020?ooo`800?l000<0oooo003o003o
ool00`3oool00`00o`00oooo0?ooo`0K0?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3o
ool0203oool00`00o`00oooo003o00030?ooo`<00?l0:03oool00`00o`00oooo003o00030?ooo`03
003o003oool00?l00080oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0;0?ooo`03
003o003oool0oooo0140oooo0P00o`030?ooo`03003o003oool0oooo00@0oooo0`00o`020?ooo`03
003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo003o00020?ooo`05
003o003oool0oooo003o003oool00P00o`000`3oool00?l00?ooo`040?ooo`03003o003oool0oooo
0080oooo00<00?l00?ooo`3oool01`3oool01000o`00oooo003o0000o`050?ooo`03003o003oool0
oooo0080oooo00@00?l00?ooo`3oool00?l0A03oool01000o`00oooo0?ooo`00o`020?ooo`03003o
003oool0oooo01D0oooo00<000000?ooo`3oool0:03oool002l0oooo00<000000?ooo`3oool04@3o
ool4000000@0oooo1000000;0?ooo`030000003oool0oooo05/0oooo00<00?l00?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`0Q0?ooo`03003o003oool0oooo01D0oooo00<00?l00?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`080?ooo`03003o003oool00?l001D0oooo00<00?l00?ooo`3oool00P00
o`000`3oool00?l00?ooo`0L0?ooo`09003o003oool0oooo0?ooo`00o`00oooo003o003oool00?l0
02@0oooo0P00o`020?ooo`800?l000<0oooo003o003oool00`3oool00`00o`00oooo0?ooo`0Q0?oo
o`03003o003oool0oooo00P0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o000Z0?oo
o`07003o003oool0oooo0?ooo`00o`00oooo003o00020?ooo`03003o003oool0oooo00L0oooo00<0
0?l00?ooo`3oool02`3oool00`00o`00oooo0?ooo`0B0?ooo`05003o003oool0oooo0?ooo`00o`00
1`3oool2003o0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o
003oool00?l00080oooo00D00?l00?ooo`3oool00?l00?ooo`02003o00030?ooo`00o`00oooo00@0
oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`070?ooo`04003o003oool00?l0003o
00D0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`150?ooo`04003o003oool0oooo
003o0080oooo00<00?l00?ooo`3oool05@3oool00`000000oooo0?ooo`0X0?ooo`00;`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo05/0oooo00<00?l00?ooo`3oool0?`3oool0
0`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`00o`005@3oool0
1@00o`00oooo003o003oool00?l001l0oooo00H00?l00?ooo`3oool0oooo003o003oool2003o02D0
oooo0P00o`020?ooo`800?l000<0oooo003o003oool00`3oool00`00o`00oooo0?ooo`0Q0?ooo`03
003o003oool0oooo00P0oooo00<00?l00?ooo`00o`000`3oool00`00o`00oooo003o000Z0?ooo`07
003o003oool0oooo0?ooo`00o`00oooo003o00020?ooo`03003o003oool0oooo00L0oooo00<00?l0
0?ooo`3oool02`3oool00`00o`00oooo0?ooo`0F0?ooo`03003o003oool0oooo00H0oooo00@00?l0
0?ooo`3oool00?l00`3oool2003o00@0oooo00D00?l00?ooo`00o`00oooo003o00030?ooo`06003o
003oool00?l0003o003oool00?l01@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo
00L0oooo00@00?l00?ooo`00o`000?l01@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0
oooo04D0oooo00@00?l00?ooo`3oool00?l00P3oool00`00o`00oooo0?ooo`0E0?ooo`030000003o
ool0oooo02P0oooo000`0?ooo`L000002`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1K0?ooo`03003o003o
ool0oooo03l0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`080?ooo`03003o003o
ool00?l001D0oooo00D00?l00?ooo`00o`00oooo003o000P0?ooo`800?l000D0oooo003o003oool0
oooo003o000U0?ooo`800?l00P3oool2003o00030?ooo`00o`00oooo00<0oooo00<00?l00?ooo`3o
ool08@3oool00`00o`00oooo0?ooo`080?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00
o`00;P3oool00`00o`00oooo003o00020?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3o
ool02`3oool00`00o`00oooo0?ooo`0F0?ooo`03003o003oool0oooo00H0oooo00@00?l00?ooo`3o
ool00?l00`3oool2003o00@0oooo00D00?l00?ooo`00o`00oooo003o00030?ooo`06003o003oool0
0?l0003o003oool00?l01@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00L0oooo
00@00?l00?ooo`00o`000?l01@3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo04T0
oooo0P00o`0H0?ooo`030000003oool0oooo02P0oooo00170?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1K0?ooo`03003o003oool0oooo04@0
oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo003o000F0?ooo`800?l000<0oooo003o003o
ool07`3oool2003o00050?ooo`00o`00oooo0?ooo`00o`009@3oool2003o0080oooo0P00o`000`3o
ool00?l00?ooo`030?ooo`03003o003oool0oooo0240oooo00<00?l00?ooo`3oool0203oool00`00
o`00oooo003o00030?ooo`03003o003oool00?l002h0oooo00<00?l00?ooo`00o`006P3oool00`00
o`00oooo0?ooo`0F0?ooo`03003o003oool0oooo00H0oooo00@00?l00?ooo`3oool00?l00`3oool2
003o00@0oooo00D00?l00?ooo`00o`00oooo003o00030?ooo`03003o003oool00?l00080oooo00<0
0?l00?ooo`3oool00`3oool01000o`00oooo0?ooo`3oool2003o00T0oooo00@00?l00?ooo`00o`00
0?l0103oool2003o00@0oooo00<00?l00?ooo`3oool0B@3oool2003o01P0oooo00<000000?ooo`3o
ool0:03oool004L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`D0
0000F@3oool00`00o`00oooo0?ooo`1?0?ooo`03003o003oool00?l001L0oooo00<00?l00?ooo`00
o`00803oool2003o00050?ooo`00o`00oooo0?ooo`00o`009@3oool2003o0080oooo0P00o`000`3o
ool00?l00?ooo`030?ooo`03003o003oool0oooo0240oooo00<00?l00?ooo`3oool0203oool00`00
o`00oooo003o00050?ooo`03003o003oool0oooo02`0oooo00<00?l00?ooo`00o`006P3oool00`00
o`00oooo0?ooo`0F0?ooo`03003o003oool0oooo00H0oooo00@00?l00?ooo`3oool00?l00`3oool0
0`00o`00oooo003o00030?ooo`05003o003oool00?l00?ooo`00o`000`3oool2003o00<0oooo00<0
0?l00?ooo`3oool00`3oool01000o`00oooo0?ooo`3oool2003o00X0oooo0`00o`040?ooo`800?l0
103oool00`00o`00oooo0?ooo`190?ooo`800?l0603oool00`000000oooo0?ooo`0X0?ooo`00A03o
ool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo05/0oooo00<00?l00?ooo`3oool0C`3oool00`00o`00oooo003o000j0?ooo`800?l000D0
oooo003o003oool0oooo003o000U0?ooo`800?l00P3oool2003o00030?ooo`00o`00oooo0380oooo
00<00?l00?ooo`00o`00=03oool00`00o`00oooo003o000J0?ooo`03003o003oool0oooo01H0oooo
00<00?l00?ooo`3oool01P3oool01000o`00oooo0?ooo`00o`030?ooo`03003o003oool00?l000<0
oooo00D00?l00?ooo`00o`00oooo003o00030?ooo`800?l00`3oool00`00o`00oooo0?ooo`030?oo
o`05003o003oool0oooo0?ooo`00o`002`3oool3003o00@0oooo0P00o`040?ooo`03003o003oool0
oooo04T0oooo0P00o`0H0?ooo`030000003oool0oooo02P0oooo00170?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2]0?ooo`03003o003oool0
0?l003X0oooo0P00o`001@3oool00?l00?ooo`3oool00?l002D0oooo0P00o`020?ooo`800?l000<0
oooo003o003oool0<P3oool00`00o`00oooo0?ooo`0d0?ooo`03003o003oool00?l001X0oooo00<0
0?l00?ooo`3oool05P3oool00`00o`00oooo0?ooo`090?ooo`07003o003oool0oooo0?ooo`00o`00
oooo003o00030?ooo`05003o003oool00?l00?ooo`00o`000`3oool2003o00<0oooo00<00?l00?oo
o`3oool00`3oool01@00o`00oooo0?ooo`3oool00?l000/0oooo0`00o`040?ooo`800?l0103oool0
0`00o`00oooo0?ooo`1S0?ooo`030000003oool0oooo02P0oooo00120?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0:d0oooo00<00?l00?ooo`00o`00>P3oool2003o00050?ooo`00o`00oooo0?ooo`00o`009@3o
ool2003o0080oooo0P00o`000`3oool00?l00?ooo`1Y0?ooo`03003o003oool00?l003<0oooo00<0
0?l00?ooo`3oool02@3oool01`00o`00oooo0?ooo`3oool00?l00?ooo`00o`000P3oool01P00o`00
oooo0?ooo`00o`00oooo003o00<0oooo0P00o`030?ooo`03003o003oool0oooo0080oooo0P00o`03
0?ooo`03003o003oool0oooo00T0oooo0`00o`040?ooo`800?l0103oool00`00o`00oooo0?ooo`1S
0?ooo`030000003oool0oooo02P0oooo00120?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0:d0oooo00<00?l0
0?ooo`00o`00>`3oool00`00o`00oooo003o00020?ooo`03003o003oool0oooo02<0oooo0P00o`02
0?ooo`04003o003oool0oooo003o06X0oooo00<00?l00?ooo`00o`00<`3oool00`00o`00oooo0?oo
o`090?ooo`07003o003oool0oooo0?ooo`00o`00oooo003o00020?ooo`06003o003oool0oooo003o
003oool00?l00`3oool2003o00<0oooo00<00?l00?ooo`3oool00P3oool2003o00<0oooo00<00?l0
0?ooo`3oool02@3oool3003o00@0oooo0P00o`040?ooo`03003o003oool0oooo06<0oooo00<00000
0?ooo`3oool0:03oool004<0oooo100000040?ooo`@000002`3oool300000:d0oooo00<00?l00?oo
o`00o`00>`3oool00`00o`00oooo003o000X0?ooo`800?l00P3oool01000o`00oooo0?ooo`00o`1Z
0?ooo`03003o003oool00?l003<0oooo00<00?l00?ooo`3oool02@3oool01`00o`00oooo0?ooo`3o
ool00?l00?ooo`00o`000P3oool01P00o`00oooo0?ooo`00o`00oooo003o00<0oooo0P00o`030?oo
o`03003o003oool0oooo0080oooo0P00o`030?ooo`03003o003oool0oooo00T0oooo0`00o`040?oo
o`800?l0103oool00`00o`00oooo0?ooo`1S0?ooo`030000003oool0oooo02P0oooo001J0?ooo`03
0000003oool0oooo0:d0oooo00<00?l00?ooo`00o`00>`3oool00`00o`00oooo003o000X0?ooo`80
0?l00P3oool00`00o`00oooo0?ooo`1[0?ooo`03003o003oool00?l003<0oooo00<00?l00?ooo`3o
ool02@3oool01`00o`00oooo0?ooo`3oool00?l00?ooo`00o`000P3oool00`00o`00oooo0?ooo`02
003o00@0oooo0P00o`030?ooo`03003o003oool0oooo0080oooo0P00o`030?ooo`03003o003oool0
oooo00T0oooo0`00o`040?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`3oool0H`3oool0
0`000000oooo0?ooo`0X0?ooo`00FP3oool00`000000oooo0?ooo`2]0?ooo`03003o003oool00?l0
03/0oooo00<00?l00?ooo`00o`00:03oool2003o0080oooo00<00?l00?ooo`3oool0J`3oool00`00
o`00oooo003o000o0?ooo`08003o003oool0oooo0?ooo`00o`00oooo003o003oool2003o0080oooo
0P00o`040?ooo`800?l0103oool01000o`00oooo0?ooo`3oool2003o00<0oooo00<00?l00?ooo`3o
ool02@3oool2003o00030?ooo`00o`00oooo0080oooo00<00?l00?ooo`00o`000`3oool00`00o`00
oooo0?ooo`1S0?ooo`030000003oool0oooo02P0oooo001J0?ooo`030000003oool0oooo0:d0oooo
00<00?l00?ooo`00o`00>`3oool00`00o`00oooo003o000X0?ooo`800?l00P3oool00`00o`00oooo
0?ooo`1[0?ooo`03003o003oool00?l003l0oooo00P00?l00?ooo`3oool0oooo003o003oool00?l0
0?ooo`800?l00P3oool2003o00@0oooo0P00o`040?ooo`04003o003oool0oooo0?ooo`800?l00`3o
ool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`000P3o
ool00`00o`00oooo0?ooo`1T0?ooo`030000003oool0oooo02P0oooo001J0?ooo`030000003oool0
oooo0:h0oooo0P00o`0k0?ooo`03003o003oool00?l002P0oooo0P00o`1`0?ooo`03003o003oool0
0?l003l0oooo00P00?l00?ooo`3oool0oooo003o003oool00?l00?ooo`800?l00P3oool2003o00@0
oooo0P00o`040?ooo`04003o003oool0oooo0?ooo`800?l00`3oool00`00o`00oooo0?ooo`0:0?oo
o`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`000P3oool00`00o`00oooo0?ooo`1T0?oo
o`030000003oool0oooo02P0oooo001J0?ooo`030000003oool0oooo0:h0oooo0P00o`0k0?ooo`80
0?l0:@3oool2003o0700oooo00<00?l00?ooo`00o`00?`3oool02000o`00oooo0?ooo`3oool00?l0
0?ooo`00o`00oooo0P00o`020?ooo`03003o003oool0oooo00<0oooo0P00o`040?ooo`04003o003o
ool0oooo0?ooo`800?l00`3oool00`00o`00oooo0?ooo`0:0?ooo`03003o003oool00?l000<0oooo
00<00?l00?ooo`00o`000P3oool00`00o`00oooo0?ooo`1T0?ooo`030000003oool0oooo02P0oooo
001J0?ooo`<00000[P3oool2003o03/0oooo0P00o`0Y0?ooo`03003o003oool0oooo06l0oooo00<0
0?l00?ooo`00o`00?`3oool02000o`00oooo0?ooo`3oool00?l00?ooo`00o`00oooo0P00o`020?oo
o`03003o003oool0oooo00<0oooo0P00o`040?ooo`04003o003oool0oooo0?ooo`800?l00`3oool0
0`00o`00oooo0?ooo`0:0?ooo`03003o003oool00?l000<0oooo00<00?l00?ooo`00o`000`00o`1V
0?ooo`030000003oool0oooo02P0oooo001J0?ooo`030000003oool0oooo0:h0oooo00<00?l00?oo
o`3oool0>P3oool2003o02T0oooo00<00?l00?ooo`3oool0K`3oool00`00o`00oooo003o000o0?oo
o`06003o003oool0oooo0?ooo`00o`00oooo1000o`020?ooo`03003o003oool0oooo00<0oooo00<0
0?l00?ooo`3oool00`3oool01000o`00oooo0?ooo`3oool2003o00<0oooo00<00?l00?ooo`3oool0
303oool01P00o`00oooo0?ooo`3oool00?l00?ooo`800?l000<0oooo003o003oool0I@3oool00`00
0000oooo0?ooo`0X0?ooo`00FP3oool00`000000oooo0?ooo`2^0?ooo`03003o003oool0oooo03/0
oooo00<00?l00?ooo`3oool09`3oool00`00o`00oooo0?ooo`1_0?ooo`03003o003oool00?l003l0
oooo00H00?l00?ooo`3oool0oooo003o003oool4003o00P0oooo00<00?l00?ooo`3oool00`3oool0
1000o`00oooo0?ooo`3oool2003o00<0oooo00<00?l00?ooo`3oool0303oool01P00o`00oooo0?oo
o`3oool00?l00?ooo`800?l0J03oool00`000000oooo0?ooo`0X0?ooo`00FP3oool00`000000oooo
0?ooo`2^0?ooo`03003o003oool0oooo03/0oooo00<00?l00?ooo`3oool09`3oool00`00o`00oooo
0?ooo`1`0?ooo`03003o003oool0oooo03h0oooo00H00?l00?ooo`3oool0oooo003o003oool2003o
00030?ooo`00o`00oooo00L0oooo00<00?l00?ooo`3oool00`3oool01000o`00oooo0?ooo`3oool2
003o00<0oooo00<00?l00?ooo`3oool0303oool01P00o`00oooo0?ooo`3oool00?l00?ooo`800?l0
J03oool00`000000oooo0?ooo`0X0?ooo`00FP3oool00`000000oooo0?ooo`2^0?ooo`03003o003o
ool0oooo03/0oooo00<00?l00?ooo`3oool09`3oool00`00o`00oooo0?ooo`1`0?ooo`03003o003o
ool0oooo03h0oooo00H00?l00?ooo`3oool0oooo003o003oool2003o00030?ooo`00o`00oooo00L0
oooo00<00?l00?ooo`3oool00`3oool01000o`00oooo0?ooo`3oool2003o00<0oooo00<00?l00?oo
o`3oool0303oool01P00o`00oooo0?ooo`3oool00?l00?ooo`800?l0J03oool00`000000oooo0?oo
o`0X0?ooo`00FP3oool300000:h0oooo00<00?l00?ooo`3oool0>`3oool00`00o`00oooo0?ooo`0W
0?ooo`03003o003oool0oooo0700oooo00<00?l00?ooo`3oool0?P3oool01P00o`00oooo003o003o
ool00?l00?ooo`800?l000<0oooo003o003oool01`3oool00`00o`00oooo0?ooo`030?ooo`04003o
003oool0oooo0?ooo`800?l00`3oool00`00o`00oooo0?ooo`0<0?ooo`07003o003oool0oooo0?oo
o`00o`00oooo003o001Y0?ooo`030000003oool0oooo02P0oooo001J0?ooo`030000003oool0oooo
0>`0oooo00<00?l00?ooo`3oool09`3oool00`00o`00oooo0?ooo`1`0?ooo`03003o003oool0oooo
03h0oooo00H00?l00?ooo`00o`00oooo003o003oool2003o00030?ooo`00o`00oooo00L0oooo00<0
0?l00?ooo`3oool00`3oool01000o`00oooo0?ooo`3oool2003o00<0oooo00<00?l00?ooo`3oool0
303oool01`00o`00oooo0?ooo`3oool00?l00?ooo`00o`00J@3oool00`000000oooo0?ooo`0X0?oo
o`00FP3oool00`000000oooo0?ooo`3/0?ooo`03003o003oool0oooo02L0oooo00<00?l00?ooo`3o
ool0L03oool00`00o`00oooo0?ooo`0n0?ooo`06003o003oool00?l00?ooo`00o`00oooo0P00o`00
0`3oool00?l00?ooo`070?ooo`03003o003oool0oooo00<0oooo00@00?l00?ooo`3oool0oooo0P00
o`030?ooo`03003o003oool0oooo00`0oooo00L00?l00?ooo`3oool0oooo003o003oool00?l006T0
oooo00<000000?ooo`3oool0:03oool005X0oooo00<000000?ooo`3oool0k03oool00`00o`00oooo
0?ooo`0W0?ooo`03003o003oool0oooo0700oooo00<00?l00?ooo`3oool0?P3oool01000o`00oooo
003o0000o`030?ooo`03003o003oool00?l000P0oooo00<00?l00?ooo`3oool00`3oool01000o`00
oooo0?ooo`3oool2003o00<0oooo00<00?l00?ooo`3oool0303oool01`00o`00oooo0?ooo`3oool0
0?l00?ooo`00o`00J@3oool00`000000oooo0?ooo`0X0?ooo`00FP3oool00`000000oooo0?ooo`3/
0?ooo`03003o003oool0oooo02L0oooo00<00?l00?ooo`3oool0L03oool00`00o`00oooo0?ooo`0n
0?ooo`04003o003oool00?l0003o00<0oooo00<00?l00?ooo`3oool03P3oool01000o`00oooo0?oo
o`3oool2003o00<0oooo00<00?l00?ooo`3oool0303oool01`00o`00oooo0?ooo`3oool00?l00?oo
o`00o`00J@3oool00`000000oooo0?ooo`0X0?ooo`00FP3oool00`000000oooo0?ooo`3/0?ooo`03
003o003oool0oooo02L0oooo00<00?l00?ooo`3oool0L03oool00`00o`00oooo0?ooo`0n0?ooo`04
003o003oool00?l0003o00<0oooo00<00?l00?ooo`3oool03P3oool01000o`00oooo0?ooo`3oool2
003o00<0oooo00<00?l00?ooo`3oool0303oool01`00o`00oooo0?ooo`3oool00?l00?ooo`00o`00
J@3oool00`000000oooo0?ooo`0X0?ooo`00FP3oool300000>`0oooo00<00?l00?ooo`3oool09`3o
ool00`00o`00oooo0?ooo`1`0?ooo`03003o003oool0oooo03h0oooo00@00?l00?ooo`00o`000?l0
503oool01000o`00oooo0?ooo`3oool2003o00<0oooo00<00?l00?ooo`3oool0303oool01@00o`00
oooo0?ooo`3oool00?l006/0oooo00<000000?ooo`3oool0:03oool004H0oooo00<000000?ooo`3o
ool00P3oool4000000/0oooo00<000000?ooo`3oool0k03oool00`00o`00oooo0?ooo`0W0?ooo`03
003o003oool0oooo0700oooo00<00?l00?ooo`3oool0?P3oool01000o`00oooo003o0000o`0D0?oo
o`04003o003oool0oooo0?ooo`800?l00`3oool00`00o`00oooo0?ooo`0<0?ooo`05003o003oool0
oooo0?ooo`00o`00J`3oool00`000000oooo0?ooo`0X0?ooo`00AP3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3/0?ooo`03003o003o
ool0oooo02L0oooo00<00?l00?ooo`3oool0L03oool00`00o`00oooo0?ooo`0n0?ooo`800?l000<0
oooo003o003oool04`3oool01000o`00oooo0?ooo`3oool2003o00<0oooo00<00?l00?ooo`3oool0
303oool01@00o`00oooo0?ooo`3oool00?l006/0oooo00<000000?ooo`3oool0:03oool00440oooo
1`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3/0?ooo`03003o003oool0oooo02L0oooo00<00?l00?ooo`3oool0L03oool00`00o`00oooo
0?ooo`0n0?ooo`800?l000<0oooo003o003oool04`3oool01000o`00oooo0?ooo`3oool2003o00<0
oooo00<00?l00?ooo`3oool0303oool01@00o`00oooo0?ooo`3oool00?l006/0oooo00<000000?oo
o`3oool0:03oool00440oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3/0?ooo`03003o003oool0oooo
02L0oooo00<00?l00?ooo`3oool0L03oool00`00o`00oooo0?ooo`0n0?ooo`800?l000<0oooo003o
003oool04`3oool01000o`00oooo0?ooo`3oool2003o00<0oooo00<00?l00?ooo`3oool0303oool0
1@00o`00oooo0?ooo`3oool00?l006/0oooo00<000000?ooo`3oool0:03oool00480oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool500000>X0oooo00<00?l00?ooo`3oool09`3oool00`00o`00oooo0?ooo`1`0?ooo`03003o003o
ool0oooo03h0oooo0P00o`000`3oool00?l00?ooo`0C0?ooo`04003o003oool0oooo0?ooo`800?l0
0`3oool00`00o`00oooo0?ooo`0<0?ooo`05003o003oool0oooo0?ooo`00o`00J`3oool00`000000
oooo0?ooo`0X0?ooo`00@`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oooaL0oooo00<00?l00?ooo`3o
ool0L03oool00`00o`00oooo0?ooo`0n0?ooo`800?l000<0oooo003o003oool04`3oool01000o`00
oooo0?ooo`3oool2003o00<0oooo00<00?l00?ooo`3oool0303oool01@00o`00oooo0?ooo`3oool0
0?l006/0oooo00<000000?ooo`3oool0:03oool004<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolG
0?ooo`03003o003oool0oooo0700oooo00<00?l00?ooo`3oool0?P3oool2003o01H0oooo00@00?l0
0?ooo`3oool0oooo0P00o`030?ooo`03003o003oool0oooo00`0oooo00D00?l00?ooo`3oool0oooo
003o001[0?ooo`030000003oool0oooo02P0oooo00140?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo5`3o
ool00`00o`00oooo0?ooo`1`0?ooo`03003o003oool0oooo03h0oooo0P00o`0F0?ooo`04003o003o
ool0oooo0?ooo`800?l00`3oool00`00o`00oooo0?ooo`0<0?ooo`05003o003oool0oooo0?ooo`00
o`00J`3oool00`000000oooo0?ooo`0X0?ooo`00A@3oool2000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo5`3oool00`00o`00oooo
0?ooo`1`0?ooo`03003o003oool0oooo03h0oooo0P00o`0F0?ooo`04003o003oool0oooo0?ooo`80
0?l00`3oool00`00o`00oooo0?ooo`0<0?ooo`05003o003oool0oooo0?ooo`00o`00J`3oool00`00
0000oooo0?ooo`0X0?ooo`00AP3oool00`000000oooo0?ooo`020?ooo`@000002`3oool00`000000
oooo0?ooo`3o0?oooaL0oooo00<00?l00?ooo`3oool0L03oool00`00o`00oooo0?ooo`0n0?ooo`80
0?l05P3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`0>0?ooo`05003o003oool0oooo
0?ooo`00o`00J`3oool00`000000oooo0?ooo`0X0?ooo`00FP3oool300000?l0ooooRP3oool00`00
o`00oooo0?ooo`0n0?ooo`800?l05P3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`0>
0?ooo`05003o003oool0oooo0?ooo`00o`00J`3oool00`000000oooo0?ooo`0X0?ooo`00FP3oool0
0`000000oooo0?ooo`3o0?ooohX0oooo00<00?l00?ooo`3oool0?P3oool2003o01H0oooo00@00?l0
0?ooo`3oool0oooo0P00o`020?ooo`800?l03P3oool01@00o`00oooo0?ooo`3oool00?l006/0oooo
00<000000?ooo`3oool0:03oool005X0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`03003o003o
ool0oooo03h0oooo0P00o`0F0?ooo`04003o003oool0oooo0?ooo`800?l00P3oool2003o00h0oooo
00D00?l00?ooo`3oool0oooo003o001[0?ooo`030000003oool0oooo02P0oooo001J0?ooo`030000
003oool0oooo0?l0ooooRP3oool00`00o`00oooo0?ooo`0n0?ooo`800?l05P3oool01000o`00oooo
0?ooo`3oool2003o0080oooo0P00o`0>0?ooo`05003o003oool0oooo0?ooo`00o`00J`3oool00`00
0000oooo0?ooo`0X0?ooo`00FP3oool00`000000oooo0?ooo`3o0?ooohX0oooo00<00?l00?ooo`3o
ool0?P3oool2003o01H0oooo00@00?l00?ooo`3oool0oooo0P00o`020?ooo`800?l03P3oool01000
o`00oooo0?ooo`00o`1/0?ooo`030000003oool0oooo02P0oooo001J0?ooool00000S@0000000`00
o`0000000000000n000000800?l05P0000001000o`000000000000000002003o008000000P00o`0>
00000004003o000000000000003o06d00000:P3oool00001\
\>"],
  ImageRangeCache->{{{0, 753}, {149.688, 0}} -> {-121.617, -10.357, 1.15506, \
0.363811}}]
}, Open  ]],

Cell["\<\
There is no up- or downward trend recognizable in the data. Remarkable are \
the repeating patterns in the data. Observable are also jumps with different \
magnitude, whereby the level comes back very fast after a jump.\
\>", "Text"],

Cell["\<\
The third column within the Excel sheet has the prices for the peak load.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(peak\  = \ \(\(XLGetRange["\<C2:C685\>"] // \ Flatten\)\  // \ 
            Reverse\)\  // \ Rest;\)\), "\[IndentingNewLine]", 
    \(\(plpeak\  = 
        ListPlot[peak, PlotJoined \[Rule] True, AspectRatio \[Rule] \ 0.2, 
          Frame \[Rule] True, 
          FrameTicks \[Rule] {ticks, Automatic, None, None}, 
          PlotStyle \[Rule] Red, FrameLabel \[Rule] \ "\<\:f280/MWh\>", 
          Axes \[Rule] None];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0238095 0.00139441 0.0047619 0.0033871 [
[.0252 -0.0125 -33.7813 -17.75 ]
[.0252 -0.0125 33.7813 0 ]
[.16464 -0.0125 -33.7813 -17.75 ]
[.16464 -0.0125 33.7813 0 ]
[.30409 -0.0125 -29.875 -17.75 ]
[.30409 -0.0125 29.875 0 ]
[.44353 -0.0125 -33.7813 -17.75 ]
[.44353 -0.0125 33.7813 0 ]
[.58297 -0.0125 -33.7813 -17.75 ]
[.58297 -0.0125 33.7813 0 ]
[.72241 -0.0125 -37.6875 -17.75 ]
[.72241 -0.0125 37.6875 0 ]
[.86185 -0.0125 -29.875 -17.75 ]
[.86185 -0.0125 29.875 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00476 -11.8125 -8.875 ]
[-0.0125 .00476 0 8.875 ]
[-0.0125 .03863 -19.625 -8.875 ]
[-0.0125 .03863 0 8.875 ]
[-0.0125 .0725 -19.625 -8.875 ]
[-0.0125 .0725 0 8.875 ]
[-0.0125 .10637 -19.625 -8.875 ]
[-0.0125 .10637 0 8.875 ]
[-0.0125 .14025 -19.625 -8.875 ]
[-0.0125 .14025 0 8.875 ]
[-0.0125 .17412 -19.625 -8.875 ]
[-0.0125 .17412 0 8.875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .1 -37.375 -24.8125 ]
[-0.01875 .1 -19.625 24.8125 ]
[ 0 .2 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0252 0 m
.0252 .00625 L
s
gsave
.0252 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16464 0 m
.16464 .00625 L
s
gsave
.16464 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.30409 0 m
.30409 .00625 L
s
gsave
.30409 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.44353 0 m
.44353 .00625 L
s
gsave
.44353 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.58297 0 m
.58297 .00625 L
s
gsave
.58297 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72241 0 m
.72241 .00625 L
s
gsave
.72241 -0.0125 -98.6875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.688 17.625 moveto
(\\220) show
103.125 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
134.375 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86185 0 m
.86185 .00625 L
s
gsave
.86185 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2002) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .00476 m
.00625 .00476 L
s
gsave
-0.0125 .00476 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .03863 m
.00625 .03863 L
s
gsave
-0.0125 .03863 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .0725 m
.00625 .0725 L
s
gsave
-0.0125 .0725 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .10637 m
.00625 .10637 L
s
gsave
-0.0125 .10637 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .14025 m
.00625 .14025 L
s
gsave
-0.0125 .14025 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .17412 m
.00625 .17412 L
s
gsave
-0.0125 .17412 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01154 m
.00375 .01154 L
s
0 .01831 m
.00375 .01831 L
s
0 .02508 m
.00375 .02508 L
s
0 .03186 m
.00375 .03186 L
s
0 .04541 m
.00375 .04541 L
s
0 .05218 m
.00375 .05218 L
s
0 .05896 m
.00375 .05896 L
s
0 .06573 m
.00375 .06573 L
s
0 .07928 m
.00375 .07928 L
s
0 .08605 m
.00375 .08605 L
s
0 .09283 m
.00375 .09283 L
s
0 .0996 m
.00375 .0996 L
s
0 .11315 m
.00375 .11315 L
s
0 .11992 m
.00375 .11992 L
s
0 .1267 m
.00375 .1267 L
s
0 .13347 m
.00375 .13347 L
s
0 .14702 m
.00375 .14702 L
s
0 .15379 m
.00375 .15379 L
s
0 .16057 m
.00375 .16057 L
s
0 .16734 m
.00375 .16734 L
s
0 .18089 m
.00375 .18089 L
s
0 .18767 m
.00375 .18767 L
s
0 .19444 m
.00375 .19444 L
s
.25 Mabswid
0 0 m
0 .2 L
s
gsave
-0.01875 .1 -114.313 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.8125 12.875 translate
90 rotate
-85.8125 -12.875 translate
0 25.75 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
%%BeginResource: font Arial-MISO
%%BeginFont: Arial-MISO
/Arial /Arial-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
currentpoint currentpoint
newpath
 moveto
 0.813 0.000 rmoveto
 0 -10.063 rlineto
 6.688 0 rlineto
 0 10.063 rlineto
 -6.688 0 rlineto
closepath
fill moveto
8.313 0.000 rmoveto
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.313 17.625 moveto
(\\220) show
75.750 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MWh) show
108.625 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
1 .2 L
s
1 0 m
1 .2 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.0252 .07421 m
.0266 .05618 L
.02799 .04737 L
.02939 .079 L
.03078 .08218 L
.03218 .08044 L
.03357 .05496 L
.03496 .06221 L
.03636 .05199 L
.03775 .04583 L
.03915 .08102 L
.04054 .0716 L
.04194 .071 L
.04333 .08098 L
.04473 .06876 L
.04612 .05172 L
.04751 .04651 L
.04891 .07369 L
.0503 .07939 L
.0517 .07533 L
.05309 .08073 L
.05449 .07505 L
.05588 .05362 L
.05728 .0428 L
.05867 .07852 L
.06006 .08198 L
.06146 .0814 L
.06285 .07278 L
.06425 .0669 L
.06564 .05065 L
.06704 .04321 L
.06843 .06839 L
.06983 .06371 L
.07122 .06406 L
.07261 .06452 L
.07401 .07016 L
.0754 .05638 L
.0768 .04443 L
.07819 .06826 L
.07959 .06328 L
.08098 .07109 L
.08237 .06435 L
.08377 .06511 L
.08516 .05263 L
.08656 .04641 L
.08795 .06895 L
.08935 .0652 L
.09074 .06106 L
.09214 .06833 L
.09353 .06896 L
Mistroke
.09492 .05513 L
.09632 .0437 L
.09771 .05925 L
.09911 .06353 L
.1005 .06066 L
.1019 .06481 L
.10329 .06116 L
.10469 .05475 L
.10608 .04388 L
.10747 .06649 L
.10887 .05876 L
.11026 .0732 L
.11166 .07434 L
.11305 .07002 L
.11445 .06165 L
.11584 .04823 L
.11723 .08522 L
.11863 .10128 L
.12002 .07203 L
.12142 .09248 L
.12281 .08221 L
.12421 .05393 L
.1256 .0404 L
.127 .0878 L
.12839 .09145 L
.12978 .10676 L
.13118 .09205 L
.13257 .10131 L
.13397 .06454 L
.13536 .05422 L
.13676 .09812 L
.13815 .11105 L
.13955 .10594 L
.14094 .10971 L
.14233 .11231 L
.14373 .06172 L
.14512 .04592 L
.14652 .1022 L
.14791 .11248 L
.14931 .11359 L
.1507 .14001 L
.1521 .09777 L
.15349 .06858 L
.15488 .05281 L
.15628 .09842 L
.15767 .10019 L
.15907 .10478 L
.16046 .13557 L
.16186 .09837 L
.16325 .07212 L
Mistroke
.16464 .05275 L
.16604 .09679 L
.16743 .1001 L
.16883 .09581 L
.17022 .10041 L
.17162 .09328 L
.17301 .07305 L
.17441 .04508 L
.1758 .08467 L
.17719 .0721 L
.17859 .09644 L
.17998 .08399 L
.18138 .08134 L
.18277 .06853 L
.18417 .04643 L
.18556 .10088 L
.18696 .08974 L
.18835 .11907 L
.18974 .10291 L
.19114 .09387 L
.19253 .05143 L
.19393 .03927 L
.19532 .07391 L
.19672 .09818 L
.19811 .08478 L
.1995 .08699 L
.2009 .08291 L
.20229 .06087 L
.20369 .04484 L
.20508 .10091 L
.20648 .09887 L
.20787 .0927 L
.20927 .09681 L
.21066 .09757 L
.21205 .07268 L
.21345 .05262 L
.21484 .11668 L
.21624 .10444 L
.21763 .08327 L
.21903 .14337 L
.22042 .08089 L
.22182 .07748 L
.22321 .05293 L
.2246 .10428 L
.226 .10724 L
.22739 .1049 L
.22879 .08085 L
.23018 .08972 L
.23158 .06527 L
.23297 .05454 L
Mistroke
.23437 .10944 L
.23576 .10135 L
.23715 .11328 L
.23855 .11131 L
.23994 .11197 L
.24134 .07675 L
.24273 .07342 L
.24413 .11378 L
.24552 .10727 L
.24691 .11499 L
.24831 .11739 L
.2497 .10181 L
.2511 .0932 L
.25249 .0594 L
.25389 .11991 L
.25528 .10931 L
.25668 .11149 L
.25807 .13257 L
.25946 .10306 L
.26086 .06972 L
.26225 .07026 L
.26365 .12415 L
.26504 .10326 L
.26644 .13334 L
.26783 .11151 L
.26923 .06937 L
.27062 .08388 L
.27201 .06897 L
.27341 .11078 L
.2748 .11144 L
.2762 .08998 L
.27759 .1018 L
.27899 .11162 L
.28038 .07687 L
.28178 .06633 L
.28317 .13984 L
.28456 .16294 L
.28596 .1478 L
.28735 .11266 L
.28875 .09131 L
.29014 .07557 L
.29154 .06541 L
.29293 .05789 L
.29432 .05765 L
.29572 .08701 L
.29711 .07803 L
.29851 .07319 L
.2999 .07414 L
.3013 .06777 L
.30269 .04468 L
Mistroke
.30409 .07853 L
.30548 .07417 L
.30687 .08736 L
.30827 .08559 L
.30966 .06673 L
.31106 .06347 L
.31245 .10529 L
.31385 .10719 L
.31524 .11236 L
.31664 .11029 L
.31803 .10026 L
.31942 .08755 L
.32082 .0792 L
.32221 .1299 L
.32361 .12261 L
.325 .1324 L
.3264 .11332 L
.32779 .12807 L
.32918 .0883 L
.33058 .07043 L
.33197 .13182 L
.33337 .10944 L
.33476 .08361 L
.33616 .11086 L
.33755 .09986 L
.33895 .06896 L
.34034 .06276 L
.34173 .10242 L
.34313 .11491 L
.34452 .1063 L
.34592 .10101 L
.34731 .12627 L
.34871 .08808 L
.3501 .07487 L
.3515 .11986 L
.35289 .09027 L
.35428 .10019 L
.35568 .09632 L
.35707 .09469 L
.35847 .08038 L
.35986 .06469 L
.36126 .09318 L
.36265 .08724 L
.36405 .08735 L
.36544 .10966 L
.36683 .09266 L
.36823 .07636 L
.36962 .06564 L
.37102 .08916 L
.37241 .09055 L
Mistroke
.37381 .088 L
.3752 .08752 L
.37659 .10387 L
.37799 .09175 L
.37938 .06832 L
.38078 .11366 L
.38217 .13687 L
.38357 .12209 L
.38496 .17576 L
.38636 .1106 L
.38775 .09802 L
.38914 .07103 L
.39054 .11794 L
.39193 .14172 L
.39333 .115 L
.39472 .10707 L
.39612 .08036 L
.39751 .07581 L
.39891 .06333 L
.4003 .09474 L
.40169 .0682 L
.40309 .08664 L
.40448 .08823 L
.40588 .08375 L
.40727 .07291 L
.40867 .05919 L
.41006 .07405 L
.41146 .0903 L
.41285 .07594 L
.41424 .08608 L
.41564 .07733 L
.41703 .06996 L
.41843 .03516 L
.41982 .0795 L
.42122 .08878 L
.42261 .07119 L
.424 .08279 L
.4254 .09063 L
.42679 .06895 L
.42819 .06227 L
.42958 .11161 L
.43098 .10131 L
.43237 .07873 L
.43377 .09292 L
.43516 .09737 L
.43655 .08112 L
.43795 .06469 L
.43934 .09092 L
.44074 .1064 L
.44213 .10634 L
Mistroke
.44353 .08029 L
.44492 .06059 L
.44632 .0783 L
.44771 .06038 L
.4491 .04711 L
.4505 .11831 L
.45189 .11182 L
.45329 .18182 L
.45468 .11523 L
.45608 .08462 L
.45747 .07573 L
.45886 .16119 L
.46026 .12884 L
.46165 .10589 L
.46305 .10454 L
.46444 .1375 L
.46584 .08258 L
.46723 .0696 L
.46863 .09283 L
.47002 .05416 L
.47141 .14471 L
.47281 .08983 L
.4742 .08906 L
.4756 .07457 L
.47699 .06865 L
.47839 .11235 L
.47978 .09839 L
.48118 .08754 L
.48257 .10332 L
.48396 .07792 L
.48536 .07809 L
.48675 .05773 L
.48815 .11067 L
.48954 .10875 L
.49094 .11554 L
.49233 .09405 L
.49373 .10042 L
.49512 .07027 L
.49651 .06431 L
.49791 .13427 L
.4993 .12935 L
.5007 .10251 L
.50209 .05743 L
.50349 .06913 L
.50488 .06196 L
.50627 .04643 L
.50767 .10867 L
.50906 .10571 L
.51046 .11205 L
.51185 .12338 L
Mistroke
.51325 .07952 L
.51464 .05839 L
.51604 .03804 L
.51743 .04763 L
.51882 .10895 L
.52022 .13589 L
.52161 .0881 L
.52301 .09743 L
.5244 .09423 L
.5258 .05965 L
.52719 .10006 L
.52859 .10942 L
.52998 .14753 L
.53137 .08352 L
.53277 .08119 L
.53416 .08631 L
.53556 .0554 L
.53695 .13049 L
.53835 .11124 L
.53974 .12774 L
.54114 .10722 L
.54253 .09024 L
.54392 .06629 L
.54532 .05015 L
.54671 .11494 L
.54811 .14144 L
.5495 .11391 L
.5509 .15065 L
.55229 .11892 L
.55368 .0713 L
.55508 .0449 L
.55647 .15994 L
.55787 .1245 L
.55926 .1237 L
.56066 .14854 L
.56205 .11951 L
.56345 .09261 L
.56484 .04712 L
.56623 .13505 L
.56763 .11463 L
.56902 .11415 L
.57042 .10001 L
.57181 .09974 L
.57321 .06281 L
.5746 .04886 L
.576 .12036 L
.57739 .09707 L
.57878 .08454 L
.58018 .09662 L
.58157 .09492 L
Mistroke
.58297 .0572 L
.58436 .04232 L
.58576 .08547 L
.58715 .08818 L
.58854 .07508 L
.58994 .0916 L
.59133 .0755 L
.59273 .05975 L
.59412 .04279 L
.59552 .09036 L
.59691 .09475 L
.59831 .07664 L
.5997 .08722 L
.60109 .08241 L
.60249 .06389 L
.60388 .04243 L
.60528 .10208 L
.60667 .08687 L
.60807 .09153 L
.60946 .07799 L
.61086 .09634 L
.61225 .04189 L
.61364 .02782 L
.61504 .07618 L
.61643 .08234 L
.61783 .07416 L
.61922 .11212 L
.62062 .11427 L
.62201 .07359 L
.62341 .04964 L
.6248 .10627 L
.62619 .13009 L
.62759 .10765 L
.62898 .13232 L
.63038 .11552 L
.63177 .08493 L
.63317 .06615 L
.63456 .12151 L
.63595 .11321 L
Mfstroke
.63595 .11321 m
.63694 .2 L
s
.63777 .2 m
.63874 .11705 L
.64014 .09687 L
.64153 .07727 L
.64293 .06275 L
.64432 .1381 L
.64572 .10554 L
.64711 .10091 L
.6485 .10689 L
.6499 .09518 L
.65129 .07327 L
.65269 .05836 L
.65408 .10372 L
.65548 .10535 L
.65687 .12606 L
.65827 .10601 L
.65966 .13108 L
.66105 .07256 L
.66245 .06073 L
.66384 .10638 L
.66524 .11243 L
.66663 .11193 L
.66803 .10814 L
.66942 .11063 L
.67082 .08158 L
.67221 .07276 L
.6736 .11231 L
.675 .11249 L
.67639 .11627 L
.67779 .10193 L
.67918 .10225 L
.68058 .07833 L
.68197 .07058 L
.68336 .15218 L
.68476 .10761 L
.68615 .08342 L
.68755 .09828 L
.68894 .0919 L
.69034 .07703 L
.69173 .05782 L
.69313 .09517 L
.69452 .09349 L
.69591 .09749 L
.69731 .11373 L
.6987 .08311 L
.7001 .07006 L
.70149 .06841 L
.70289 .1019 L
.70428 .10328 L
.70568 .10661 L
Mistroke
.70707 .10279 L
.70846 .1034 L
.70986 .08223 L
.71125 .07679 L
.71265 .10994 L
.71404 .11683 L
.71544 .12168 L
.71683 .12502 L
.71822 .09999 L
.71962 .09109 L
.72101 .06987 L
.72241 .15238 L
.7238 .12389 L
.7252 .10086 L
.72659 .07365 L
.72799 .10475 L
.72938 .09147 L
.73077 .07375 L
.73217 .12703 L
.73356 .11761 L
.73496 .12233 L
.73635 .12124 L
.73775 .13104 L
.73914 .09469 L
.74054 .07279 L
.74193 .12737 L
Mfstroke
.74193 .12737 m
.74296 .2 L
s
.74453 .2 m
.74472 .19612 L
.74611 .15793 L
.74751 .17544 L
.7489 .13188 L
.7503 .10007 L
.75169 .15938 L
.75309 .16738 L
.75448 .15894 L
.75587 .14263 L
.75727 .16396 L
.75866 .10384 L
.76006 .07038 L
.76145 .15924 L
.76285 .1487 L
.76424 .14355 L
.76563 .13814 L
.76703 .11778 L
.76842 .07766 L
.76982 .06859 L
.77121 .19082 L
.77261 .1531 L
.774 .12417 L
.7754 .11867 L
.77679 .12806 L
.77818 .10448 L
.77958 .08372 L
s
.77958 .08372 m
.78018 .2 L
s
.78737 .2 m
.78795 .14508 L
.78934 .09809 L
s
.78934 .09809 m
.78944 .2 L
s
.79349 .2 m
.79352 .18129 L
s
.79352 .18129 m
.79391 .2 L
s
.79546 .2 m
.79631 .12284 L
.79771 .12269 L
.7991 .09182 L
.8005 .09629 L
.80189 .06291 L
.80328 .07323 L
.80468 .13289 L
.80607 .06568 L
.80747 .07913 L
.80886 .06992 L
.81026 .09885 L
.81165 .05473 L
.81304 .13184 L
.81444 .14016 L
.81583 .13496 L
.81723 .11017 L
.81862 .08315 L
s
.81862 .08315 m
.81973 .2 L
s
.82491 .2 m
.82559 .17405 L
.82699 .13936 L
.82838 .10931 L
.82978 .17593 L
.83117 .13524 L
.83257 .14849 L
.83396 .1417 L
.83536 .13384 L
.83675 .06718 L
.83814 .06969 L
.83954 .12516 L
.84093 .12053 L
.84233 .11359 L
.84372 .11386 L
.84512 .10535 L
.84651 .07988 L
.8479 .06906 L
.8493 .11288 L
.85069 .08519 L
.85209 .10398 L
.85348 .09174 L
.85488 .08858 L
.85627 .06467 L
.85767 .05706 L
.85906 .09413 L
.86045 .09317 L
.86185 .0883 L
.86324 .08602 L
.86464 .07958 L
.86603 .07185 L
.86743 .06213 L
.86882 .08197 L
.87022 .06853 L
.87161 .09405 L
.873 .10013 L
.8744 .07311 L
.87579 .09454 L
.87719 .07225 L
.87858 .09983 L
.87998 .09298 L
.88137 .09797 L
.88277 .11173 L
.88416 .08677 L
.88555 .07462 L
.88695 .07369 L
.88834 .1018 L
.88974 .09622 L
.89113 .08594 L
.89253 .09552 L
Mistroke
.89392 .1196 L
.89531 .07616 L
.89671 .06505 L
.8981 .10017 L
.8995 .10538 L
.90089 .09625 L
.90229 .09083 L
.90368 .08516 L
.90508 .08151 L
.90647 .06998 L
.90786 .08987 L
.90926 .09194 L
.91065 .0807 L
.91205 .08832 L
.91344 .0752 L
.91484 .07042 L
.91623 .06016 L
.91763 .08794 L
.91902 .08623 L
.92041 .08976 L
.92181 .08414 L
.9232 .08258 L
.9246 .06165 L
.92599 .04851 L
.92739 .09406 L
.92878 .09705 L
.93017 .10218 L
.93157 .09632 L
.93296 .05861 L
.93436 .06391 L
.93575 .03805 L
.93715 .02866 L
.93854 .08851 L
.93994 .07733 L
.94133 .08401 L
.94272 .07301 L
.94412 .0725 L
.94551 .05716 L
.94691 .11783 L
.9483 .10349 L
.9497 .10375 L
.95109 .12091 L
.95249 .10903 L
.95388 .07901 L
.95527 .06136 L
.95667 .11909 L
.95806 .13806 L
.95946 .12312 L
.96085 .11811 L
.96225 .10351 L
Mistroke
.96364 .09122 L
.96504 .05765 L
.96643 .10398 L
.96782 .11537 L
.96922 .13008 L
.97061 .09922 L
.97201 .08955 L
.9734 .06383 L
.9748 .05154 L
.97619 .09339 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{716, 143.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;<0000Sb000`400?l00000o`00003oo`3ooooo
0?ooolh0oooo003o0?ooool0oooocP3oool00?l0ooooo`3oooo>0?ooo`00E`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0800oooo001G0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0P03oool005L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`20
0?ooo`00C03oool00`000000oooo0?ooo`030?ooo`@000000P3oool00`000000oooo0?ooo`030?oo
o`@000000P3oool00`000000oooo0?ooo`020?ooo`H000000`3oool4000000@0oooo100000040?oo
o`@00000503oool6000000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`<00000103oool0
10000000oooo0?ooo`3oool6000000<0oooo100000040?ooo`@00000103oool4000001T0oooo1P00
00000`3oool000000?ooo`060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo
1P0000030?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`020?ooo`H000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`00
0000103oool6000000<0oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`0C0?ooo`H0
00001@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`3oool6000000<0oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`0@
0?ooo`H000000`3oool3000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`H000000`3oool4000000@0oooo10000006
0?ooo`030000003oool0oooo01@0oooo100000030?ooo`040000003oool0oooo0?ooo`H000000P3o
ool010000000oooo0?ooo`3oool6000000<0oooo100000040?ooo`@000000`3oool600000600oooo
001<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0203oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000
I03oool004`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`L0
00000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0700000080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1Q0?ooo`00C03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0D0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1P0?ooo`00
C03oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000oooo0?ooo`0000030?ooo`80
00000`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
5@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`050000003o
ool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo0`000000
1@3oool000000?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?oo
o`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0G`3oool004`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo00000002000000<0oooo00H000000?ooo`3oool0oooo
0000003oool3000000<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0F0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000<0oooo0P0000030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool06`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00L0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool01P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0
oooo000000<0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo00000002000000@0oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0GP3oool004`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0F0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
01/0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`040000
003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo00@00000
0?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
05h0oooo001:0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool01P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00001@3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
0000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0000000H0oooo00<000000?ooo`000000
103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00L000000?oo
o`3oool0oooo0000003oool0000001X0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000D0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000001D0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool00000
0180oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
000E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0GP3oool004/0
oooo0P0000050?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo0P0000050?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000060?ooo`030000003oool0000000@0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0080oooo0P00000K0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool2000000D0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oool2000001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`80
00001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
0000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3oool200000180oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`050000003oool0oooo0?ooo`000000103oool2000000@0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2
000001H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
05h0oooo001<0?ooo`030000003oool0oooo00@0oooo0`0000050?ooo`040000003oool0oooo0?oo
o`<000001@3oool00`000000oooo0?ooo`04000000@0oooo100000040?ooo`@00000103oool40000
01D0oooo100000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`0000060?oo
o`030000003oool0000000<00000103oool4000000@0oooo100000040?ooo`@000006P3oool40000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool00000
00<00000103oool4000000@0oooo100000060?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool00`3oool4000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@00000103oool4000000@0oooo100000060?ooo`030000003oool0oooo
01@0oooo100000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@0000050?oo
o`030000003oool0000000<00000103oool4000000@0oooo100000060?ooo`030000003oool0oooo
0140oooo100000040?ooo`@000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo100000050?ooo`030000003oool0oooo00@00000103oool4000000@0oooo100000060?oo
o`030000003oool0oooo01D0oooo0`0000060?ooo`030000003oool0000000<000001P3oool00`00
0000oooo00000003000000@0oooo100000040?ooo`@00000103oool400000640oooo003o0?ooool0
oooocP3oool00?l0ooooo`3oooo>0?ooo`00o`3ooooo0?ooolh0oooo003o0?ooool0oooocP3oool0
0?l0ooooo`3oooo>0?ooo`00o`3ooooo0?ooolh0oooo003o0?ooool0oooocP3oool00?l0ooooo`3o
ooo>0?ooo`00o`3ooooo0?ooolh0oooo00190?ooo`@00000303ooooo00000?l00000C000000Y0?oo
o`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02L0oooo00180?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool09`3oool004P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`090?ooo`@000002P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo02L0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool09`3oool0
04P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0?l0ooooo`3ooom80?ooo`030000003oool0oooo02L0oooo00180?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000
oooo0?ooo`0W0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
0`00003o0?ooool0ooooB03oool00`000000oooo0?ooo`0W0?ooo`00B03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<0
00000?ooo`3oool09`3oool004T0oooo1000000<0?ooo`030000003oool0oooo0?l0ooooo`3ooom8
0?ooo`030000003oool0oooo02L0oooo001I0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?oo
o`030000003oool0oooo02L0oooo001I0?ooo`<00000o`3ooooo0?ooodP0oooo00<000000?ooo`3o
ool09`3oool005T0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0
9`3oool005T0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool09`3o
ool005T0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool09`3oool0
05T0oooo0`00003o0?ooool0ooooB03oool00`000000oooo0?ooo`0W0?ooo`00F@3oool00`000000
oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`0W0?ooo`00F@3oool00`000000oooo
0?ooo`3o0?ooofD0oooo00<0o`000?ooo`3oool0^P3oool00`3o0000oooo0?ooo`0R0?ooo`030000
003oool0oooo02L0oooo001I0?ooo`030000003oool0oooo0?l0ooooI@3oool00`3o0000oooo0?oo
o`2j0?ooo`030?l0003oool0oooo0280oooo00<000000?ooo`3oool09`3oool004@0oooo00<00000
0?ooo`3oool00`3oool4000000/0oooo0`00003o0?ooofD0oooo00<0o`000?ooo`3oool0^P3oool0
0`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo02L0oooo00140?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0ooooI@3oool00`3o0000oooo0?ooo`2i0?ooo`80o`00903oool00`000000oooo0?ooo`0W0?oo
o`00A03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`3a0?ooo`030?l0003oool0oooo06l0oooo0P3o002k0?ooo`80
o`00903oool00`000000oooo0?ooo`0W0?ooo`00A03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3a0?ooo`030?l0
003oool0oooo06l0oooo0P3o002k0?ooo`80o`00903oool00`000000oooo0?ooo`0W0?ooo`00A03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool4000006d0oooo00<0o`000?ooo`3oool0P03oool00`3o0000oooo0?ooo`0f0?ooo`030?l0003o
ool0oooo03H0oooo0P3o002k0?ooo`80o`00903oool00`000000oooo0?ooo`0W0?ooo`00A03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`160?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool0P03oool0
0`3o0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo03H0oooo0P3o002k0?ooo`80o`00903oool0
0`000000oooo0?ooo`0W0?ooo`00A03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`160?ooo`030?l0003oool0oooo
02D0oooo00<0o`000?ooo`3oool0P03oool00`3o0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo
02D0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`020?ooo`80o`00^`3oool20?l0
02@0oooo00<000000?ooo`3oool09`3oool00480oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool09@3oool00`3o0000
oooo0?ooo`200?ooo`030?l0003oool0oooo03H0oooo0P3o000V0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80o`00^`3oool20?l002@0
oooo00<000000?ooo`3oool09`3oool004<0oooo0P0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool3000001<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00L0oooo0P3o00050?ooo`030?l0003oool0oooo03L0oooo
00<0o`000?ooo`3oool0@03oool00`3o0000oooo0?ooo`0f0?ooo`80o`005@3oool00`3o0000oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`80o`00^`3oool20?l002@0oooo00<000000?ooo`3oool09`3oool004@0oooo00<0
00000?ooo`3oool00`3oool4000000/0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`80o`001@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`80o`002`3oool00`3o0000oooo0?oo
o`0>0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool20?l000D0oooo00<0
o`000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`100?ooo`030?l0003oool0oooo00l0oooo00<0
o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`020?ooo`80o`005@3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo0P3o002k0?ooo`80o`00903oool00`000000oooo0?oo
o`0W0?ooo`00F@3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo0P3o0004
0?ooo`030?l0003oool0oooo0080oooo0P3o00040?ooo`80o`001@3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo0P3o000;0?ooo`030?l0003oool0oooo00h0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`80o`001@3oool00`3o0000oooo0?ooo`0g
0?ooo`030?l0003oool0oooo0400oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0O
0?ooo`030?l0003oool0oooo0080oooo0P3o000E0?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80o`00]@3oool00`3o0000oooo0?ooo`03
0?ooo`80o`00903oool00`000000oooo0?ooo`0W0?ooo`00F@3oool00`000000oooo0?ooo`0=0?oo
o`030?l0003oool0oooo0080oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo0P3o00040?oo
o`80o`00103oool20?l000<0oooo0P3o00040?ooo`80o`00103oool20?l000@0oooo00<0o`000?oo
o`3oool00P3oool20?l000/0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo0P3o00050?ooo`030?l0003oool0oooo03L0oooo00<0o`000?oo
o`3oool0@03oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?oo
o`3oool00P3oool20?l00100oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo00<0o`000?oo
o`3oool0[P3oool00`3o0000oooo0?ooo`030?ooo`80o`00903oool00`000000oooo0?ooo`0W0?oo
o`00F@3oool3000000`0oooo0P3o00040?ooo`80o`00103oool00`3o0000oooo0?ooo`020?ooo`80
o`00103oool20?l000@0oooo0P3o00030?ooo`80o`00103oool00`3o0000oooo0?l000030?ooo`80
o`00103oool00`3o0000oooo0?ooo`020?ooo`80o`002`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo0P3o00050?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0/0?ooo`030?l0003oool0oooo0400oooo00<0o`000?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0080oooo0P3o000@0?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool20?l000D0oooo00<0o`000?ooo`3o
ool00P3oool20?l000@0oooo00<0o`000?ooo`3oool0[P3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0o`0001D0oooo00<0o`000?ooo`3oool0303oool00`000000oooo0?ooo`0W0?ooo`00
F@3oool00`000000oooo0?ooo`0<0?ooo`80o`00103oool20?l000@0oooo00<0o`000?ooo`3oool0
0P3oool20?l000@0oooo0P3o00040?ooo`80o`000`3oool20?l000@0oooo00<0o`000?ooo`3o0000
0`3oool20?l000@0oooo00<0o`000?ooo`3oool00P3oool20?l000D0oooo00<0o`000?ooo`3oool0
0P3oool20?l000@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo0P3o00040?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0
003oool0oooo0400oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo0180oooo00<0o`000?ooo`3oool00P3oool20?l00100oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`80o`00103oool20?l000@0oooo0P3o00040?ooo`030?l0
003oool0oooo0:h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?l0000E0?ooo`030?l0
003oool0oooo00`0oooo00<000000?ooo`3oool09`3oool005T0oooo00<000000?ooo`3oool0303o
ool20?l00080oooo00@0o`000?ooo`3o0000o`00103oool00`3o0000oooo0?ooo`020?ooo`80o`00
103oool20?l000@0oooo0P3o00030?ooo`80o`00103oool00`3o0000oooo0?l000030?ooo`80o`00
103oool00`3o0000oooo0?ooo`020?ooo`80o`001@3oool00`3o0000oooo0?ooo`020?ooo`80o`00
103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`80o`00103oool20?l000@0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool0
@03oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0
4@3oool20?l000@0oooo0P3o000:0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P3o00040?ooo`030?l0
003oool0oooo0080oooo0P3o00040?ooo`80o`00103oool20?l000@0oooo00<0o`000?ooo`3oool0
J`3oool00`3o0000oooo0?ooo`0o0?ooo`80o`00103oool00`3o0000oooo0?l0000E0?ooo`030?l0
003oool0oooo00`0oooo00<000000?ooo`3oool09`3oool005T0oooo00<000000?ooo`3oool0303o
ool20?l00080oooo0P3o00000`3oool0o`000?ooo`030?ooo`030?l0003oool0oooo0080oooo0P3o
00040?ooo`030?l0003oool0o`0000<0oooo0P3o00030?ooo`80o`00103oool00`3o0000oooo0?l0
00030?ooo`80o`00103oool00`3o0000oooo0?ooo`020?ooo`80o`001@3oool00`3o0000oooo0?oo
o`020?ooo`80o`00103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0o`0000<0oooo0P3o
00040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0P0?ooo`80o`000`3oool20?l00480oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0103o0000oooo0?l0
003o00040?ooo`80o`002P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80o`00103oool00`3o0000oooo
0?ooo`020?ooo`80o`00103oool20?l000@0oooo0P3o00040?ooo`030?l0003oool0oooo02D0oooo
00<0o`000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo02@0oooo
0P3o00040?ooo`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool09`3oool005T0oooo0`00
000<0?ooo`80o`000P3oool20?l000030?ooo`3o0000oooo00<0oooo00<0o`000?ooo`3oool00P3o
ool20?l000<0oooo00@0o`000?ooo`3oool0o`000`3oool20?l000<0oooo00<0o`000?ooo`3o0000
0`3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0o`000?l000<0oooo00<0o`000?ooo`3o
ool00P3oool20?l000@0oooo0P3o00040?ooo`80o`00103oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
00000`3oool20?l000@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool05@3oool20?l000<0oooo0P3o000m0?ooo`03
0?l0003oool0oooo0080oooo0P3o000@0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`060?ooo`040?l0003oool0o`000?l000@0oooo0P3o00040?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80o`00103oool00`3o0000oooo0?ooo`020?oo
o`80o`00103oool20?l000@0oooo0P3o00040?ooo`030?l0003oool0oooo00h0oooo00<0o`000?oo
o`3oool0503oool00`3o0000oooo0?ooo`130?ooo`030?l0003oool0oooo01P0oooo00<0o`000?oo
o`3oool0903oool20?l000<0oooo0P3o00020?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool0
0`3o0000oooo0?ooo`020?ooo`80o`003P3oool00`000000oooo0?ooo`0W0?ooo`00F@3oool00`00
0000oooo0?ooo`0<0?ooo`80o`000P3oool20?l000030?ooo`3o0000oooo0080oooo0P3o00040?oo
o`80o`000`3oool0103o0000oooo0?ooo`3o00030?ooo`80o`000`3oool0203o0000oooo0?l0003o
ool0o`000?ooo`3o0000oooo0P3o00000`3oool0o`000?ooo`020?l000<0oooo00<0o`000?ooo`3o
ool00P3oool20?l000@0oooo0P3o00040?ooo`80o`000`3oool20?l000D0oooo00<0o`000?ooo`3o
ool00P3oool20?l000@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?l000030?ooo`80
o`00103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P3o000:0?ooo`03
0?l0003oool0oooo01D0oooo0P3o00030?ooo`80o`00?@3oool00`3o0000oooo0?ooo`020?ooo`80
o`003P3oool00`3o0000oooo0?l0000<0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool0103o0000oooo0?l0003o00040?ooo`80o`00103oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo0P3o00040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool20?l000@0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo0P3o00040?oo
o`80o`00103oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool03P3oool00`3o0000oooo0?ooo`130?ooo`030?l0003oool0oooo01P0oooo00<0o`000?oo
o`3oool0803oool0103o0000oooo0?ooo`3oool20?l000<0oooo0P3o00020?ooo`050?l0003oool0
oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P3o
000>0?ooo`030000003oool0oooo02L0oooo001I0?ooo`030000003oool0oooo00`0oooo0P3o0002
0?ooo`80o`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0
o`000080oooo00@0o`000?ooo`3oool0o`000`3oool20?l000<0oooo00@0o`000?ooo`3o0000oooo
0P3o00030?ooo`80o`000P3oool20?l000<0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo
0P3o00040?ooo`80o`000`3oool20?l000@0oooo0P3o00040?ooo`80o`00103oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0o`0000<0oooo0P3o00040?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool00P3oool20?l000X0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo
0?l000030?ooo`030?l0003oool0o`0001@0oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo
0?ooo`020?ooo`80o`00103oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0o`0000`0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`040?l0003oool0o`000?l000@0
oooo0P3o00040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20?l000@0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80o`00103oool00`3o0000
oooo0?ooo`020?ooo`80o`00103oool20?l000@0oooo0P3o00030?ooo`80o`002`3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0n0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0603oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo01X0oooo00@0o`000?ooo`3oool0oooo0P3o00030?oo
o`80o`000P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`80o`003P3oool00`000000oooo0?ooo`0W0?ooo`00;03oool:0000
02<0oooo00<000000?ooo`3oool0303oool01@3o0000oooo0?l0003oool0o`0000<0oooo00H0o`00
0?ooo`3oool0o`000?ooo`3o00020?ooo`040?l0003oool0oooo0?l00080oooo00<0o`000?ooo`3o
ool0103o0000103oool0o`000?l0003oool20?l000030?ooo`3o0000o`000080o`000`3oool20?l0
0080oooo0P3o00030?ooo`030?l0003oool0oooo0080oooo0P3o00040?ooo`80o`00103oool20?l0
00<0oooo0P3o00040?ooo`80o`00103oool20?l000@0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?l000030?ooo`80o`00103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo0P3o000:0?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3o00000`3oool00`3o
0000oooo0?l000030?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0203oool00`3o
0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20?l0
00@0oooo00<0o`000?ooo`3oool00`3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o0000303o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
00040?ooo`80o`00103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P3o
00040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo0P3o
00030?ooo`80o`00103oool20?l000@0oooo0P3o00030?ooo`80o`002`3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0n0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo01X0oooo00@0o`000?ooo`3oool0oooo0P3o00030?ooo`80o`00
0P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020?ooo`80o`003P3oool00`000000oooo0?ooo`0W0?ooo`00;03oool:000000/0oooo
1P0000030?ooo`@000002`3oool3000000/0oooo00H0o`000?ooo`3oool0o`000?ooo`3o00030?oo
o`060?l0003oool0oooo0?l0003oool0o`000P3oool0103o0000oooo0?ooo`3o00020?ooo`050?l0
003oool0oooo0?l0003oool00P3o0000103oool0o`000?l0003oool20?l000050?ooo`3o0000o`00
0?ooo`3o00001`3oool20?l00080oooo0P3o00040?ooo`030?l0003oool0o`0000<0oooo0P3o0004
0?ooo`80o`000`3oool20?l000@0oooo0P3o00040?ooo`80o`00103oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0o`0000<0oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo0P3o0004
0?ooo`80o`002P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`80o`003`3oool20?l000X0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0080oooo0P3o0004
0?ooo`80o`000`3oool20?l000D0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`0000`0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080o`00
00<0oooo0?l0003oool00`3oool20?l000@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`80o`00103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
0P3o00040?ooo`80o`000`3oool20?l000@0oooo0P3o00040?ooo`80o`000`3oool20?l000D0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0n0?ooo`030?l0003oool0o`000080oooo
00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00h0oooo
00<0o`000?ooo`3oool0203oool20?l000<0oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o
00000P3oool20?l000@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80
o`003P3oool00`000000oooo0?ooo`0W0?ooo`00;03oool:000000`0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2`3oool01P3o0000oooo0?ooo`3o0000oooo0?l000<0oooo00H0o`000?ooo`3oool0o`000?ooo`3o
00020?ooo`040?l0003oool0oooo0?l00080oooo00D0o`000?ooo`3oool0o`000?ooo`020?l00004
0?ooo`3o0000o`000?l000<0oooo00@0o`000?ooo`3oool0o`002@3oool01@3o0000oooo0?l0003o
ool0o`0000<0oooo00<0o`000?ooo`3o00000`3oool20?l000@0oooo0P3o00030?ooo`80o`00103o
ool20?l000@0oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00000`3o
ool20?l000@0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo0P3o000:0?ooo`030?l0003o
ool0oooo00h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?l000030?ooo`030?l0003o
ool0o`000080oooo0P3o000?0?ooo`80o`002P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?l000020?ooo`80o`00103o
ool20?l000<0oooo0P3o00050?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l0000<0?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool20?l00080oooo0P3o00000`3oool0
o`000?ooo`030?ooo`80o`00103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080
oooo0P3o00040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20?l000@0
oooo0P3o00030?ooo`030?l0003oool0o`0000<0oooo0P3o00040?ooo`80o`000`3oool20?l000D0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo0P3o000?0?ooo`80o`00@03oool00`3o0000oooo0?l000020?ooo`030?l0003oool0oooo00`0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`020?ooo`80o`00403oool00`3o0000
oooo0?ooo`080?ooo`80o`000`3oool20?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000020?oo
o`80o`00103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P3o000>0?oo
o`030000003oool0oooo02L0oooo000/0?ooo`X000003@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo0080o`00103oool01P3o0000oooo0?ooo`3o0000oooo0?l00080oooo00@0o`00
0?ooo`3oool0o`000P3oool0103o0000oooo0?ooo`3o00020?ooo`050?l0003oool0oooo0?ooo`3o
00000`3oool0103o0000oooo0?ooo`3o00090?ooo`050?l0003oool0o`000?ooo`3o00000P3oool0
103o0000oooo0?ooo`3o00030?ooo`80o`00103oool20?l000<0oooo0P3o00040?ooo`80o`00103o
ool20?l000@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?l000030?ooo`80o`00103o
ool00`3o0000oooo0?ooo`020?ooo`80o`00103oool20?l000X0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`000080oooo0P3o000?0?ooo`80o`002P3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203o
ool00`3o0000oooo0?l000020?ooo`80o`00103oool20?l000<0oooo0P3o00050?ooo`040?l0003o
ool0oooo0?ooo`<0o`002P3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool20?l00080oooo0P3o00000`3oool0o`000?ooo`020?ooo`030?l0
003oool0o`0000@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80o`00
103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P3o00040?ooo`80o`00
0`3oool00`3o0000oooo0?l000030?ooo`80o`000`3oool00`3o0000oooo0?l000030?ooo`80o`00
1@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool20?l000l0oooo0P3o00040?ooo`80o`002P3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0
003oool0oooo0100oooo0`3o00000`3oool0o`000?l0000>0?ooo`80o`001@3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo0P3o00000`3oool0o`000?ooo`0=0?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20?l000<0oooo0P3o00030?ooo`050?l0
003oool0oooo0?ooo`3o00000P3oool20?l000@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020?ooo`80o`003P3oool00`000000oooo0?ooo`0W0?ooo`00;03oool:000000h0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?l000@0oooo0P3o0000103oool0o`00
0?ooo`3o00020?ooo`060?l0003oool0oooo0?l0003oool0o`001P3oool01@3o0000oooo0?ooo`3o
ool0o`000100oooo00D0o`000?ooo`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?l000<0
oooo0P3o00040?ooo`80o`000`3oool20?l000@0oooo0P3o00040?ooo`80o`00103oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0o`0000<0oooo0P3o00040?ooo`030?l0003oool0oooo0080
oooo0P3o00040?ooo`80o`002P3oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool00`3o0000
oooo0?l000040?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0o`000P3oool0103o
0000oooo0?ooo`3o00020?ooo`80o`002P3oool00`3o0000oooo0?ooo`020?ooo`80o`002P3oool0
0`3o0000oooo0?ooo`020?ooo`80o`001@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo0P3o0000103oool0o`000?ooo`3oool20?l000@0oooo0P3o00000`3oool0o`000?oo
o`020?l000D0oooo00D0o`000?ooo`3oool0o`000?ooo`020?l000X0oooo00<0o`000?ooo`3o0000
0`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo0P3o00020?ooo`040?l0
003oool0oooo0?l000<0oooo00<0o`000?ooo`3o0000103oool00`3o0000oooo0?ooo`020?ooo`80
o`00103oool20?l000@0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo0P3o00040?ooo`80
o`000`3oool00`3o0000oooo0?l000030?ooo`80o`000`3oool00`3o0000oooo0?l000030?ooo`80
o`001@3oool00`3o0000oooo0?ooo`020?ooo`80o`00103oool00`3o0000oooo0?ooo`020?ooo`80
o`002`3oool0103o0000oooo0?ooo`3oool20?l000@0oooo0P3o000:0?ooo`030?l0003oool0oooo
01@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0@0?ooo`<0o`0000<0oooo0?l0
003o00003P3oool20?l000D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`80o`0000<0oooo0?l0003oool0303oool20?l000D0oooo00<0o`000?ooo`3oool00P3oool20?l0
00<0oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool20?l000@0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80o`003P3oool00`000000oooo0?ooo`0W
0?ooo`00;03oool:000000l0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00P0oooo1000000:0?ooo`030?l0003oool0oooo0080o`00103oool20?l000040?ooo`3o0000
oooo0?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`3o000K0?ooo`80o`000P3oool0103o0000
oooo0?l0003o00020?ooo`040?l0003oool0oooo0?ooo`80o`00103oool20?l000<0oooo0P3o0004
0?ooo`80o`00103oool30?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`060?l0003o
ool0oooo0?l0003oool0o`00103oool00`3o0000oooo0?ooo`020?ooo`80o`00103oool20?l000D0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool00`3o0000
oooo0?l000040?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0`3o00020?oo
o`030?l0003oool0oooo0080o`002P3oool00`3o0000oooo0?ooo`020?ooo`80o`002@3oool20?l0
00@0oooo0P3o00050?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool20?l0
00040?ooo`3o0000oooo0?ooo`80o`00103oool20?l000030?ooo`3o0000oooo0080o`00103oool2
0?l00080oooo00@0o`000?ooo`3o0000o`002P3oool00`3o0000oooo0?l000020?ooo`80o`00103o
ool00`3o0000oooo0?ooo`020?ooo`80o`000P3oool0103o0000oooo0?ooo`3o00030?ooo`030?l0
003oool0o`0000@0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo0P3o00040?ooo`030?l0
003oool0oooo0080oooo0P3o00040?ooo`80o`00103oool20?l000<0oooo00<0o`000?ooo`3o0000
0`3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0o`0000<0oooo0P3o00050?ooo`030?l0
003oool0oooo0080oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo0P3o00050?ooo`030?l0
003oool0oooo00<0oooo00@0o`000?ooo`3oool0oooo0P3o00040?ooo`80o`002P3oool00`3o0000
oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0@0?ooo`<0o`0000<0oooo0?l0003o00003P3oool20?l000D0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`080?l0003oool0o`000?l0003oool0o`000?ooo`3o
00090?ooo`80o`001@3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o00000`3oool00`3o0000
oooo0?l000020?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0`3o00040?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool20?l000h0oooo00<000000?ooo`3oool09`3oool0
02`0oooo2P00000@0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080o`00103oool20?l000040?ooo`3o0000
oooo0?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`3o000L0?ooo`050?l0003oool0oooo0?l0
003oool00P3o00020?ooo`040?l0003oool0oooo0?ooo`80o`00103oool20?l000<0oooo0P3o0004
0?ooo`80o`00103oool30?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`040?l0003o
ool0oooo0?l00080oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`80o`00103oool20?l000@0
oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo0P3o00030?ooo`030?l0003oool0o`0000@0
oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool30?l00080oooo00<0o`000?oo
o`3oool00P3o000:0?ooo`030?l0003oool0oooo0080oooo0P3o00040?ooo`030?l0003oool0oooo
0080oooo0P3o00040?ooo`80o`001@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo0P3o0000103oool0o`000?ooo`3oool20?l000<0oooo00H0o`000?ooo`3o0000oooo0?l0
003oool20?l000@0oooo0P3o00020?ooo`040?l0003oool0o`000?l000X0oooo0`3o00020?ooo`80
o`00103oool00`3o0000oooo0?ooo`020?ooo`80o`000P3oool0103o0000oooo0?ooo`3o00030?oo
o`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo0P3o00040?oo
o`030?l0003oool0oooo0080oooo0P3o00040?ooo`80o`00103oool20?l000060?ooo`3o0000oooo
0?l0003oool0o`000P3oool0103o0000oooo0?ooo`3o00020?ooo`060?l0003oool0o`000?ooo`3o
0000oooo0P3o00050?ooo`030?l0003oool0oooo0080oooo0P3o00040?ooo`030?l0003oool0oooo
0080oooo0P3o00050?ooo`030?l0003oool0oooo0080oooo0P3o00030?ooo`80o`00103oool20?l0
00X0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`0000D0oooo00<0o`000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`020?ooo`80o`004P3oool60?l000h0oooo0P3o00040?ooo`80o`00103o
ool00`3o0000oooo0?ooo`020?ooo`080?l0003oool0o`000?l0003oool0o`000?ooo`3o00040?oo
o`030?l0003oool0oooo0080oooo0P3o00050?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l0
00030?ooo`030?l0003oool0o`000080oooo00T0o`000?ooo`3oool0oooo0?l0003oool0o`000?oo
o`3o0000103oool00`3o0000oooo0?ooo`020?ooo`80o`00103oool00`3o0000oooo0?l0000=0?oo
o`030000003oool0oooo02L0oooo000f0?ooo`<000003@3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool20?l000@0oooo0`3o00020?oo
o`040?l0003oool0o`000?l00080oooo00<0o`000?ooo`3o00007`3oool0103o0000oooo0?l0003o
00020?ooo`040?l0003oool0oooo0?ooo`80o`00103oool20?l000<0oooo00<0o`000?ooo`3o0000
0`3oool00`3o0000oooo0?l000030?ooo`<0o`000P3oool00`3o0000oooo0?l000020?ooo`040?l0
003oool0oooo0?l00080oooo00@0o`000?ooo`3oool0o`000`3oool00`3o0000oooo0?ooo`020?oo
o`80o`00103oool20?l000@0oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo0P3o00030?oo
o`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
o`0000@0oooo00<0o`000?ooo`3oool00P3o000:0?ooo`030?l0003oool0oooo0080oooo0P3o0004
0?ooo`030?l0003oool0oooo0080oooo0P3o00040?ooo`80o`001@3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo0P3o0000103oool0o`000?ooo`3oool20?l000090?ooo`3o
0000oooo0?l0003oool0o`000?ooo`3o0000oooo0080o`00103oool20?l00080oooo00@0o`000?oo
o`3o0000o`00103oool00`3o0000oooo0?ooo`020?ooo`@0o`000P3oool20?l000@0oooo00<0o`00
0?ooo`3oool00P3oool20?l00080oooo00@0o`000?ooo`3oool0o`000`3oool00`3o0000oooo0?l0
00040?ooo`030?l0003oool0oooo0080oooo0P3o00040?ooo`80o`00103oool00`3o0000oooo0?oo
o`020?ooo`80o`00103oool20?l000<0oooo00X0o`000?ooo`3o0000oooo0?l0003oool0o`000?oo
o`3o0000oooo0P3o00020?ooo`090?l0003oool0oooo0?l0003oool0o`000?ooo`3o0000oooo0080
o`00103oool20?l000@0oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo0P3o00050?ooo`03
0?l0003oool0oooo0080oooo0P3o00030?ooo`80o`000`3oool00`3o0000oooo0?l000050?ooo`03
0?l0003oool0oooo0080oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`0000D0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`020?ooo`80o`004P3oool60?l000h0oooo0P3o0004
0?ooo`80o`000`3oool20?l000<0oooo00<0o`000?ooo`3oool00P3o0000103oool0o`000?ooo`3o
00040?ooo`030?l0003oool0oooo0080oooo0P3o00040?ooo`80o`000`3oool00`3o0000oooo0?l0
00030?ooo`030?l0003oool0o`000080oooo00T0o`000?ooo`3oool0oooo0?l0003oool0o`000?oo
o`3o0000103oool00`3o0000oooo0?ooo`020?ooo`80o`00103oool00`3o0000oooo0?l0000=0?oo
o`030000003oool0oooo02L0oooo000c0?ooo`<000002`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?oo
o`80o`00103oool00`3o0000oooo0?l000030?ooo`<0o`000P3oool00`3o0000oooo0?l0000O0?oo
o`040?l0003oool0o`000?l00080oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`0000<0oooo
0P3o00030?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o00000`3oool30?l00080oooo
00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o00020?ooo`040?l0003oool0oooo0?l0
00<0oooo00<0o`000?ooo`3oool00P3oool20?l000<0oooo00<0o`000?ooo`3o0000103oool20?l0
00@0oooo00<0o`000?ooo`3oool00P3oool20?l000<0oooo0`3o00040?ooo`030?l0003oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`050?l0003oool0o`000?ooo`3o00002P3o
ool00`3o0000oooo0?ooo`020?ooo`80o`00103oool00`3o0000oooo0?ooo`020?ooo`80o`00103o
ool20?l000D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`80o`0000d0
oooo0?l0003oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo00@0o`00103o
ool20?l00080oooo00@0o`000?ooo`3o0000o`00103oool00`3o0000oooo0?ooo`020?ooo`@0o`00
0P3oool20?l000<0oooo0P3o00040?ooo`80o`000P3oool0103o0000oooo0?ooo`3o00030?ooo`03
0?l0003oool0o`0000<0oooo0P3o00040?ooo`80o`000`3oool00`3o0000oooo0?l000040?ooo`03
0?l0003oool0oooo0080oooo0P3o00040?ooo`80o`000`3oool02P3o0000oooo0?l0003oool0o`00
0?ooo`3o0000oooo0?l0003oool20?l00080oooo00T0o`000?ooo`3o0000o`000?ooo`3o0000oooo
0?l0003oool00P3o00040?ooo`80o`00103oool20?l000@0oooo00<0o`000?ooo`3oool00P3oool2
0?l000@0oooo0P3o00040?ooo`80o`000`3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0
o`0000D0oooo00<0o`000?ooo`3oool00P3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o0000
1@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo0P3o000B0?ooo`H0o`00
3P3oool20?l000@0oooo0P3o00030?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool0
0P3o0000103oool0o`000?ooo`3o00040?ooo`030?l0003oool0oooo0080oooo0P3o00040?ooo`80
o`000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`000080oooo00T0o`000?ooo`3o
ool0oooo0?l0003oool0o`000?ooo`3o0000103oool00`3o0000oooo0?ooo`020?ooo`80o`000`3o
ool0103o0000oooo0?ooo`3o000=0?ooo`030000003oool0oooo02L0oooo000`0?ooo`<000003P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
203oool3000000h0oooo0P3o00040?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o0000
0P3oool00`3o0000oooo0?l0000O0?ooo`040?l0003oool0o`000?l00080oooo00L0o`000?ooo`3o
ool0oooo0?l0003oool0o`0000<0oooo0P3o00030?ooo`030?l0003oool0o`0000<0oooo00<0o`00
0?ooo`3o00000`3oool30?l00080oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o
00020?ooo`040?l0003oool0oooo0?l000<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?l000020?ooo`030?l0003oool0o`0000@0oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo
0P3o00030?ooo`<0o`00103oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o
0000103oool01@3o0000oooo0?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool00P3oool20?l0
00@0oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00000`3oool00`3o
0000oooo0?l000030?ooo`80o`00103oool04P3o0000oooo0?ooo`3oool0o`000?ooo`3o0000oooo
0?l0003oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`80o`0000@0oooo0?l0003o0000
o`000P3oool01`3o0000oooo0?l0003oool0o`000?ooo`3o00000P3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo103o00020?ooo`80o`000`3oool20?l000@0oooo0P3o0002
0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool0103o0000oooo0?ooo`3o00020?ooo`80o`00
103oool20?l000<0oooo00<0o`000?ooo`3o0000103oool00`3o0000oooo0?ooo`020?ooo`80o`00
103oool20?l000<0oooo00X0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0P3o
00020?ooo`050?l0003oool0o`000?l0003oool00`3o0000103oool0o`000?ooo`3o00030?ooo`80
o`00103oool20?l000@0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo0P3o00040?ooo`80
o`000`3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0o`0000@0oooo0P3o00040?ooo`07
0?l0003oool0oooo0?ooo`3o0000oooo0?l000050?ooo`030?l0003oool0oooo00P0oooo00<0o`00
0?ooo`3oool00P3oool20?l00140oooo00<0o`000?ooo`3o0000103o000>0?ooo`80o`00103oool2
0?l000<0oooo00<0o`000?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?l000040?ooo`3o0000
oooo0?l000@0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo0P3o00030?ooo`030?l0003o
ool0o`0000<0oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3oool20?l00080oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool0103o0000oooo
0?ooo`3o000=0?ooo`030000003oool0oooo02L0oooo000]0?ooo`<000004P3oool4000000@0oooo
1000000;0?ooo`030000003oool0oooo00h0oooo0P3o00040?ooo`030?l0003oool0o`0000D0oooo
00@0o`000?ooo`3oool0oooo0P3o000O0?ooo`040?l0003oool0o`000?l00080oooo00L0o`000?oo
o`3oool0oooo0?l0003oool0o`0000<0oooo0P3o00030?ooo`030?l0003oool0o`0000<0oooo00<0
o`000?ooo`3o00000`3oool30?l00080oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?oo
o`3o00020?ooo`040?l0003oool0oooo0?l000<0oooo00<0o`000?ooo`3oool00P3oool0103o0000
oooo0?l0003oool20?l000030?ooo`3o0000oooo00<0oooo0P3o00040?ooo`030?l0003oool0oooo
0080oooo0P3o00030?ooo`<0o`00103oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`3o0000103oool01@3o0000oooo0?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool00P3o
ool20?l000@0oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00000`3o
ool00`3o0000oooo0?l000030?ooo`80o`00103oool01@3o0000oooo0?ooo`3oool0o`000080oooo
0P3o00002@3oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`020?l000040?ooo`3o0000
oooo0?l00080oooo00L0o`000?ooo`3o0000oooo0?l0003oool0o`000080oooo00@0o`000?ooo`3o
ool0oooo0P3o00040?ooo`@0o`000P3oool20?l000<0oooo0P3o00040?ooo`80o`000P3oool01@3o
0000oooo0?ooo`3oool0o`000080oooo00@0o`000?ooo`3oool0o`000P3oool00`3o0000oooo0?l0
00020?ooo`<0o`000`3oool00`3o0000oooo0?l000040?ooo`030?l0003oool0oooo0080oooo0P3o
00030?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o00000P3o00001@3oool0o`000?oo
o`3o0000oooo0080o`000P3oool0103o0000oooo0?l0003o00020?ooo`80o`0000@0oooo0?l0003o
ool0o`000`3oool20?l000@0oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo0P3o00040?oo
o`80o`00103oool20?l000<0oooo00<0o`000?ooo`3o00000P3oool00`3o0000oooo0?l000040?oo
o`80o`00103oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o00001@3oool00`3o0000oooo0?oo
o`080?ooo`030?l0003oool0oooo0080oooo0P3o000A0?ooo`050?l0003oool0o`000?l0003oool0
0P3o000>0?ooo`80o`00103oool20?l000<0oooo00<0o`000?ooo`3o00000P3oool00`3o0000oooo
0?ooo`020?l000040?ooo`3o0000oooo0?l000<0oooo0P3o00040?ooo`80o`00103oool00`3o0000
oooo0?l000020?l00080oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`000080oooo00@0o`00
0?ooo`3oool0oooo0P3o00020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?l000d0oooo00<000000?ooo`3oool0
9`3oool002`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo02l0oooo00@0o`000?ooo`3o0000o`000P3oool0103o0000oooo0?ooo`3o00020?ooo`04
0?l0003oool0oooo0?ooo`80o`000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`00
0080oooo00H0o`000?ooo`3o0000o`000?ooo`3o00020?ooo`040?l0003oool0oooo0?l00080oooo
00@0o`000?ooo`3oool0o`000P3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00H0o`000?oo
o`3o0000oooo0?l0003oool20?l00080oooo00@0o`000?ooo`3oool0oooo0P3o00040?ooo`030?l0
003oool0oooo0080oooo0P3o00030?ooo`<0o`00103oool00`3o0000oooo0?ooo`020?ooo`050?l0
003oool0oooo0?ooo`3o00001@3oool20?l000030?ooo`3o0000oooo00<0oooo00<0o`000?ooo`3o
ool00P3oool20?l000070?ooo`3o0000oooo0?ooo`3o0000oooo0?l000030?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000030?ooo`80o`00103oool0
1@3o0000oooo0?ooo`3oool0o`000080oooo0P3o00001`3oool0o`000?ooo`3oool0o`000?ooo`3o
00000P3oool20?l000040?ooo`3o0000oooo0?l00080oooo00L0o`000?ooo`3o0000oooo0?l0003o
ool0o`000080oooo00@0o`000?ooo`3oool0oooo0P3o00040?ooo`080?l0003oool0o`000?l0003o
ool0o`000?ooo`3o00030?ooo`80o`00103oool20?l00080oooo00D0o`000?ooo`3oool0oooo0?l0
00020?ooo`040?l0003oool0oooo0?l00080oooo00@0o`000?ooo`3o0000oooo103o00030?ooo`03
0?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool00P3oool20?l000<0oooo00<0o`000?ooo`3o
00000`3oool00`3o0000oooo0?l000020?l000050?ooo`3o0000oooo0?l0003oool00P3o00020?oo
o`040?l0003oool0o`000?l00080oooo0P3o0000103oool0o`000?ooo`3o00030?ooo`80o`00103o
ool20?l000@0oooo0P3o00030?ooo`80o`00103oool20?l000@0oooo0P3o00001P3oool0o`000?oo
o`3o0000oooo0?l00080oooo00<0o`000?ooo`3o0000103oool20?l000@0oooo00@0o`000?ooo`3o
ool0oooo0`3o00050?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool20?l0
00D0oooo00<0o`000?ooo`3oool02@3oool01@3o0000oooo0?l0003o0000oooo0080o`00103oool0
0`3o0000oooo0?ooo`070?ooo`80o`00103oool20?l000<0oooo00<0o`000?ooo`3o00000P3oool0
0`3o0000oooo0?ooo`020?ooo`80o`0000<0oooo0?l0003oool00P3oool20?l000@0oooo0P3o0003
0?ooo`030?l0003oool0oooo00<0o`000P3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o0000
0P3oool0103o0000oooo0?ooo`3oool20?l00080oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0o`000080oooo00@0o`000?ooo`3oool0o`003@3oool00`00
0000oooo0?ooo`0W0?ooo`00F@3oool00`000000oooo0?ooo`110?ooo`040?l0003oool0o`000?l0
0080oooo00@0o`000?ooo`3oool0o`000P3oool0103o0000oooo0?ooo`3oool20?l000<0oooo00<0
o`000?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`060?l0003oool0o`000?l0003oool0
o`000P3oool0103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0o`0000<0oooo00D0o`000?oo
o`3oool0oooo0?l000020?ooo`060?l0003oool0o`000?ooo`3o0000oooo0P3o00020?ooo`040?l0
003oool0oooo0?ooo`80o`00103oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool30?l000@0
oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000D0oooo0P3o00000`3o
ool0o`000?ooo`020?ooo`80o`00103oool20?l000040?ooo`3o0000oooo0?l00080oooo00D0o`00
0?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0o`000080oooo00@0o`000?ooo`3oool0o`00
0`3oool20?l000<0oooo0P3o00030?ooo`030?l0003oool0oooo0080o`0000L0oooo0?l0003oool0
oooo0?l0003oool0o`0000<0oooo00D0o`000?ooo`3o0000oooo0?l000020?ooo`070?l0003oool0
o`000?ooo`3o0000oooo0?l000030?ooo`030?l0003oool0oooo0080o`00103oool0203o0000oooo
0?l0003o0000oooo0?l0003oool0o`000`3oool00`3o0000oooo0?l000030?ooo`80o`000P3oool0
1@3o0000oooo0?ooo`3oool0o`000080oooo00@0o`000?ooo`3oool0o`000P3oool01P3o0000oooo
0?l0003oool0o`000?ooo`80o`000`3oool00`3o0000oooo0?l000040?ooo`030?l0003oool0oooo
0080oooo0P3o00030?ooo`080?l0003oool0o`000?ooo`3o0000oooo0?l0003oool20?l000060?oo
o`3o0000oooo0?ooo`3o0000oooo0P3o00020?ooo`@0o`000`3oool01@3o0000oooo0?l0003oool0
o`0000<0oooo0P3o00040?ooo`80o`000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0
o`0000<0oooo0P3o00040?ooo`80o`0000H0oooo0?l0003oool0o`000?ooo`3o00020?ooo`030?l0
003oool0o`0000@0oooo0P3o00040?ooo`040?l0003oool0oooo0?ooo`<0o`00103oool20?l000X0
oooo00<0o`000?ooo`3oool00P3oool20?l000D0oooo00<0o`000?ooo`3oool02@3oool0103o0000
oooo0?l0003o00020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool20?l0
00@0oooo0`3o00020?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool00P3oool40?l0
00<0oooo0P3o00040?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool00`3o00020?oo
o`040?l0003oool0oooo0?l00080oooo00@0o`000?ooo`3oool0o`000`3oool20?l00080oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0o`000080oooo00@0
o`000?ooo`3oool0o`003@3oool00`000000oooo0?ooo`0W0?ooo`00;03oool:000002<0oooo0`00
00110?ooo`040?l0003oool0o`000?l00080oooo00@0o`000?ooo`3oool0o`000P3oool0103o0000
oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o0002
0?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool0103o0000oooo0?ooo`3o00020?ooo`030?l0
003oool0o`0000<0oooo00d0o`000?ooo`3oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?oo
o`3o0000oooo0080o`000P3oool0103o0000oooo0?ooo`3oool20?l000@0oooo00L0o`000?ooo`3o
ool0oooo0?l0003oool0o`0000<0oooo00<0o`000?ooo`3o0000103oool00`3o0000oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool20?l000030?ooo`3o0000oooo0080oooo0P3o
00040?ooo`80o`0000@0oooo0?l0003oool0o`000P3oool01@3o0000oooo0?ooo`3oool0o`0000@0
oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o00030?ooo`80o`000`3oool20?l0
00<0oooo00<0o`000?ooo`3oool00`3o00030?ooo`030?l0003oool0o`0000<0oooo00D0o`000?oo
o`3o0000oooo0?l000020?ooo`070?l0003oool0o`000?ooo`3o0000oooo0?l000030?ooo`030?l0
003oool0oooo0080o`00103oool0203o0000oooo0?l0003o0000oooo0?l0003oool0o`000`3oool0
0`3o0000oooo0?l000020?ooo`030?l0003oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l0
00020?ooo`040?l0003oool0oooo0?l00080oooo00H0o`000?ooo`3o0000oooo0?l0003oool20?l0
00<0oooo00<0o`000?ooo`3o0000103oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool00`3o
0000oooo0?ooo`020?l000030?ooo`3o0000oooo0080o`0000@0oooo0?l0003oool0oooo0`3o0003
0?ooo`@0o`000`3oool01@3o0000oooo0?l0003oool0o`0000<0oooo0P3o00040?ooo`80o`000`3o
ool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000<0oooo0P3o00040?ooo`80o`0000H0
oooo0?l0003oool0o`000?ooo`3o00020?ooo`040?l0003oool0oooo0?l000<0oooo0P3o00040?oo
o`040?l0003oool0oooo0?ooo`<0o`00103oool20?l000X0oooo00<0o`000?ooo`3oool00P3oool2
0?l000D0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?l0003o00020?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool01`3oool20?l000@0oooo0`3o00020?ooo`030?l0003o
ool0o`000080oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?l0003o00030?ooo`80o`00
0P3oool01@3o0000oooo0?l0003oool0o`000080oooo00<0o`000?ooo`3oool00`3o00020?ooo`80
o`0000D0oooo0?l0003oool0oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00000P3oool0
103o0000oooo0?ooo`3o000=0?ooo`030000003oool0oooo02L0oooo000]0?ooo`800000:P3oool0
0`000000oooo0?ooo`110?ooo`80o`0000D0oooo0?l0003oool0oooo0?l000020?ooo`040?l0003o
ool0oooo0?l00080oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`040?l0
003oool0oooo0?l00080oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`040?l0003oool0oooo
0?l000<0oooo0P3o00030?ooo`0=0?l0003oool0oooo0?l0003oool0o`000?ooo`3o0000oooo0?l0
003oool0o`000?ooo`020?l00080oooo00@0o`000?ooo`3oool0oooo0P3o00040?ooo`070?l0003o
ool0oooo0?ooo`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo0?l000<0oooo0P3o00040?oo
o`80o`0000@0oooo0?l0003oool0o`000P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0
o`000?ooo`3oool0103o00020?ooo`<0o`0000<0oooo0?l0003o00000`3oool20?l000<0oooo00H0
o`000?ooo`3oool0o`000?ooo`3o00030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
00000P3oool02@3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l000030?ooo`030?l0003o
ool0oooo0080o`00103oool03P3o0000oooo0?l0003o0000oooo0?l0003oool0o`000?ooo`3o0000
oooo0?l0003oool0o`000P3oool00`3o0000oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o
00000P3oool01@3o0000oooo0?ooo`3o0000oooo0080o`0000@0oooo0?l0003oool0o`000P3oool0
1`3o0000oooo0?ooo`3oool0o`000?ooo`3o0000103oool00`3o0000oooo0?ooo`020?ooo`80o`00
0`3oool00`3o0000oooo0?ooo`020?l000070?ooo`3o0000oooo0?ooo`3o0000oooo0?l000020?oo
o`<0o`000`3oool20?l000030?ooo`3o0000oooo0080oooo00D0o`000?ooo`3o0000oooo0?l00003
0?ooo`80o`000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000<0oooo00<0o`00
0?ooo`3o00000`3oool20?l000@0oooo0P3o00001P3oool0o`000?ooo`3o0000oooo0?l00080oooo
00@0o`000?ooo`3oool0o`000`3oool20?l000@0oooo00<0o`000?ooo`3oool0103o00040?ooo`80
o`002@3oool20?l000@0oooo0P3o00050?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3o
0000o`000P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo0P3o00040?oo
o`<0o`000P3oool01@3o0000oooo0?l0003oool0o`0000D0oooo00D0o`000?ooo`3o0000oooo0?l0
00020?ooo`80o`000P3oool01`3o0000oooo0?l0003oool0o`000?ooo`3o00000`3oool30?l00080
oooo0`3o00030?ooo`040?l0003oool0oooo0?l000<0oooo00<0o`000?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o
000=0?ooo`030000003oool0oooo02L0oooo000_0?ooo`800000:03oool00`000000oooo0?ooo`11
0?ooo`80o`0000D0oooo0?l0003oool0oooo0?l000020?ooo`040?l0003oool0oooo0?l00080oooo
00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?l00080
oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`0000<0oooo0?l0003oool00P3oool20?l0
00<0oooo00d0o`000?ooo`3oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo
0080o`000P3oool0103o0000oooo0?ooo`3oool20?l000@0oooo00L0o`000?ooo`3oool0oooo0?l0
003oool0o`0000<0oooo00D0o`000?ooo`3o0000oooo0?l000020?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool02P3oool0103o0000oooo0?ooo`3oool20?l000@0oooo0P3o0000103o
ool0o`000?ooo`3o00020?ooo`090?l0003oool0oooo0?ooo`3o0000oooo0?l0003oool0o`000080
oooo103o00020?ooo`040?l0003oool0o`000?ooo`80o`000`3oool20?l000<0oooo00@0o`000?oo
o`3oool0o`001@3oool00`3o0000oooo0?ooo`050?ooo`050?l0003oool0oooo0?l0003oool00P3o
00020?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3oool00P3o00040?ooo`030?l0003o
ool0o`0000<0o`0000P0oooo0?l0003oool0o`000?ooo`3o0000oooo0?l00080oooo00<0o`000?oo
o`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3oool0o`000?oo
o`020?l000040?ooo`3o0000oooo0?l00080oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`00
00@0oooo00<0o`000?ooo`3oool00P3oool20?l000<0oooo00<0o`000?ooo`3oool00P3o00000`3o
ool0o`000?ooo`030?ooo`030?l0003oool0oooo0080o`00103oool20?l000030?ooo`3o0000oooo
0080oooo00D0o`000?ooo`3o0000oooo0?l000030?ooo`80o`000`3oool00`3o0000oooo0?l00003
0?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o00000`3oool20?l000<0oooo00T0o`00
0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o00030?oo
o`80o`00103oool00`3o0000oooo0?ooo`040?l000@0oooo0P3o00090?ooo`80o`00103oool20?l0
00D0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?l0003o00020?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool01`3oool20?l000@0oooo0`3o00001`3oool0o`000?ooo`3o
ool0o`000?ooo`3o00001@3oool01@3o0000oooo0?l0003oool0o`000080oooo00/0o`000?ooo`3o
0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l000030?ooo`80o`001@3oool01@3o0000oooo
0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`00
00@0oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o000=0?ooo`030000003oool0
oooo02L0oooo000a0?ooo`<000009@3oool00`000000oooo0?ooo`110?ooo`80o`0000<0oooo0?l0
003oool00P3oool30?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`3o00030?ooo`030?l0003o
ool0o`000080oooo00@0o`000?ooo`3oool0o`000P3oool01@3o0000oooo0?ooo`3oool0o`0000<0
oooo0P3o00000`3oool0o`000?ooo`020?ooo`030?l0003oool0oooo0080oooo00h0o`000?ooo`3o
ool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l000<0oooo00@0o`000?oo
o`3oool0oooo0P3o00040?ooo`80o`000P3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0
oooo0?ooo`80o`000P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00@0
o`000?ooo`3oool0oooo0P3o00040?ooo`80o`0000@0oooo0?l0003oool0o`000P3oool02@3o0000
oooo0?ooo`3oool0o`000?ooo`3o0000oooo0?l000020?ooo`040?l0003oool0o`000?l000@0oooo
00@0o`000?ooo`3o0000o`000`3oool20?l000<0oooo00@0o`000?ooo`3oool0o`003@3oool00`3o
0000oooo0?ooo`040?l00080oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?ooo`020?l0
00@0oooo00<0o`000?ooo`3o00000P3o00020?ooo`040?l0003oool0o`000?l00080oooo00H0o`00
0?ooo`3oool0o`000?ooo`3o00020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000
oooo0?ooo`3o0000oooo0080o`0000@0oooo0?l0003oool0o`000P3oool01`3o0000oooo0?ooo`3o
ool0o`000?ooo`3o0000103oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool01@3o0000oooo
0?ooo`3o0000oooo0080o`00103oool00`3o0000oooo0?ooo`020?l000@0oooo0P3o00000`3oool0
o`000?ooo`020?ooo`050?l0003oool0o`000?ooo`3o00000`3oool20?l000<0oooo00<0o`000?oo
o`3o00000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000<0oooo0P3o00030?oo
o`040?l0003oool0o`000?ooo`<0o`0000D0oooo0?l0003oool0oooo0?l000020?ooo`040?l0003o
ool0oooo0?ooo`80o`00103oool00`3o0000oooo0?ooo`040?l000@0oooo0P3o00090?ooo`80o`00
103oool20?l000D0oooo00<0o`000?ooo`3oool0203oool20?l000030?ooo`3o0000o`000080oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`80o`00103oool30?l000040?oo
o`3o0000oooo0?ooo`80o`001P3oool01@3o0000oooo0?l0003oool0o`000080oooo00D0o`000?oo
o`3o0000o`000?ooo`020?l000040?ooo`3o0000oooo0?l000@0oooo00<0o`000?ooo`3oool01`3o
ool0103o0000oooo0?ooo`3o00080?ooo`040?l0003oool0oooo0?ooo`80o`000`3oool00`3o0000
oooo0?l000020?ooo`040?l0003oool0oooo0?l000d0oooo00<000000?ooo`3oool09`3oool003@0
oooo0P00000S0?ooo`<00000@@3oool20?l000030?ooo`3o0000oooo0080oooo0`3o00020?ooo`06
0?l0003oool0oooo0?l0003oool0o`000`3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0
oooo0?l00080oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`80o`0000<0oooo0?l0003oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`80o`0000`0oooo0?l0003oool0o`000?ooo`3o0000oooo
0?l0003oool0o`000?ooo`3o00030?ooo`040?l0003oool0oooo0?ooo`80o`00103oool20?l00080
oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3oool20?l00080oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo0?ooo`80o`00103oool2
0?l000040?ooo`3o0000oooo0?l00080oooo00T0o`000?ooo`3oool0oooo0?l0003oool0o`000?oo
o`3o00000P3oool0103o0000oooo0?l0003o00040?ooo`040?l0003oool0o`000?l000<0oooo0P3o
00030?ooo`040?l0003oool0oooo0?l00100oooo103o00020?ooo`80o`00103oool00`3o0000oooo
0?ooo`020?l000@0oooo00<0o`000?ooo`3o00000P3o00020?ooo`@0o`000P3oool01P3o0000oooo
0?ooo`3o0000oooo0?l00080oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0
oooo0?l0003oool00P3o0000103oool0o`000?ooo`3o00020?ooo`070?l0003oool0oooo0?ooo`3o
0000oooo0?l000040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00000P3oool01@3o
0000oooo0?ooo`3o0000oooo0080o`00203oool00`3o0000oooo0?ooo`020?ooo`80o`0000<0oooo
0?l0003oool00P3oool01@3o0000oooo0?l0003oool0o`0000<0oooo0P3o00030?ooo`030?l0003o
ool0o`0000<0oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000030?ooo`030?l0003o
ool0o`000080oooo00@0o`000?ooo`3o0000oooo0`3o00001@3oool0o`000?l0003oool0o`000080
oooo00H0o`000?ooo`3oool0o`000?ooo`3o00040?ooo`030?l0003oool0oooo00@0o`00103oool2
0?l000T0oooo0P3o00040?ooo`80o`001@3oool00`3o0000oooo0?ooo`080?ooo`80o`0000<0oooo
0?l0003o00000P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo0P3o0003
0?ooo`060?l0003oool0o`000?l0003oool0o`000P3oool20?l000H0oooo00D0o`000?ooo`3o0000
oooo0?l000020?ooo`050?l0003oool0o`000?l0003oool00P3o0000103oool0o`000?ooo`3o000>
0?ooo`040?l0003oool0oooo0?l000P0oooo00@0o`000?ooo`3oool0oooo0P3o00030?ooo`030?l0
003oool0o`000080oooo00@0o`000?ooo`3oool0o`003@3oool00`000000oooo0?ooo`0W0?ooo`00
<@3oool3000002D0oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`030?ooo`<0o`00
0P3oool01P3o0000oooo0?ooo`3o0000oooo0?l000<0oooo00<0o`000?ooo`3o00000P3oool0103o
0000oooo0?ooo`3o00020?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool20?l000030?ooo`3o
0000oooo0080oooo00<0o`000?ooo`3oool00P3oool20?l000030?ooo`3o0000oooo00<0o`0000H0
oooo0?l0003oool0o`000?ooo`3o00030?ooo`060?l0003oool0oooo0?l0003oool0o`00103oool2
0?l00080oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3oool20?l000030?ooo`3o
0000o`0000@0oooo00<0o`000?ooo`3oool02P3oool0103o0000oooo0?ooo`3oool20?l000@0oooo
0P3o0000103oool0o`000?ooo`3o00020?ooo`090?l0003oool0oooo0?ooo`3o0000oooo0?l0003o
ool0o`0000@0oooo0P3o00040?ooo`040?l0003oool0o`000?l000<0oooo00<0o`000?ooo`3o0000
0P3oool0103o0000oooo0?ooo`3o000@0?ooo`@0o`000P3oool20?l000@0oooo00<0o`000?ooo`3o
ool00P3o00040?ooo`030?l0003oool0oooo0080o`000P3oool40?l00080oooo00H0o`000?ooo`3o
ool0o`000?ooo`3o00020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?oo
o`3o0000oooo0080o`0000@0oooo0?l0003oool0o`000`3oool01P3o0000oooo0?ooo`3o0000oooo
0?l000<0oooo0P3o00040?ooo`030?l0003oool0o`000080oooo00D0o`000?ooo`3oool0o`000?oo
o`020?l000P0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3o00040?ooo`80o`00
00<0oooo0?l0003oool00P3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0o`0000<0oooo
00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`000080oooo
00H0o`000?ooo`3o0000o`000?ooo`3o00020?ooo`80o`0000D0oooo0?l0003oool0oooo0?l00002
0?ooo`040?l0003oool0oooo0?l000<0oooo00<0o`000?ooo`3oool0103o00040?ooo`80o`002@3o
ool20?l000@0oooo0P3o00040?ooo`80o`002P3oool20?l000030?ooo`3o0000o`000080oooo0P3o
00030?ooo`030?l0003oool0oooo00L0oooo0P3o00030?ooo`030?l0003oool0o`0000<0o`000P3o
ool00`3o0000oooo0?ooo`050?ooo`050?l0003oool0o`000?ooo`3o00000P3oool01@3o0000oooo
0?l0003o0000oooo0080o`0000@0oooo0?l0003oool0o`003P3oool0103o0000oooo0?ooo`3o0008
0?ooo`060?l0003oool0oooo0?l0003oool0o`000`3oool01@3o0000oooo0?l0003oool0o`000140
oooo00<000000?ooo`3oool09`3oool002l0oooo0P00000X0?ooo`030000003oool0oooo0480oooo
00<0o`000?ooo`3oool00`3oool30?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`3o00030?oo
o`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool00`3o00040?ooo`040?l0003oool0oooo
0?ooo`80o`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0
o`000?l0003oool00`3o00001P3oool0o`000?ooo`3o0000oooo0?l000<0oooo00H0o`000?ooo`3o
ool0o`000?ooo`3o00040?ooo`80o`000P3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0
oooo0?ooo`D0o`00103oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo0?ooo`80o`00
103oool20?l000040?ooo`3o0000oooo0?l00080oooo00H0o`000?ooo`3oool0oooo0?l0003oool3
0?l000@0oooo0P3o00050?ooo`<0o`000`3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0
oooo0140oooo0P3o0000103oool0o`000?ooo`3oool20?l000@0oooo00<0o`000?ooo`3oool00P3o
00040?ooo`030?l0003oool0oooo0080o`000P3oool20?l000050?ooo`3o0000oooo0?ooo`3o0000
0P3oool00`3o0000oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000
oooo0?ooo`3o0000oooo0080o`0000@0oooo0?l0003oool0o`000`3oool01P3o0000oooo0?ooo`3o
0000oooo0?l000<0oooo0P3o00040?ooo`030?l0003oool0o`000080oooo00H0o`000?ooo`3oool0
o`000?ooo`3o000>0?ooo`040?l0003oool0oooo0?l000@0oooo0P3o00000`3oool0o`000?ooo`02
0?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l00003
0?ooo`030?l0003oool0o`000080oooo00@0o`000?ooo`3oool0o`000P3oool01P3o0000oooo0?l0
003o0000oooo0?l000@0oooo0P3o00020?ooo`040?l0003oool0oooo0?l00080oooo00<0o`000?oo
o`3oool00P3o00020?ooo`@0o`00103oool20?l000T0oooo0P3o00040?ooo`80o`00103oool20?l0
00X0oooo0P3o00000`3oool0o`000?l000020?ooo`80o`000P3oool20?l000T0oooo0P3o00030?oo
o`030?l0003oool0o`0000<0o`002P3oool0103o0000oooo0?ooo`3oool20?l000030?ooo`3o0000
oooo0080o`0000L0oooo0?l0003o0000oooo0?l0003oool0o`0000l0oooo00<0o`000?ooo`3o0000
203oool01P3o0000oooo0?ooo`3o0000oooo0?l000<0oooo00D0o`000?ooo`3o0000oooo0?l0000A
0?ooo`030000003oool0oooo02L0oooo000]0?ooo`800000:P3oool00`000000oooo0?ooo`120?oo
o`030?l0003oool0oooo00<0oooo0`3o00020?ooo`060?l0003oool0oooo0?l0003oool0o`000`3o
ool00`3o0000oooo0?l000020?ooo`030?l0003oool0oooo00<0o`00203oool20?l000030?ooo`3o
0000oooo0080oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o0000oooo00<0o`00
00H0oooo0?l0003oool0o`000?ooo`3o00030?ooo`060?l0003oool0oooo0?l0003oool0o`000`3o
ool00`3o0000oooo0?l000020?ooo`060?l0003oool0oooo0?l0003oool0o`000`3oool50?l000@0
oooo00<0o`000?ooo`3oool02P3oool0103o0000oooo0?ooo`3oool20?l000@0oooo0P3o0000103o
ool0o`000?l0003o00020?ooo`040?l0003oool0oooo0?ooo`@0o`001@3oool20?l000D0oooo00<0
o`000?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0oooo0140oooo0P3o
00040?ooo`80o`00103oool00`3o0000oooo0?ooo`020?l000@0oooo00<0o`000?ooo`3oool00P3o
00020?ooo`80o`0000D0oooo0?l0003oool0oooo0?l000020?ooo`030?l0003oool0o`000080oooo
00D0o`000?ooo`3oool0oooo0?l000020?ooo`060?l0003oool0oooo0?l0003oool0o`000P3oool0
0`3o0000oooo0?l000030?ooo`030?l0003oool0o`000080oooo00@0o`000?ooo`3oool0oooo0P3o
00040?ooo`030?l0003oool0o`000080oooo00@0o`000?ooo`3oool0o`00403oool00`3o0000oooo
0?ooo`050?ooo`80o`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?l000020?ooo`030?l0
003oool0o`0000<0oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`040?l0
003oool0oooo0?l00080oooo00H0o`000?ooo`3o0000o`000?ooo`3o00040?ooo`80o`000P3oool0
103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0oooo0080o`000P3oool20?l000030?ooo`3o
0000oooo00<0oooo0P3o00090?ooo`80o`000`3oool00`3o0000oooo0?l000040?ooo`80o`00103o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080o`000P3oool20?l00080oooo0P3o
00090?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3o00000P3o000;0?ooo`040?l0003o
ool0oooo0?ooo`80o`0000<0oooo0?l0003oool00P3o00001`3oool0o`000?l0003oool0o`000?oo
o`3o00003`3oool00`3o0000oooo0?l000080?ooo`060?l0003oool0oooo0?l0003oool0o`000`3o
ool01@3o0000oooo0?l0003oool0o`000140oooo00<000000?ooo`3oool09`3oool002`0oooo2P00
000<0?ooo`@00000103oool4000000/0oooo0`0000120?ooo`030?l0003oool0oooo00@0oooo0P3o
00020?ooo`060?l0003oool0oooo0?l0003oool0o`000`3oool01P3o0000oooo0?ooo`3o0000oooo
0?l000<0oooo0P3o00080?ooo`80o`0000<0oooo0?l0003oool01`3oool00`3o0000oooo0?ooo`02
0?ooo`<0o`0000H0oooo0?l0003oool0o`000?ooo`3o00030?ooo`060?l0003oool0oooo0?l0003o
ool0o`000`3oool00`3o0000oooo0?l000020?ooo`060?l0003oool0oooo0?l0003oool0o`000`3o
ool50?l000@0oooo00<0o`000?ooo`3oool02P3oool0103o0000oooo0?ooo`3oool20?l000@0oooo
0P3o0000103oool0o`000?l0003o00020?ooo`040?l0003oool0oooo0?ooo`@0o`001@3oool20?l0
00D0oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0oooo
0140oooo0P3o00040?ooo`80o`00103oool00`3o0000oooo0?ooo`020?l000@0oooo00<0o`000?oo
o`3oool00P3o00020?ooo`80o`0000D0oooo0?l0003oool0oooo0?l000020?ooo`060?l0003oool0
oooo0?l0003oool0o`000`3oool0103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0o`000080
oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?oo
o`80o`00103oool0103o0000oooo0?l0003oool20?l00080oooo00<0o`000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`050?ooo`80o`0000D0oooo0?l0003oool0oooo0?l000020?ooo`060?l0003o
ool0oooo0?l0003oool0o`000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`000080
oooo00@0o`000?ooo`3oool0o`000P3oool0103o0000oooo0?l0003o00060?ooo`80o`000P3oool0
103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0oooo0080o`000P3oool20?l000030?ooo`3o
0000oooo00<0oooo0P3o00050?ooo`040?l0003oool0oooo0?ooo`80o`000`3oool00`3o0000oooo
0?l000040?ooo`80o`00103oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo0?l000@0
oooo00<0o`000?ooo`3oool00P3o00090?ooo`030?l0003oool0o`000080oooo00D0o`000?ooo`3o
0000oooo0?l0000;0?ooo`040?l0003oool0oooo0?ooo`<0o`000P3oool00`3o0000oooo0?ooo`02
0?l000040?ooo`3o0000oooo0?l00100oooo00<0o`000?ooo`3oool01`3oool01P3o0000oooo0?oo
o`3o0000oooo0?l000<0oooo00D0o`000?ooo`3o0000oooo0?l0000A0?ooo`030000003oool0oooo
02L0oooo00110?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3oool0103oool20?l0
0080oooo00H0o`000?ooo`3oool0o`000?ooo`3o00030?ooo`060?l0003oool0oooo0?l0003oool0
o`003@3oool20?l000030?ooo`3o0000oooo00L0oooo00<0o`000?ooo`3oool00P3oool30?l00006
0?ooo`3o0000oooo0?l0003oool0o`000`3oool20?l000040?ooo`3o0000oooo0?l000<0oooo00<0
o`000?ooo`3o00000P3oool01P3o0000oooo0?ooo`3o0000oooo0?l000<0oooo00<0o`000?ooo`3o
00000P3o00030?ooo`030?l0003oool0oooo00/0oooo00@0o`000?ooo`3oool0oooo0P3o00040?oo
o`80o`0000@0oooo0?l0003o0000o`000P3oool0103o0000oooo0?l0003oool30?l000H0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`000080oooo00<0
o`000?ooo`3oool04@3oool20?l000@0oooo0P3o00040?ooo`030?l0003oool0oooo0080o`00103o
ool00`3o0000oooo0?ooo`020?l00080oooo0P3o00001@3oool0o`000?ooo`3oool0o`000080oooo
00H0o`000?ooo`3oool0o`000?ooo`3o00030?ooo`030?l0003oool0o`0000<0oooo00<0o`000?oo
o`3o00000P3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`000080oooo00@0o`000?oo
o`3oool0oooo0P3o00040?ooo`050?l0003oool0o`000?ooo`3o00000`3oool00`3o0000oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00D0oooo0P3o00001@3oool0o`000?ooo`3oool0o`000080oooo
00@0o`000?ooo`3oool0o`000P3oool30?l00080oooo00L0o`000?ooo`3oool0oooo0?l0003oool0
o`000080oooo00D0o`000?ooo`3oool0o`000?ooo`020?l000030?ooo`3o0000o`0000H0oooo0P3o
00020?ooo`040?l0003oool0oooo0?l00080oooo00<0o`000?ooo`3oool00P3o00020?ooo`80o`00
0P3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o0000103oool0103o0000oooo0?ooo`3oool2
0?l000<0oooo00<0o`000?ooo`3o0000103oool20?l000@0oooo00<0o`000?ooo`3oool00`3oool0
103o0000oooo0?ooo`3o00040?ooo`030?l0003oool0oooo0080o`00203oool0103o0000oooo0?oo
o`3o00020?ooo`050?l0003oool0o`000?ooo`3o0000403oool20?l00080oooo00<0o`000?ooo`3o
ool00P3o00000`3oool0o`000?l0000A0?ooo`030?l0003oool0oooo00L0oooo00H0o`000?ooo`3o
ool0o`000?ooo`3o00030?ooo`050?l0003oool0o`000?ooo`3o00004@3oool00`000000oooo0?oo
o`0W0?ooo`00@@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`190?ooo`050?l0003oool0oooo0?ooo`3o0000
0P3oool00`3o0000oooo0?l000030?ooo`040?l0003oool0oooo0?ooo`80o`003P3oool00`3o0000
oooo0?l0000=0?ooo`<0o`0000H0oooo0?l0003oool0o`000?ooo`3o00030?ooo`80o`0000@0oooo
0?l0003oool0o`000`3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0oooo00<0o`000`3o
ool01P3o0000oooo0?l0003o0000oooo0?l00080oooo00<0o`000?ooo`3oool02`3oool0103o0000
oooo0?ooo`3oool20?l000@0oooo00<0o`000?ooo`3o00000`3o00020?ooo`040?l0003oool0o`00
0?ooo`<0o`001P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0o`0000<0oooo00<0o`00
0?ooo`3o00000P3oool00`3o0000oooo0?ooo`0A0?ooo`80o`00103oool20?l000@0oooo00<0o`00
0?ooo`3oool00P3o00040?ooo`030?l0003oool0oooo0080o`000P3oool20?l000050?ooo`3o0000
oooo0?ooo`3o00000P3oool01P3o0000oooo0?ooo`3o0000oooo0?l000<0oooo00<0o`000?ooo`3o
00000`3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o
00000P3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o00000`3oool01@3o0000oooo0?l0003o
ool0o`0000<0oooo00<0o`000?ooo`3oool05P3oool20?l000050?ooo`3o0000oooo0?ooo`3o0000
0P3oool0103o0000oooo0?ooo`3o00020?ooo`<0o`000P3oool01`3o0000oooo0?ooo`3oool0o`00
0?ooo`3o00000P3oool01P3o0000oooo0?ooo`3o0000oooo0?l00080oooo0P3o00060?ooo`80o`00
0`3oool30?l00080oooo00<0o`000?ooo`3oool00P3o00020?ooo`80o`000P3oool01`3o0000oooo
0?ooo`3oool0o`000?ooo`3o0000103oool0103o0000oooo0?ooo`3oool20?l000<0oooo00<0o`00
0?ooo`3o0000103oool20?l000@0oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`3o
00040?ooo`030?l0003oool0oooo0080o`00203oool0103o0000oooo0?ooo`3o00020?ooo`050?l0
003oool0o`000?ooo`3o0000403oool20?l000D0oooo0P3o00020?ooo`030?l0003oool0oooo01T0
oooo0P3o0000103oool0o`000?ooo`3o00030?ooo`050?l0003oool0o`000?ooo`3o00004@3oool0
0`000000oooo0?ooo`0W0?ooo`00;03oool2000001P0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo04T0oooo00@0o`000?ooo`3oool0oooo0P3o
0000103oool0o`000?ooo`3o00030?ooo`040?l0003oool0oooo0?ooo`80o`003`3oool20?l000d0
oooo0`3o00001P3oool0o`000?ooo`3o0000oooo0?l000<0oooo0P3o0000103oool0o`000?ooo`3o
00030?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool00`3o00030?ooo`060?l0003o
ool0o`000?l0003oool0o`000P3oool00`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?l0
0080oooo00H0o`000?ooo`3oool0oooo0?l0003oool30?l000<0oooo0`3o00000`3oool0o`000?l0
00070?ooo`030?l0003oool0oooo00H0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`000080
oooo00<0o`000?ooo`3oool04@3oool20?l000@0oooo0P3o00040?ooo`030?l0003oool0oooo0080
o`000P3oool00`3o0000oooo0?l000020?ooo`80o`000P3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0o`0000<0oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000030?ooo`03
0?l0003oool0o`000080oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`07
0?l0003oool0oooo0?ooo`3o0000oooo0?l000030?ooo`050?l0003oool0o`000?ooo`3o00000`3o
ool00`3o0000oooo0?ooo`0F0?ooo`80o`0000D0oooo0?l0003oool0oooo0?l000020?ooo`040?l0
003oool0oooo0?l00080oooo00<0o`000?ooo`3o00000`3oool01P3o0000oooo0?ooo`3o0000oooo
0?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`3o00020?ooo`80o`001P3oool20?l000<0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?l00080oooo0P3o00020?ooo`070?l0
003oool0oooo0?ooo`3o0000oooo0?l000040?ooo`040?l0003oool0oooo0?ooo`80o`000`3oool0
0`3o0000oooo0?l000040?ooo`80o`00103oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0
oooo0?l000@0oooo00<0o`000?ooo`3oool00P3o00080?ooo`040?l0003oool0oooo0?l00080oooo
00<0o`000?ooo`3o00004P3oool20?l000D0oooo0P3o00020?ooo`030?l0003oool0oooo01T0oooo
0P3o0000103oool0o`000?ooo`3o00030?ooo`050?l0003oool0o`000?ooo`3o00004@3oool00`00
0000oooo0?ooo`0W0?ooo`00;P3oool3000001D0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`080?ooo`@00000B03oool0103o0000oooo0?ooo`3oool20?l000040?ooo`3o0000
oooo0?l000<0oooo00@0o`000?ooo`3oool0oooo0P3o000?0?ooo`80o`003@3oool30?l000050?oo
o`3o0000oooo0?ooo`3o0000103oool20?l000030?ooo`3o0000oooo0080o`000P3oool00`3o0000
oooo0?l000020?ooo`030?l0003oool0oooo00<0o`000`3oool01P3o0000oooo0?l0003o0000oooo
0?l00080oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?l000020?ooo`060?l0003oool0
oooo0?ooo`3o0000oooo0`3o00030?ooo`@0o`0000<0oooo0?l0003oool01P3oool00`3o0000oooo
0?ooo`060?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l000020?ooo`030?l0003oool0oooo
0140oooo00<0o`000?ooo`3oool00`3oool20?l000@0oooo00<0o`000?ooo`3oool00P3o00020?oo
o`030?l0003oool0o`000080oooo0P3o00020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3o00000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000<0oooo00<0o`000?oo
o`3o00000`3oool20?l000<0oooo00<0o`000?ooo`3o00000P3oool01`3o0000oooo0?ooo`3oool0
o`000?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?l000@0oooo00<0o`000?ooo`3oool05P3o
ool20?l000030?ooo`3o0000oooo0080o`000P3oool00`3o0000oooo0?l000030?ooo`030?l0003o
ool0o`0000<0oooo00H0o`000?ooo`3o0000o`000?ooo`3o00020?ooo`060?l0003oool0oooo0?l0
003oool0o`000P3oool20?l000L0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`030?l0003o
ool0oooo0080o`000P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3o0000
103oool0103o0000oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3o0000103oool20?l000@0
oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0o`000?oo
o`3oool00P3o00080?ooo`040?l0003oool0oooo0?l00080oooo00<0o`000?ooo`3o00004`3oool0
0`3o0000oooo0?ooo`030?ooo`80o`007P3oool20?l000040?ooo`3o0000oooo0?l000<0oooo00D0
o`000?ooo`3o0000oooo0?l0000A0?ooo`030000003oool0oooo02L0oooo000a0?ooo`<000003`3o
ool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo04d0oooo00@0o`000?ooo`3o0000o`000P3oool0103o0000oooo0?ooo`3o00030?ooo`80
o`003`3oool20?l000d0oooo0`3o00000`3oool0o`000?ooo`060?ooo`80o`0000<0oooo0?l0003o
ool00P3o00020?ooo`060?l0003oool0o`000?l0003oool0o`000P3oool30?l000<0oooo00H0o`00
0?ooo`3oool0o`000?ooo`3o00020?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3o0000
0P3oool0103o0000oooo0?ooo`3o00020?ooo`<0o`000`3oool40?l000030?ooo`3o0000oooo00H0
oooo00<0o`000?ooo`3oool01P3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o00000P3oool0
0`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool00P3o0002
0?ooo`030?l0003oool0o`000080oooo0P3o00020?ooo`030?l0003oool0oooo00<0oooo0`3o0003
0?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l00003
0?ooo`80o`000`3oool00`3o0000oooo0?l000020?ooo`070?l0003oool0oooo0?ooo`3o0000oooo
0?l000020?ooo`030?l0003oool0oooo0080o`00103oool00`3o0000oooo0?ooo`0F0?ooo`80o`00
00<0oooo0?l0003oool00P3o00020?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3oool0
0`3oool01`3o0000oooo0?l0003o0000oooo0?l0003oool00P3o00020?ooo`030?l0003oool0o`00
0080oooo0P3o00070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3o00020?oo
o`050?l0003oool0oooo0?ooo`3o00000`3oool00`3o0000oooo0?l000040?ooo`040?l0003oool0
oooo0?ooo`80o`000`3oool00`3o0000oooo0?l000040?ooo`80o`00103oool00`3o0000oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`020?l000@0oooo
00D0o`000?ooo`3oool0oooo0?l000020?ooo`060?l0003oool0oooo0?l0003oool0o`004`3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01`0oooo0P3o0000103oool0o`000?ooo`3o
00030?ooo`050?l0003oool0o`000?ooo`3o00004@3oool00`000000oooo0?ooo`0W0?ooo`00=03o
ool200000100oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo04d0oooo00@0o`000?ooo`3o0000o`000P3oool0103o0000oooo0?ooo`3o00030?oo
o`80o`003`3oool20?l000d0oooo0`3o00000`3oool0o`000?ooo`060?ooo`80o`0000<0oooo0?l0
003oool00P3o0000103oool0o`000?ooo`3oool20?l000040?ooo`3o0000oooo0?ooo`<0o`000`3o
ool01P3o0000oooo0?ooo`3o0000oooo0?l00080oooo00<0o`000?ooo`3oool03@3oool20?l00080
oooo00@0o`000?ooo`3oool0o`000P3oool30?l000<0oooo103o00000`3oool0o`000?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`000080oooo00<0
o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0080o`000P3o
ool20?l000<0oooo0P3o00020?ooo`030?l0003oool0oooo00<0oooo0`3o00030?ooo`030?l0003o
ool0o`0000@0oooo0P3o00030?ooo`030?l0003oool0o`0000<0oooo0P3o00030?ooo`030?l0003o
ool0o`000080oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`000080oooo00<0o`000?ooo`3o
ool00P3o00040?ooo`030?l0003oool0oooo01H0oooo0P3o00000`3oool0o`000?ooo`020?l00080
oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0o`000?l0
0080oooo0`3o00020?ooo`80o`000`3oool20?l000L0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`020?l00080oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0
o`0000@0oooo00@0o`000?ooo`3oool0oooo0P3o00030?ooo`030?l0003oool0o`0000@0oooo0P3o
00040?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`030?l0
003oool0oooo0080o`00103oool01@3o0000oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3o
00000P3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0703oool20?l000040?ooo`3o0000oooo0?l000<0oooo00<0o`000?ooo`3oool00P3o000A0?oo
o`030000003oool0oooo02L0oooo000a0?ooo`<000003@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1@0?oo
o`040?l0003oool0oooo0?l00080oooo00@0o`000?ooo`3oool0oooo0P3o000?0?ooo`030?l0003o
ool0oooo00`0oooo00@0o`000?ooo`3o0000o`002@3oool30?l000030?ooo`3o0000oooo0080o`00
0P3oool40?l00080oooo0`3o00030?ooo`060?l0003oool0oooo0?l0003oool0o`000P3oool00`3o
0000oooo0?ooo`0=0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`02
0?l000@0oooo00H0o`000?ooo`3o0000o`000?ooo`3o000@0?ooo`090?l0003oool0oooo0?ooo`3o
0000oooo0?l0003oool0o`0001@0oooo00<0o`000?ooo`3oool02@3oool20?l000030?ooo`3o0000
o`000080oooo0P3o00030?ooo`80o`000P3oool00`3o0000oooo0?ooo`040?ooo`80o`000`3oool0
0`3o0000oooo0?l000040?ooo`80o`000`3oool20?l000@0oooo0P3o00030?ooo`<0o`000P3oool0
1`3o0000oooo0?ooo`3oool0o`000?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?l000@0oooo
00<0o`000?ooo`3oool05P3oool20?l000030?ooo`3o0000oooo0080o`000P3oool00`3o0000oooo
0?l000030?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3o0000o`000P3oool20?l000<0
oooo0P3o00030?ooo`80o`001`3oool00`3o0000oooo0?ooo`060?ooo`080?l0003oool0oooo0?l0
003oool0o`000?ooo`3o00030?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l000040?ooo`04
0?l0003oool0oooo0?ooo`80o`000`3oool00`3o0000oooo0?l000040?ooo`80o`00103oool00`3o
0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`02
0?l000@0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0o`000080oooo00<0
o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01`0oooo0P3o
0000103oool0o`000?ooo`3o00020?ooo`040?l0003oool0oooo0?ooo`80o`004@3oool00`000000
oooo0?ooo`0W0?ooo`00;@3oool400000100oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00P0oooo0`00001D0?ooo`030?l0003oool0o`0000<0
oooo0P3o000?0?ooo`030?l0003oool0oooo00`0oooo00@0o`000?ooo`3oool0o`002@3oool01P3o
0000oooo0?ooo`3oool0o`000?ooo`80o`000P3oool40?l00080oooo0`3o00080?ooo`040?l0003o
ool0oooo0?l001<0oooo00@0o`000?ooo`3oool0o`000P3oool20?l000@0oooo00H0o`000?ooo`3o
0000o`000?ooo`3o000@0?ooo`090?l0003oool0oooo0?ooo`3o0000oooo0?l0003oool0o`000200
oooo0P3o00000`3oool0o`000?l000020?ooo`80o`000`3oool20?l000X0oooo00L0o`000?ooo`3o
ool0oooo0?l0003oool0o`0000@0oooo0P3o00030?ooo`80o`00103oool20?l000<0oooo0`3o0002
0?ooo`070?l0003oool0o`000?ooo`3o0000oooo0?l000020?ooo`030?l0003oool0oooo0080o`00
103oool00`3o0000oooo0?ooo`0G0?ooo`040?l0003oool0o`000?ooo`80o`000P3oool30?l000<0
oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?l0003o00070?ooo`80o`000`3oool20?l0
00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?l000020?ooo`80o`00103oool0103o
0000oooo0?ooo`3o00020?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0P3o
00030?ooo`030?l0003oool0o`0000@0oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0oooo0080o`00103oool01@3o0000oooo
0?ooo`3oool0o`000080oooo0`3o00020?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3o
ool0703oool01P3o0000oooo0?l0003o0000oooo0?l00080oooo00@0o`000?ooo`3oool0oooo0P3o
000A0?ooo`030000003oool0oooo02L0oooo000/0?ooo`030000003oool0oooo01<0oooo10000004
0?ooo`@000002`3oool00`000000oooo0?ooo`1D0?ooo`030?l0003oool0o`0000<0oooo0P3o000?
0?ooo`030?l0003oool0oooo00`0oooo00@0o`000?ooo`3oool0o`003`3oool20?l00080oooo00@0
o`000?ooo`3o0000o`000P3oool30?l000P0oooo00@0o`000?ooo`3oool0o`004`3oool0103o0000
oooo0?ooo`3o00020?ooo`80o`00103oool01P3o0000oooo0?ooo`3o0000oooo0?l00100oooo00T0
o`000?ooo`3oool0oooo0?l0003oool0o`000?ooo`3o0000803oool20?l000030?ooo`3o0000o`00
0080oooo0P3o00030?ooo`80o`002P3oool0103o0000oooo0?ooo`3oool20?l000D0oooo0P3o0003
0?ooo`80o`00103oool20?l000<0oooo0`3o00020?ooo`070?l0003oool0o`000?ooo`3o0000oooo
0?l000020?ooo`030?l0003oool0oooo0080o`00103oool00`3o0000oooo0?ooo`0I0?ooo`040?l0
003oool0o`000?l00080oooo0`3o00030?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3o
0000o`00203oool0103o0000oooo0?ooo`3oool20?l00100oooo00<0o`000?ooo`3o00000P3oool2
0?l000@0oooo00@0o`000?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`020?ooo`040?l0003o
ool0oooo0?ooo`80o`000`3oool00`3o0000oooo0?l000040?ooo`80o`00103oool00`3o0000oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`020?l000@0
oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`80o`007P3oool00`3o0000oooo0?ooo`0L0?oo
o`030?l0003oool0o`000080oooo00@0o`000?ooo`3oool0o`000`3oool20?l00140oooo00<00000
0?ooo`3oool09`3oool002d0oooo1000000X0?ooo`030000003oool0oooo05@0oooo00<0o`000?oo
o`3o00000`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo00@0o`000?oo
o`3oool0o`00403oool01@3o0000oooo0?ooo`3o0000oooo0080o`000P3oool30?l000P0oooo00@0
o`000?ooo`3oool0o`004`3oool0103o0000oooo0?ooo`3o00020?ooo`80o`001`3oool00`3o0000
oooo0?l0000@0?ooo`090?l0003oool0oooo0?ooo`3o0000oooo0?l0003oool0o`000200oooo0P3o
0000103oool0o`000?l0003oool30?l000<0oooo00<0o`000?ooo`3oool03@3oool20?l000D0oooo
0P3o00030?ooo`80o`00103oool20?l000<0oooo0P3o00030?ooo`070?l0003oool0o`000?ooo`3o
0000oooo0?l000020?ooo`030?l0003oool0oooo0080o`00103oool00`3o0000oooo0?ooo`0I0?oo
o`040?l0003oool0o`000?l00080oooo0`3o00030?ooo`030?l0003oool0oooo00@0oooo0`3o0008
0?ooo`040?l0003oool0oooo0?ooo`80o`00403oool00`3o0000oooo0?l000020?ooo`80o`00103o
ool20?l000050?ooo`3o0000oooo0?ooo`3o00000`3oool20?l000<0oooo00<0o`000?ooo`3o0000
0P3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`3oool00P3o00040?ooo`05
0?l0003oool0oooo0?ooo`3o00000P3oool20?l001h0oooo00<0o`000?ooo`3oool0703oool00`3o
0000oooo0?l000020?ooo`040?l0003oool0oooo0?l000<0oooo0P3o000A0?ooo`030000003oool0
oooo02L0oooo000a0?ooo`<000009@3oool00`000000oooo0?ooo`1D0?ooo`80o`00103oool00`3o
0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool04@3oool0103o
0000oooo0?l0003o00020?ooo`<0o`00203oool0103o0000oooo0?ooo`3o000C0?ooo`040?l0003o
ool0oooo0?l00080oooo0P3o00070?ooo`030?l0003oool0o`000100oooo00T0o`000?ooo`3oool0
oooo0?l0003oool0o`000?ooo`3o0000803oool20?l000040?ooo`3o0000o`000?ooo`<0o`000`3o
ool00`3o0000oooo0?ooo`0=0?ooo`80o`001P3oool0103o0000oooo0?ooo`3oool20?l000@0oooo
0P3o00030?ooo`80o`000`3oool01`3o0000oooo0?l0003oool0o`000?ooo`3o00000P3oool00`3o
0000oooo0?ooo`020?l000@0oooo00<0o`000?ooo`3oool06@3oool40?l00080oooo0`3o00030?oo
o`030?l0003oool0oooo00@0oooo0`3o000<0?ooo`80o`00403oool00`3o0000oooo0?l000020?oo
o`80o`00103oool20?l000050?ooo`3o0000oooo0?ooo`3o00000`3oool20?l000<0oooo00<0o`00
0?ooo`3o00000P3oool00`3o0000oooo0?l000020?ooo`80o`0000<0oooo0?l0003oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?oo
o`020?l000@0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`80o`007P3oool00`3o0000oooo
0?ooo`0N0?ooo`040?l0003oool0oooo0?l00080oooo00@0o`000?ooo`3oool0oooo0P3o000A0?oo
o`030000003oool0oooo02L0oooo000d0?ooo`8000008`3oool3000005@0oooo0P3o00040?ooo`03
0?l0003oool0oooo0200oooo00<0o`000?ooo`3oool04@3oool0103o0000oooo0?l0003o00020?oo
o`<0o`00203oool0103o0000oooo0?ooo`3o000C0?ooo`040?l0003oool0oooo0?l00080oooo0P3o
00070?ooo`030?l0003oool0o`000100oooo00T0o`000?ooo`3oool0oooo0?l0003oool0o`000?oo
o`3o00008@3oool0103o0000oooo0?l0003oool40?l000<0oooo00<0o`000?ooo`3oool03@3oool2
0?l000H0oooo00@0o`000?ooo`3oool0oooo0P3o00040?ooo`80o`000`3oool20?l000<0oooo00L0
o`000?ooo`3o0000oooo0?l0003oool0o`000080oooo00<0o`000?ooo`3oool00P3o00040?ooo`03
0?l0003oool0oooo01X0oooo00<0o`000?ooo`3o00000P3oool30?l000<0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?l0000<0?ooo`80o`004@3oool20?l00080oooo0P3o00040?ooo`@0
o`000P3oool0103o0000oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3o00000P3oool00`3o
0000oooo0?l000020?ooo`80o`0000<0oooo0?l0003oool00`3oool00`3o0000oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`020?l000@0oooo00D0o`00
0?ooo`3oool0oooo0?l000020?ooo`80o`00?`3oool0103o0000oooo0?ooo`3o00020?ooo`040?l0
003oool0oooo0?ooo`80o`004@3oool00`000000oooo0?ooo`0W0?ooo`00<@3oool3000002D0oooo
00<000000?ooo`3oool0E03oool20?l000@0oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo
0?ooo`0C0?ooo`80o`000P3oool30?l000P0oooo00@0o`000?ooo`3oool0o`004`3oool20?l00005
0?ooo`3o0000oooo0?ooo`3o0000203oool00`3o0000oooo0?ooo`0@0?ooo`090?l0003oool0o`00
0?ooo`3o0000oooo0?l0003oool0o`000240oooo00@0o`000?ooo`3o0000oooo0P3o00000`3oool0
o`000?ooo`020?ooo`030?l0003oool0oooo00d0oooo0P3o00060?ooo`040?l0003oool0oooo0?oo
o`80o`00103oool20?l000<0oooo0P3o00030?ooo`070?l0003oool0o`000?ooo`3o0000oooo0?l0
00020?ooo`030?l0003oool0oooo0080o`008@3oool00`3o0000oooo0?l000020?ooo`<0o`000`3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0o`0000`0oooo0P3o000A0?ooo`80o`000P3o
ool20?l000@0oooo00@0o`000?ooo`3o0000o`000P3oool0103o0000oooo0?ooo`3oool20?l000<0
oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?l0003oool30?l000030?ooo`3o0000oooo
00<0oooo00@0o`000?ooo`3oool0oooo0P3o00030?ooo`030?l0003oool0oooo0080oooo00D0o`00
0?ooo`3o0000oooo0?l000040?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool20?l00480oooo
00<0o`000?ooo`3o0000103oool20?l00140oooo00<000000?ooo`3oool09`3oool002h0oooo0`00
000X0?ooo`030000003oool0oooo05@0oooo0P3o00040?ooo`030?l0003oool0oooo0200oooo00<0
o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`020?l000T0oooo00@0o`000?ooo`3oool0o`00
4`3oool40?l00080oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0@0?ooo`090?l0
003oool0o`000?ooo`3o0000oooo0?l0003oool0o`000240oooo00@0o`000?ooo`3o0000oooo0P3o
00000`3oool0o`000?ooo`020?ooo`030?l0003oool0oooo00d0oooo0P3o00060?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool20?l000<0oooo0P3o00030?ooo`060?l0003o
ool0o`000?ooo`3o0000oooo103o00020?ooo`80o`008@3oool00`3o0000oooo0?l000030?ooo`80
o`000`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0o`0000`0oooo0P3o000A0?ooo`80
o`000P3oool20?l000@0oooo00@0o`000?ooo`3o0000o`000P3oool0103o0000oooo0?ooo`3oool2
0?l000<0oooo00<0o`000?ooo`3o00000P3oool02@3o0000oooo0?l0003oool0o`000?ooo`3o0000
oooo0?l000040?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`020?oo
o`050?l0003oool0o`000?ooo`3o00000`3oool20?l000<0oooo00@0o`000?ooo`3oool0o`00@`3o
ool00`3o0000oooo0?l000050?ooo`030?l0003oool0oooo00l0oooo00<000000?ooo`3oool09`3o
ool002`0oooo0P00000[0?ooo`030000003oool0oooo05@0oooo0P3o00040?ooo`030?l0003oool0
oooo0200oooo00<0o`000?ooo`3oool0503oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00@0
o`000?ooo`3oool0o`004`3oool40?l00080oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`0@0?ooo`090?l0003oool0o`000?ooo`3o0000oooo0?l0003oool0o`000240oooo00@0o`00
0?ooo`3o0000oooo0P3o00000`3oool0o`000?ooo`020?ooo`030?l0003oool0oooo00d0oooo0P3o
000;0?ooo`030?l0003oool0oooo0080oooo0P3o00030?ooo`80o`000`3oool01P3o0000oooo0?l0
003oool0o`000?ooo`@0o`000P3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0o`0000<0
oooo0P3o00030?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o0000303oool20?l00180
oooo00<0o`000?ooo`3oool00P3o00040?ooo`040?l0003oool0o`000?l00080oooo00@0o`000?oo
o`3oool0oooo0P3o00030?ooo`030?l0003oool0o`000080oooo00T0o`000?ooo`3o0000oooo0?l0
003oool0o`000?ooo`3o0000103oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0o`000?oo
o`3oool00P3oool01@3o0000oooo0?l0003oool0o`0000<0oooo0P3o00030?ooo`040?l0003oool0
oooo0?l004<0oooo00<0o`000?ooo`3o00001@3oool00`3o0000oooo0?ooo`0?0?ooo`030000003o
ool0oooo02L0oooo001I0?ooo`<00000E@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo0200oooo00<0o`000?ooo`3oool0503oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00@0
o`000?ooo`3oool0o`004`3oool40?l00080oooo00<0o`000?ooo`3oool06P3oool20?l000060?oo
o`3o0000oooo0?l0003oool0o`008@3oool0103o0000oooo0?l0003oool20?l000030?ooo`3o0000
oooo0080oooo00<0o`000?ooo`3oool03@3oool20?l000/0oooo00<0o`000?ooo`3oool00P3oool2
0?l000<0oooo0P3o00030?ooo`<0o`0000<0oooo0?l0003oool0103o00020?ooo`030?l0003oool0
oooo0200oooo00<0o`000?ooo`3o00000`3oool20?l000<0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0:0?ooo`80o`005@3oool20?l000@0oooo00@0o`000?ooo`3oool0o`000P3o
ool0103o0000oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3o00000P3oool02@3o0000oooo
0?l0003oool0o`000?ooo`3o0000oooo0?l000040?ooo`050?l0003oool0oooo0?ooo`3o0000103o
ool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0o`000?ooo`3o00000`3oool20?l000<0oooo
00<0o`000?ooo`3oool0A03oool00`3o0000oooo0?l000050?ooo`030?l0003oool0oooo00l0oooo
00<000000?ooo`3oool09`3oool002`0oooo2P00000S0?ooo`030000003oool0oooo05D0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo01@0oooo00D0
o`000?ooo`3oool0oooo0?l000090?ooo`040?l0003oool0oooo0?l001<0oooo00<0o`000?ooo`3o
00000`3oool00`3o0000oooo0?ooo`0J0?ooo`80o`0000<0oooo0?l0003oool00P3o000R0?ooo`04
0?l0003oool0o`000?ooo`80o`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?ooo`0=0?oo
o`80o`002`3oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool00`3o0000oooo0?ooo`030?oo
o`80o`0000<0oooo0?l0003oool0103o00020?ooo`030?l0003oool0oooo0200oooo00<0o`000?oo
o`3o00000`3oool20?l000<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0:0?oo
o`80o`005@3oool20?l000L0oooo00@0o`000?ooo`3oool0o`000`3oool20?l000<0oooo00<0o`00
0?ooo`3o00000P3oool01@3o0000oooo0?l0003oool0o`0000<0oooo00<0o`000?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo
0?l0003oool0o`0000<0oooo0P3o00030?ooo`030?l0003oool0oooo04D0oooo0P3o00050?ooo`03
0?l0003oool0oooo00l0oooo00<000000?ooo`3oool09`3oool002l0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`1E0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
803oool00`3o0000oooo0?ooo`0D0?ooo`050?l0003oool0oooo0?ooo`3o00002@3oool00`3o0000
oooo0?l0000F0?ooo`050?l0003oool0oooo0?ooo`3o0000703oool20?l000050?ooo`3o0000oooo
0?ooo`3o00008P3oool0103o0000oooo0?l0003oool20?l000030?ooo`3o0000oooo0080oooo00<0
o`000?ooo`3oool03@3oool20?l000/0oooo00<0o`000?ooo`3oool00`3oool01@3o0000oooo0?oo
o`3oool0o`0000D0oooo0P3o00000`3oool0o`000?ooo`040?l00080oooo00<0o`000?ooo`3oool0
803oool00`3o0000oooo0?l000030?ooo`80o`000`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00X0oooo00<0o`000?ooo`3oool0503oool20?l000L0oooo00@0o`000?ooo`3oool0
o`000`3oool20?l000<0oooo00<0o`000?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?l000<0
oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0o`000?oo
o`3oool00P3oool01@3o0000oooo0?l0003oool0o`0000<0oooo0P3o00030?ooo`030?l0003oool0
oooo04D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0
oooo02L0oooo000^0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0E@3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool0503oool01@3o
0000oooo0?ooo`3oool0o`0000T0oooo00<0o`000?ooo`3o00005P3oool01@3o0000oooo0?ooo`3o
ool0o`0001`0oooo0P3o00001@3oool0o`000?ooo`3oool0o`000280oooo00@0o`000?ooo`3o0000
oooo0P3o00000`3oool0o`000?ooo`020?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo0P3o00000`3oool0
o`000?ooo`040?l00080oooo00<0o`000?ooo`3oool08P3oool0103o0000oooo0?ooo`3oool20?l0
00<0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0D0?ooo`80o`002P3oool0103o
0000oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3o00000P3oool00`3o0000oooo0?ooo`02
0?l000<0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0
o`000?ooo`3oool00P3oool01@3o0000oooo0?l0003oool0o`0000<0oooo0P3o00030?ooo`030?l0
003oool0oooo04D0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`0W0?ooo`00;P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo1000000;0?ooo`<00000E@3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool0603o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0o`0003L0oooo0P3o00001@3oool0o`000?oo
o`3oool0o`000280oooo00@0o`000?ooo`3o0000oooo0P3o00000`3oool0o`000?ooo`020?ooo`03
0?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo00L0oooo00D0o`000?ooo`3o0000o`000?ooo`040?l00080oooo00<0o`000?oo
o`3oool09P3oool20?l000<0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0D0?oo
o`80o`002P3oool0103o0000oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3o00000P3oool0
0`3o0000oooo0?ooo`020?l000<0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0o`0000T0oooo00D0o`000?ooo`3o0000oooo0?l000030?ooo`80o`000`3oool00`3o0000oooo
0?ooo`150?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool002h0oooo00<0
00000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`1E0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
803oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0o`0003L0oooo0P3o00001@3oool0o`00
0?ooo`3oool0o`000280oooo00@0o`000?ooo`3o0000oooo0P3o00000`3oool0o`000?ooo`020?oo
o`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0o`000080oooo103o00020?ooo`030?l0003oool0oooo02H0oooo0P3o00030?oo
o`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool0503oool20?l000X0oooo00@0o`000?oo
o`3oool0oooo0P3o00030?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool00P3o0003
0?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l000090?ooo`050?l0003o
ool0o`000?ooo`3o00000`3oool20?l000040?ooo`3o0000oooo0?l004L0oooo00<0o`000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0W0?ooo`00;`3oool7000000X0oooo1`0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1E0?ooo`030?l0
003oool0oooo02D0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?l0000g0?ooo`80o`00
00D0oooo0?l0003oool0oooo0?l0000R0?ooo`040?l0003oool0o`000?ooo`80o`0000<0oooo0?l0
003oool00P3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3o00000P3oool20?l000030?ooo`3o0000oooo02X0oooo0P3o00030?ooo`030?l0003oool0oooo
01<0oooo00<0o`000?ooo`3oool0503oool20?l000X0oooo00@0o`000?ooo`3oool0oooo0P3o0003
0?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool00P3o00030?ooo`030?l0003oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`040?l0003oool0oooo0?l000<0oooo
0P3o00000`3oool0o`000?l000180?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool0
9`3oool00400oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1E0?ooo`030?l0003oool0oooo02D0oooo
00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?l0000h0?ooo`030?l0003oool0o`000080oooo
00<0o`000?ooo`3oool0803oool0103o0000oooo0?l0003oool20?l000D0oooo00<0o`000?ooo`3o
ool0803oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0o`000080oooo0P3o00000`3oool0
o`000?ooo`0Z0?ooo`80o`006@3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00T0
oooo00@0o`000?ooo`3oool0oooo0P3o00030?ooo`030?l0003oool0o`000080oooo00<0o`000?oo
o`3oool00P3o00030?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0000:
0?ooo`040?l0003oool0oooo0?l000<0oooo0P3o00000`3oool0o`000?l0001Q0?ooo`030000003o
ool0oooo02L0oooo00110?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo1000001l0?ooo`030?l0003oool0oooo0280oooo00<0
o`000?ooo`3o0000>03oool00`3o0000oooo0?l000020?ooo`030?l0003oool0oooo0200oooo00@0
o`000?ooo`3o0000oooo0P3o00050?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?l000020?ooo`80o`0000<0oooo0?l0003oool0:P3oool20?l001T0oooo
00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`090?ooo`040?l0003oool0oooo0?ooo`80
o`000`3oool01@3o0000oooo0?l0003oool0o`0000<0oooo0P3o00030?ooo`030?l0003oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0?l0000=0?ooo`040?l0003oool0oooo0?ooo`80o`0000<0
oooo0?l0003o0000H@3oool00`000000oooo0?ooo`0W0?ooo`00@P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1m0?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3o0000>03oool20?l002H0oooo00@0
o`000?ooo`3o0000oooo0P3o00050?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool0
2@3oool0103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0oooo02T0oooo0P3o000I0?ooo`03
0?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`3oool20?l0
0080oooo0P3o0000103oool0o`000?ooo`3o00030?ooo`80o`000`3oool00`3o0000oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool01P3o0000oooo0?ooo`3oool0o`000?ooo`<0
o`00H@3oool00`000000oooo0?ooo`0W0?ooo`00@P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2R0?ooo`03
0?l0003oool0o`0003P0oooo0P3o000V0?ooo`040?l0003oool0o`000?ooo`80o`001@3oool00`3o
0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3oool0o`000P3oool0
0`3o0000oooo0?ooo`0Y0?ooo`80o`006@3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0
oooo00T0oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`0000@0oooo0?l0003oool0o`00
0`3oool20?l000<0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000d0
oooo00H0o`000?ooo`3oool0oooo0?l0003oool30?l00640oooo00<000000?ooo`3oool09`3oool0
04<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0XP3oool00`3o0000oooo0?l0000h0?ooo`80o`009P3oool01@3o
0000oooo0?l0003oool0o`0002T0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`3o
00020?ooo`030?l0003oool0oooo02T0oooo0P3o000I0?ooo`030?l0003oool0oooo01@0oooo00<0
o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`3oool20?l00080oooo0P3o00000`3oool0o`00
0?l000040?ooo`80o`000`3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o
00003@3oool01P3o0000oooo0?ooo`3oool0o`000?ooo`<0o`00H@3oool00`000000oooo0?ooo`0W
0?ooo`00A03oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?oo
o`<00000XP3oool00`3o0000oooo0?l0000h0?ooo`80o`009`3oool20?l000030?ooo`3o0000oooo
02P0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0
oooo02T0oooo0P3o000I0?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool02@3oool0
103o0000oooo0?ooo`3oool20?l00080oooo0P3o00000`3oool0o`000?l000040?ooo`80o`000`3o
ool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool01P3o0000oooo
0?ooo`3oool0o`000?ooo`<0o`00H@3oool00`000000oooo0?ooo`0W0?ooo`00A@3oool00`000000
oooo0?ooo`020?ooo`@000002`3oool00`000000oooo0?ooo`2R0?ooo`030?l0003oool0o`0003T0
oooo00<0o`000?ooo`3oool09@3oool0103o0000oooo0?ooo`3o000e0?ooo`040?l0003oool0oooo
0?l002h0oooo0P3o000I0?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool02@3oool0
103o0000oooo0?ooo`3oool20?l00080oooo0P3o00000`3oool0o`000?l000040?ooo`80o`000`3o
ool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool01P3o0000oooo
0?ooo`3oool0o`000?ooo`80o`00HP3oool00`000000oooo0?ooo`0W0?ooo`00F@3oool00`000000
oooo0?ooo`2R0?ooo`030?l0003oool0o`0003T0oooo00<0o`000?ooo`3oool09@3oool0103o0000
oooo0?ooo`3o000e0?ooo`040?l0003oool0oooo0?l002h0oooo0P3o000I0?ooo`030?l0003oool0
oooo01@0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`3oool20?l000050?ooo`3o
0000o`000?l0003oool00P3o00040?ooo`80o`000`3oool00`3o0000oooo0?ooo`020?ooo`050?l0
003oool0oooo0?ooo`3o00003@3oool01P3o0000oooo0?ooo`3oool0o`000?ooo`80o`00HP3oool0
0`000000oooo0?ooo`0W0?ooo`00F@3oool300000:<0oooo0P3o000i0?ooo`030?l0003oool0oooo
02D0oooo00@0o`000?ooo`3oool0o`00>03oool00`3o0000oooo0?ooo`0/0?ooo`80o`006@3oool0
0`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3oool0oooo0P3o
00001@3oool0o`000?l0003o0000oooo0080o`00103oool20?l000<0oooo00<0o`000?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0o`0000d0oooo00H0o`000?ooo`3oool0oooo0?l0003oool2
0?l00680oooo00<000000?ooo`3oool09`3oool005T0oooo00<000000?ooo`3oool0X`3oool20?l0
03T0oooo00<0o`000?ooo`3oool09@3oool0103o0000oooo0?ooo`3o000h0?ooo`030?l0003oool0
oooo02`0oooo0P3o000l0?ooo`0<0?l0003oool0oooo0?l0003oool0o`000?ooo`3o0000oooo0?l0
003oool0o`001@3oool20?l000<0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0o`0000d0oooo00H0o`000?ooo`3oool0oooo0?l0003oool20?l00680oooo00<000000?ooo`3o
ool09`3oool005T0oooo00<000000?ooo`3oool0X`3oool00`3o0000oooo0?ooo`0h0?ooo`030?l0
003oool0oooo02D0oooo00@0o`000?ooo`3oool0o`00>03oool00`3o0000oooo0?ooo`0/0?ooo`80
o`00?03oool0303o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l000D0
oooo0P3o00030?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0000=0?oo
o`070?l0003oool0oooo0?ooo`3o0000oooo0?l0001S0?ooo`030000003oool0oooo02L0oooo001I
0?ooo`030000003oool0oooo0:<0oooo00<0o`000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0U
0?ooo`040?l0003oool0oooo0?l003P0oooo00<0o`000?ooo`3oool0;03oool20?l003`0oooo00`0
o`000?ooo`3o0000o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o00050?ooo`80o`000`3o
ool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool01`3o0000oooo
0?ooo`3oool0o`000?ooo`3o0000H`3oool00`000000oooo0?ooo`0W0?ooo`00F@3oool300000:<0
oooo00<0o`000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0U0?ooo`040?l0003oool0oooo0?l0
03P0oooo00<0o`000?ooo`3oool0;03oool20?l003`0oooo00`0o`000?ooo`3o0000o`000?ooo`3o
0000oooo0?l0003oool0o`000?ooo`3o00050?ooo`80o`000`3oool00`3o0000oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`3o00003@3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o0000
H`3oool00`000000oooo0?ooo`0W0?ooo`00F@3oool00`000000oooo0?ooo`2S0?ooo`030?l0003o
ool0oooo03P0oooo00<0o`000?ooo`3oool09@3oool0103o0000oooo0?ooo`3o001W0?ooo`80o`00
?03oool02P3o0000oooo0?l0003o0000oooo0?l0003oool0o`000?ooo`3o00070?ooo`80o`000`3o
ool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool01`3o0000oooo
0?ooo`3oool0o`000?ooo`3o0000H`3oool00`000000oooo0?ooo`0W0?ooo`00F@3oool00`000000
oooo0?ooo`2S0?ooo`030?l0003oool0oooo03P0oooo00<0o`000?ooo`3oool09@3oool00`3o0000
oooo0?ooo`1X0?ooo`80o`00?03oool01@3o0000oooo0?l0003o0000oooo0080o`000P3oool00`3o
0000oooo0?ooo`050?ooo`80o`000`3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`3o00003@3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o0000H`3oool00`000000oooo
0?ooo`0W0?ooo`00F@3oool00`000000oooo0?ooo`3N0?ooo`030?l0003oool0oooo02D0oooo00<0
o`000?ooo`3oool0J03oool20?l003`0oooo00@0o`000?ooo`3o0000o`000P3oool00`3o0000oooo
0?ooo`080?ooo`80o`000`3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o
00003@3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o0000H`3oool00`000000oooo0?ooo`0W
0?ooo`00F@3oool300000=h0oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`1X0?oo
o`80o`00?03oool0103o0000oooo0?l0003o00020?ooo`030?l0003oool0oooo00P0oooo0P3o0003
0?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0000=0?ooo`070?l0003o
ool0oooo0?ooo`3o0000oooo0?l0001S0?ooo`030000003oool0oooo02L0oooo00120?ooo`@00000
103oool4000000/0oooo00<000000?ooo`3oool0gP3oool00`3o0000oooo0?ooo`0U0?ooo`030?l0
003oool0oooo06P0oooo0P3o000l0?ooo`040?l0003oool0o`000?l000d0oooo0P3o00030?ooo`03
0?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0000=0?ooo`070?l0003oool0oooo
0?ooo`3o0000oooo0?l0001S0?ooo`030000003oool0oooo02L0oooo00110?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0gP3oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo06P0oooo0P3o
000l0?ooo`040?l0003oool0o`000?l000d0oooo0P3o00030?ooo`030?l0003oool0oooo0080oooo
00D0o`000?ooo`3oool0oooo0?l0000=0?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l0001S
0?ooo`030000003oool0oooo02L0oooo00110?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0=h0oooo00<0o`00
0?ooo`3oool09@3oool00`3o0000oooo0?ooo`1X0?ooo`80o`00?03oool0103o0000oooo0?l0003o
000=0?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0P3o00030?ooo`030?l0
003oool0oooo00/0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`0006<0oooo00<000000?oo
o`3oool09`3oool004H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?oo
o`@00000g@3oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo06P0oooo0P3o000l0?oo
o`040?l0003oool0o`000?l000d0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3o
ool20?l000<0oooo00<0o`000?ooo`3oool02`3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o
0000H`3oool00`000000oooo0?ooo`0W0?ooo`00AP3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0gP3oool00`3o0000oooo0?ooo`0U0?ooo`03
0?l0003oool0oooo06P0oooo0P3o000l0?ooo`040?l0003oool0o`000?l000d0oooo00<0o`000?oo
o`3oool00P3oool0103o0000oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3oool02`3oool0
1`3o0000oooo0?ooo`3oool0o`000?ooo`3o0000H`3oool00`000000oooo0?ooo`0W0?ooo`00@@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<0o`000?ooo`3oool0J03oool20?l003`0oooo
0P3o000?0?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0P3o00030?ooo`03
0?l0003oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo0?l0001U0?ooo`030000003oool0oooo
02L0oooo00110?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0o`3oool70?ooo`030?l0003oool0oooo06P0oooo0P3o000l0?ooo`80
o`003`3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?ooo`80o`000`3oool00`3o
0000oooo0?ooo`0;0?ooo`050?l0003oool0oooo0?ooo`3o0000I@3oool00`000000oooo0?ooo`0W
0?ooo`00@@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool300000?l0oooo1`3oool00`3o0000oooo0?ooo`1X0?ooo`80o`00?03oool20?l0
00l0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool20?l000<0oooo00<0o`00
0?ooo`3oool02`3oool01@3o0000oooo0?ooo`3oool0o`0006D0oooo00<000000?ooo`3oool09`3o
ool00480oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0o`3oool70?ooo`030?l0003oool0oooo06P0oooo0P3o000l
0?ooo`80o`003`3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?ooo`80o`000P3o
ool20?l000d0oooo00D0o`000?ooo`3oool0oooo0?l0001U0?ooo`030000003oool0oooo02L0oooo
00120?ooo`D000000`3oool4000000/0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`80o`00?03o
ool20?l000l0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool20?l00080oooo
0P3o000=0?ooo`050?l0003oool0oooo0?ooo`3o0000I@3oool00`000000oooo0?ooo`0W0?ooo`00
F@3oool00`000000oooo0?ooo`3o0?ooog80oooo0P3o000l0?ooo`80o`003`3oool00`3o0000oooo
0?ooo`020?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool20?l000d0oooo00D0o`000?ooo`3o
ool0oooo0?l0001U0?ooo`030000003oool0oooo02L0oooo001I0?ooo`<00000o`3ooomb0?ooo`80
o`00?03oool20?l000l0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool20?l0
0080oooo0P3o000=0?ooo`040?l0003oool0oooo0?l006H0oooo00<000000?ooo`3oool09`3oool0
05T0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`80o`00?03oool20?l000l0oooo00<0o`000?oo
o`3oool00P3oool0103o0000oooo0?ooo`3oool20?l00080oooo0P3o000=0?ooo`040?l0003oool0
oooo0?l006H0oooo00<000000?ooo`3oool09`3oool005T0oooo00<000000?ooo`3oool0o`3ooomb
0?ooo`80o`00?03oool20?l000l0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3o
ool20?l00080oooo0P3o000=0?ooo`040?l0003oool0oooo0?l006H0oooo00<000000?ooo`3oool0
9`3oool005T0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`80o`00?03oool20?l001@0oooo00@0
o`000?ooo`3oool0oooo0P3o00020?ooo`80o`003@3oool0103o0000oooo0?ooo`3o001V0?ooo`03
0000003oool0oooo02L0oooo001I0?ooo`<00000o`3ooomb0?ooo`80o`00?03oool20?l001@0oooo
00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`003@3oool0103o0000oooo0?ooo`3o001V0?oo
o`030000003oool0oooo02L0oooo001I0?ooo`030000003oool0oooo0?l0ooooLP3oool20?l003`0
oooo0P3o000D0?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool20?l000d0oooo00@0o`000?oo
o`3oool0o`00IP3oool00`000000oooo0?ooo`0W0?ooo`00F@3oool00`000000oooo0?ooo`3o0?oo
og80oooo0P3o000l0?ooo`80o`00503oool0103o0000oooo0?ooo`3oool20?l00080oooo0P3o000=
0?ooo`040?l0003oool0oooo0?l006H0oooo00<000000?ooo`3oool09`3oool005T0ooooo`00001e
00000080o`00?00000020?l001@0000000@0o`0000000000000000000P3o000200000080o`003@00
0000103o000000000000003o001W000002T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 715}, {142.063, 0}} -> {-126.318, -14.0548, 1.22591, \
0.504685}}]
}, Open  ]],

Cell["\<\
The plot for the peak load looks at first sight very similar to the plot of \
the base load. The similarity will be analyzed later.\
\>", "Text"],

Cell["In the Excel sheets are also the prices for every hour.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hour\  = \ \(XLGetRange["\<L2:AI685\>"]\  // \ Reverse\)\  // 
          Rest;\)\), "\[IndentingNewLine]", 
    \(\(ListPlot3D[hour, BoxRatios \[Rule] \ {2, 3, 1}, 
        Ticks \[Rule] {Automatic, ticks, Automatic}, 
        ViewPoint -> {2.848, \ 1.291, \ 1.294}, 
        PlotRange \[Rule] {0, 100}];\)\)}], "Input"],

Cell[BoxData[
    \(Plot3D::"gval" \(\(:\)\(\ \)\) 
      "Function value \!\(Null\) at grid point xi = \!\(3\), yi = \!\(283\) \
is not a real number."\)], "Message"],

Cell[BoxData[
    \(Plot3D::"gval" \(\(:\)\(\ \)\) 
      "Function value \!\(Null\) at grid point xi = \!\(3\), yi = \!\(654\) \
is not a real number."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .58554 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
4.27718e-017 1.02704 -0.185491 1.02704 [
[.23611 .57459 -6.14009 0 ]
[.23611 .57459 5.67241 17.75 ]
[.17969 .54304 -10.2821 0 ]
[.17969 .54304 9.34288 17.75 ]
[.11928 .50926 -10.3698 0 ]
[.11928 .50926 9.2552 17.75 ]
[.05444 .473 -10.4649 0 ]
[.05444 .473 9.16013 17.75 ]
[.02045 .15598 -31.253 -17.75 ]
[.02045 .15598 36.3095 0 ]
[.12502 .13366 -31.7824 -17.75 ]
[.12502 .13366 35.7801 0 ]
[.23319 .11057 -28.595 -17.75 ]
[.23319 .11057 31.155 0 ]
[.34516 .08668 -32.9088 -17.75 ]
[.34516 .08668 34.6537 0 ]
[.46112 .06193 -33.5087 -17.75 ]
[.46112 .06193 34.0538 0 ]
[.58129 .0363 -38.0823 -17.75 ]
[.58129 .0363 37.2927 0 ]
[.7059 .00971 -30.7672 -17.75 ]
[.7059 .00971 28.9828 0 ]
[.00693 .17146 -11.8125 -6.98531 ]
[.00693 .17146 0 10.7647 ]
[.00314 .22185 -19.625 -7.05665 ]
[.00314 .22185 0 10.6934 ]
[-0.00072 .27302 -19.625 -7.12918 ]
[-0.00072 .27302 0 10.6208 ]
[-0.00464 .32499 -19.625 -7.20293 ]
[-0.00464 .32499 0 10.5471 ]
[-0.00861 .37777 -19.625 -7.27793 ]
[-0.00861 .37777 0 10.4721 ]
[-0.01265 .43138 -27.4375 -7.35421 ]
[-0.01265 .43138 0 10.3958 ]
[ 0 0 0 0 ]
[ 1 .58554 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27906 .58554 m
0 .42921 L
s
.23662 .56176 m
.23687 .55535 L
s
gsave
.23611 .57459 -67.1401 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.1803 .53022 m
.18061 .52381 L
s
gsave
.17969 .54304 -71.2821 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.12001 .49644 m
.12037 .49003 L
s
gsave
.11928 .50926 -71.3698 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.05529 .46019 m
.05572 .45378 L
s
gsave
.05444 .473 -71.4649 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.22566 .55562 m
.22581 .55177 L
s
.21454 .5494 m
.21471 .54555 L
s
.20328 .54309 m
.20346 .53924 L
s
.19187 .5367 m
.19205 .53285 L
s
.16858 .52365 m
.16877 .5198 L
s
.15669 .51699 m
.15688 .51314 L
s
.14463 .51023 m
.14483 .50639 L
s
.13241 .50338 m
.13262 .49954 L
s
.10743 .4894 m
.10766 .48555 L
s
.09468 .48225 m
.09491 .47841 L
s
.08174 .475 m
.08198 .47116 L
s
.06861 .46765 m
.06886 .4638 L
s
.24744 .56783 m
.24758 .56398 L
s
.25812 .57381 m
.25826 .56996 L
s
.26866 .57971 m
.26879 .57586 L
s
.04177 .45261 m
.04204 .44877 L
s
.02806 .44493 m
.02833 .44109 L
s
.01413 .43713 m
.01441 .43329 L
s
.25 Mabswid
.01949 .16878 m
.81218 0 L
s
.01949 .16878 m
.01901 .17518 L
s
gsave
.02045 .15598 -92.253 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.12426 .14647 m
.12388 .15288 L
s
gsave
.12502 .13366 -92.7824 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23264 .1234 m
.23237 .12981 L
s
gsave
.23319 .11057 -89.595 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34483 .09951 m
.34466 .10593 L
s
gsave
.34516 .08668 -93.9088 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.46101 .07477 m
.46096 .08119 L
s
gsave
.46112 .06193 -94.5087 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.58142 .04913 m
.58149 .05555 L
s
gsave
.58129 .0363 -99.0823 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.688 17.625 moveto
(\\220) show
103.125 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
134.375 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.70629 .02255 m
.70648 .02896 L
s
gsave
.7059 .00971 -91.7672 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2002) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01949 .16878 m
0 .42921 L
s
.01949 .16878 m
.02577 .16744 L
s
gsave
.00693 .17146 -72.8125 -10.9853 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01571 .21927 m
.022 .21799 L
s
gsave
.00314 .22185 -80.625 -11.0567 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.01187 .27054 m
.01817 .26931 L
s
gsave
-0.00072 .27302 -80.625 -11.1292 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.00798 .32261 m
.01429 .32142 L
s
gsave
-0.00464 .32499 -80.625 -11.2029 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.00402 .37549 m
.01034 .37436 L
s
gsave
-0.00861 .37777 -80.625 -11.2779 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
0 .42921 m
.00633 .42813 L
s
gsave
-0.01265 .43138 -88.4375 -11.3542 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.01855 .18133 m
.02232 .18054 L
s
.01761 .19393 m
.02138 .19314 L
s
.01666 .20658 m
.02043 .2058 L
s
.01476 .23202 m
.01853 .23125 L
s
.0138 .24481 m
.01758 .24405 L
s
.01284 .25765 m
.01662 .2569 L
s
.01091 .28349 m
.01469 .28275 L
s
.00993 .29648 m
.01372 .29575 L
s
.00896 .30952 m
.01274 .3088 L
s
.00699 .33576 m
.01078 .33505 L
s
.00601 .34895 m
.00979 .34825 L
s
.00502 .3622 m
.0088 .36151 L
s
.00302 .38884 m
.00681 .38817 L
s
.00202 .40225 m
.00581 .40158 L
s
.00101 .4157 m
.00481 .41504 L
s
.25 Mabswid
.28669 .35731 m
.27906 .58554 L
s
.27906 .58554 m
1 .48484 L
s
1 .48484 m
.98247 .23563 L
s
.98247 .23563 m
.28669 .35731 L
s
.01949 .16878 m
.81218 0 L
s
.81218 0 m
.82554 .28775 L
s
.82554 .28775 m
0 .42921 L
s
0 .42921 m
.01949 .16878 L
s
.28669 .35731 m
.27906 .58554 L
s
.27906 .58554 m
0 .42921 L
s
0 .42921 m
.01949 .16878 L
s
.01949 .16878 m
.28669 .35731 L
s
.98247 .23563 m
.81218 0 L
s
.81218 0 m
.82554 .28775 L
s
.82554 .28775 m
1 .48484 L
s
1 .48484 m
.98247 .23563 L
s
0 0 m
1 0 L
1 .58554 L
0 .58554 L
closepath
clip
newpath
.5 Mabswid
.933 .765 .651 r
.28577 .38487 .28687 .37944 .27682 .37244 .27571 .37788 Metetra
.933 .765 .651 r
.27571 .37788 .27682 .37244 .26664 .3654 .26552 .37087 Metetra
.933 .765 .651 r
.26552 .37087 .26664 .3654 .25633 .35827 .25519 .36377 Metetra
.933 .765 .651 r
.25519 .36377 .25633 .35827 .2459 .35105 .24474 .35658 Metetra
.933 .766 .651 r
.24474 .35658 .2459 .35105 .23532 .34378 .23415 .34947 Metetra
.943 .777 .645 r
.23415 .34947 .23532 .34378 .2245 .33908 .22324 .3464 Metetra
.942 .763 .632 r
.22324 .3464 .2245 .33908 .21334 .33833 .21225 .34156 Metetra
.977 .879 .667 r
.21225 .34156 .21334 .33833 .20233 .33071 .20044 .35109 Metetra
.947 .743 .595 r
.20044 .35109 .20233 .33071 .19091 .32856 .18908 .34677 Metetra
.944 .742 .599 r
.18908 .34677 .19091 .32856 .1796 .32083 .1777 .3396 Metetra
.951 .748 .594 r
.1777 .3396 .1796 .32083 .16812 .31305 .16571 .34118 Metetra
.942 .733 .593 r
.16571 .34118 .16812 .31305 .1565 .30512 .15448 .32484 Metetra
.942 .739 .599 r
.15448 .32484 .1565 .30512 .14473 .29693 .14283 .31358 Metetra
.941 .74 .604 r
.14283 .31358 .14473 .29693 .13283 .28791 .13104 .30221 Metetra
.932 .733 .613 r
.13104 .30221 .13283 .28791 .12081 .27823 .11963 .28147 Metetra
.903 .768 .703 r
.11963 .28147 .12081 .27823 .10873 .26655 .10759 .26901 Metetra
.903 .799 .734 r
.10759 .26901 .10873 .26655 .0963 .25799 .09515 .26044 Metetra
.901 .797 .735 r
.09515 .26044 .0963 .25799 .08388 .24624 .08256 .25139 Metetra
.929 .77 .662 r
.08256 .25139 .08388 .24624 .0711 .23745 .06977 .24238 Metetra
.936 .782 .664 r
.06977 .24238 .0711 .23745 .05814 .22838 .05657 .23665 Metetra
.935 .754 .633 r
.05657 .23665 .05814 .22838 .04499 .21933 .0435 .22613 Metetra
.931 .758 .645 r
.0435 .22613 .04499 .21933 .03165 .21018 .0303 .21477 Metetra
.927 .775 .674 r
.0303 .21477 .03165 .21018 .01811 .20084 .01674 .20549 Metetra
.564 .788 .983 r
.28687 .37944 .28779 .37932 .27774 .37237 .27682 .37244 Metetra
.53 .776 .988 r
.27682 .37244 .27774 .37237 .26766 .3629 .26664 .3654 Metetra
.909 .794 .722 r
.26664 .3654 .26766 .3629 .25736 .35576 .25633 .35827 Metetra
.909 .794 .722 r
.25633 .35827 .25736 .35576 .24693 .34852 .2459 .35105 Metetra
.909 .794 .722 r
.2459 .35105 .24693 .34852 .23639 .34073 .23532 .34378 Metetra
.927 .802 .701 r
.23532 .34378 .23639 .34073 .22565 .33422 .2245 .33908 Metetra
.948 .793 .654 r
.2245 .33908 .22565 .33422 .21468 .32947 .21334 .33833 Metetra
.939 .754 .625 r
.21334 .33833 .21468 .32947 .20354 .32507 .20233 .33071 Metetra
.946 .781 .646 r
.20233 .33071 .20354 .32507 .19235 .31849 .19091 .32856 Metetra
.94 .751 .619 r
.19091 .32856 .19235 .31849 .18086 .31477 .1796 .32083 Metetra
.934 .764 .647 r
.1796 .32083 .18086 .31477 .16938 .30742 .16812 .31305 Metetra
.933 .766 .653 r
.16812 .31305 .16938 .30742 .15777 .29946 .1565 .30512 Metetra
.932 .766 .653 r
.1565 .30512 .15777 .29946 .14604 .29073 .14473 .29693 Metetra
.932 .762 .647 r
.14473 .29693 .14604 .29073 .13441 .27735 .13283 .28791 Metetra
.939 .749 .619 r
.13283 .28791 .13441 .27735 .12233 .26892 .12081 .27823 Metetra
.935 .749 .626 r
.12081 .27823 .12233 .26892 .11009 .26047 .10873 .26655 Metetra
.933 .765 .649 r
.10873 .26655 .11009 .26047 .09766 .252 .0963 .25799 Metetra
.927 .758 .652 r
.0963 .25799 .09766 .252 .08506 .24339 .08388 .24624 Metetra
.911 .793 .718 r
.08388 .24624 .08506 .24339 .07229 .23458 .0711 .23745 Metetra
.91 .792 .718 r
.0711 .23745 .07229 .23458 .05934 .22559 .05814 .22838 Metetra
.909 .794 .722 r
.05814 .22838 .05934 .22559 .0462 .21653 .04499 .21933 Metetra
.909 .795 .722 r
.04499 .21933 .0462 .21653 .03286 .20738 .03165 .21018 Metetra
.908 .795 .723 r
.03165 .21018 .03286 .20738 .01934 .198 .01811 .20084 Metetra
.953 .659 .442 r
.28779 .37932 .28857 .38355 .27852 .37661 .27774 .37237 Metetra
.959 .663 .428 r
.27774 .37237 .27852 .37661 .26851 .3651 .26766 .3629 Metetra
.932 .563 .286 r
.26766 .3629 .26851 .3651 .25821 .35796 .25736 .35576 Metetra
.932 .563 .286 r
.25736 .35576 .25821 .35796 .24778 .35074 .24693 .34852 Metetra
.932 .562 .278 r
.24693 .34852 .24778 .35074 .23699 .34888 .23639 .34073 Metetra
.952 .694 .51 r
.23639 .34073 .23699 .34888 .22603 .34752 .22565 .33422 Metetra
.949 .707 .537 r
.22565 .33422 .22603 .34752 .21502 .34332 .21468 .32947 Metetra
.949 .707 .538 r
.21468 .32947 .21502 .34332 .20323 .3527 .20354 .32507 Metetra
.95 .719 .555 r
.20354 .32507 .20323 .3527 .19167 .353 .19235 .31849 Metetra
.948 .72 .559 r
.19235 .31849 .19167 .353 .17999 .35208 .18086 .31477 Metetra
.949 .722 .559 r
.18086 .31477 .17999 .35208 .16846 .34445 .16938 .30742 Metetra
.95 .722 .559 r
.16938 .30742 .16846 .34445 .15678 .33666 .15777 .29946 Metetra
.95 .722 .559 r
.15777 .29946 .15678 .33666 .14544 .31969 .14604 .29073 Metetra
.952 .722 .552 r
.14604 .29073 .14544 .31969 .13476 .28852 .13441 .27735 Metetra
.953 .704 .524 r
.13441 .27735 .13476 .28852 .12266 .28025 .12233 .26892 Metetra
.952 .704 .524 r
.12233 .26892 .12266 .28025 .11055 .2692 .11009 .26047 Metetra
.953 .695 .509 r
.11009 .26047 .11055 .2692 .09812 .26068 .09766 .252 Metetra
.953 .695 .508 r
.09766 .252 .09812 .26068 .08533 .25473 .08506 .24339 Metetra
.952 .704 .524 r
.08506 .24339 .08533 .25473 .07254 .24596 .07229 .23458 Metetra
.953 .704 .523 r
.07229 .23458 .07254 .24596 .05957 .23696 .05934 .22559 Metetra
.953 .703 .523 r
.05934 .22559 .05957 .23696 .04641 .22793 .0462 .21653 Metetra
.952 .703 .523 r
.0462 .21653 .04641 .22793 .03332 .2151 .03286 .20738 Metetra
.954 .689 .497 r
.03286 .20738 .03332 .2151 .01978 .20581 .01934 .198 Metetra
.76 .254 0 r
.28857 .38355 .28945 .38459 .27959 .37252 .27852 .37661 Metetra
.913 .757 .676 r
.27852 .37661 .27959 .37252 .2694 .36615 .26851 .3651 Metetra
.758 .252 0 r
.26851 .3651 .2694 .36615 .2591 .35902 .25821 .35796 Metetra
.758 .252 0 r
.25821 .35796 .2591 .35902 .24847 .35705 .24778 .35074 Metetra
.942 .676 .503 r
.24778 .35074 .24847 .35705 .23786 .35065 .23699 .34888 Metetra
.894 .517 .315 r
.23699 .34888 .23786 .35065 .22695 .34807 .22603 .34752 Metetra
.503 0 0 r
.22603 .34752 .22695 .34807 .21577 .34799 .21502 .34332 Metetra
.908 .634 .51 r
.21502 .34332 .21577 .34799 .20437 .34874 .20323 .3527 Metetra
.95 .812 .671 r
.20323 .3527 .20437 .34874 .19255 .35476 .19167 .353 Metetra
.888 .509 .313 r
.19167 .353 .19255 .35476 .18112 .3486 .17999 .35208 Metetra
.921 .785 .693 r
.17999 .35208 .18112 .3486 .16943 .34441 .16846 .34445 Metetra
.479 .762 .993 r
.16846 .34445 .16943 .34441 .15793 .33336 .15678 .33666 Metetra
.888 .747 .699 r
.15678 .33666 .15793 .33336 .1461 .32542 .14544 .31969 Metetra
.984 .7 .363 r
.14544 .31969 .1461 .32542 .13521 .29791 .13476 .28852 Metetra
.953 .698 .514 r
.13476 .28852 .13521 .29791 .12309 .28971 .12266 .28025 Metetra
.956 .701 .51 r
.12266 .28025 .12309 .28971 .111 .27813 .11055 .2692 Metetra
.953 .696 .51 r
.11055 .2692 .111 .27813 .09903 .26201 .09812 .26068 Metetra
.845 .383 .081 r
.09812 .26068 .09903 .26201 .08635 .25441 .08533 .25473 Metetra
.655 .817 .961 r
.08533 .25473 .08635 .25441 .07356 .24568 .07254 .24596 Metetra
.632 .81 .968 r
.07254 .24596 .07356 .24568 .06067 .23566 .05957 .23696 Metetra
.851 .825 .821 r
.05957 .23696 .06067 .23566 .04744 .22773 .04641 .22793 Metetra
.615 .748 .94 r
.04641 .22793 .04744 .22773 .03418 .21736 .03332 .2151 Metetra
.925 .546 .26 r
.03332 .2151 .03418 .21736 .02101 .20303 .01978 .20581 Metetra
.818 .763 .8 r
.28945 .38459 .29041 .38348 .28052 .37233 .27959 .37252 Metetra
.598 .815 .983 r
.27959 .37252 .28052 .37233 .27033 .36596 .2694 .36615 Metetra
.607 .803 .975 r
.2694 .36615 .27033 .36596 .26004 .35883 .2591 .35902 Metetra
.453 .855 .97 r
.2591 .35902 .26004 .35883 .2495 .35474 .24847 .35705 Metetra
.909 .805 .733 r
.24847 .35705 .2495 .35474 .23885 .34959 .23786 .35065 Metetra
.866 .9 .855 r
.23786 .35065 .23885 .34959 .22784 .34942 .22695 .34807 Metetra
.857 .448 .258 r
.22695 .34807 .22784 .34942 .21676 .34708 .21577 .34799 Metetra
.84 .967 .884 r
.21577 .34799 .21676 .34708 .20539 .3473 .20437 .34874 Metetra
.909 .979 .78 r
.20437 .34874 .20539 .3473 .1939 .34652 .19255 .35476 Metetra
.941 .759 .627 r
.19255 .35476 .1939 .34652 .18208 .34881 .18112 .3486 Metetra
0 .531 .819 r
.18112 .3486 .18208 .34881 .17017 .34917 .16943 .34441 Metetra
.96 .668 .436 r
.16943 .34441 .17017 .34917 .15888 .33397 .15793 .33336 Metetra
0 .181 .609 r
.15793 .33336 .15888 .33397 .14738 .31997 .1461 .32542 Metetra
.89 .719 .663 r
.1461 .32542 .14738 .31997 .13609 .29973 .13521 .29791 Metetra
.904 .494 .185 r
.13521 .29791 .13609 .29973 .12409 .28952 .12309 .28971 Metetra
.615 .752 .943 r
.12309 .28971 .12409 .28952 .11237 .27179 .111 .27813 Metetra
.92 .747 .65 r
.111 .27813 .11237 .27179 .10017 .25965 .09903 .26201 Metetra
.906 .808 .741 r
.09903 .26201 .10017 .25965 .08736 .25428 .08635 .25441 Metetra
.543 .784 .987 r
.08635 .25441 .08736 .25428 .07458 .24543 .07356 .24568 Metetra
.626 .791 .961 r
.07356 .24568 .07458 .24543 .0617 .23528 .06067 .23566 Metetra
.672 .839 .964 r
.06067 .23566 .0617 .23528 .04875 .22338 .04744 .22773 Metetra
.922 .773 .678 r
.04744 .22773 .04875 .22338 .03546 .21364 .03418 .21736 Metetra
.906 .764 .694 r
.03418 .21736 .03546 .21364 .02193 .20434 .02101 .20303 Metetra
.741 .271 0 r
.29041 .38348 .29129 .38477 .28143 .37271 .28052 .37233 Metetra
0 .432 .818 r
.28052 .37233 .28143 .37271 .27129 .36499 .27033 .36596 Metetra
.832 .828 .844 r
.27033 .36596 .27129 .36499 .26101 .35785 .26004 .35883 Metetra
.85 .878 .86 r
.26004 .35883 .26101 .35785 .25059 .35062 .2495 .35474 Metetra
.934 .784 .672 r
.2495 .35474 .25059 .35062 .24006 .34282 .23885 .34959 Metetra
.951 .777 .631 r
.23885 .34959 .24006 .34282 .22917 .34018 .22784 .34942 Metetra
.948 .761 .618 r
.22784 .34942 .22917 .34018 .21812 .33757 .21676 .34708 Metetra
.951 .765 .615 r
.21676 .34708 .21812 .33757 .20711 .33065 .20539 .3473 Metetra
.95 .749 .597 r
.20539 .3473 .20711 .33065 .19589 .32466 .1939 .34652 Metetra
.951 .746 .59 r
.1939 .34652 .19589 .32466 .18453 .31846 .18208 .34881 Metetra
.95 .741 .586 r
.18208 .34881 .18453 .31846 .17305 .31127 .17017 .34917 Metetra
.944 .733 .587 r
.17017 .34917 .17305 .31127 .16148 .30282 .15888 .33397 Metetra
.944 .734 .59 r
.15888 .33397 .16148 .30282 .14974 .29449 .14738 .31997 Metetra
.94 .732 .596 r
.14738 .31997 .14974 .29449 .13798 .28352 .13609 .29973 Metetra
.942 .742 .604 r
.13609 .29973 .13798 .28352 .12593 .2748 .12409 .28952 Metetra
.935 .737 .61 r
.12409 .28952 .12593 .2748 .1137 .26621 .11237 .27179 Metetra
.924 .758 .657 r
.11237 .27179 .1137 .26621 .1014 .25581 .10017 .25965 Metetra
.933 .795 .685 r
.10017 .25965 .1014 .25581 .08882 .24709 .08736 .25428 Metetra
.936 .761 .639 r
.08736 .25428 .08882 .24709 .07606 .23829 .07458 .24543 Metetra
.934 .759 .64 r
.07458 .24543 .07606 .23829 .06295 .23178 .0617 .23528 Metetra
.91 .774 .698 r
.0617 .23528 .06295 .23178 .04981 .22275 .04875 .22338 Metetra
.753 .824 .907 r
.04875 .22338 .04981 .22275 .03648 .2136 .03546 .21364 Metetra
.469 .753 .992 r
.03546 .21364 .03648 .2136 .02316 .20154 .02193 .20434 Metetra
.898 .759 .7 r
.29129 .38477 .29231 .38169 .28243 .37054 .28143 .37271 Metetra
.899 .795 .737 r
.28143 .37271 .28243 .37054 .27228 .36348 .27129 .36499 Metetra
.877 .815 .785 r
.27129 .36499 .27228 .36348 .262 .35633 .26101 .35785 Metetra
.877 .815 .785 r
.26101 .35785 .262 .35633 .25159 .34909 .25059 .35062 Metetra
.874 .81 .784 r
.25059 .35062 .25159 .34909 .241 .34274 .24006 .34282 Metetra
.34 .788 .955 r
.24006 .34282 .241 .34274 .2301 .3406 .22917 .34018 Metetra
.457 0 0 r
.22917 .34018 .2301 .3406 .2189 .34154 .21812 .33757 Metetra
.95 .649 .43 r
.21812 .33757 .2189 .34154 .2078 .3364 .20711 .33065 Metetra
.95 .675 .481 r
.20711 .33065 .2078 .3364 .19666 .32877 .19589 .32466 Metetra
.948 .649 .439 r
.19589 .32466 .19666 .32877 .18513 .32597 .18453 .31846 Metetra
.953 .69 .5 r
.18453 .31846 .18513 .32597 .17367 .3183 .17305 .31127 Metetra
.955 .688 .492 r
.17305 .31127 .17367 .3183 .16208 .31003 .16148 .30282 Metetra
.954 .689 .494 r
.16148 .30282 .16208 .31003 .15029 .30244 .14974 .29449 Metetra
.958 .696 .496 r
.14974 .29449 .15029 .30244 .13867 .28875 .13798 .28352 Metetra
.954 .67 .459 r
.13798 .28352 .13867 .28875 .12686 .2757 .12593 .2748 Metetra
.631 .094 0 r
.12593 .2748 .12686 .2757 .11461 .26743 .1137 .26621 Metetra
.762 .268 0 r
.1137 .26621 .11461 .26743 .1022 .25887 .1014 .25581 Metetra
.945 .611 .361 r
.1014 .25581 .1022 .25887 .08944 .25304 .08882 .24709 Metetra
.954 .677 .473 r
.08882 .24709 .08944 .25304 .07684 .24165 .07606 .23829 Metetra
.941 .62 .398 r
.07606 .23829 .07684 .24165 .06396 .23165 .06295 .23178 Metetra
.545 .783 .987 r
.06295 .23178 .06396 .23165 .05083 .22261 .04981 .22275 Metetra
.544 .783 .987 r
.04981 .22275 .05083 .22261 .03777 .20984 .03648 .2136 Metetra
.913 .773 .692 r
.03648 .2136 .03777 .20984 .02467 .19487 .02316 .20154 Metetra
.948 .591 .268 r
.29231 .38169 .29315 .38425 .28329 .3723 .28243 .37054 Metetra
.908 .503 .194 r
.28243 .37054 .28329 .3723 .27316 .36473 .27228 .36348 Metetra
.829 .356 0 r
.27228 .36348 .27316 .36473 .26292 .35675 .262 .35633 Metetra
0 .408 .814 r
.262 .35633 .26292 .35675 .25251 .34952 .25159 .34909 Metetra
0 .363 .755 r
.25159 .34909 .25251 .34952 .24199 .34154 .241 .34274 Metetra
.883 .898 .836 r
.241 .34274 .24199 .34154 .23122 .33634 .2301 .3406 Metetra
.953 .808 .662 r
.2301 .3406 .23122 .33634 .22019 .33377 .2189 .34154 Metetra
.943 .762 .629 r
.2189 .34154 .22019 .33377 .20918 .32693 .2078 .3364 Metetra
.941 .753 .621 r
.2078 .3364 .20918 .32693 .19778 .32526 .19666 .32877 Metetra
.939 .807 .687 r
.19666 .32877 .19778 .32526 .18644 .31878 .18513 .32597 Metetra
.938 .76 .636 r
.18513 .32597 .18644 .31878 .17498 .3115 .17367 .3183 Metetra
.936 .761 .64 r
.17367 .3183 .17498 .3115 .16355 .30047 .16208 .31003 Metetra
.941 .754 .621 r
.16208 .31003 .16355 .30047 .15188 .29098 .15029 .30244 Metetra
.936 .743 .617 r
.15029 .30244 .15188 .29098 .14009 .28093 .13867 .28875 Metetra
.93 .749 .635 r
.13867 .28875 .14009 .28093 .1281 .27125 .12686 .2757 Metetra
.928 .776 .672 r
.12686 .2757 .1281 .27125 .11588 .2628 .11461 .26743 Metetra
.928 .774 .67 r
.11461 .26743 .11588 .2628 .10363 .25182 .1022 .25887 Metetra
.941 .767 .638 r
.1022 .25887 .10363 .25182 .09107 .24312 .08944 .25304 Metetra
.937 .749 .623 r
.08944 .25304 .09107 .24312 .07832 .23427 .07684 .24165 Metetra
.935 .758 .638 r
.07684 .24165 .07832 .23427 .06541 .2252 .06396 .23165 Metetra
.935 .764 .646 r
.06396 .23165 .06541 .2252 .05229 .21612 .05083 .22261 Metetra
.928 .756 .648 r
.05083 .22261 .05229 .21612 .03899 .20696 .03777 .20984 Metetra
.89 .766 .718 r
.03777 .20984 .03899 .20696 .02549 .19759 .02467 .19487 Metetra
.931 .746 .63 r
.29315 .38425 .29433 .37614 .28433 .36883 .28329 .3723 Metetra
.921 .779 .688 r
.28329 .3723 .28433 .36883 .2742 .36165 .27316 .36473 Metetra
.915 .782 .7 r
.27316 .36473 .2742 .36165 .26394 .35426 .26292 .35675 Metetra
.909 .795 .723 r
.26292 .35675 .26394 .35426 .25354 .34701 .25251 .34952 Metetra
.906 .791 .723 r
.25251 .34952 .25354 .34701 .24305 .33873 .24199 .34154 Metetra
.923 .804 .71 r
.24199 .34154 .24305 .33873 .23234 .33236 .23122 .33634 Metetra
.942 .798 .673 r
.23122 .33634 .23234 .33236 .22149 .32577 .22019 .33377 Metetra
.94 .758 .628 r
.22019 .33377 .22149 .32577 .21025 .32445 .20918 .32693 Metetra
.934 .839 .726 r
.20918 .32693 .21025 .32445 .19911 .31741 .19778 .32526 Metetra
.941 .76 .63 r
.19778 .32526 .19911 .31741 .18783 .30994 .18644 .31878 Metetra
.941 .756 .624 r
.18644 .31878 .18783 .30994 .17641 .30237 .17498 .3115 Metetra
.936 .749 .626 r
.17498 .3115 .17641 .30237 .16485 .2941 .16355 .30047 Metetra
.933 .76 .645 r
.16355 .30047 .16485 .2941 .15313 .28589 .15188 .29098 Metetra
.927 .765 .662 r
.15188 .29098 .15313 .28589 .14128 .27715 .14009 .28093 Metetra
.919 .776 .687 r
.14009 .28093 .14128 .27715 .12934 .26692 .1281 .27125 Metetra
.927 .776 .675 r
.1281 .27125 .12934 .26692 .11713 .25843 .11588 .2628 Metetra
.92 .768 .675 r
.11588 .2628 .11713 .25843 .10474 .24991 .10363 .25182 Metetra
.888 .81 .767 r
.10363 .25182 .10474 .24991 .09207 .24309 .09107 .24312 Metetra
.472 .753 .991 r
.09107 .24312 .09207 .24309 .07933 .23431 .07832 .23427 Metetra
.408 .722 .988 r
.07832 .23427 .07933 .23431 .0664 .22536 .06541 .2252 Metetra
.272 .653 .967 r
.06541 .2252 .0664 .22536 .05329 .21636 .05229 .21612 Metetra
.176 .597 .94 r
.05229 .21612 .05329 .21636 .03999 .20715 .03899 .20696 Metetra
.243 .636 .96 r
.03899 .20696 .03999 .20715 .02652 .1976 .02549 .19759 Metetra
.954 .697 .508 r
.29433 .37614 .29499 .38434 .28499 .37684 .28433 .36883 Metetra
.954 .696 .506 r
.28433 .36883 .28499 .37684 .27484 .36988 .2742 .36165 Metetra
.954 .697 .508 r
.2742 .36165 .27484 .36988 .26454 .36335 .26394 .35426 Metetra
.954 .7 .514 r
.26394 .35426 .26454 .36335 .25413 .35614 .25354 .34701 Metetra
.955 .701 .512 r
.25354 .34701 .25413 .35614 .24354 .34997 .24305 .33873 Metetra
.952 .704 .527 r
.24305 .33873 .24354 .34997 .23273 .34569 .23234 .33236 Metetra
.952 .708 .534 r
.23234 .33236 .23273 .34569 .22143 .34915 .22149 .32577 Metetra
.948 .715 .553 r
.22149 .32577 .22143 .34915 .20993 .35296 .21025 .32445 Metetra
.95 .72 .554 r
.21025 .32445 .20993 .35296 .19869 .34711 .19911 .31741 Metetra
.951 .72 .554 r
.19911 .31741 .19869 .34711 .18698 .34762 .18783 .30994 Metetra
.95 .722 .558 r
.18783 .30994 .18698 .34762 .17531 .34383 .17641 .30237 Metetra
.95 .723 .559 r
.17641 .30237 .17531 .34383 .16379 .33341 .16485 .2941 Metetra
.95 .723 .558 r
.16485 .2941 .16379 .33341 .15247 .31657 .15313 .28589 Metetra
.951 .721 .554 r
.15313 .28589 .15247 .31657 .14079 .30373 .14128 .27715 Metetra
.952 .72 .551 r
.14128 .27715 .14079 .30373 .12959 .27971 .12934 .26692 Metetra
.953 .707 .529 r
.12934 .26692 .12959 .27971 .11734 .2717 .11713 .25843 Metetra
.953 .708 .53 r
.11713 .25843 .11734 .2717 .10494 .26306 .10474 .24991 Metetra
.951 .706 .531 r
.10474 .24991 .10494 .26306 .09235 .25447 .09207 .24309 Metetra
.953 .704 .522 r
.09207 .24309 .09235 .25447 .07959 .24568 .07933 .23431 Metetra
.953 .704 .522 r
.07933 .23431 .07959 .24568 .06672 .23575 .0664 .22536 Metetra
.953 .701 .517 r
.0664 .22536 .06672 .23575 .05359 .22673 .05329 .21636 Metetra
.953 .701 .516 r
.05329 .21636 .05359 .22673 .04027 .21758 .03999 .20715 Metetra
.954 .701 .516 r
.03999 .20715 .04027 .21758 .02676 .20824 .02652 .1976 Metetra
.938 .755 .629 r
.29499 .38434 .29616 .37654 .28616 .36945 .28499 .37684 Metetra
.939 .758 .631 r
.28499 .37684 .28616 .36945 .27604 .36218 .27484 .36988 Metetra
.94 .758 .629 r
.27484 .36988 .27604 .36218 .26577 .3552 .26454 .36335 Metetra
.94 .756 .627 r
.26454 .36335 .26577 .3552 .25538 .34799 .25413 .35614 Metetra
.941 .758 .626 r
.25413 .35614 .25538 .34799 .24476 .34314 .24354 .34997 Metetra
.943 .768 .634 r
.24354 .34997 .24476 .34314 .23363 .3469 .23273 .34569 Metetra
.828 .431 .297 r
.23273 .34569 .23363 .3469 .22264 .34315 .22143 .34915 Metetra
.96 .795 .633 r
.22143 .34915 .22264 .34315 .21135 .34257 .20993 .35296 Metetra
.944 .754 .616 r
.20993 .35296 .21135 .34257 .2002 .33528 .19869 .34711 Metetra
.952 .759 .606 r
.19869 .34711 .2002 .33528 .18836 .3392 .18698 .34762 Metetra
.946 .763 .624 r
.18698 .34762 .18836 .3392 .17689 .33156 .17531 .34383 Metetra
.94 .746 .612 r
.17531 .34383 .17689 .33156 .16554 .31846 .16379 .33341 Metetra
.936 .737 .609 r
.16379 .33341 .16554 .31846 .15387 .30865 .15247 .31657 Metetra
.931 .749 .634 r
.15247 .31657 .15387 .30865 .1425 .29058 .14079 .30373 Metetra
.928 .731 .616 r
.14079 .30373 .1425 .29058 .1306 .27935 .12959 .27971 Metetra
.674 .829 .958 r
.12959 .27971 .1306 .27935 .11835 .27133 .11734 .2717 Metetra
.676 .82 .953 r
.11734 .2717 .11835 .27133 .10598 .26235 .10494 .26306 Metetra
.777 .835 .897 r
.10494 .26306 .10598 .26235 .0934 .25368 .09235 .25447 Metetra
.791 .834 .885 r
.09235 .25447 .0934 .25368 .08065 .24491 .07959 .24568 Metetra
.783 .82 .882 r
.07959 .24568 .08065 .24491 .06793 .23272 .06672 .23575 Metetra
.913 .792 .713 r
.06672 .23575 .06793 .23272 .05481 .22368 .05359 .22673 Metetra
.913 .792 .713 r
.05359 .22673 .05481 .22368 .04133 .21701 .04027 .21758 Metetra
.735 .831 .924 r
.04027 .21758 .04133 .21701 .02823 .20206 .02676 .20824 Metetra
.953 .651 .425 r
.29616 .37654 .29696 .38041 .28679 .37827 .28616 .36945 Metetra
.954 .699 .512 r
.28616 .36945 .28679 .37827 .27682 .36633 .27604 .36218 Metetra
.953 .656 .437 r
.27604 .36218 .27682 .36633 .26656 .35919 .26577 .3552 Metetra
.953 .652 .429 r
.26577 .3552 .26656 .35919 .25598 .3569 .25538 .34799 Metetra
.95 .696 .517 r
.25538 .34799 .25598 .3569 .24546 .34926 .24476 .34314 Metetra
.931 .665 .512 r
.24476 .34314 .24546 .34926 .23462 .34576 .23363 .3469 Metetra
.869 .879 .842 r
.23363 .3469 .23462 .34576 .22348 .34581 .22264 .34315 Metetra
.917 .589 .405 r
.22264 .34315 .22348 .34581 .21238 .34109 .21135 .34257 Metetra
.874 .823 .794 r
.21135 .34257 .21238 .34109 .2011 .33679 .2002 .33528 Metetra
.851 .478 .343 r
.2002 .33528 .2011 .33679 .18967 .33196 .18836 .3392 Metetra
.938 .76 .635 r
.18836 .3392 .18967 .33196 .17789 .33107 .17689 .33156 Metetra
.718 .753 .879 r
.17689 .33156 .17789 .33107 .16642 .32036 .16554 .31846 Metetra
.909 .501 .164 r
.16554 .31846 .16642 .32036 .15495 .30682 .15387 .30865 Metetra
.84 .739 .752 r
.15387 .30865 .15495 .30682 .1433 .29399 .1425 .29058 Metetra
.956 .631 .365 r
.1425 .29058 .1433 .29399 .13154 .2803 .1306 .27935 Metetra
.683 .151 0 r
.1306 .27935 .13154 .2803 .11951 .26855 .11835 .27133 Metetra
.909 .792 .72 r
.11835 .27133 .11951 .26855 .10698 .2622 .10598 .26235 Metetra
.56 .789 .985 r
.10598 .26235 .10698 .2622 .09447 .25266 .0934 .25368 Metetra
.824 .832 .854 r
.0934 .25368 .09447 .25266 .08166 .24483 .08065 .24491 Metetra
.552 .73 .957 r
.08065 .24491 .08166 .24483 .06895 .23262 .06793 .23272 Metetra
.527 .777 .989 r
.06793 .23272 .06895 .23262 .05588 .22292 .05481 .22368 Metetra
.789 .871 .909 r
.05481 .22368 .05588 .22292 .04252 .21453 .04133 .21701 Metetra
.881 .769 .734 r
.04133 .21701 .04252 .21453 .02911 .20405 .02823 .20206 Metetra
.94 .652 .468 r
.29696 .38041 .29775 .38473 .28778 .37636 .28679 .37827 Metetra
.868 .767 .748 r
.28679 .37827 .28778 .37636 .27783 .36403 .27682 .36633 Metetra
.905 .799 .732 r
.27682 .36633 .27783 .36403 .26758 .35681 .26656 .35919 Metetra
.931 .835 .727 r
.26656 .35919 .26758 .35681 .25718 .35004 .25598 .3569 Metetra
.937 .76 .637 r
.25598 .3569 .25718 .35004 .24633 .35097 .24546 .34926 Metetra
.898 .503 .261 r
.24546 .34926 .24633 .35097 .23551 .34728 .23462 .34576 Metetra
.871 .478 .29 r
.23462 .34576 .23551 .34728 .22406 .35448 .22348 .34581 Metetra
.95 .694 .514 r
.22348 .34581 .22406 .35448 .21313 .34583 .21238 .34109 Metetra
.945 .659 .465 r
.21238 .34109 .21313 .34583 .20199 .3382 .2011 .33679 Metetra
.866 .426 .143 r
.2011 .33679 .20199 .3382 .19036 .33778 .18967 .33196 Metetra
.939 .667 .494 r
.18967 .33196 .19036 .33778 .17793 .34989 .17789 .33107 Metetra
.954 .717 .541 r
.17789 .33107 .17793 .34989 .16659 .33624 .16642 .32036 Metetra
.957 .716 .533 r
.16642 .32036 .16659 .33624 .15554 .31428 .15495 .30682 Metetra
.962 .696 .485 r
.15495 .30682 .15554 .31428 .14402 .29874 .1433 .29399 Metetra
.965 .67 .42 r
.1433 .29399 .14402 .29874 .13214 .28715 .13154 .2803 Metetra
.96 .69 .479 r
.13154 .2803 .13214 .28715 .12016 .27434 .11951 .26855 Metetra
.95 .672 .476 r
.11951 .26855 .12016 .27434 .10777 .26568 .10698 .2622 Metetra
.951 .63 .383 r
.10698 .2622 .10777 .26568 .09517 .2574 .09447 .25266 Metetra
.951 .658 .447 r
.09447 .25266 .09517 .2574 .08246 .24806 .08166 .24483 Metetra
.954 .619 .341 r
.08166 .24483 .08246 .24806 .0697 .23643 .06895 .23262 Metetra
.952 .639 .4 r
.06895 .23262 .0697 .23643 .05654 .22809 .05588 .22292 Metetra
.952 .664 .455 r
.05588 .22292 .05654 .22809 .04336 .21712 .04252 .21453 Metetra
.938 .576 .291 r
.04252 .21453 .04336 .21712 .0299 .20729 .02911 .20405 Metetra
.878 .798 .768 r
.29775 .38473 .29872 .38306 .28897 .36852 .28778 .37636 Metetra
.93 .746 .632 r
.28778 .37636 .28897 .36852 .27887 .3611 .27783 .36403 Metetra
.916 .788 .705 r
.27783 .36403 .27887 .3611 .26862 .35391 .26758 .35681 Metetra
.918 .792 .706 r
.26758 .35681 .26862 .35391 .25825 .34667 .25718 .35004 Metetra
.952 .827 .683 r
.25718 .35004 .25825 .34667 .24736 .34886 .24633 .35097 Metetra
.919 .834 .746 r
.24633 .35097 .24736 .34886 .23662 .34332 .23551 .34728 Metetra
.972 .843 .655 r
.23551 .34728 .23662 .34332 .22546 .34424 .22406 .35448 Metetra
.94 .75 .618 r
.22406 .35448 .22546 .34424 .2143 .34088 .21313 .34583 Metetra
.932 .771 .66 r
.21313 .34583 .2143 .34088 .20314 .33416 .20199 .3382 Metetra
.949 .809 .671 r
.20199 .3382 .20314 .33416 .19185 .32694 .19036 .33778 Metetra
.966 .778 .598 r
.19036 .33778 .19185 .32694 .17896 .34883 .17793 .34989 Metetra
.806 .764 .814 r
.17793 .34989 .17896 .34883 .16884 .31123 .16659 .33624 Metetra
.939 .732 .596 r
.16659 .33624 .16884 .31123 .15718 .30186 .15554 .31428 Metetra
.935 .74 .614 r
.15554 .31428 .15718 .30186 .14567 .28656 .14402 .29874 Metetra
.939 .745 .613 r
.14402 .29874 .14567 .28656 .13374 .27637 .13214 .28715 Metetra
.937 .746 .619 r
.13214 .28715 .13374 .27637 .12153 .26797 .12016 .27434 Metetra
.935 .764 .645 r
.12016 .27434 .12153 .26797 .10915 .2594 .10777 .26568 Metetra
.936 .766 .646 r
.10777 .26568 .10915 .2594 .09659 .25073 .09517 .2574 Metetra
.935 .762 .643 r
.09517 .2574 .09659 .25073 .08386 .24189 .08246 .24806 Metetra
.929 .76 .65 r
.08246 .24806 .08386 .24189 .07102 .23183 .0697 .23643 Metetra
.93 .778 .671 r
.0697 .23643 .07102 .23183 .05802 .22133 .05654 .22809 Metetra
.933 .76 .644 r
.05654 .22809 .05802 .22133 .0447 .21264 .04336 .21712 Metetra
.926 .776 .675 r
.04336 .21712 .0447 .21264 .03137 .20111 .0299 .20729 Metetra
.934 .738 .614 r
.29872 .38306 .30002 .37103 .29005 .364 .28897 .36852 Metetra
.929 .771 .664 r
.28897 .36852 .29005 .364 .27994 .35687 .27887 .3611 Metetra
.928 .775 .67 r
.27887 .3611 .27994 .35687 .26978 .3478 .26862 .35391 Metetra
.936 .763 .643 r
.26862 .35391 .26978 .3478 .25942 .34051 .25825 .34667 Metetra
.957 .788 .632 r
.25825 .34667 .25942 .34051 .24892 .33312 .24736 .34886 Metetra
.946 .746 .6 r
.24736 .34886 .24892 .33312 .23829 .32561 .23662 .34332 Metetra
.952 .749 .593 r
.23662 .34332 .23829 .32561 .22707 .32872 .22546 .34424 Metetra
.948 .748 .599 r
.22546 .34424 .22707 .32872 .21574 .33013 .2143 .34088 Metetra
.944 .752 .614 r
.2143 .34088 .21574 .33013 .20462 .32285 .20314 .33416 Metetra
.943 .751 .613 r
.20314 .33416 .20462 .32285 .19331 .31661 .19185 .32694 Metetra
.978 .795 .587 r
.19185 .32694 .19331 .31661 .18187 .30952 .17896 .34883 Metetra
.938 .726 .59 r
.17896 .34883 .18187 .30952 .17035 .30085 .16884 .31123 Metetra
.94 .75 .618 r
.16884 .31123 .17035 .30085 .15869 .29178 .15718 .30186 Metetra
.932 .743 .623 r
.15718 .30186 .15869 .29178 .147 .28025 .14567 .28656 Metetra
.932 .76 .646 r
.14567 .28656 .147 .28025 .13535 .26528 .13374 .27637 Metetra
.942 .751 .615 r
.13374 .27637 .13535 .26528 .12324 .25552 .12153 .26797 Metetra
.943 .749 .611 r
.12153 .26797 .12324 .25552 .11063 .25131 .10915 .2594 Metetra
.939 .758 .631 r
.10915 .2594 .11063 .25131 .09808 .24284 .09659 .25073 Metetra
.938 .759 .633 r
.09659 .25073 .09808 .24284 .08545 .23279 .08386 .24189 Metetra
.939 .754 .626 r
.08386 .24189 .08545 .23279 .07274 .22119 .07102 .23183 Metetra
.94 .75 .619 r
.07102 .23183 .07274 .22119 .05967 .21202 .05802 .22133 Metetra
.941 .756 .625 r
.05802 .22133 .05967 .21202 .04623 .20529 .0447 .21264 Metetra
.934 .757 .64 r
.0447 .21264 .04623 .20529 .03347 .18641 .03137 .20111 Metetra
.932 .77 .659 r
.30002 .37103 .3011 .36623 .29113 .35917 .29005 .364 Metetra
.932 .77 .659 r
.29005 .364 .29113 .35917 .28104 .35202 .27994 .35687 Metetra
.927 .764 .66 r
.27994 .35687 .28104 .35202 .27082 .3448 .26978 .3478 Metetra
.917 .788 .702 r
.26978 .3478 .27082 .3448 .26047 .33748 .25942 .34051 Metetra
.917 .788 .702 r
.25942 .34051 .26047 .33748 .24998 .33008 .24892 .33312 Metetra
.917 .788 .702 r
.24892 .33312 .24998 .33008 .23936 .32257 .23829 .32561 Metetra
.959 .851 .691 r
.23829 .32561 .23936 .32257 .22832 .32152 .22707 .32872 Metetra
.955 .779 .625 r
.22707 .32872 .22832 .32152 .21715 .31971 .21574 .33013 Metetra
.943 .752 .616 r
.21574 .33013 .21715 .31971 .20571 .3201 .20462 .32285 Metetra
.919 .803 .716 r
.20462 .32285 .20571 .3201 .19444 .3131 .19331 .31661 Metetra
.925 .788 .691 r
.19331 .31661 .19444 .3131 .18304 .30542 .18187 .30952 Metetra
.925 .776 .678 r
.18187 .30952 .18304 .30542 .1716 .29545 .17035 .30085 Metetra
.931 .766 .656 r
.17035 .30085 .1716 .29545 .15996 .2863 .15869 .29178 Metetra
.926 .76 .657 r
.15869 .29178 .15996 .2863 .14841 .27257 .147 .28025 Metetra
.928 .747 .637 r
.147 .28025 .14841 .27257 .13648 .26279 .13535 .26528 Metetra
.9 .791 .731 r
.13535 .26528 .13648 .26279 .12433 .25387 .12324 .25552 Metetra
.899 .859 .792 r
.12324 .25552 .12433 .25387 .11196 .24573 .11063 .25131 Metetra
.934 .769 .655 r
.11063 .25131 .11196 .24573 .09904 .24358 .09808 .24284 Metetra
0 .119 .579 r
.09808 .24284 .09904 .24358 .08632 .23499 .08545 .23279 Metetra
.924 .535 .204 r
.08545 .23279 .08632 .23499 .07338 .22668 .07274 .22119 Metetra
.954 .671 .46 r
.07274 .22119 .07338 .22668 .06029 .2179 .05967 .21202 Metetra
.95 .671 .474 r
.05967 .21202 .06029 .2179 .047 .20896 .04623 .20529 Metetra
.965 .64 .322 r
.04623 .20529 .047 .20896 .03462 .1846 .03347 .18641 Metetra
.955 .684 .483 r
.3011 .36623 .30183 .37236 .29186 .3653 .29113 .35917 Metetra
.955 .684 .483 r
.29113 .35917 .29186 .3653 .28177 .35796 .28104 .35202 Metetra
.955 .682 .479 r
.28104 .35202 .28177 .35796 .27159 .34939 .27082 .3448 Metetra
.954 .664 .448 r
.27082 .3448 .27159 .34939 .26117 .34383 .26047 .33748 Metetra
.955 .685 .485 r
.26047 .33748 .26117 .34383 .25047 .34189 .24998 .33008 Metetra
.954 .707 .526 r
.24998 .33008 .25047 .34189 .23936 .3459 .23936 .32257 Metetra
.948 .715 .552 r
.23936 .32257 .23936 .3459 .22823 .34626 .22832 .32152 Metetra
.949 .716 .553 r
.22832 .32152 .22823 .34626 .21727 .33901 .21715 .31971 Metetra
.947 .711 .549 r
.21715 .31971 .21727 .33901 .20579 .33945 .20571 .3201 Metetra
.952 .715 .544 r
.20571 .3201 .20579 .33945 .19449 .33252 .19444 .3131 Metetra
.952 .716 .544 r
.19444 .3131 .19449 .33252 .1819 .34864 .18304 .30542 Metetra
.951 .724 .558 r
.18304 .30542 .1819 .34864 .17115 .32366 .1716 .29545 Metetra
.952 .721 .551 r
.1716 .29545 .17115 .32366 .15978 .30848 .15996 .2863 Metetra
.955 .72 .543 r
.15996 .2863 .15978 .30848 .14837 .29126 .14841 .27257 Metetra
.953 .716 .541 r
.14841 .27257 .14837 .29126 .13643 .28123 .13648 .26279 Metetra
.953 .715 .541 r
.13648 .26279 .13643 .28123 .12453 .26751 .12433 .25387 Metetra
.953 .708 .53 r
.12433 .25387 .12453 .26751 .11217 .25886 .11196 .24573 Metetra
.947 .702 .534 r
.11196 .24573 .11217 .25886 .09964 .25013 .09904 .24358 Metetra
.954 .682 .481 r
.09904 .24358 .09964 .25013 .08692 .24126 .08632 .23499 Metetra
.954 .678 .477 r
.08632 .23499 .08692 .24126 .07407 .23159 .07338 .22668 Metetra
.953 .662 .446 r
.07338 .22668 .07407 .23159 .06099 .22246 .06029 .2179 Metetra
.953 .655 .434 r
.06029 .2179 .06099 .22246 .04773 .21304 .047 .20896 Metetra
.971 .656 .309 r
.047 .20896 .04773 .21304 .03476 .19676 .03462 .1846 Metetra
.954 .702 .516 r
.30183 .37236 .30246 .38182 .29258 .3717 .29186 .3653 Metetra
.955 .686 .486 r
.29186 .3653 .29258 .3717 .2825 .36382 .28177 .35796 Metetra
.958 .683 .473 r
.28177 .35796 .2825 .36382 .27227 .35664 .27159 .34939 Metetra
.952 .689 .501 r
.27159 .34939 .27227 .35664 .26186 .35041 .26117 .34383 Metetra
.944 .678 .503 r
.26117 .34383 .26186 .35041 .25105 .35114 .25047 .34189 Metetra
.938 .686 .531 r
.25047 .34189 .25105 .35114 .24009 .35144 .23936 .3459 Metetra
.937 .663 .495 r
.23936 .3459 .24009 .35144 .22908 .34899 .22823 .34626 Metetra
.942 .599 .345 r
.22823 .34626 .22908 .34899 .21808 .34244 .21727 .33901 Metetra
.924 .619 .446 r
.21727 .33901 .21808 .34244 .20696 .33501 .20579 .33945 Metetra
.932 .778 .669 r
.20579 .33945 .20696 .33501 .19517 .33866 .19449 .33252 Metetra
.906 .644 .531 r
.19449 .33252 .19517 .33866 .18202 .36625 .1819 .34864 Metetra
.965 .726 .526 r
.1819 .34864 .18202 .36625 .17159 .33438 .17115 .32366 Metetra
.962 .71 .509 r
.17115 .32366 .17159 .33438 .16051 .31331 .15978 .30848 Metetra
.972 .676 .402 r
.15978 .30848 .16051 .31331 .14914 .29524 .14837 .29126 Metetra
.956 .648 .406 r
.14837 .29126 .14914 .29524 .13763 .27754 .13643 .28123 Metetra
.906 .762 .691 r
.13643 .28123 .13763 .27754 .12538 .27009 .12453 .26751 Metetra
.938 .581 .31 r
.12453 .26751 .12538 .27009 .11307 .26062 .11217 .25886 Metetra
.895 .475 .152 r
.11217 .25886 .11307 .26062 .10049 .2525 .09964 .25013 Metetra
.931 .559 .277 r
.09964 .25013 .10049 .2525 .08786 .24237 .08692 .24126 Metetra
.73 .218 0 r
.08692 .24126 .08786 .24237 .07504 .23226 .07407 .23159 Metetra
0 .152 .588 r
.07407 .23159 .07504 .23226 .06224 .21898 .06099 .22246 Metetra
.919 .786 .699 r
.06099 .22246 .06224 .21898 .04898 .20977 .04773 .21304 Metetra
.894 .76 .705 r
.04773 .21304 .04898 .20977 .03586 .19576 .03476 .19676 Metetra
.691 .765 .908 r
.30246 .38182 .30339 .38148 .29357 .36968 .29258 .3717 Metetra
.894 .798 .746 r
.29258 .3717 .29357 .36968 .28348 .3624 .2825 .36382 Metetra
.872 .818 .793 r
.2825 .36382 .28348 .3624 .27326 .35503 .27227 .35664 Metetra
.888 .825 .779 r
.27227 .35664 .27326 .35503 .2629 .34783 .26186 .35041 Metetra
.948 .852 .714 r
.26186 .35041 .2629 .34783 .25217 .34668 .25105 .35114 Metetra
.953 .803 .658 r
.25105 .35114 .25217 .34668 .24108 .35044 .24009 .35144 Metetra
.858 .91 .867 r
.24009 .35144 .24108 .35044 .22978 .3549 .22908 .34899 Metetra
.953 .678 .479 r
.22908 .34899 .22978 .3549 .21891 .3454 .21808 .34244 Metetra
.945 .611 .363 r
.21808 .34244 .21891 .3454 .20767 .34077 .20696 .33501 Metetra
.93 .659 .504 r
.20696 .33501 .20767 .34077 .1964 .33321 .19517 .33866 Metetra
.995 .867 .569 r
.19517 .33866 .1964 .33321 .1838 .3497 .18202 .36625 Metetra
.926 .725 .61 r
.18202 .36625 .1838 .3497 .1732 .32178 .17159 .33438 Metetra
.93 .734 .616 r
.17159 .33438 .1732 .32178 .1617 .30931 .16051 .31331 Metetra
.897 .744 .684 r
.16051 .31331 .1617 .30931 .15027 .29263 .14914 .29524 Metetra
.872 .746 .721 r
.14914 .29524 .15027 .29263 .13856 .27861 .13763 .27754 Metetra
.756 .244 0 r
.13763 .27754 .13856 .27861 .12645 .26868 .12538 .27009 Metetra
.859 .813 .804 r
.12538 .27009 .12645 .26868 .11412 .25969 .11307 .26062 Metetra
.817 .841 .867 r
.11307 .26062 .11412 .25969 .10163 .25037 .10049 .2525 Metetra
.889 .798 .753 r
.10049 .2525 .10163 .25037 .08894 .24118 .08786 .24237 Metetra
.837 .815 .828 r
.08786 .24237 .08894 .24118 .076 .23307 .07504 .23226 Metetra
0 .141 .645 r
.07504 .23226 .076 .23307 .06293 .22395 .06224 .21898 Metetra
.954 .662 .445 r
.06224 .21898 .06293 .22395 .04966 .21471 .04898 .20977 Metetra
.963 .668 .425 r
.04898 .20977 .04966 .21471 .03682 .19673 .03586 .19576 Metetra
.913 .757 .674 r
.30339 .38148 .30444 .37736 .29458 .36726 .29357 .36968 Metetra
.908 .796 .725 r
.29357 .36968 .29458 .36726 .28449 .3601 .28348 .3624 Metetra
.905 .798 .732 r
.28348 .3624 .28449 .3601 .27427 .35289 .27326 .35503 Metetra
.901 .803 .742 r
.27326 .35503 .27427 .35289 .26391 .34603 .2629 .34783 Metetra
.924 .872 .767 r
.2629 .34783 .26391 .34603 .25306 .34819 .25217 .34668 Metetra
.854 .482 .346 r
.25217 .34668 .25306 .34819 .24218 .34685 .24108 .35044 Metetra
.965 .841 .67 r
.24108 .35044 .24218 .34685 .23077 .35422 .22978 .3549 Metetra
.774 .804 .877 r
.22978 .3549 .23077 .35422 .21991 .34438 .21891 .3454 Metetra
.849 .876 .86 r
.21891 .3454 .21991 .34438 .20866 .34015 .20767 .34077 Metetra
.766 .838 .907 r
.20767 .34077 .20866 .34015 .19683 .34482 .1964 .33321 Metetra
.927 .682 .549 r
.1964 .33321 .19683 .34482 .18473 .35082 .1838 .3497 Metetra
.116 .27 .745 r
.1838 .3497 .18473 .35082 .17353 .33484 .1732 .32178 Metetra
.958 .712 .523 r
.1732 .32178 .17353 .33484 .16257 .31147 .1617 .30931 Metetra
.892 .496 .058 r
.1617 .30931 .16257 .31147 .15075 .30206 .15027 .29263 Metetra
.962 .705 .501 r
.15027 .29263 .15075 .30206 .13955 .27862 .13856 .27861 Metetra
.481 .73 .98 r
.13856 .27861 .13955 .27862 .12736 .27017 .12645 .26868 Metetra
.856 .402 .043 r
.12645 .26868 .12736 .27017 .11502 .26141 .11412 .25969 Metetra
.888 .46 .121 r
.11412 .25969 .11502 .26141 .10249 .25274 .10163 .25037 Metetra
.931 .559 .272 r
.10163 .25037 .10249 .25274 .08978 .24386 .08894 .24118 Metetra
.937 .584 .325 r
.08894 .24118 .08978 .24386 .07694 .23417 .076 .23307 Metetra
.733 .218 0 r
.076 .23307 .07694 .23417 .06382 .2257 .06293 .22395 Metetra
.89 .464 .136 r
.06293 .22395 .06382 .2257 .05059 .21609 .04966 .21471 Metetra
.628 .185 0 r
.04966 .21471 .05059 .21609 .03788 .19621 .03682 .19673 Metetra
.75 .779 .876 r
.30444 .37736 .30538 .37679 .29552 .36667 .29458 .36726 Metetra
.766 .832 .903 r
.29458 .36726 .29552 .36667 .28545 .35933 .28449 .3601 Metetra
.803 .832 .873 r
.28449 .3601 .28545 .35933 .27524 .35207 .27427 .35289 Metetra
.813 .839 .869 r
.27427 .35289 .27524 .35207 .26489 .34502 .26391 .34603 Metetra
.859 .98 .857 r
.26391 .34603 .26489 .34502 .25407 .34637 .25306 .34819 Metetra
.924 .87 .767 r
.25306 .34819 .25407 .34637 .24316 .34617 .24218 .34685 Metetra
.444 .837 .624 r
.24218 .34685 .24316 .34617 .23228 .34097 .23077 .35422 Metetra
.942 .745 .608 r
.23077 .35422 .23228 .34097 .22087 .34447 .21991 .34438 Metetra
.19 .675 .927 r
.21991 .34438 .22087 .34447 .20971 .33821 .20866 .34015 Metetra
.949 .925 .748 r
.20866 .34015 .20971 .33821 .19808 .33877 .19683 .34482 Metetra
.965 .802 .63 r
.19683 .34482 .19808 .33877 .18609 .34291 .18473 .35082 Metetra
.927 .744 .635 r
.18473 .35082 .18609 .34291 .17518 .32147 .17353 .33484 Metetra
.929 .732 .615 r
.17353 .33484 .17518 .32147 .16368 .30907 .16257 .31147 Metetra
.9 .794 .734 r
.16257 .31147 .16368 .30907 .152 .29734 .15075 .30206 Metetra
.893 .729 .672 r
.15075 .30206 .152 .29734 .14073 .27524 .13955 .27862 Metetra
.92 .787 .698 r
.13955 .27862 .14073 .27524 .12856 .26665 .12736 .27017 Metetra
.921 .785 .694 r
.12736 .27017 .12856 .26665 .11615 .25917 .11502 .26141 Metetra
.899 .805 .747 r
.11502 .26141 .11615 .25917 .10366 .24997 .10249 .25274 Metetra
.91 .796 .722 r
.10249 .25274 .10366 .24997 .09096 .24114 .08978 .24386 Metetra
.906 .793 .725 r
.08978 .24386 .09096 .24114 .07813 .23154 .07694 .23417 Metetra
.91 .803 .729 r
.07694 .23417 .07813 .23154 .06526 .21958 .06382 .2257 Metetra
.934 .766 .65 r
.06382 .2257 .06526 .21958 .0518 .2133 .05059 .21609 Metetra
.873 .745 .718 r
.05059 .21609 .0518 .2133 .03887 .19668 .03788 .19621 Metetra
.956 .621 .335 r
.30538 .37679 .30622 .3798 .29637 .36908 .29552 .36667 Metetra
.939 .581 .306 r
.29552 .36667 .29637 .36908 .28644 .35757 .28545 .35933 Metetra
.889 .81 .765 r
.28545 .35933 .28644 .35757 .27624 .35028 .27524 .35207 Metetra
.891 .812 .764 r
.27524 .35207 .27624 .35028 .2659 .34299 .26489 .34502 Metetra
.943 .885 .746 r
.26489 .34502 .2659 .34299 .25546 .33483 .25407 .34637 Metetra
.952 .759 .605 r
.25407 .34637 .25546 .33483 .24455 .33511 .24316 .34617 Metetra
.946 .754 .611 r
.24316 .34617 .24455 .33511 .2336 .33221 .23228 .34097 Metetra
.958 .775 .613 r
.23228 .34097 .2336 .33221 .22263 .32608 .22087 .34447 Metetra
.947 .744 .596 r
.22087 .34447 .22263 .32608 .21133 .32372 .20971 .33821 Metetra
.953 .755 .598 r
.20971 .33821 .21133 .32372 .20011 .31608 .19808 .33877 Metetra
.954 .748 .587 r
.19808 .33877 .20011 .31608 .18872 .30855 .18609 .34291 Metetra
.943 .732 .588 r
.18609 .34291 .18872 .30855 .1772 .30056 .17518 .32147 Metetra
.944 .739 .596 r
.17518 .32147 .1772 .30056 .16574 .28836 .16368 .30907 Metetra
.944 .739 .596 r
.16368 .30907 .16574 .28836 .15391 .28003 .152 .29734 Metetra
.936 .733 .605 r
.152 .29734 .15391 .28003 .14218 .26688 .14073 .27524 Metetra
.94 .757 .628 r
.14073 .27524 .14218 .26688 .13002 .25851 .12856 .26665 Metetra
.941 .76 .629 r
.12856 .26665 .13002 .25851 .1177 .24989 .11615 .25917 Metetra
.94 .755 .624 r
.11615 .25917 .1177 .24989 .10495 .2453 .10366 .24997 Metetra
.929 .776 .669 r
.10366 .24997 .10495 .2453 .09227 .23645 .09096 .24114 Metetra
.928 .774 .67 r
.09096 .24114 .09227 .23645 .07943 .22716 .07813 .23154 Metetra
.92 .769 .677 r
.07813 .23154 .07943 .22716 .06647 .21661 .06526 .21958 Metetra
.923 .81 .716 r
.06526 .21958 .06647 .21661 .0533 .20642 .0518 .2133 Metetra
.924 .749 .646 r
.0518 .2133 .0533 .20642 .04031 .19101 .03887 .19668 Metetra
.934 .75 .63 r
.30622 .3798 .30738 .37195 .29751 .36268 .29637 .36908 Metetra
.928 .752 .643 r
.29637 .36908 .29751 .36268 .28744 .35554 .28644 .35757 Metetra
.898 .804 .747 r
.28644 .35757 .28744 .35554 .27724 .3483 .27624 .35028 Metetra
.896 .806 .751 r
.27624 .35028 .27724 .3483 .26691 .341 .2659 .34299 Metetra
.892 .8 .75 r
.2659 .34299 .26691 .341 .25645 .3336 .25546 .33483 Metetra
.895 .934 .834 r
.25546 .33483 .25645 .3336 .24585 .32611 .24455 .33511 Metetra
.949 .762 .618 r
.24455 .33511 .24585 .32611 .23499 .32168 .2336 .33221 Metetra
.945 .754 .614 r
.2336 .33221 .23499 .32168 .22408 .3145 .22263 .32608 Metetra
.95 .757 .607 r
.22263 .32608 .22408 .3145 .21262 .31646 .21133 .32372 Metetra
.939 .761 .634 r
.21133 .32372 .21262 .31646 .20133 .31062 .20011 .31608 Metetra
.935 .77 .653 r
.20011 .31608 .20133 .31062 .18973 .30799 .18872 .30855 Metetra
.748 .834 .917 r
.18872 .30855 .18973 .30799 .1784 .29613 .1772 .30056 Metetra
.918 .762 .673 r
.1772 .30056 .1784 .29613 .16688 .28517 .16574 .28836 Metetra
.918 .789 .703 r
.16574 .28836 .16688 .28517 .15547 .26934 .15391 .28003 Metetra
.937 .746 .619 r
.15391 .28003 .15547 .26934 .14373 .25689 .14218 .26688 Metetra
.942 .754 .619 r
.14218 .26688 .14373 .25689 .1316 .24831 .13002 .25851 Metetra
.942 .753 .618 r
.13002 .25851 .1316 .24831 .11933 .23935 .1177 .24989 Metetra
.947 .758 .614 r
.1177 .24989 .11933 .23935 .10659 .2349 .10495 .2453 Metetra
.942 .753 .618 r
.10495 .2453 .10659 .2349 .09393 .22606 .09227 .23645 Metetra
.942 .753 .618 r
.09227 .23645 .09393 .22606 .08108 .21731 .07943 .22716 Metetra
.94 .752 .622 r
.07943 .22716 .08108 .21731 .06798 .20928 .06647 .21661 Metetra
.936 .76 .638 r
.06647 .21661 .06798 .20928 .05461 .20232 .0533 .20642 Metetra
.909 .76 .685 r
.0533 .20642 .05461 .20232 .04164 .18667 .04031 .19101 Metetra
.236 .576 .942 r
.30738 .37195 .3083 .37226 .29837 .36486 .29751 .36268 Metetra
.931 .56 .275 r
.29751 .36268 .29837 .36486 .28832 .35695 .28744 .35554 Metetra
.86 .408 .056 r
.28744 .35554 .28832 .35695 .27813 .34974 .27724 .3483 Metetra
.865 .416 .067 r
.27724 .3483 .27813 .34974 .26779 .34281 .26691 .341 Metetra
.909 .503 .19 r
.26691 .341 .26779 .34281 .25726 .33714 .25645 .3336 Metetra
.952 .637 .4 r
.25645 .3336 .25726 .33714 .24616 .34247 .24585 .32611 Metetra
.951 .711 .54 r
.24585 .32611 .24616 .34247 .23492 .34661 .23499 .32168 Metetra
.952 .719 .549 r
.23499 .32168 .23492 .34661 .22387 .34189 .22408 .3145 Metetra
.947 .716 .555 r
.22408 .3145 .22387 .34189 .21254 .33992 .21262 .31646 Metetra
.951 .717 .548 r
.21262 .31646 .21254 .33992 .20109 .33676 .20133 .31062 Metetra
.95 .717 .552 r
.20133 .31062 .20109 .33676 .1887 .3498 .18973 .30799 Metetra
.953 .725 .556 r
.18973 .30799 .1887 .3498 .17744 .3352 .1784 .29613 Metetra
.953 .724 .555 r
.1784 .29613 .17744 .3352 .16655 .31083 .16688 .28517 Metetra
.956 .723 .545 r
.16688 .28517 .16655 .31083 .15508 .29517 .15547 .26934 Metetra
.954 .721 .547 r
.15547 .26934 .15508 .29517 .14346 .27958 .14373 .25689 Metetra
.953 .718 .546 r
.14373 .25689 .14346 .27958 .1314 .26924 .1316 .24831 Metetra
.953 .717 .543 r
.1316 .24831 .1314 .26924 .11917 .25897 .11933 .23935 Metetra
.95 .713 .544 r
.11933 .23935 .11917 .25897 .10667 .25011 .10659 .2349 Metetra
.954 .711 .533 r
.10659 .2349 .10667 .25011 .09407 .23996 .09393 .22606 Metetra
.954 .709 .529 r
.09393 .22606 .09407 .23996 .08112 .23237 .08108 .21731 Metetra
.953 .71 .533 r
.08108 .21731 .08112 .23237 .06816 .22187 .06798 .20928 Metetra
.952 .704 .526 r
.06798 .20928 .06816 .22187 .05491 .21271 .05461 .20232 Metetra
.962 .707 .505 r
.05461 .20232 .05491 .21271 .04199 .19626 .04164 .18667 Metetra
.954 .711 .531 r
.3083 .37226 .30882 .38574 .29885 .37904 .29837 .36486 Metetra
.955 .712 .532 r
.29837 .36486 .29885 .37904 .28896 .36609 .28832 .35695 Metetra
.955 .7 .512 r
.28832 .35695 .28896 .36609 .27875 .35897 .27813 .34974 Metetra
.954 .7 .513 r
.27813 .34974 .27875 .35897 .26834 .35355 .26779 .34281 Metetra
.952 .703 .523 r
.26779 .34281 .26834 .35355 .25792 .34494 .25726 .33714 Metetra
.934 .677 .525 r
.25726 .33714 .25792 .34494 .24693 .34717 .24616 .34247 Metetra
.924 .644 .492 r
.24616 .34247 .24693 .34717 .23588 .34649 .23492 .34661 Metetra
.488 .823 .999 r
.23492 .34661 .23588 .34649 .22488 .34077 .22387 .34189 Metetra
.872 .912 .854 r
.22387 .34189 .22488 .34077 .21339 .34265 .21254 .33992 Metetra
.928 .593 .382 r
.21254 .33992 .21339 .34265 .20174 .34385 .20109 .33676 Metetra
.918 .659 .53 r
.20109 .33676 .20174 .34385 .18944 .35482 .1887 .3498 Metetra
.968 .676 .421 r
.1887 .3498 .18944 .35482 .17875 .32863 .17744 .3352 Metetra
.906 .729 .65 r
.17744 .3352 .17875 .32863 .16747 .31207 .16655 .31083 Metetra
0 0 .432 r
.16655 .31083 .16747 .31207 .15597 .29697 .15508 .29517 Metetra
.837 .412 0 r
.15508 .29517 .15597 .29697 .14435 .28157 .14346 .27958 Metetra
.913 .51 .173 r
.14346 .27958 .14435 .28157 .13229 .2712 .1314 .26924 Metetra
.909 .502 .165 r
.1314 .26924 .13229 .2712 .11993 .26305 .11917 .25897 Metetra
.953 .646 .415 r
.11917 .25897 .11993 .26305 .10746 .25375 .10667 .25011 Metetra
.953 .634 .383 r
.10667 .25011 .10746 .25375 .09472 .24568 .09407 .23996 Metetra
.952 .671 .467 r
.09407 .23996 .09472 .24568 .08187 .23642 .08112 .23237 Metetra
.955 .645 .403 r
.08112 .23237 .08187 .23642 .06886 .22664 .06816 .22187 Metetra
.954 .659 .438 r
.06816 .22187 .06886 .22664 .05573 .21579 .05491 .21271 Metetra
.954 .607 .278 r
.05491 .21271 .05573 .21579 .04283 .19889 .04199 .19626 Metetra
.941 .759 .63 r
.30882 .38574 .30996 .37836 .3001 .36886 .29885 .37904 Metetra
.935 .743 .619 r
.29885 .37904 .3001 .36886 .29006 .36105 .28896 .36609 Metetra
.934 .77 .655 r
.28896 .36609 .29006 .36105 .27993 .35192 .27875 .35897 Metetra
.943 .764 .632 r
.27875 .35897 .27993 .35192 .26953 .34673 .26834 .35355 Metetra
.936 .759 .637 r
.26834 .35355 .26953 .34673 .25889 .34431 .25792 .34494 Metetra
.686 .978 .89 r
.25792 .34494 .25889 .34431 .24802 .34349 .24693 .34717 Metetra
.949 .814 .677 r
.24693 .34717 .24802 .34349 .2368 .34743 .23588 .34649 Metetra
.736 .212 0 r
.23588 .34649 .2368 .34743 .22591 .33915 .22488 .34077 Metetra
.928 .922 .785 r
.22488 .34077 .22591 .33915 .21434 .3429 .21339 .34265 Metetra
.429 0 0 r
.21339 .34265 .21434 .3429 .20278 .34231 .20174 .34385 Metetra
.86 .981 .689 r
.20174 .34385 .20278 .34231 .19108 .34087 .18944 .35482 Metetra
.928 .729 .614 r
.18944 .35482 .19108 .34087 .1798 .32727 .17875 .32863 Metetra
.819 .745 .782 r
.17875 .32863 .1798 .32727 .16808 .31934 .16747 .31207 Metetra
.966 .697 .472 r
.16747 .31207 .16808 .31934 .15695 .29727 .15597 .29697 Metetra
.373 .579 .921 r
.15597 .29697 .15695 .29727 .14453 .29634 .14435 .28157 Metetra
.955 .712 .53 r
.14435 .28157 .14453 .29634 .13338 .26964 .13229 .2712 Metetra
.875 .824 .794 r
.13229 .2712 .13338 .26964 .12106 .26091 .11993 .26305 Metetra
.894 .803 .752 r
.11993 .26305 .12106 .26091 .10855 .25223 .10746 .25375 Metetra
.872 .829 .802 r
.10746 .25375 .10855 .25223 .09611 .2396 .09472 .24568 Metetra
.935 .767 .649 r
.09472 .24568 .09611 .2396 .08327 .23048 .08187 .23642 Metetra
.934 .767 .651 r
.08187 .23642 .08327 .23048 .07021 .22173 .06886 .22664 Metetra
.927 .77 .667 r
.06886 .22664 .07021 .22173 .05696 .21282 .05573 .21579 Metetra
.887 .759 .714 r
.05573 .21579 .05696 .21282 .044 .19692 .04283 .19889 Metetra
.91 .774 .698 r
.30996 .37836 .31098 .37524 .30108 .36718 .3001 .36886 Metetra
.882 .806 .769 r
.3001 .36886 .30108 .36718 .29103 .35999 .29006 .36105 Metetra
.831 .802 .823 r
.29006 .36105 .29103 .35999 .28084 .35282 .27993 .35192 Metetra
.727 .199 0 r
.27993 .35192 .28084 .35282 .27051 .3456 .26953 .34673 Metetra
.875 .9 .846 r
.26953 .34673 .27051 .3456 .25991 .34228 .25889 .34431 Metetra
.932 .866 .75 r
.25889 .34431 .25991 .34228 .24903 .34216 .24802 .34349 Metetra
.905 .973 .805 r
.24802 .34349 .24903 .34216 .23781 .34605 .2368 .34743 Metetra
.863 .815 .8 r
.2368 .34743 .23781 .34605 .2269 .33858 .22591 .33915 Metetra
.56 .933 .823 r
.22591 .33915 .2269 .33858 .21584 .33105 .21434 .3429 Metetra
.952 .759 .605 r
.21434 .3429 .21584 .33105 .20429 .33079 .20278 .34231 Metetra
.951 .759 .607 r
.20278 .34231 .20429 .33079 .19236 .33465 .19108 .34087 Metetra
.925 .752 .648 r
.19108 .34087 .19236 .33465 .18132 .31631 .1798 .32727 Metetra
.944 .752 .614 r
.1798 .32727 .18132 .31631 .17001 .30101 .16808 .31934 Metetra
.937 .733 .603 r
.16808 .31934 .17001 .30101 .15817 .29279 .15695 .29727 Metetra
.95 .804 .664 r
.15695 .29727 .15817 .29279 .14625 .28307 .14453 .29634 Metetra
.927 .73 .616 r
.14453 .29634 .14625 .28307 .13434 .27025 .13338 .26964 Metetra
0 .214 .65 r
.13338 .26964 .13434 .27025 .12201 .2618 .12106 .26091 Metetra
.612 .071 0 r
.12106 .26091 .12201 .2618 .10953 .2527 .10855 .25223 Metetra
.084 .464 .888 r
.10855 .25223 .10953 .2527 .09715 .23925 .09611 .2396 Metetra
.666 .817 .956 r
.09611 .2396 .09715 .23925 .0843 .23022 .08327 .23048 Metetra
.616 .813 .976 r
.08327 .23048 .0843 .23022 .07115 .22288 .07021 .22173 Metetra
.759 .252 0 r
.07021 .22173 .07115 .22288 .0579 .21397 .05696 .21282 Metetra
0 0 .452 r
.05696 .21282 .0579 .21397 .0453 .19309 .044 .19692 Metetra
.908 .788 .717 r
.31098 .37524 .31199 .37265 .30206 .36565 .30108 .36718 Metetra
.878 .815 .783 r
.30108 .36718 .30206 .36565 .29201 .35845 .29103 .35999 Metetra
.879 .817 .783 r
.29103 .35999 .29201 .35845 .28183 .35125 .28084 .35282 Metetra
.88 .817 .781 r
.28084 .35282 .28183 .35125 .27152 .34398 .27051 .3456 Metetra
.906 .859 .783 r
.27051 .3456 .27152 .34398 .26107 .33671 .25991 .34228 Metetra
.953 .789 .641 r
.25991 .34228 .26107 .33671 .24998 .34211 .24903 .34216 Metetra
.201 0 0 r
.24903 .34216 .24998 .34211 .23882 .3449 .23781 .34605 Metetra
.849 .83 .828 r
.23781 .34605 .23882 .3449 .22792 .33718 .2269 .33858 Metetra
.868 .824 .803 r
.2269 .33858 .22792 .33718 .21687 .32962 .21584 .33105 Metetra
.908 .914 .813 r
.21584 .33105 .21687 .32962 .20558 .32381 .20429 .33079 Metetra
.961 .788 .624 r
.20429 .33079 .20558 .32381 .19363 .32839 .19236 .33465 Metetra
.916 .741 .65 r
.19236 .33465 .19363 .32839 .18271 .30805 .18132 .31631 Metetra
.93 .745 .632 r
.18132 .31631 .18271 .30805 .17115 .29793 .17001 .30101 Metetra
.917 .792 .706 r
.17001 .30101 .17115 .29793 .15934 .2895 .15817 .29279 Metetra
.915 .782 .7 r
.15817 .29279 .15934 .2895 .1474 .28022 .14625 .28307 Metetra
.897 .772 .716 r
.14625 .28307 .1474 .28022 .13578 .26245 .13434 .27025 Metetra
.94 .76 .632 r
.13434 .27025 .13578 .26245 .12335 .25604 .12201 .2618 Metetra
.934 .768 .652 r
.12201 .2618 .12335 .25604 .11083 .24788 .10953 .2527 Metetra
.92 .761 .668 r
.10953 .2527 .11083 .24788 .0982 .2386 .09715 .23925 Metetra
.76 .833 .908 r
.09715 .23925 .0982 .2386 .08546 .22807 .0843 .23022 Metetra
.904 .821 .755 r
.0843 .23022 .08546 .22807 .07242 .21914 .07115 .22288 Metetra
.924 .787 .691 r
.07115 .22288 .07242 .21914 .05921 .20981 .0579 .21397 Metetra
.896 .743 .684 r
.0579 .21397 .05921 .20981 .04688 .18527 .0453 .19309 Metetra
.791 .834 .885 r
.31199 .37265 .31293 .37195 .30302 .36461 .30206 .36565 Metetra
.84 .827 .835 r
.30206 .36565 .30302 .36461 .29298 .35729 .29201 .35845 Metetra
.852 .826 .822 r
.29201 .35845 .29298 .35729 .28281 .34991 .28183 .35125 Metetra
.867 .822 .802 r
.28183 .35125 .28281 .34991 .27251 .3426 .27152 .34398 Metetra
.869 .822 .8 r
.27152 .34398 .27251 .3426 .26207 .33507 .26107 .33671 Metetra
.935 .957 .761 r
.26107 .33671 .26207 .33507 .25134 .33165 .24998 .34211 Metetra
.957 .767 .605 r
.24998 .34211 .25134 .33165 .24055 .32575 .23882 .3449 Metetra
.947 .743 .594 r
.23882 .3449 .24055 .32575 .22946 .32354 .22792 .33718 Metetra
.946 .748 .604 r
.22792 .33718 .22946 .32354 .21825 .32001 .21687 .32962 Metetra
.945 .757 .617 r
.21687 .32962 .21825 .32001 .20705 .31275 .20558 .32381 Metetra
.959 .768 .603 r
.20558 .32381 .20705 .31275 .19572 .30485 .19363 .32839 Metetra
.941 .734 .595 r
.19363 .32839 .19572 .30485 .18424 .29693 .18271 .30805 Metetra
.941 .749 .614 r
.18271 .30805 .18424 .29693 .17262 .28834 .17115 .29793 Metetra
.942 .754 .62 r
.17115 .29793 .17262 .28834 .16106 .27558 .15934 .2895 Metetra
.944 .747 .605 r
.15934 .2895 .16106 .27558 .14926 .26446 .1474 .28022 Metetra
.938 .738 .605 r
.1474 .28022 .14926 .26446 .13728 .2534 .13578 .26245 Metetra
.945 .76 .622 r
.13578 .26245 .13728 .2534 .12486 .2472 .12335 .25604 Metetra
.942 .758 .625 r
.12335 .25604 .12486 .2472 .1124 .23854 .11083 .24788 Metetra
.941 .755 .623 r
.11083 .24788 .1124 .23854 .09953 .23343 .0982 .2386 Metetra
.929 .768 .662 r
.0982 .2386 .09953 .23343 .08673 .22401 .08546 .22807 Metetra
.926 .783 .683 r
.08546 .22807 .08673 .22401 .07375 .21444 .07242 .21914 Metetra
.93 .776 .67 r
.07242 .21914 .07375 .21444 .06057 .20498 .05921 .20981 Metetra
.895 .733 .672 r
.05921 .20981 .06057 .20498 .04796 .1845 .04688 .18527 Metetra
.884 .81 .771 r
.31293 .37195 .31391 .3703 .30399 .36326 .30302 .36461 Metetra
.867 .818 .799 r
.30302 .36461 .30399 .36326 .29395 .35614 .29298 .35729 Metetra
.851 .823 .821 r
.29298 .35729 .29395 .35614 .28379 .3489 .28281 .34991 Metetra
.836 .829 .841 r
.28281 .34991 .28379 .3489 .27349 .34159 .27251 .3426 Metetra
.835 .827 .841 r
.27251 .3426 .27349 .34159 .26305 .33417 .26207 .33507 Metetra
.84 .899 .88 r
.26207 .33507 .26305 .33417 .25248 .32669 .25134 .33165 Metetra
.938 .777 .656 r
.25134 .33165 .25248 .32669 .24178 .31909 .24055 .32575 Metetra
.949 .776 .632 r
.24055 .32575 .24178 .31909 .23086 .31303 .22946 .32354 Metetra
.949 .758 .611 r
.22946 .32354 .23086 .31303 .21939 .31624 .21825 .32001 Metetra
.927 .785 .683 r
.21825 .32001 .21939 .31624 .2082 .30898 .20705 .31275 Metetra
.926 .783 .684 r
.20705 .31275 .2082 .30898 .19683 .30201 .19572 .30485 Metetra
.915 .795 .714 r
.19572 .30485 .19683 .30201 .18536 .29393 .18424 .29693 Metetra
.915 .79 .708 r
.18424 .29693 .18536 .29393 .17378 .28489 .17262 .28834 Metetra
.907 .767 .695 r
.17262 .28834 .17378 .28489 .1624 .26884 .16106 .27558 Metetra
.933 .758 .641 r
.16106 .27558 .1624 .26884 .15071 .25601 .14926 .26446 Metetra
.937 .753 .628 r
.14926 .26446 .15071 .25601 .13851 .24934 .13728 .2534 Metetra
.934 .79 .678 r
.13728 .2534 .13851 .24934 .12631 .23958 .12486 .2472 Metetra
.94 .761 .633 r
.12486 .2472 .12631 .23958 .11373 .23311 .1124 .23854 Metetra
.942 .782 .654 r
.1124 .23854 .11373 .23311 .10091 .22744 .09953 .23343 Metetra
.935 .767 .65 r
.09953 .23343 .10091 .22744 .08807 .21899 .08673 .22401 Metetra
.931 .773 .664 r
.08673 .22401 .08807 .21899 .07479 .21415 .07375 .21444 Metetra
.633 .808 .967 r
.07375 .21444 .07479 .21415 .06146 .20691 .06057 .20498 Metetra
.803 .395 0 r
.06057 .20498 .06146 .20691 .04912 .18253 .04796 .1845 Metetra
.565 .788 .983 r
.31391 .3703 .31484 .37018 .30493 .36324 .30399 .36326 Metetra
.495 .761 .99 r
.30399 .36326 .30493 .36324 .29489 .35611 .29395 .35614 Metetra
.496 .761 .99 r
.29395 .35614 .29489 .35611 .28473 .34889 .28379 .3489 Metetra
.476 .753 .991 r
.28379 .3489 .28473 .34889 .27443 .34161 .27349 .34159 Metetra
.456 .744 .99 r
.27349 .34159 .27443 .34161 .26381 .33945 .26305 .33417 Metetra
.956 .673 .461 r
.26305 .33417 .26381 .33945 .25282 .34275 .25248 .32669 Metetra
.954 .714 .536 r
.25248 .32669 .25282 .34275 .24161 .34718 .24178 .31909 Metetra
.952 .72 .551 r
.24178 .31909 .24161 .34718 .2308 .33757 .23086 .31303 Metetra
.947 .714 .553 r
.23086 .31303 .2308 .33757 .21964 .33258 .21939 .31624 Metetra
.954 .713 .536 r
.21939 .31624 .21964 .33258 .20839 .32619 .2082 .30898 Metetra
.953 .714 .538 r
.2082 .30898 .20839 .32619 .19665 .32663 .19683 .30201 Metetra
.953 .719 .547 r
.19683 .30201 .19665 .32663 .18551 .31114 .18536 .29393 Metetra
.955 .715 .536 r
.18536 .29393 .18551 .31114 .17394 .30128 .17378 .28489 Metetra
.96 .719 .528 r
.17378 .28489 .17394 .30128 .16236 .28845 .1624 .26884 Metetra
.957 .719 .538 r
.1624 .26884 .16236 .28845 .15049 .27838 .15071 .25601 Metetra
.952 .717 .545 r
.15071 .25601 .15049 .27838 .13874 .26301 .13851 .24934 Metetra
.956 .71 .526 r
.13851 .24934 .13874 .26301 .12645 .25439 .12631 .23958 Metetra
.952 .709 .532 r
.12631 .23958 .12645 .25439 .11388 .2474 .11373 .23311 Metetra
.952 .707 .532 r
.11373 .23311 .11388 .2474 .10125 .23838 .10091 .22744 Metetra
.955 .702 .516 r
.10091 .22744 .10125 .23838 .08836 .23035 .08807 .21899 Metetra
.951 .7 .522 r
.08807 .21899 .08836 .23035 .07533 .22156 .07479 .21415 Metetra
.953 .685 .491 r
.07479 .21415 .07533 .22156 .06214 .21198 .06146 .20691 Metetra
.978 .681 .372 r
.06146 .20691 .06214 .21198 .04944 .19273 .04912 .18253 Metetra
.956 .686 .484 r
.31484 .37018 .31558 .37662 .3058 .36527 .30493 .36324 Metetra
.924 .54 .243 r
.30493 .36324 .3058 .36527 .29577 .35777 .29489 .35611 Metetra
.895 .474 .147 r
.29489 .35611 .29577 .35777 .28562 .35024 .28473 .34889 Metetra
.845 .383 .021 r
.28473 .34889 .28562 .35024 .27532 .34315 .27443 .34161 Metetra
.882 .476 .247 r
.27443 .34161 .27532 .34315 .26466 .34194 .26381 .33945 Metetra
.899 .574 .422 r
.26381 .33945 .26466 .34194 .25377 .3429 .25282 .34275 Metetra
.456 0 0 r
.25282 .34275 .25377 .3429 .24295 .33772 .24161 .34718 Metetra
.94 .751 .62 r
.24161 .34718 .24295 .33772 .23201 .33171 .2308 .33757 Metetra
.943 .774 .644 r
.2308 .33757 .23201 .33171 .22094 .32501 .21964 .33258 Metetra
.943 .763 .63 r
.21964 .33258 .22094 .32501 .20972 .31824 .20839 .32619 Metetra
.955 .775 .621 r
.20839 .32619 .20972 .31824 .19771 .32504 .19665 .32663 Metetra
.839 .754 .769 r
.19665 .32663 .19771 .32504 .18681 .30448 .18551 .31114 Metetra
.935 .76 .641 r
.18551 .31114 .18681 .30448 .17528 .29432 .17394 .30128 Metetra
.93 .753 .64 r
.17394 .30128 .17528 .29432 .16345 .28659 .16236 .28845 Metetra
.88 .799 .766 r
.16236 .28845 .16345 .28659 .15178 .27295 .15049 .27838 Metetra
.919 .752 .659 r
.15049 .27838 .15178 .27295 .13966 .26441 .13874 .26301 Metetra
.836 .368 .003 r
.13874 .26301 .13966 .26441 .12738 .25574 .12645 .25439 Metetra
.84 .372 .042 r
.12645 .25439 .12738 .25574 .11491 .24715 .11388 .2474 Metetra
.62 .805 .971 r
.11388 .2474 .11491 .24715 .10228 .23806 .10125 .23838 Metetra
.649 .832 .971 r
.10125 .23838 .10228 .23806 .08946 .22911 .08836 .23035 Metetra
.848 .832 .832 r
.08836 .23035 .08946 .22911 .0765 .21926 .07533 .22156 Metetra
.898 .804 .746 r
.07533 .22156 .0765 .21926 .06334 .20947 .06214 .21198 Metetra
.868 .748 .729 r
.06214 .21198 .06334 .20947 .05037 .19414 .04944 .19273 Metetra
.77 .766 .849 r
.31558 .37662 .31653 .37593 .3067 .36603 .3058 .36527 Metetra
.51 0 0 r
.3058 .36527 .3067 .36603 .29674 .35675 .29577 .35777 Metetra
.836 .825 .837 r
.29577 .35777 .29674 .35675 .28658 .34953 .28562 .35024 Metetra
.792 .837 .886 r
.28562 .35024 .28658 .34953 .27626 .34325 .27532 .34315 Metetra
0 .511 .705 r
.27532 .34315 .27626 .34325 .26569 .33984 .26466 .34194 Metetra
.943 .88 .743 r
.26466 .34194 .26569 .33984 .25477 .34169 .25377 .3429 Metetra
.868 .858 .828 r
.25377 .3429 .25477 .34169 .24368 .34327 .24295 .33772 Metetra
.952 .673 .471 r
.24295 .33772 .24368 .34327 .23303 .33025 .23201 .33171 Metetra
.878 .832 .798 r
.23201 .33171 .23303 .33025 .22184 .32659 .22094 .32501 Metetra
.884 .453 .137 r
.22094 .32501 .22184 .32659 .21061 .32014 .20972 .31824 Metetra
.861 .518 .403 r
.20972 .31824 .21061 .32014 .19893 .31977 .19771 .32504 Metetra
.905 .736 .662 r
.19771 .32504 .19893 .31977 .18779 .30456 .18681 .30448 Metetra
.437 .698 .975 r
.18681 .30448 .18779 .30456 .17621 .29543 .17528 .29432 Metetra
.763 .256 0 r
.17528 .29432 .17621 .29543 .16443 .28676 .16345 .28659 Metetra
.429 .637 .943 r
.16345 .28659 .16443 .28676 .15274 .27354 .15178 .27295 Metetra
0 .243 .676 r
.15178 .27295 .15274 .27354 .14059 .2656 .13966 .26441 Metetra
.779 .282 0 r
.13966 .26441 .14059 .2656 .12836 .25615 .12738 .25574 Metetra
0 .431 .83 r
.12738 .25574 .12836 .25615 .11589 .24764 .11491 .24715 Metetra
0 .361 .781 r
.11491 .24715 .11589 .24764 .1033 .23805 .10228 .23806 Metetra
.448 .744 .991 r
.10228 .23806 .1033 .23805 .09047 .22916 .08946 .22911 Metetra
.423 .718 .986 r
.08946 .22911 .09047 .22916 .07745 .22038 .0765 .21926 Metetra
.728 .216 0 r
.0765 .21926 .07745 .22038 .06431 .21039 .06334 .20947 Metetra
0 .102 .625 r
.06334 .20947 .06431 .21039 .05136 .19469 .05037 .19414 Metetra
.475 .689 .961 r
.31653 .37593 .31745 .37602 .30767 .36488 .3067 .36603 Metetra
.839 .798 .812 r
.3067 .36603 .30767 .36488 .29767 .3569 .29674 .35675 Metetra
.309 .672 .975 r
.29674 .35675 .29767 .3569 .28753 .3493 .28658 .34953 Metetra
.622 .829 .98 r
.28658 .34953 .28753 .3493 .27722 .34279 .27626 .34325 Metetra
.712 .909 .964 r
.27626 .34325 .27722 .34279 .2667 .33825 .26569 .33984 Metetra
.929 .924 .785 r
.26569 .33984 .2667 .33825 .25575 .34087 .25477 .34169 Metetra
.801 .986 .89 r
.25477 .34169 .25575 .34087 .24471 .34154 .24368 .34327 Metetra
.858 .768 .762 r
.24368 .34327 .24471 .34154 .23399 .33024 .23303 .33025 Metetra
.295 .749 .956 r
.23303 .33025 .23399 .33024 .22281 .32654 .22184 .32659 Metetra
.473 .783 .998 r
.22184 .32659 .22281 .32654 .21155 .32084 .21061 .32014 Metetra
.704 .182 0 r
.21061 .32014 .21155 .32084 .19998 .31828 .19893 .31977 Metetra
.835 .756 .776 r
.19893 .31977 .19998 .31828 .18871 .30591 .18779 .30456 Metetra
.818 .344 0 r
.18779 .30456 .18871 .30591 .17709 .29749 .17621 .29543 Metetra
.918 .524 .215 r
.17621 .29543 .17709 .29749 .16551 .28507 .16443 .28676 Metetra
.857 .776 .771 r
.16443 .28676 .16551 .28507 .15372 .27376 .15274 .27354 Metetra
.183 .611 .943 r
.15274 .27354 .15372 .27376 .14155 .26649 .14059 .2656 Metetra
.57 .035 0 r
.14059 .2656 .14155 .26649 .12937 .25608 .12836 .25615 Metetra
.505 .772 .992 r
.12836 .25615 .12937 .25608 .11689 .24781 .11589 .24764 Metetra
.301 .655 .971 r
.11589 .24764 .11689 .24781 .10433 .23772 .1033 .23805 Metetra
.654 .819 .963 r
.1033 .23805 .10433 .23772 .09138 .23093 .09047 .22916 Metetra
.892 .468 .144 r
.09047 .22916 .09138 .23093 .07843 .22103 .07745 .22038 Metetra
0 .212 .66 r
.07745 .22038 .07843 .22103 .06526 .21145 .06431 .21039 Metetra
0 .002 .534 r
.06431 .21039 .06526 .21145 .05246 .19381 .05136 .19469 Metetra
.963 .645 .368 r
.31745 .37602 .31828 .37961 .3085 .36839 .30767 .36488 Metetra
.955 .639 .392 r
.30767 .36488 .3085 .36839 .29848 .36104 .29767 .3569 Metetra
.956 .656 .425 r
.29767 .3569 .29848 .36104 .28832 .35394 .28753 .3493 Metetra
.953 .663 .448 r
.28753 .3493 .28832 .35394 .27803 .34681 .27722 .34279 Metetra
.946 .647 .439 r
.27722 .34279 .27803 .34681 .2675 .34237 .2667 .33825 Metetra
.925 .636 .475 r
.2667 .33825 .2675 .34237 .25673 .34022 .25575 .34087 Metetra
.744 .977 .921 r
.25575 .34087 .25673 .34022 .24587 .33671 .24471 .34154 Metetra
.923 .761 .663 r
.24471 .34154 .24587 .33671 .23498 .32969 .23399 .33024 Metetra
.743 .909 .95 r
.23399 .33024 .23498 .32969 .22368 .32883 .22281 .32654 Metetra
.927 .562 .307 r
.22281 .32654 .22368 .32883 .2123 .32595 .21155 .32084 Metetra
.943 .66 .473 r
.21155 .32084 .2123 .32595 .1991 .35849 .19998 .31828 Metetra
.954 .725 .553 r
.19998 .31828 .1991 .35849 .18961 .30753 .18871 .30591 Metetra
.878 .441 .097 r
.18871 .30591 .18961 .30753 .17806 .2979 .17709 .29749 Metetra
.176 .512 .914 r
.17709 .29749 .17806 .2979 .16665 .28222 .16551 .28507 Metetra
.903 .779 .715 r
.16551 .28507 .16665 .28222 .15467 .27461 .15372 .27376 Metetra
.634 .086 0 r
.15372 .27376 .15467 .27461 .14259 .26568 .14155 .26649 Metetra
.788 .81 .87 r
.14155 .26649 .14259 .26568 .13041 .25534 .12937 .25608 Metetra
.783 .842 .897 r
.12937 .25608 .13041 .25534 .11789 .24798 .11689 .24781 Metetra
.319 .655 .971 r
.11689 .24781 .11789 .24798 .10535 .23754 .10433 .23772 Metetra
.543 .823 .998 r
.10433 .23772 .10535 .23754 .09253 .22879 .09138 .23093 Metetra
.892 .804 .755 r
.09138 .23093 .09253 .22879 .07954 .21976 .07843 .22103 Metetra
.847 .825 .826 r
.07843 .22103 .07954 .21976 .06632 .211 .06526 .21145 Metetra
.689 .718 .872 r
.06526 .21145 .06632 .211 .05346 .19425 .05246 .19381 Metetra
.85 .775 .778 r
.31828 .37961 .31925 .37815 .3094 .36936 .3085 .36839 Metetra
.687 .164 0 r
.3085 .36839 .3094 .36936 .29938 .36201 .29848 .36104 Metetra
.7 .177 0 r
.29848 .36104 .29938 .36201 .28924 .35466 .28832 .35394 Metetra
.498 0 0 r
.28832 .35394 .28924 .35466 .27901 .34582 .27803 .34681 Metetra
.849 .877 .86 r
.27803 .34681 .27901 .34582 .26859 .33843 .2675 .34237 Metetra
.946 .803 .671 r
.2675 .34237 .26859 .33843 .258 .33213 .25673 .34022 Metetra
.948 .766 .622 r
.25673 .34022 .258 .33213 .24712 .32921 .24587 .33671 Metetra
.942 .762 .63 r
.24587 .33671 .24712 .32921 .23602 .32792 .23498 .32969 Metetra
.924 .884 .775 r
.23498 .32969 .23602 .32792 .225 .32074 .22368 .32883 Metetra
.95 .768 .622 r
.22368 .32883 .225 .32074 .21363 .31801 .2123 .32595 Metetra
.997 .835 .56 r
.2123 .32595 .21363 .31801 .20226 .31148 .1991 .35849 Metetra
.938 .724 .587 r
.1991 .35849 .20226 .31148 .19108 .29742 .18961 .30753 Metetra
.942 .752 .618 r
.18961 .30753 .19108 .29742 .17951 .28847 .17806 .2979 Metetra
.933 .744 .625 r
.17806 .2979 .17951 .28847 .16776 .27999 .16665 .28222 Metetra
.904 .812 .746 r
.16665 .28222 .16776 .27999 .15603 .26778 .15467 .27461 Metetra
.938 .763 .639 r
.15467 .27461 .15603 .26778 .14401 .2581 .14259 .26568 Metetra
.937 .758 .634 r
.14259 .26568 .14401 .2581 .13182 .24828 .13041 .25534 Metetra
.942 .766 .636 r
.13041 .25534 .13182 .24828 .11939 .23954 .11789 .24798 Metetra
.939 .756 .628 r
.11789 .24798 .11939 .23954 .10658 .23408 .10535 .23754 Metetra
.922 .79 .697 r
.10535 .23754 .10658 .23408 .0939 .22328 .09253 .22879 Metetra
.935 .772 .656 r
.09253 .22879 .0939 .22328 .08096 .21366 .07954 .21976 Metetra
.937 .77 .649 r
.07954 .21976 .08096 .21366 .06774 .20517 .06632 .211 Metetra
.921 .752 .656 r
.06632 .211 .06774 .20517 .05504 .18636 .05346 .19425 Metetra
.939 .755 .627 r
.31925 .37815 .3204 .37029 .31052 .3632 .3094 .36936 Metetra
.938 .764 .64 r
.3094 .36936 .31052 .3632 .30058 .35393 .29938 .36201 Metetra
.942 .757 .625 r
.29938 .36201 .30058 .35393 .29045 .34644 .28924 .35466 Metetra
.939 .754 .625 r
.28924 .35466 .29045 .34644 .28012 .34103 .27901 .34582 Metetra
.933 .773 .659 r
.27901 .34582 .28012 .34103 .26971 .33361 .26859 .33843 Metetra
.937 .777 .658 r
.26859 .33843 .26971 .33361 .2594 .3203 .258 .33213 Metetra
.951 .756 .605 r
.258 .33213 .2594 .3203 .24848 .31905 .24712 .32921 Metetra
.952 .763 .61 r
.24712 .32921 .24848 .31905 .23762 .31243 .23602 .32792 Metetra
.947 .747 .599 r
.23602 .32792 .23762 .31243 .22629 .31312 .225 .32074 Metetra
.95 .771 .625 r
.225 .32074 .22629 .31312 .21509 .30688 .21363 .31801 Metetra
.946 .754 .611 r
.21363 .31801 .21509 .30688 .20368 .30185 .20226 .31148 Metetra
.935 .746 .622 r
.20226 .31148 .20368 .30185 .1924 .2904 .19108 .29742 Metetra
.938 .761 .636 r
.19108 .29742 .1924 .2904 .18085 .28136 .17951 .28847 Metetra
.939 .762 .636 r
.17951 .28847 .18085 .28136 .16925 .27022 .16776 .27999 Metetra
.938 .749 .621 r
.16776 .27999 .16925 .27022 .15763 .25653 .15603 .26778 Metetra
.943 .751 .613 r
.15603 .26778 .15763 .25653 .14547 .24973 .14401 .2581 Metetra
.94 .757 .628 r
.14401 .2581 .14547 .24973 .13321 .24158 .13182 .24828 Metetra
.938 .765 .641 r
.13182 .24828 .13321 .24158 .1207 .23443 .11939 .23954 Metetra
.941 .784 .658 r
.11939 .23954 .1207 .23443 .10787 .2296 .10658 .23408 Metetra
.925 .773 .673 r
.10658 .23408 .10787 .2296 .09508 .22067 .0939 .22328 Metetra
.906 .798 .73 r
.0939 .22328 .09508 .22067 .0821 .21179 .08096 .21366 Metetra
.889 .821 .775 r
.08096 .21366 .0821 .21179 .06886 .20384 .06774 .20517 Metetra
.809 .743 .79 r
.06774 .20517 .06886 .20384 .0559 .18883 .05504 .18636 Metetra
.95 .627 .378 r
.3204 .37029 .32124 .37348 .31144 .36344 .31052 .3632 Metetra
.308 .62 .958 r
.31052 .3632 .31144 .36344 .30145 .35604 .30058 .35393 Metetra
.927 .547 .248 r
.30058 .35393 .30145 .35604 .29131 .34881 .29045 .34644 Metetra
.932 .575 .322 r
.29045 .34644 .29131 .34881 .28104 .34156 .28012 .34103 Metetra
0 .281 .712 r
.28012 .34103 .28104 .34156 .27053 .33745 .26971 .33361 Metetra
.966 .652 .364 r
.26971 .33361 .27053 .33745 .2596 .34016 .2594 .3203 Metetra
.95 .713 .545 r
.2594 .3203 .2596 .34016 .24873 .3371 .24848 .31905 Metetra
.954 .715 .539 r
.24848 .31905 .24873 .3371 .23763 .33565 .23762 .31243 Metetra
.949 .715 .549 r
.23762 .31243 .23763 .33565 .2266 .32875 .22629 .31312 Metetra
.953 .712 .534 r
.22629 .31312 .2266 .32875 .21538 .32254 .21509 .30688 Metetra
.952 .711 .535 r
.21509 .30688 .21538 .32254 .20364 .32401 .20368 .30185 Metetra
.956 .72 .541 r
.20368 .30185 .20364 .32401 .1926 .30683 .1924 .2904 Metetra
.955 .714 .533 r
.1924 .2904 .1926 .30683 .18099 .29857 .18085 .28136 Metetra
.957 .716 .533 r
.18085 .28136 .18099 .29857 .16922 .29018 .16925 .27022 Metetra
.958 .72 .536 r
.16925 .27022 .16922 .29018 .15735 .28054 .15763 .25653 Metetra
.953 .718 .545 r
.15763 .25653 .15735 .28054 .14572 .26333 .14547 .24973 Metetra
.955 .709 .526 r
.14547 .24973 .14572 .26333 .13348 .2545 .13321 .24158 Metetra
.954 .707 .525 r
.13321 .24158 .13348 .2545 .12096 .24717 .1207 .23443 Metetra
.952 .704 .526 r
.1207 .23443 .12096 .24717 .10845 .23673 .10787 .2296 Metetra
.956 .686 .483 r
.10787 .2296 .10845 .23673 .09559 .22882 .09508 .22067 Metetra
.956 .692 .494 r
.09508 .22067 .09559 .22882 .08266 .219 .0821 .21179 Metetra
.954 .684 .486 r
.0821 .21179 .08266 .219 .06951 .20955 .06886 .20384 Metetra
.966 .68 .438 r
.06886 .20384 .06951 .20955 .05644 .19589 .0559 .18883 Metetra
.961 .644 .377 r
.32124 .37348 .32207 .37707 .31226 .36746 .31144 .36344 Metetra
.955 .653 .42 r
.31144 .36344 .31226 .36746 .30231 .35838 .30145 .35604 Metetra
.936 .571 .29 r
.30145 .35604 .30231 .35838 .29219 .35073 .29131 .34881 Metetra
.916 .52 .212 r
.29131 .34881 .29219 .35073 .28188 .34482 .28104 .34156 Metetra
.94 .622 .407 r
.28104 .34156 .28188 .34482 .27119 .34545 .27053 .33745 Metetra
.94 .682 .519 r
.27053 .33745 .27119 .34545 .26057 .34002 .2596 .34016 Metetra
.448 .836 .984 r
.2596 .34016 .26057 .34002 .24966 .33797 .24873 .3371 Metetra
.765 .267 .029 r
.24873 .3371 .24966 .33797 .23885 .32957 .23763 .33565 Metetra
.94 .769 .643 r
.23763 .33565 .23885 .32957 .22771 .32534 .2266 .32875 Metetra
.929 .795 .692 r
.2266 .32875 .22771 .32534 .21655 .318 .21538 .32254 Metetra
.958 .811 .656 r
.21538 .32254 .21655 .318 .20505 .31465 .20364 .32401 Metetra
.93 .742 .626 r
.20364 .32401 .20505 .31465 .19383 .30173 .1926 .30683 Metetra
.934 .773 .658 r
.1926 .30683 .19383 .30173 .18232 .29163 .18099 .29857 Metetra
.939 .763 .637 r
.18099 .29857 .18232 .29163 .17065 .28172 .16922 .29018 Metetra
.94 .756 .627 r
.16922 .29018 .17065 .28172 .15872 .27343 .15735 .28054 Metetra
.924 .745 .641 r
.15735 .28054 .15872 .27343 .14659 .26573 .14572 .26333 Metetra
.932 .561 .272 r
.14572 .26333 .14659 .26573 .13436 .25679 .13348 .2545 Metetra
.925 .55 .277 r
.13348 .2545 .13436 .25679 .12195 .24764 .12096 .24717 Metetra
0 .427 .85 r
.12096 .24717 .12195 .24764 .10938 .23819 .10845 .23673 Metetra
.853 .395 .057 r
.10845 .23673 .10938 .23819 .09658 .22926 .09559 .22882 Metetra
0 .429 .84 r
.09559 .22882 .09658 .22926 .08361 .2202 .08266 .219 Metetra
.765 .264 0 r
.08266 .219 .08361 .2202 .07044 .21104 .06951 .20955 Metetra
.791 .325 0 r
.06951 .20955 .07044 .21104 .05745 .19628 .05644 .19589 Metetra
.892 .783 .734 r
.32207 .37707 .32306 .37485 .31325 .36543 .31226 .36746 Metetra
.889 .79 .745 r
.31226 .36746 .31325 .36543 .3033 .35657 .30231 .35838 Metetra
.89 .807 .761 r
.30231 .35838 .3033 .35657 .29318 .34927 .29219 .35073 Metetra
.883 .836 .795 r
.29219 .35073 .29318 .34927 .28291 .34225 .28188 .34482 Metetra
.949 .855 .714 r
.28188 .34482 .28291 .34225 .27247 .33642 .27119 .34545 Metetra
.946 .759 .618 r
.27119 .34545 .27247 .33642 .26153 .33984 .26057 .34002 Metetra
.422 .841 .963 r
.26057 .34002 .26153 .33984 .25066 .33701 .24966 .33797 Metetra
.824 .822 .847 r
.24966 .33797 .25066 .33701 .23967 .33302 .23885 .32957 Metetra
.941 .627 .413 r
.23885 .32957 .23967 .33302 .22868 .32542 .22771 .32534 Metetra
.36 .711 .986 r
.22771 .32534 .22868 .32542 .21734 .32218 .21655 .318 Metetra
.942 .644 .446 r
.21655 .318 .21734 .32218 .20384 .36267 .20505 .31465 Metetra
.954 .726 .555 r
.20505 .31465 .20384 .36267 .19459 .30651 .19383 .30173 Metetra
.96 .665 .431 r
.19383 .30173 .19459 .30651 .18308 .29639 .18232 .29163 Metetra
.959 .664 .431 r
.18232 .29163 .18308 .29639 .1713 .28832 .17065 .28172 Metetra
.956 .683 .478 r
.17065 .28172 .1713 .28832 .1597 .27389 .15872 .27343 Metetra
0 .353 .755 r
.15872 .27343 .1597 .27389 .14771 .2636 .14659 .26573 Metetra
.896 .807 .752 r
.14659 .26573 .14771 .2636 .1355 .25435 .13436 .25679 Metetra
.904 .801 .736 r
.13436 .25679 .1355 .25435 .12309 .24536 .12195 .24764 Metetra
.899 .803 .745 r
.12195 .24764 .12309 .24536 .11049 .23664 .10938 .23819 Metetra
.871 .823 .798 r
.10938 .23819 .11049 .23664 .09779 .22638 .09658 .22926 Metetra
.914 .797 .718 r
.09658 .22926 .09779 .22638 .0848 .21765 .08361 .2202 Metetra
.907 .803 .734 r
.08361 .2202 .0848 .21765 .07176 .20664 .07044 .21104 Metetra
.915 .763 .678 r
.07044 .21104 .07176 .20664 .05882 .19141 .05745 .19628 Metetra
.244 .578 .943 r
.32306 .37485 .32398 .37516 .31414 .36715 .31325 .36543 Metetra
.893 .471 .107 r
.31325 .36543 .31414 .36715 .30424 .35681 .3033 .35657 Metetra
.197 .605 .946 r
.3033 .35657 .30424 .35681 .29412 .3494 .29318 .34927 Metetra
.323 .686 .979 r
.29318 .34927 .29412 .3494 .28383 .34316 .28291 .34225 Metetra
.706 .174 0 r
.28291 .34225 .28383 .34316 .27334 .33866 .27247 .33642 Metetra
.892 .556 .405 r
.27247 .33642 .27334 .33866 .26251 .33935 .26153 .33984 Metetra
.716 .922 .962 r
.26153 .33984 .26251 .33935 .25166 .33602 .25066 .33701 Metetra
.849 .889 .867 r
.25066 .33701 .25166 .33602 .24079 .32924 .23967 .33302 Metetra
.927 .784 .682 r
.23967 .33302 .24079 .32924 .22945 .33032 .22868 .32542 Metetra
.945 .658 .465 r
.22868 .32542 .22945 .33032 .2183 .32264 .21734 .32218 Metetra
.636 .36 .484 r
.21734 .32218 .2183 .32264 .20663 .32296 .20384 .36267 Metetra
.934 .721 .591 r
.20384 .36267 .20663 .32296 .19558 .30628 .19459 .30651 Metetra
.632 .776 .95 r
.19459 .30651 .19558 .30628 .18434 .29083 .18308 .29639 Metetra
.936 .771 .652 r
.18308 .29639 .18434 .29083 .17267 .281 .1713 .28832 Metetra
.93 .75 .638 r
.1713 .28832 .17267 .281 .16079 .27214 .1597 .27389 Metetra
.875 .801 .774 r
.1597 .27389 .16079 .27214 .14879 .26228 .14771 .2636 Metetra
.854 .82 .815 r
.14771 .2636 .14879 .26228 .13661 .25245 .1355 .25435 Metetra
.888 .812 .768 r
.1355 .25435 .13661 .25245 .12421 .24357 .12309 .24536 Metetra
.884 .818 .778 r
.12309 .24536 .12421 .24357 .11162 .23467 .11049 .23664 Metetra
.885 .803 .763 r
.11049 .23664 .11162 .23467 .09876 .22717 .09779 .22638 Metetra
.534 0 0 r
.09779 .22638 .09876 .22717 .08592 .21605 .0848 .21765 Metetra
.864 .806 .792 r
.0848 .21765 .08592 .21605 .07286 .20564 .07176 .20664 Metetra
.793 .769 .831 r
.07176 .20664 .07286 .20564 .06014 .18725 .05882 .19141 Metetra
.844 .814 .82 r
.32398 .37516 .32495 .37404 .31517 .36385 .31414 .36715 Metetra
.911 .77 .693 r
.31414 .36715 .31517 .36385 .30518 .35649 .30424 .35681 Metetra
.678 .818 .95 r
.30424 .35681 .30518 .35649 .29507 .34915 .29412 .3494 Metetra
.634 .833 .977 r
.29412 .3494 .29507 .34915 .28482 .34198 .28383 .34316 Metetra
.87 .868 .833 r
.28383 .34316 .28482 .34198 .2744 .33546 .27334 .33866 Metetra
.953 .834 .688 r
.27334 .33866 .2744 .33546 .26348 .3389 .26251 .33935 Metetra
.698 .911 .969 r
.26251 .33935 .26348 .3389 .25264 .33568 .25166 .33602 Metetra
.671 .838 .964 r
.25166 .33602 .25264 .33568 .24179 .32855 .24079 .32924 Metetra
.748 .981 .913 r
.24079 .32924 .24179 .32855 .23064 .32497 .22945 .33032 Metetra
.936 .772 .653 r
.22945 .33032 .23064 .32497 .2193 .32215 .2183 .32264 Metetra
.63 .951 .937 r
.2183 .32264 .2193 .32215 .20755 .32446 .20663 .32296 Metetra
.659 .23 0 r
.20663 .32296 .20755 .32446 .19655 .30662 .19558 .30628 Metetra
.351 .56 .914 r
.19558 .30628 .19655 .30662 .18523 .29285 .18434 .29083 Metetra
.915 .514 .181 r
.18434 .29083 .18523 .29285 .17369 .28045 .17267 .281 Metetra
.741 .826 .917 r
.17267 .281 .17369 .28045 .16178 .27234 .16079 .27214 Metetra
.301 .642 .967 r
.16079 .27214 .16178 .27234 .14974 .26325 .14879 .26228 Metetra
.627 .102 0 r
.14879 .26228 .14974 .26325 .13751 .25451 .13661 .25245 Metetra
.916 .52 .21 r
.13661 .25245 .13751 .25451 .12509 .24585 .12421 .24357 Metetra
.926 .545 .25 r
.12421 .24357 .12509 .24585 .1125 .23696 .11162 .23467 Metetra
.924 .547 .272 r
.11162 .23467 .1125 .23696 .09973 .22796 .09876 .22717 Metetra
0 .103 .579 r
.09876 .22717 .09973 .22796 .08677 .21887 .08592 .21605 Metetra
.943 .589 .305 r
.08592 .21605 .08677 .21887 .07362 .20969 .07286 .20564 Metetra
.968 .65 .344 r
.07286 .20564 .07362 .20969 .06045 .19774 .06014 .18725 Metetra
.464 .678 .958 r
.32495 .37404 .32587 .37415 .31604 .36589 .31517 .36385 Metetra
.924 .537 .233 r
.31517 .36385 .31604 .36589 .30608 .35781 .30518 .35649 Metetra
.836 .368 0 r
.30518 .35649 .30608 .35781 .29602 .34891 .29507 .34915 Metetra
.632 .813 .97 r
.29507 .34915 .29602 .34891 .28578 .34156 .28482 .34198 Metetra
.711 .845 .946 r
.28482 .34198 .28578 .34156 .2754 .33407 .2744 .33546 Metetra
.914 .963 .799 r
.2744 .33546 .2754 .33407 .26484 .32799 .26348 .3389 Metetra
.951 .758 .607 r
.26348 .3389 .26484 .32799 .25415 .32119 .25264 .33568 Metetra
.948 .748 .6 r
.25264 .33568 .25415 .32119 .24299 .32264 .24179 .32855 Metetra
.947 .779 .641 r
.24179 .32855 .24299 .32264 .23187 .31888 .23064 .32497 Metetra
.949 .78 .638 r
.23064 .32497 .23187 .31888 .22064 .31367 .2193 .32215 Metetra
.959 .777 .614 r
.2193 .32215 .22064 .31367 .2091 .31185 .20755 .32446 Metetra
.936 .739 .612 r
.20755 .32446 .2091 .31185 .198 .29677 .19655 .30662 Metetra
.937 .747 .621 r
.19655 .30662 .198 .29677 .18649 .2872 .18523 .29285 Metetra
.927 .759 .653 r
.18523 .29285 .18649 .2872 .17491 .27605 .17369 .28045 Metetra
.931 .78 .671 r
.17369 .28045 .17491 .27605 .16351 .25819 .16178 .27234 Metetra
.946 .748 .603 r
.16178 .27234 .16351 .25819 .15149 .24944 .14974 .26325 Metetra
.946 .749 .604 r
.14974 .26325 .15149 .24944 .13929 .24057 .13751 .25451 Metetra
.947 .749 .604 r
.13751 .25451 .13929 .24057 .12651 .23886 .12509 .24585 Metetra
.939 .765 .638 r
.12509 .24585 .12651 .23886 .11396 .22956 .1125 .23696 Metetra
.94 .763 .635 r
.1125 .23696 .11396 .22956 .10122 .22037 .09973 .22796 Metetra
.941 .763 .633 r
.09973 .22796 .10122 .22037 .08831 .21092 .08677 .21887 Metetra
.941 .762 .631 r
.08677 .21887 .08831 .21092 .07509 .20299 .07362 .20969 Metetra
.934 .761 .644 r
.07362 .20969 .07509 .20299 .06236 .18491 .06045 .19774 Metetra
.924 .776 .68 r
.32587 .37415 .32691 .37042 .31706 .3631 .31604 .36589 Metetra
.913 .788 .709 r
.31604 .36589 .31706 .3631 .30713 .35428 .30608 .35781 Metetra
.92 .776 .686 r
.30608 .35781 .30713 .35428 .29705 .34609 .29602 .34891 Metetra
.917 .793 .709 r
.29602 .34891 .29705 .34609 .28682 .33875 .28578 .34156 Metetra
.916 .793 .71 r
.28578 .34156 .28682 .33875 .27645 .33124 .2754 .33407 Metetra
.923 .802 .709 r
.2754 .33407 .27645 .33124 .26598 .32279 .26484 .32799 Metetra
.938 .774 .653 r
.26484 .32799 .26598 .32279 .2552 .31907 .25415 .32119 Metetra
.945 .885 .741 r
.25415 .32119 .2552 .31907 .2442 .3166 .24299 .32264 Metetra
.947 .778 .64 r
.24299 .32264 .2442 .3166 .23311 .31231 .23187 .31888 Metetra
.945 .771 .636 r
.23187 .31888 .23311 .31231 .22196 .30575 .22064 .31367 Metetra
.952 .772 .622 r
.22064 .31367 .22196 .30575 .21049 .30273 .2091 .31185 Metetra
.933 .745 .625 r
.2091 .31185 .21049 .30273 .19925 .29123 .198 .29677 Metetra
.933 .767 .652 r
.198 .29677 .19925 .29123 .18779 .281 .18649 .2872 Metetra
.932 .76 .646 r
.18649 .2872 .18779 .281 .17617 .27073 .17491 .27605 Metetra
.913 .746 .661 r
.17491 .27605 .17617 .27073 .16452 .258 .16351 .25819 Metetra
.595 .796 .976 r
.16351 .25819 .16452 .258 .15252 .24881 .15149 .24944 Metetra
.76 .831 .907 r
.15149 .24944 .15252 .24881 .1403 .24052 .13929 .24057 Metetra
.2 .719 .873 r
.13929 .24057 .1403 .24052 .12792 .23197 .12651 .23886 Metetra
.939 .764 .639 r
.12651 .23886 .12792 .23197 .115 .22915 .11396 .22956 Metetra
.686 .822 .948 r
.11396 .22956 .115 .22915 .10226 .22006 .10122 .22037 Metetra
.645 .81 .962 r
.10122 .22037 .10226 .22006 .08931 .21119 .08831 .21092 Metetra
.085 .56 .904 r
.08831 .21092 .08931 .21119 .07614 .20267 .07509 .20299 Metetra
.656 .702 .881 r
.07509 .20299 .07614 .20267 .06335 .18565 .06236 .18491 Metetra
.926 .543 .24 r
.32691 .37042 .32778 .37249 .31799 .36323 .31706 .3631 Metetra
.404 .682 .974 r
.31706 .3631 .31799 .36323 .30802 .35595 .30713 .35428 Metetra
.889 .462 .107 r
.30713 .35428 .30802 .35595 .29795 .34769 .29705 .34609 Metetra
.885 .454 .115 r
.29705 .34609 .29795 .34769 .28768 .34132 .28682 .33875 Metetra
.941 .588 .313 r
.28682 .33875 .28768 .34132 .27708 .34071 .27645 .33124 Metetra
.958 .702 .507 r
.27645 .33124 .27708 .34071 .26643 .33681 .26598 .32279 Metetra
.952 .708 .532 r
.26598 .32279 .26643 .33681 .25559 .33383 .2552 .31907 Metetra
.951 .708 .535 r
.2552 .31907 .25559 .33383 .24446 .3344 .2442 .3166 Metetra
.953 .713 .539 r
.2442 .3166 .24446 .3344 .23343 .32824 .23311 .31231 Metetra
.954 .713 .533 r
.23311 .31231 .23343 .32824 .22218 .32332 .22196 .30575 Metetra
.951 .712 .539 r
.22196 .30575 .22218 .32332 .21037 .32732 .21049 .30273 Metetra
.956 .721 .542 r
.21049 .30273 .21037 .32732 .19951 .30662 .19925 .29123 Metetra
.957 .714 .528 r
.19925 .29123 .19951 .30662 .18807 .29555 .18779 .281 Metetra
.957 .713 .526 r
.18779 .281 .18807 .29555 .17639 .28618 .17617 .27073 Metetra
.959 .716 .526 r
.17617 .27073 .17639 .28618 .16452 .27727 .16452 .258 Metetra
.955 .717 .537 r
.16452 .258 .16452 .27727 .15276 .26296 .15252 .24881 Metetra
.955 .71 .526 r
.15252 .24881 .15276 .26296 .14057 .25374 .1403 .24052 Metetra
.956 .708 .523 r
.1403 .24052 .14057 .25374 .12812 .24589 .12792 .23197 Metetra
.95 .705 .531 r
.12792 .23197 .12812 .24589 .11553 .23729 .115 .22915 Metetra
.957 .692 .492 r
.115 .22915 .11553 .23729 .10293 .22581 .10226 .22006 Metetra
.956 .673 .458 r
.10226 .22006 .10293 .22581 .08992 .21783 .08931 .21119 Metetra
.956 .681 .475 r
.08931 .21119 .08992 .21783 .07689 .20699 .07614 .20267 Metetra
.968 .657 .371 r
.07614 .20267 .07689 .20699 .06425 .18765 .06335 .18565 Metetra
.713 .787 .91 r
.32778 .37249 .32872 .37208 .31893 .36302 .31799 .36323 Metetra
.622 .804 .969 r
.31799 .36323 .31893 .36302 .30898 .3552 .30802 .35595 Metetra
.795 .817 .87 r
.30802 .35595 .30898 .3552 .29889 .34757 .29795 .34769 Metetra
.546 .803 .993 r
.29795 .34769 .29889 .34757 .28864 .3409 .28768 .34132 Metetra
.623 .939 .957 r
.28768 .34132 .28864 .3409 .27825 .33432 .27708 .34071 Metetra
.947 .774 .635 r
.27708 .34071 .27825 .33432 .26728 .33974 .26643 .33681 Metetra
.932 .604 .393 r
.26643 .33681 .26728 .33974 .25641 .33783 .25559 .33383 Metetra
.931 .635 .459 r
.25559 .33383 .25641 .33783 .24554 .33167 .24446 .3344 Metetra
.922 .807 .716 r
.24446 .3344 .24554 .33167 .23456 .32424 .23343 .32824 Metetra
.938 .794 .675 r
.23343 .32824 .23456 .32424 .22339 .3179 .22218 .32332 Metetra
.964 .807 .637 r
.22218 .32332 .22339 .3179 .21184 .31648 .21037 .32732 Metetra
.93 .737 .62 r
.21037 .32732 .21184 .31648 .20078 .3006 .19951 .30662 Metetra
.932 .761 .648 r
.19951 .30662 .20078 .3006 .18922 .29234 .18807 .29555 Metetra
.916 .786 .702 r
.18807 .29555 .18922 .29234 .17752 .28349 .17639 .28618 Metetra
.91 .796 .722 r
.17639 .28618 .17752 .28349 .16562 .27537 .16452 .27727 Metetra
.863 .77 .758 r
.16452 .27727 .16562 .27537 .15368 .2646 .15276 .26296 Metetra
.874 .435 .08 r
.15276 .26296 .15368 .2646 .14154 .25441 .14057 .25374 Metetra
.433 0 0 r
.14057 .25374 .14154 .25441 .1291 .2466 .12812 .24589 Metetra
.454 0 0 r
.12812 .24589 .1291 .2466 .11656 .23714 .11553 .23729 Metetra
.586 .755 .959 r
.11553 .23729 .11656 .23714 .10388 .22691 .10293 .22581 Metetra
.747 .232 0 r
.10293 .22581 .10388 .22691 .09086 .21916 .08992 .21783 Metetra
.784 .298 0 r
.08992 .21783 .09086 .21916 .078 .20589 .07689 .20699 Metetra
.787 .735 .805 r
.07689 .20699 .078 .20589 .06508 .19068 .06425 .18765 Metetra
.698 .787 .919 r
.32872 .37208 .32967 .37172 .31987 .36299 .31893 .36302 Metetra
.512 .753 .983 r
.31893 .36302 .31987 .36299 .30991 .35555 .30898 .3552 Metetra
.06 .508 .894 r
.30898 .3552 .30991 .35555 .29982 .34813 .29889 .34757 Metetra
0 .222 .643 r
.29889 .34757 .29982 .34813 .28958 .34111 .28864 .3409 Metetra
.172 .61 .939 r
.28864 .3409 .28958 .34111 .27905 .33869 .27825 .33432 Metetra
.92 .636 .488 r
.27825 .33432 .27905 .33869 .26823 .34003 .26728 .33974 Metetra
.312 0 0 r
.26728 .33974 .26823 .34003 .25726 .34062 .25641 .33783 Metetra
.94 .599 .351 r
.25641 .33783 .25726 .34062 .24659 .3295 .24554 .33167 Metetra
.904 .809 .744 r
.24554 .33167 .24659 .3295 .23555 .32392 .23456 .32424 Metetra
.654 .847 .974 r
.23456 .32424 .23555 .32392 .22446 .31572 .22339 .3179 Metetra
.933 .86 .745 r
.22339 .3179 .22446 .31572 .2131 .3104 .21184 .31648 Metetra
.922 .749 .65 r
.21184 .31648 .2131 .3104 .20183 .29926 .20078 .3006 Metetra
.861 .826 .812 r
.20078 .3006 .20183 .29926 .19024 .29175 .18922 .29234 Metetra
.753 .826 .908 r
.18922 .29234 .19024 .29175 .17853 .2832 .17752 .28349 Metetra
.641 .819 .969 r
.17752 .28349 .17853 .2832 .16693 .26935 .16562 .27537 Metetra
.933 .763 .648 r
.16562 .27537 .16693 .26935 .15497 .25921 .15368 .2646 Metetra
.932 .768 .656 r
.15368 .2646 .15497 .25921 .14278 .25032 .14154 .25441 Metetra
.931 .786 .679 r
.14154 .25441 .14278 .25032 .13038 .24194 .1291 .2466 Metetra
.93 .776 .668 r
.1291 .2466 .13038 .24194 .11787 .2323 .11656 .23714 Metetra
.93 .773 .666 r
.11656 .23714 .11787 .2323 .10507 .22429 .10388 .22691 Metetra
.914 .81 .73 r
.10388 .22691 .10507 .22429 .09211 .21574 .09086 .21916 Metetra
.908 .774 .701 r
.09086 .21916 .09211 .21574 .07916 .20393 .078 .20589 Metetra
.864 .773 .76 r
.078 .20589 .07916 .20393 .06654 .18436 .06508 .19068 Metetra
0 .183 .659 r
.32967 .37172 .33058 .37241 .32076 .36462 .31987 .36299 Metetra
.889 .462 .12 r
.31987 .36299 .32076 .36462 .31083 .35615 .30991 .35555 Metetra
0 .211 .654 r
.30991 .35555 .31083 .35615 .30075 .34851 .29982 .34813 Metetra
0 .461 .851 r
.29982 .34813 .30075 .34851 .29051 .34186 .28958 .34111 Metetra
.704 .167 0 r
.28958 .34111 .29051 .34186 .2801 .33609 .27905 .33869 Metetra
.953 .86 .711 r
.27905 .33869 .2801 .33609 .26916 .34085 .26823 .34003 Metetra
.761 .278 .09 r
.26823 .34003 .26916 .34085 .25839 .33634 .25726 .34062 Metetra
.921 .766 .672 r
.25726 .34062 .25839 .33634 .24755 .32972 .24659 .3295 Metetra
.074 .573 .892 r
.24659 .3295 .24755 .32972 .23647 .32523 .23555 .32392 Metetra
.816 .338 0 r
.23555 .32392 .23647 .32523 .22529 .31932 .22446 .31572 Metetra
.945 .631 .409 r
.22446 .31572 .22529 .31932 .21237 .34892 .2131 .3104 Metetra
.955 .725 .551 r
.2131 .3104 .21237 .34892 .20245 .30729 .20183 .29926 Metetra
.956 .693 .495 r
.20183 .29926 .20245 .30729 .19109 .29455 .19024 .29175 Metetra
.943 .595 .323 r
.19024 .29175 .19109 .29455 .17968 .28008 .17853 .2832 Metetra
.9 .766 .705 r
.17853 .2832 .17968 .28008 .16783 .27117 .16693 .26935 Metetra
.894 .472 .115 r
.16693 .26935 .16783 .27117 .15588 .26097 .15497 .25921 Metetra
.891 .465 .128 r
.15497 .25921 .15588 .26097 .14369 .25206 .14278 .25032 Metetra
.89 .464 .137 r
.14278 .25032 .14369 .25206 .1313 .24359 .13038 .24194 Metetra
.873 .432 .073 r
.13038 .24194 .1313 .24359 .11881 .23358 .11787 .2323 Metetra
.812 .327 0 r
.11787 .2323 .11881 .23358 .10601 .22561 .10507 .22429 Metetra
.814 .332 0 r
.10507 .22429 .10601 .22561 .0931 .21626 .09211 .21574 Metetra
0 .401 .84 r
.09211 .21574 .0931 .21626 .08021 .20369 .07916 .20393 Metetra
.634 .679 .875 r
.07916 .20393 .08021 .20369 .06734 .18793 .06654 .18436 Metetra
.949 .611 .341 r
.33058 .37241 .33144 .37529 .32164 .36666 .32076 .36462 Metetra
.923 .531 .204 r
.32076 .36462 .32164 .36666 .31177 .35617 .31083 .35615 Metetra
.468 .74 .987 r
.31083 .35615 .31177 .35617 .30169 .34866 .30075 .34851 Metetra
.275 .668 .97 r
.30075 .34851 .30169 .34866 .29141 .34338 .29051 .34186 Metetra
.88 .446 .137 r
.29051 .34186 .29141 .34338 .28094 .33936 .2801 .33609 Metetra
.91 .607 .459 r
.2801 .33609 .28094 .33936 .27023 .33786 .26916 .34085 Metetra
.932 .81 .702 r
.26916 .34085 .27023 .33786 .25919 .34074 .25839 .33634 Metetra
.953 .656 .435 r
.25839 .33634 .25919 .34074 .24844 .33177 .24755 .32972 Metetra
.915 .536 .285 r
.24755 .32972 .24844 .33177 .23722 .33072 .23647 .32523 Metetra
.953 .671 .465 r
.23647 .32523 .23722 .33072 .22602 .32522 .22529 .31932 Metetra
.881 .622 .544 r
.22529 .31932 .22602 .32522 .21433 .32701 .21237 .34892 Metetra
.929 .722 .602 r
.21237 .34892 .21433 .32701 .2029 .31893 .20245 .30729 Metetra
.961 .71 .511 r
.20245 .30729 .2029 .31893 .19204 .29557 .19109 .29455 Metetra
0 .042 .578 r
.19109 .29455 .19204 .29557 .18058 .28195 .17968 .28008 Metetra
.903 .489 .157 r
.17968 .28008 .18058 .28195 .16893 .26935 .16783 .27117 Metetra
.879 .802 .769 r
.16783 .27117 .16893 .26935 .15689 .26087 .15588 .26097 Metetra
.532 .773 .986 r
.15588 .26097 .15689 .26087 .14474 .25147 .14369 .25206 Metetra
.749 .839 .92 r
.14369 .25206 .14474 .25147 .13233 .24329 .1313 .24359 Metetra
.649 .797 .954 r
.1313 .24359 .13233 .24329 .11985 .23318 .11881 .23358 Metetra
.682 .842 .96 r
.11881 .23358 .11985 .23318 .10701 .22601 .10601 .22561 Metetra
0 .47 .864 r
.10601 .22561 .10701 .22601 .09401 .2181 .0931 .21626 Metetra
.88 .45 .06 r
.0931 .21626 .09401 .2181 .08094 .20826 .08021 .20369 Metetra
.967 .662 .391 r
.08021 .20369 .08094 .20826 .06827 .18942 .06734 .18793 Metetra
.903 .789 .724 r
.33144 .37529 .33243 .37287 .32267 .36313 .32164 .36666 Metetra
.914 .769 .686 r
.32164 .36666 .32267 .36313 .31274 .35519 .31177 .35617 Metetra
.832 .828 .844 r
.31177 .35617 .31274 .35519 .30266 .34783 .30169 .34866 Metetra
.821 .869 .882 r
.30169 .34866 .30266 .34783 .29245 .34047 .29141 .34338 Metetra
.933 .814 .704 r
.29141 .34338 .29245 .34047 .2821 .33317 .28094 .33936 Metetra
.953 .782 .634 r
.28094 .33936 .2821 .33317 .27162 .32562 .27023 .33786 Metetra
.958 .763 .597 r
.27023 .33786 .27162 .32562 .26079 .32375 .25919 .34074 Metetra
.948 .744 .596 r
.25919 .34074 .26079 .32375 .24973 .32351 .24844 .33177 Metetra
.954 .772 .618 r
.24844 .33177 .24973 .32351 .23872 .31782 .23722 .33072 Metetra
.95 .753 .603 r
.23722 .33072 .23872 .31782 .22747 .31409 .22602 .32522 Metetra
.958 .766 .603 r
.22602 .32522 .22747 .31409 .21584 .31497 .21433 .32701 Metetra
.947 .752 .607 r
.21433 .32701 .21584 .31497 .20489 .2972 .2029 .31893 Metetra
.94 .733 .595 r
.2029 .31893 .20489 .2972 .19347 .28634 .19204 .29557 Metetra
.937 .749 .623 r
.19204 .29557 .19347 .28634 .18198 .27378 .18058 .28195 Metetra
.936 .753 .629 r
.18058 .28195 .18198 .27378 .17023 .26355 .16893 .26935 Metetra
.937 .77 .649 r
.16893 .26935 .17023 .26355 .15864 .24693 .15689 .26087 Metetra
.947 .749 .603 r
.15689 .26087 .15864 .24693 .14606 .24573 .14474 .25147 Metetra
.938 .773 .65 r
.14474 .25147 .14606 .24573 .1337 .23702 .13233 .24329 Metetra
.936 .765 .645 r
.13233 .24329 .1337 .23702 .12117 .22807 .11985 .23318 Metetra
.938 .781 .659 r
.11985 .23318 .12117 .22807 .10848 .21873 .10701 .22601 Metetra
.943 .767 .635 r
.10701 .22601 .10848 .21873 .09563 .20879 .09401 .2181 Metetra
.943 .757 .622 r
.09401 .2181 .09563 .20879 .08248 .20049 .08094 .20826 Metetra
.927 .746 .637 r
.08094 .20826 .08248 .20049 .06989 .18075 .06827 .18942 Metetra
.928 .764 .658 r
.33243 .37287 .3335 .36797 .32371 .35949 .32267 .36313 Metetra
.925 .78 .682 r
.32267 .36313 .32371 .35949 .31385 .34943 .31274 .35519 Metetra
.938 .768 .644 r
.31274 .35519 .31385 .34943 .3038 .34181 .30266 .34783 Metetra
.939 .767 .641 r
.30266 .34783 .3038 .34181 .29361 .33401 .29245 .34047 Metetra
.94 .765 .637 r
.29245 .34047 .29361 .33401 .28319 .32935 .2821 .33317 Metetra
.928 .782 .679 r
.2821 .33317 .28319 .32935 .27287 .31768 .27162 .32562 Metetra
.953 .771 .62 r
.27162 .32562 .27287 .31768 .26201 .31684 .26079 .32375 Metetra
.956 .781 .626 r
.26079 .32375 .26201 .31684 .25122 .31013 .24973 .32351 Metetra
.95 .752 .601 r
.24973 .32351 .25122 .31013 .2402 .30543 .23872 .31782 Metetra
.951 .756 .603 r
.23872 .31782 .2402 .30543 .22885 .3046 .22747 .31409 Metetra
.957 .77 .61 r
.22747 .31409 .22885 .3046 .21723 .30595 .21584 .31497 Metetra
.93 .742 .627 r
.21584 .31497 .21723 .30595 .20602 .29397 .20489 .2972 Metetra
.912 .778 .701 r
.20489 .2972 .20602 .29397 .19495 .27602 .19347 .28634 Metetra
.94 .749 .617 r
.19347 .28634 .19495 .27602 .18339 .2654 .18198 .27378 Metetra
.94 .756 .626 r
.18198 .27378 .18339 .2654 .17172 .25396 .17023 .26355 Metetra
.934 .744 .623 r
.17023 .26355 .17172 .25396 .15979 .24427 .15864 .24693 Metetra
.941 .848 .722 r
.15864 .24693 .15979 .24427 .1476 .23607 .14606 .24573 Metetra
.945 .757 .618 r
.14606 .24573 .1476 .23607 .13508 .23061 .1337 .23702 Metetra
.939 .768 .643 r
.1337 .23702 .13508 .23061 .12248 .22309 .12117 .22807 Metetra
.933 .775 .663 r
.12117 .22807 .12248 .22309 .10965 .21635 .10848 .21873 Metetra
.901 .801 .741 r
.10848 .21873 .10965 .21635 .09667 .2086 .09563 .20879 Metetra
.565 .808 .99 r
.09563 .20879 .09667 .2086 .08322 .20497 .08248 .20049 Metetra
.972 .662 .359 r
.08248 .20049 .08322 .20497 .07095 .18041 .06989 .18075 Metetra
.735 .237 0 r
.3335 .36797 .3344 .36911 .32462 .36065 .32371 .35949 Metetra
.69 .201 0 r
.32371 .35949 .32462 .36065 .31472 .35208 .31385 .34943 Metetra
.944 .595 .319 r
.31385 .34943 .31472 .35208 .30466 .34434 .3038 .34181 Metetra
.941 .584 .301 r
.3038 .34181 .30466 .34434 .2944 .33885 .29361 .33401 Metetra
.95 .663 .458 r
.29361 .33401 .2944 .33885 .28402 .3329 .28319 .32935 Metetra
.962 .639 .353 r
.28319 .32935 .28402 .3329 .27317 .33623 .27287 .31768 Metetra
.951 .712 .542 r
.27287 .31768 .27317 .33623 .26222 .33721 .26201 .31684 Metetra
.955 .717 .539 r
.26201 .31684 .26222 .33721 .25152 .32744 .25122 .31013 Metetra
.953 .713 .536 r
.25122 .31013 .25152 .32744 .24055 .32086 .2402 .30543 Metetra
.95 .708 .536 r
.2402 .30543 .24055 .32086 .22947 .31302 .22885 .3046 Metetra
.943 .684 .515 r
.22885 .3046 .22947 .31302 .2182 .30626 .21723 .30595 Metetra
.279 .576 .94 r
.21723 .30595 .2182 .30626 .20684 .29766 .20602 .29397 Metetra
.966 .641 .304 r
.20602 .29397 .20684 .29766 .1954 .28752 .19495 .27602 Metetra
.959 .708 .512 r
.19495 .27602 .1954 .28752 .18378 .27781 .18339 .2654 Metetra
.96 .71 .515 r
.18339 .2654 .18378 .27781 .17204 .26716 .17172 .25396 Metetra
.958 .71 .521 r
.17172 .25396 .17204 .26716 .15998 .25952 .15979 .24427 Metetra
.956 .712 .528 r
.15979 .24427 .15998 .25952 .14785 .24991 .1476 .23607 Metetra
.954 .707 .527 r
.1476 .23607 .14785 .24991 .1355 .24102 .13508 .23061 Metetra
.956 .701 .51 r
.13508 .23061 .1355 .24102 .12298 .23194 .12248 .22309 Metetra
.954 .693 .501 r
.12248 .22309 .12298 .23194 .11013 .22533 .10965 .21635 Metetra
.956 .695 .5 r
.10965 .21635 .11013 .22533 .0974 .21332 .09667 .2086 Metetra
.943 .648 .45 r
.09667 .2086 .0974 .21332 .08457 .20019 .08322 .20497 Metetra
.897 .734 .672 r
.08322 .20497 .08457 .20019 .07133 .19026 .07095 .18041 Metetra
.958 .646 .394 r
.3344 .36911 .33523 .37284 .32546 .36397 .32462 .36065 Metetra
.955 .631 .367 r
.32462 .36065 .32546 .36397 .31557 .35521 .31472 .35208 Metetra
.951 .622 .362 r
.31472 .35208 .31557 .35521 .30551 .34758 .30466 .34434 Metetra
.946 .624 .39 r
.30466 .34434 .30551 .34758 .2953 .34069 .2944 .33885 Metetra
.909 .508 .217 r
.2944 .33885 .2953 .34069 .28486 .33631 .28402 .3329 Metetra
.917 .614 .456 r
.28402 .3329 .28486 .33631 .27407 .33777 .27317 .33623 Metetra
.868 .478 .297 r
.27317 .33623 .27407 .33777 .26332 .33372 .26222 .33721 Metetra
.918 .777 .69 r
.26222 .33721 .26332 .33372 .25243 .32889 .25152 .32744 Metetra
.861 .41 .078 r
.25152 .32744 .25243 .32889 .24148 .32188 .24055 .32086 Metetra
.708 .188 0 r
.24055 .32086 .24148 .32188 .23041 .31412 .22947 .31302 Metetra
.77 .264 0 r
.22947 .31302 .23041 .31412 .21862 .31904 .2182 .30626 Metetra
.957 .709 .52 r
.2182 .30626 .21862 .31904 .20765 .30168 .20684 .29766 Metetra
.959 .648 .395 r
.20684 .29766 .20765 .30168 .19628 .28994 .1954 .28752 Metetra
.935 .562 .254 r
.1954 .28752 .19628 .28994 .18468 .27968 .18378 .27781 Metetra
.896 .476 .11 r
.18378 .27781 .18468 .27968 .17288 .27042 .17204 .26716 Metetra
.947 .617 .369 r
.17204 .26716 .17288 .27042 .16093 .26075 .15998 .25952 Metetra
.763 .266 0 r
.15998 .25952 .16093 .26075 .14878 .25148 .14785 .24991 Metetra
.864 .416 .061 r
.14785 .24991 .14878 .25148 .1364 .24323 .1355 .24102 Metetra
.922 .534 .228 r
.1355 .24102 .1364 .24323 .12392 .2333 .12298 .23194 Metetra
.839 .371 .048 r
.12298 .23194 .12392 .2333 .11135 .22196 .11013 .22533 Metetra
.912 .779 .701 r
.11013 .22533 .11135 .22196 .09839 .21395 .0974 .21332 Metetra
0 .338 .805 r
.0974 .21332 .09839 .21395 .08539 .20345 .08457 .20019 Metetra
.949 .612 .348 r
.08457 .20019 .08539 .20345 .07237 .1902 .07133 .19026 Metetra
.948 .598 .305 r
.33523 .37284 .3361 .37554 .32635 .36601 .32546 .36397 Metetra
.922 .529 .194 r
.32546 .36397 .32635 .36601 .31646 .35677 .31557 .35521 Metetra
.875 .436 .08 r
.31557 .35521 .31646 .35677 .30643 .3485 .30551 .34758 Metetra
.675 .144 0 r
.30551 .34758 .30643 .3485 .29616 .34331 .2953 .34069 Metetra
.934 .59 .355 r
.2953 .34069 .29616 .34331 .28571 .33945 .28486 .33631 Metetra
.92 .607 .435 r
.28486 .33631 .28571 .33945 .27512 .33535 .27407 .33777 Metetra
.927 .828 .728 r
.27407 .33777 .27512 .33535 .2643 .3331 .26332 .33372 Metetra
.77 .888 .929 r
.26332 .33372 .2643 .3331 .25353 .32566 .25243 .32889 Metetra
.925 .795 .697 r
.25243 .32889 .25353 .32566 .24254 .31982 .24148 .32188 Metetra
.9 .811 .751 r
.24148 .32188 .24254 .31982 .23136 .31477 .23041 .31412 Metetra
.71 .249 .155 r
.23041 .31412 .23136 .31477 .21989 .31254 .21862 .31904 Metetra
.922 .745 .646 r
.21862 .31904 .21989 .31254 .20877 .29876 .20765 .30168 Metetra
.904 .777 .711 r
.20765 .30168 .20877 .29876 .19739 .28744 .19628 .28994 Metetra
.901 .79 .729 r
.19628 .28994 .19739 .28744 .18579 .27752 .18468 .27968 Metetra
.896 .803 .749 r
.18468 .27968 .18579 .27752 .17394 .26918 .17288 .27042 Metetra
.845 .817 .821 r
.17288 .27042 .17394 .26918 .16202 .25903 .16093 .26075 Metetra
.879 .814 .78 r
.16093 .26075 .16202 .25903 .14987 .25007 .14878 .25148 Metetra
.866 .832 .812 r
.14878 .25148 .14987 .25007 .13751 .24156 .1364 .24323 Metetra
.873 .812 .786 r
.1364 .24323 .13751 .24156 .12507 .23125 .12392 .2333 Metetra
.884 .796 .757 r
.12392 .2333 .12507 .23125 .11244 .22103 .11135 .22196 Metetra
.816 .851 .875 r
.11135 .22196 .11244 .22103 .09955 .21187 .09839 .21395 Metetra
.889 .804 .759 r
.09839 .21395 .09955 .21187 .08647 .20275 .08539 .20345 Metetra
.755 .785 .878 r
.08539 .20345 .08647 .20275 .07365 .18656 .07237 .1902 Metetra
0 .076 .573 r
.3361 .37554 .33701 .37637 .32724 .36753 .32635 .36601 Metetra
.852 .404 0 r
.32635 .36601 .32724 .36753 .31741 .35656 .31646 .35677 Metetra
.63 .788 .958 r
.31646 .35677 .31741 .35656 .30736 .34893 .30643 .3485 Metetra
0 .318 .689 r
.30643 .3485 .30736 .34893 .29708 .34451 .29616 .34331 Metetra
.836 .37 .081 r
.29616 .34331 .29708 .34451 .28662 .3408 .28571 .33945 Metetra
.859 .412 .128 r
.28571 .33945 .28662 .3408 .27603 .33685 .27512 .33535 Metetra
.875 .459 .222 r
.27512 .33535 .27603 .33685 .26526 .33333 .2643 .3331 Metetra
.205 .617 .95 r
.2643 .3331 .26526 .33333 .25431 .33065 .25353 .32566 Metetra
.953 .664 .453 r
.25353 .32566 .25431 .33065 .24334 .32405 .24254 .31982 Metetra
.948 .648 .435 r
.24254 .31982 .24334 .32405 .23227 .31646 .23136 .31477 Metetra
.888 .488 .259 r
.23136 .31477 .23227 .31646 .22057 .31968 .21989 .31254 Metetra
.967 .696 .466 r
.21989 .31254 .22057 .31968 .20959 .30239 .20877 .29876 Metetra
.959 .637 .363 r
.20877 .29876 .20959 .30239 .19822 .29089 .19739 .28744 Metetra
.955 .628 .363 r
.19739 .28744 .19822 .29089 .18677 .27786 .18579 .27752 Metetra
.05 .513 .89 r
.18579 .27752 .18677 .27786 .17493 .26943 .17394 .26918 Metetra
.26 .613 .956 r
.17394 .26918 .17493 .26943 .16295 .26062 .16202 .25903 Metetra
.867 .421 .063 r
.16202 .25903 .16295 .26062 .15078 .25192 .14987 .25007 Metetra
.899 .482 .158 r
.14987 .25007 .15078 .25192 .13843 .24322 .13751 .24156 Metetra
.867 .424 .05 r
.13751 .24156 .13843 .24322 .12596 .23344 .12507 .23125 Metetra
.921 .528 .205 r
.12507 .23125 .12596 .23344 .11332 .22335 .11244 .22103 Metetra
.927 .545 .248 r
.11244 .22103 .11332 .22335 .10035 .21557 .09955 .21187 Metetra
.951 .63 .383 r
.09955 .21187 .10035 .21557 .08743 .20396 .08647 .20275 Metetra
0 0 .442 r
.08647 .20275 .08743 .20396 .07445 .19022 .07365 .18656 Metetra
.318 .633 .963 r
.33701 .37637 .33794 .37659 .32822 .36595 .32724 .36753 Metetra
.86 .78 .771 r
.32724 .36753 .32822 .36595 .31836 .35632 .31741 .35656 Metetra
.636 .803 .963 r
.31741 .35656 .31836 .35632 .30832 .34853 .30736 .34893 Metetra
.688 .885 .971 r
.30736 .34893 .30832 .34853 .29807 .34322 .29708 .34451 Metetra
.885 .875 .821 r
.29708 .34451 .29807 .34322 .28758 .34077 .28662 .3408 Metetra
.353 .773 .977 r
.28662 .3408 .28758 .34077 .27695 .33806 .27603 .33685 Metetra
.838 .376 .098 r
.27603 .33685 .27695 .33806 .26617 .3349 .26526 .33333 Metetra
.882 .471 .229 r
.26526 .33333 .26617 .3349 .25538 .32791 .25431 .33065 Metetra
.921 .805 .716 r
.25431 .33065 .25538 .32791 .24439 .32239 .24334 .32405 Metetra
.885 .822 .78 r
.24334 .32405 .24439 .32239 .23328 .31578 .23227 .31646 Metetra
.67 .976 .862 r
.23227 .31646 .23328 .31578 .22193 .31088 .22057 .31968 Metetra
.931 .743 .627 r
.22057 .31968 .22193 .31088 .2107 .29985 .20959 .30239 Metetra
.896 .782 .726 r
.20959 .30239 .2107 .29985 .19934 .28817 .19822 .29089 Metetra
.895 .772 .719 r
.19822 .29089 .19934 .28817 .18784 .27639 .18677 .27786 Metetra
.87 .824 .801 r
.18677 .27786 .18784 .27639 .17606 .26701 .17493 .26943 Metetra
.906 .803 .736 r
.17493 .26943 .17606 .26701 .16414 .25699 .16295 .26062 Metetra
.925 .788 .69 r
.16295 .26062 .16414 .25699 .15192 .24955 .15078 .25192 Metetra
.905 .807 .74 r
.15078 .25192 .15192 .24955 .13957 .24101 .13843 .24322 Metetra
.896 .804 .749 r
.13843 .24322 .13957 .24101 .12711 .23119 .12596 .23344 Metetra
.896 .802 .747 r
.12596 .23344 .12711 .23119 .11445 .22169 .11332 .22335 Metetra
.884 .834 .792 r
.11332 .22335 .11445 .22169 .10157 .21255 .10035 .21557 Metetra
.908 .786 .714 r
.10035 .21557 .10157 .21255 .08848 .20366 .08743 .20396 Metetra
.646 .751 .925 r
.08743 .20396 .08848 .20366 .07554 .18946 .07445 .19022 Metetra
.927 .761 .657 r
.33794 .37659 .339 .37161 .32922 .36379 .32822 .36595 Metetra
.892 .786 .737 r
.32822 .36595 .32922 .36379 .31932 .35573 .31836 .35632 Metetra
.765 .825 .899 r
.31836 .35632 .31932 .35573 .3093 .34761 .30832 .34853 Metetra
.836 .867 .867 r
.30832 .34853 .3093 .34761 .29911 .34043 .29807 .34322 Metetra
.939 .827 .707 r
.29807 .34322 .29911 .34043 .28878 .33346 .28758 .34077 Metetra
.952 .773 .624 r
.28758 .34077 .28878 .33346 .27845 .32242 .27695 .33806 Metetra
.953 .751 .594 r
.27695 .33806 .27845 .32242 .26754 .32401 .26617 .3349 Metetra
.947 .754 .609 r
.26617 .3349 .26754 .32401 .25654 .32307 .25538 .32791 Metetra
.941 .783 .657 r
.25538 .32791 .25654 .32307 .24557 .31713 .24439 .32239 Metetra
.94 .777 .652 r
.24439 .32239 .24557 .31713 .23425 .31601 .23328 .31578 Metetra
.015 .546 .852 r
.23328 .31578 .23425 .31601 .223 .30907 .22193 .31088 Metetra
.874 .791 .766 r
.22193 .31088 .223 .30907 .21189 .29539 .2107 .29985 Metetra
.923 .767 .671 r
.2107 .29985 .21189 .29539 .20061 .28234 .19934 .28817 Metetra
.931 .761 .65 r
.19934 .28817 .20061 .28234 .18903 .27237 .18784 .27639 Metetra
.926 .78 .679 r
.18784 .27639 .18903 .27237 .17733 .26165 .17606 .26701 Metetra
.933 .769 .656 r
.17606 .26701 .17733 .26165 .16561 .24813 .16414 .25699 Metetra
.946 .761 .621 r
.16414 .25699 .16561 .24813 .15326 .24354 .15192 .24955 Metetra
.939 .771 .646 r
.15192 .24955 .15326 .24354 .14093 .23488 .13957 .24101 Metetra
.937 .767 .646 r
.13957 .24101 .14093 .23488 .12843 .2261 .12711 .23119 Metetra
.934 .775 .661 r
.12711 .23119 .12843 .2261 .11578 .21664 .11445 .22169 Metetra
.934 .777 .662 r
.11445 .22169 .11578 .21664 .10292 .20747 .10157 .21255 Metetra
.935 .778 .661 r
.10157 .21255 .10292 .20747 .08989 .19792 .08848 .20366 Metetra
.927 .76 .655 r
.08848 .20366 .08989 .19792 .07745 .17634 .07554 .18946 Metetra
.929 .776 .67 r
.339 .37161 .34004 .36751 .33035 .35684 .32922 .36379 Metetra
.94 .761 .632 r
.32922 .36379 .33035 .35684 .32044 .3496 .31932 .35573 Metetra
.938 .764 .64 r
.31932 .35573 .32044 .3496 .31043 .34154 .3093 .34761 Metetra
.94 .767 .64 r
.3093 .34761 .31043 .34154 .30026 .33427 .29911 .34043 Metetra
.941 .768 .639 r
.29911 .34043 .30026 .33427 .28998 .32624 .28878 .33346 Metetra
.936 .755 .633 r
.28878 .33346 .28998 .32624 .27954 .31876 .27845 .32242 Metetra
.959 .829 .671 r
.27845 .32242 .27954 .31876 .26895 .31164 .26754 .32401 Metetra
.955 .759 .599 r
.26754 .32401 .26895 .31164 .25809 .30789 .25654 .32307 Metetra
.951 .75 .596 r
.25654 .32307 .25809 .30789 .24694 .30737 .24557 .31713 Metetra
.955 .766 .609 r
.24557 .31713 .24694 .30737 .23565 .30586 .23425 .31601 Metetra
.947 .757 .613 r
.23425 .31601 .23565 .30586 .22413 .30581 .223 .30907 Metetra
.902 .765 .699 r
.223 .30907 .22413 .30581 .21294 .294 .21189 .29539 Metetra
.839 .777 .792 r
.21189 .29539 .21294 .294 .20197 .27444 .20061 .28234 Metetra
.94 .758 .629 r
.20061 .28234 .20197 .27444 .19039 .26494 .18903 .27237 Metetra
.938 .759 .633 r
.18903 .27237 .19039 .26494 .17896 .24916 .17733 .26165 Metetra
.942 .746 .609 r
.17733 .26165 .17896 .24916 .16703 .24021 .16561 .24813 Metetra
.949 .77 .625 r
.16561 .24813 .16703 .24021 .15491 .23154 .15326 .24354 Metetra
.947 .753 .608 r
.15326 .24354 .15491 .23154 .14219 .23057 .14093 .23488 Metetra
.931 .782 .674 r
.14093 .23488 .14219 .23057 .12963 .22295 .12843 .2261 Metetra
.918 .793 .707 r
.12843 .2261 .12963 .22295 .11677 .21726 .11578 .21664 Metetra
0 .227 .663 r
.11578 .21664 .11677 .21726 .10377 .21036 .10292 .20747 Metetra
.943 .592 .316 r
.10292 .20747 .10377 .21036 .09069 .20153 .08989 .19792 Metetra
.962 .629 .267 r
.08989 .19792 .09069 .20153 .07847 .17658 .07745 .17634 Metetra
.956 .618 .314 r
.34004 .36751 .3409 .37055 .33115 .36202 .33035 .35684 Metetra
.958 .673 .453 r
.33035 .35684 .33115 .36202 .32129 .35302 .32044 .3496 Metetra
.955 .634 .377 r
.32044 .3496 .32129 .35302 .31125 .34567 .31043 .34154 Metetra
.956 .653 .419 r
.31043 .34154 .31125 .34567 .30106 .33883 .30026 .33427 Metetra
.958 .662 .43 r
.30026 .33427 .30106 .33883 .29063 .33544 .28998 .32624 Metetra
.958 .7 .504 r
.28998 .32624 .29063 .33544 .27979 .33924 .27954 .31876 Metetra
.956 .718 .538 r
.27954 .31876 .27979 .33924 .2689 .33971 .26895 .31164 Metetra
.954 .72 .547 r
.26895 .31164 .2689 .33971 .25822 .33001 .25809 .30789 Metetra
.952 .715 .544 r
.25809 .30789 .25822 .33001 .24721 .32506 .24694 .30737 Metetra
.952 .711 .538 r
.24694 .30737 .24721 .32506 .23608 .31928 .23565 .30586 Metetra
.949 .703 .531 r
.23565 .30586 .23608 .31928 .22438 .32301 .22413 .30581 Metetra
.959 .718 .528 r
.22413 .30581 .22438 .32301 .21354 .30276 .21294 .294 Metetra
.973 .71 .472 r
.21294 .294 .21354 .30276 .20208 .29348 .20197 .27444 Metetra
.957 .717 .534 r
.20197 .27444 .20208 .29348 .19074 .27841 .19039 .26494 Metetra
.964 .716 .513 r
.19039 .26494 .19074 .27841 .17894 .26955 .17896 .24916 Metetra
.956 .718 .536 r
.17896 .24916 .17894 .26955 .16702 .25981 .16703 .24021 Metetra
.956 .717 .535 r
.16703 .24021 .16702 .25981 .15492 .25021 .15491 .23154 Metetra
.951 .711 .539 r
.15491 .23154 .15492 .25021 .14255 .24228 .14219 .23057 Metetra
.956 .704 .515 r
.14219 .23057 .14255 .24228 .13014 .23187 .12963 .22295 Metetra
.954 .692 .502 r
.12963 .22295 .13014 .23187 .11737 .22442 .11677 .21726 Metetra
.955 .683 .483 r
.11677 .21726 .11737 .22442 .1045 .21535 .10377 .21036 Metetra
.956 .661 .436 r
.10377 .21036 .1045 .21535 .09151 .2049 .09069 .20153 Metetra
.944 .604 .188 r
.09069 .20153 .09151 .2049 .07873 .18847 .07847 .17658 Metetra
.959 .652 .403 r
.3409 .37055 .34174 .37451 .33201 .36501 .33115 .36202 Metetra
.953 .615 .331 r
.33115 .36202 .33201 .36501 .32217 .3553 .32129 .35302 Metetra
.933 .561 .268 r
.32129 .35302 .32217 .3553 .31215 .34725 .31125 .34567 Metetra
.883 .45 .116 r
.31125 .34567 .31215 .34725 .30192 .34191 .30106 .33883 Metetra
.937 .613 .396 r
.30106 .33883 .30192 .34191 .29149 .33826 .29063 .33544 Metetra
.906 .589 .435 r
.29063 .33544 .29149 .33826 .28095 .33373 .27979 .33924 Metetra
.958 .795 .638 r
.27979 .33924 .28095 .33373 .27006 .33453 .2689 .33971 Metetra
.932 .767 .655 r
.2689 .33971 .27006 .33453 .25938 .32502 .25822 .33001 Metetra
.943 .784 .654 r
.25822 .33001 .25938 .32502 .24849 .3174 .24721 .32506 Metetra
.947 .766 .626 r
.24721 .32506 .24849 .3174 .23737 .31164 .23608 .31928 Metetra
.963 .786 .616 r
.23608 .31928 .23737 .31164 .22609 .30609 .22438 .32301 Metetra
.94 .737 .601 r
.22438 .32301 .22609 .30609 .21487 .29512 .21354 .30276 Metetra
.941 .76 .63 r
.21354 .30276 .21487 .29512 .20338 .28693 .20208 .29348 Metetra
.927 .752 .644 r
.20208 .29348 .20338 .28693 .19182 .27683 .19074 .27841 Metetra
.874 .818 .791 r
.19074 .27841 .19182 .27683 .18001 .26833 .17894 .26955 Metetra
.843 .817 .824 r
.17894 .26955 .18001 .26833 .16815 .2576 .16702 .25981 Metetra
.897 .803 .747 r
.16702 .25981 .16815 .2576 .15607 .24771 .15492 .25021 Metetra
.912 .81 .734 r
.15492 .25021 .15607 .24771 .14381 .23794 .14255 .24228 Metetra
.927 .777 .675 r
.14255 .24228 .14381 .23794 .13144 .22697 .13014 .23187 Metetra
.938 .783 .663 r
.13014 .23187 .13144 .22697 .11854 .22201 .11737 .22442 Metetra
.906 .807 .74 r
.11737 .22442 .11854 .22201 .10568 .21286 .1045 .21535 Metetra
.902 .799 .737 r
.1045 .21535 .10568 .21286 .09267 .20301 .09151 .2049 Metetra
.856 .766 .762 r
.09151 .2049 .09267 .20301 .07976 .18869 .07873 .18847 Metetra
.911 .506 .144 r
.34174 .37451 .34263 .37646 .33289 .36735 .33201 .36501 Metetra
.936 .562 .231 r
.33201 .36501 .33289 .36735 .32298 .36003 .32217 .3553 Metetra
.959 .666 .435 r
.32217 .3553 .32298 .36003 .31294 .35277 .31215 .34725 Metetra
.954 .673 .467 r
.31215 .34725 .31294 .35277 .30276 .34563 .30192 .34191 Metetra
.944 .636 .425 r
.30192 .34191 .30276 .34563 .29238 .34037 .29149 .33826 Metetra
.919 .545 .29 r
.29149 .33826 .29238 .34037 .28163 .34189 .28095 .33373 Metetra
.945 .685 .512 r
.28095 .33373 .28163 .34189 .27094 .3369 .27006 .33453 Metetra
.935 .561 .244 r
.27006 .33453 .27094 .3369 .26018 .32968 .25938 .32502 Metetra
.956 .661 .434 r
.25938 .32502 .26018 .32968 .24919 .32452 .24849 .3174 Metetra
.955 .686 .487 r
.24849 .3174 .24919 .32452 .2377 .32781 .23737 .31164 Metetra
.955 .712 .531 r
.23737 .31164 .2377 .32781 .22503 .35407 .22609 .30609 Metetra
.956 .727 .552 r
.22609 .30609 .22503 .35407 .21512 .31195 .21487 .29512 Metetra
.957 .715 .53 r
.21487 .29512 .21512 .31195 .20415 .29179 .20338 .28693 Metetra
.961 .665 .427 r
.20338 .28693 .20415 .29179 .19252 .28293 .19182 .27683 Metetra
.958 .679 .463 r
.19182 .27683 .19252 .28293 .18101 .2685 .18001 .26833 Metetra
.357 .655 .969 r
.18001 .26833 .18101 .2685 .16903 .26003 .16815 .2576 Metetra
.933 .558 .25 r
.16815 .2576 .16903 .26003 .15689 .25131 .15607 .24771 Metetra
.954 .63 .371 r
.15607 .24771 .15689 .25131 .14458 .24247 .14381 .23794 Metetra
.96 .657 .41 r
.14381 .23794 .14458 .24247 .1321 .23346 .13144 .22697 Metetra
.951 .675 .478 r
.13144 .22697 .1321 .23346 .11942 .22448 .11854 .22201 Metetra
.932 .56 .269 r
.11854 .22201 .11942 .22448 .10656 .21531 .10568 .21286 Metetra
.931 .554 .253 r
.10568 .21286 .10656 .21531 .09352 .20602 .09267 .20301 Metetra
.95 .598 .276 r
.09267 .20301 .09352 .20602 .0806 .19169 .07976 .18869 Metetra
.719 .792 .909 r
.34263 .37646 .34357 .37603 .33388 .36525 .33289 .36735 Metetra
.903 .806 .742 r
.33289 .36735 .33388 .36525 .32405 .35542 .32298 .36003 Metetra
.935 .776 .66 r
.32298 .36003 .32405 .35542 .31402 .34816 .31294 .35277 Metetra
.935 .777 .66 r
.31294 .35277 .31402 .34816 .30381 .34255 .30276 .34563 Metetra
.931 .804 .698 r
.30276 .34563 .30381 .34255 .29333 .34078 .29238 .34037 Metetra
.578 .027 0 r
.29238 .34037 .29333 .34078 .28248 .34523 .28163 .34189 Metetra
.944 .623 .396 r
.28163 .34189 .28248 .34523 .27174 .34159 .27094 .3369 Metetra
.956 .662 .437 r
.27094 .3369 .27174 .34159 .26112 .33052 .26018 .32968 Metetra
.677 .131 0 r
.26018 .32968 .26112 .33052 .25006 .32737 .24919 .32452 Metetra
.908 .587 .427 r
.24919 .32452 .25006 .32737 .23879 .32515 .2377 .32781 Metetra
.799 .86 .412 r
.2377 .32781 .23879 .32515 .2269 .33346 .22503 .35407 Metetra
.929 .722 .602 r
.22503 .35407 .2269 .33346 .21629 .30786 .21512 .31195 Metetra
.896 .74 .68 r
.21512 .31195 .21629 .30786 .20505 .29402 .20415 .29179 Metetra
.926 .541 .232 r
.20415 .29179 .20505 .29402 .19334 .28683 .19252 .28293 Metetra
.965 .646 .352 r
.19252 .28293 .19334 .28683 .18154 .27797 .18101 .2685 Metetra
.958 .699 .501 r
.18101 .2685 .18154 .27797 .16973 .26608 .16903 .26003 Metetra
.958 .677 .461 r
.16903 .26003 .16973 .26608 .15763 .25655 .15689 .25131 Metetra
.957 .667 .442 r
.15689 .25131 .15763 .25655 .14543 .2456 .14458 .24247 Metetra
.947 .607 .342 r
.14458 .24247 .14543 .2456 .13302 .23512 .1321 .23346 Metetra
.875 .435 .089 r
.1321 .23346 .13302 .23512 .1199 .23374 .11942 .22448 Metetra
.958 .697 .498 r
.11942 .22448 .1199 .23374 .10702 .22471 .10656 .21531 Metetra
.958 .698 .498 r
.10656 .21531 .10702 .22471 .09445 .20766 .09352 .20602 Metetra
.817 .366 0 r
.09352 .20602 .09445 .20766 .08185 .18861 .0806 .19169 Metetra
.946 .585 .253 r
.34357 .37603 .34445 .37863 .33472 .36937 .33388 .36525 Metetra
.963 .657 .399 r
.33388 .36525 .33472 .36937 .32493 .358 .32405 .35542 Metetra
.941 .587 .309 r
.32405 .35542 .32493 .358 .3149 .35057 .31402 .34816 Metetra
.933 .574 .313 r
.31402 .34816 .3149 .35057 .30463 .3468 .30381 .34255 Metetra
.941 .646 .453 r
.30381 .34255 .30463 .3468 .29411 .34617 .29333 .34078 Metetra
.93 .655 .496 r
.29333 .34078 .29411 .34617 .28356 .34175 .28248 .34523 Metetra
.941 .808 .685 r
.28248 .34523 .28356 .34175 .27284 .33793 .27174 .34159 Metetra
.916 .771 .686 r
.27174 .34159 .27284 .33793 .2622 .32787 .26112 .33052 Metetra
.935 .831 .718 r
.26112 .33052 .2622 .32787 .25113 .32492 .25006 .32737 Metetra
.936 .845 .728 r
.25006 .32737 .25113 .32492 .23982 .32404 .23879 .32515 Metetra
.751 .976 .72 r
.23879 .32515 .23982 .32404 .22791 .33297 .2269 .33346 Metetra
.688 .64 .796 r
.2269 .33346 .22791 .33297 .21723 .30927 .21629 .30786 Metetra
.71 .25 0 r
.21629 .30786 .21723 .30927 .20613 .29217 .20505 .29402 Metetra
.896 .826 .77 r
.20505 .29402 .20613 .29217 .19469 .27949 .19334 .28683 Metetra
.942 .763 .632 r
.19334 .28683 .19469 .27949 .18296 .26973 .18154 .27797 Metetra
.939 .755 .628 r
.18154 .27797 .18296 .26973 .17104 .26027 .16973 .26608 Metetra
.937 .769 .649 r
.16973 .26608 .17104 .26027 .15891 .25153 .15763 .25655 Metetra
.93 .77 .662 r
.15763 .25655 .15891 .25153 .1466 .24286 .14543 .2456 Metetra
.907 .792 .723 r
.14543 .2456 .1466 .24286 .13424 .23177 .13302 .23512 Metetra
.948 .83 .695 r
.13302 .23512 .13424 .23177 .12146 .22482 .1199 .23374 Metetra
.945 .76 .622 r
.1199 .23374 .12146 .22482 .10859 .21599 .10702 .22471 Metetra
.933 .748 .629 r
.10702 .22471 .10859 .21599 .0956 .20602 .09445 .20766 Metetra
.831 .748 .771 r
.09445 .20766 .0956 .20602 .08281 .18987 .08185 .18861 Metetra
.936 .761 .639 r
.34445 .37863 .34554 .37241 .33581 .36357 .33472 .36937 Metetra
.93 .757 .646 r
.33472 .36937 .33581 .36357 .32592 .35609 .32493 .358 Metetra
.896 .81 .755 r
.32493 .358 .32592 .35609 .31593 .3479 .3149 .35057 Metetra
.933 .822 .713 r
.3149 .35057 .31593 .3479 .30578 .34056 .30463 .3468 Metetra
.956 .785 .63 r
.30463 .3468 .30578 .34056 .29547 .33369 .29411 .34617 Metetra
.952 .755 .601 r
.29411 .34617 .29547 .33369 .28503 .32695 .28356 .34175 Metetra
.953 .752 .595 r
.28356 .34175 .28503 .32695 .27415 .32832 .27284 .33793 Metetra
.943 .753 .617 r
.27284 .33793 .27415 .32832 .26334 .32319 .2622 .32787 Metetra
.948 .794 .656 r
.2622 .32787 .26334 .32319 .25215 .32384 .25113 .32492 Metetra
.869 .938 .863 r
.25113 .32492 .25215 .32384 .24093 .32103 .23982 .32404 Metetra
.977 .894 .671 r
.23982 .32404 .24093 .32103 .22957 .31725 .22791 .33297 Metetra
.936 .734 .604 r
.22791 .33297 .22957 .31725 .21845 .304 .21723 .30927 Metetra
.916 .749 .66 r
.21723 .30927 .21845 .304 .20726 .28924 .20613 .29217 Metetra
.901 .774 .712 r
.20613 .29217 .20726 .28924 .19601 .27276 .19469 .27949 Metetra
.939 .764 .638 r
.19469 .27949 .19601 .27276 .18435 .26189 .18296 .26973 Metetra
.942 .761 .629 r
.18296 .26973 .18435 .26189 .17276 .24632 .17104 .26027 Metetra
.949 .75 .601 r
.17104 .26027 .17276 .24632 .16033 .24393 .15891 .25153 Metetra
.943 .764 .63 r
.15891 .25153 .16033 .24393 .14785 .23856 .1466 .24286 Metetra
.925 .775 .676 r
.1466 .24286 .14785 .23856 .13533 .23061 .13424 .23177 Metetra
.85 .859 .849 r
.13424 .23177 .13533 .23061 .12268 .22152 .12146 .22482 Metetra
.923 .796 .703 r
.12146 .22482 .12268 .22152 .11036 .20394 .10859 .21599 Metetra
.947 .753 .608 r
.10859 .21599 .11036 .20394 .09667 .20547 .0956 .20602 Metetra
.715 .744 .874 r
.0956 .20602 .09667 .20547 .08429 .18302 .08281 .18987 Metetra
.931 .769 .659 r
.34554 .37241 .34659 .36768 .3369 .35789 .33581 .36357 Metetra
.939 .768 .644 r
.33581 .36357 .3369 .35789 .32711 .34751 .32592 .35609 Metetra
.944 .757 .62 r
.32592 .35609 .32711 .34751 .31711 .34005 .31593 .3479 Metetra
.944 .761 .624 r
.31593 .3479 .31711 .34005 .307 .33185 .30578 .34056 Metetra
.946 .759 .618 r
.30578 .34056 .307 .33185 .29675 .32398 .29547 .33369 Metetra
.948 .757 .613 r
.29547 .33369 .29675 .32398 .28637 .31585 .28503 .32695 Metetra
.959 .766 .6 r
.28503 .32695 .28637 .31585 .27556 .31585 .27415 .32832 Metetra
.951 .754 .601 r
.27415 .32832 .27556 .31585 .26481 .3097 .26334 .32319 Metetra
.957 .759 .595 r
.26334 .32319 .26481 .3097 .25375 .30775 .25215 .32384 Metetra
.954 .752 .592 r
.25215 .32384 .25375 .30775 .24247 .3071 .24093 .32103 Metetra
.953 .754 .597 r
.24093 .32103 .24247 .3071 .23112 .30383 .22957 .31725 Metetra
.944 .745 .605 r
.22957 .31725 .23112 .30383 .22001 .29111 .21845 .304 Metetra
.942 .744 .607 r
.21845 .304 .22001 .29111 .20877 .27805 .20726 .28924 Metetra
.938 .744 .614 r
.20726 .28924 .20877 .27805 .19739 .26467 .19601 .27276 Metetra
.94 .757 .627 r
.19601 .27276 .19739 .26467 .18569 .25507 .18435 .26189 Metetra
.929 .751 .641 r
.18435 .26189 .18569 .25507 .1738 .24568 .17276 .24632 Metetra
.751 .94 .946 r
.17276 .24632 .1738 .24568 .16168 .23757 .16033 .24393 Metetra
.947 .777 .639 r
.16033 .24393 .16168 .23757 .14926 .23156 .14785 .23856 Metetra
.943 .768 .635 r
.14785 .23856 .14926 .23156 .13673 .22392 .13533 .23061 Metetra
.941 .768 .639 r
.13533 .23061 .13673 .22392 .12396 .21737 .12268 .22152 Metetra
.907 .755 .682 r
.12268 .22152 .12396 .21737 .11139 .2039 .11036 .20394 Metetra
.039 0 0 r
.11036 .20394 .11139 .2039 .09808 .19959 .09667 .20547 Metetra
.912 .741 .656 r
.09667 .20547 .09808 .19959 .08546 .18109 .08429 .18302 Metetra
.945 .584 .265 r
.34659 .36768 .34747 .37025 .33777 .36049 .3369 .35789 Metetra
.946 .585 .26 r
.3369 .35789 .33777 .36049 .32793 .35191 .32711 .34751 Metetra
.958 .659 .426 r
.32711 .34751 .32793 .35191 .31794 .34399 .31711 .34005 Metetra
.958 .649 .402 r
.31711 .34005 .31794 .34399 .30778 .33741 .307 .33185 Metetra
.959 .677 .456 r
.307 .33185 .30778 .33741 .29739 .33373 .29675 .32398 Metetra
.959 .703 .504 r
.29675 .32398 .29739 .33373 .28654 .33942 .28637 .31585 Metetra
.952 .716 .545 r
.28637 .31585 .28654 .33942 .27579 .33692 .27556 .31585 Metetra
.956 .718 .538 r
.27556 .31585 .27579 .33692 .26507 .32915 .26481 .3097 Metetra
.953 .714 .539 r
.26481 .3097 .26507 .32915 .25379 .33228 .25375 .30775 Metetra
.953 .717 .545 r
.25375 .30775 .25379 .33228 .24177 .34917 .24247 .3071 Metetra
.954 .724 .551 r
.24247 .3071 .24177 .34917 .22883 .38234 .23112 .30383 Metetra
.956 .729 .555 r
.23112 .30383 .22883 .38234 .21949 .32574 .22001 .29111 Metetra
.958 .726 .545 r
.22001 .29111 .21949 .32574 .20855 .30484 .20877 .27805 Metetra
.959 .724 .539 r
.20877 .27805 .20855 .30484 .19743 .28517 .19739 .26467 Metetra
.958 .719 .534 r
.19739 .26467 .19743 .28517 .18572 .27487 .18569 .25507 Metetra
.957 .718 .533 r
.18569 .25507 .18572 .27487 .17402 .26138 .1738 .24568 Metetra
.957 .713 .526 r
.1738 .24568 .17402 .26138 .16194 .25194 .16168 .23757 Metetra
.955 .709 .525 r
.16168 .23757 .16194 .25194 .14969 .24225 .14926 .23156 Metetra
.957 .702 .509 r
.14926 .23156 .14969 .24225 .13735 .23107 .13673 .22392 Metetra
.955 .683 .482 r
.13673 .22392 .13735 .23107 .12459 .22419 .12396 .21737 Metetra
.965 .689 .459 r
.12396 .21737 .12459 .22419 .11166 .21667 .11139 .2039 Metetra
.953 .703 .521 r
.11139 .2039 .11166 .21667 .09874 .2057 .09808 .19959 Metetra
.972 .687 .427 r
.09808 .19959 .09874 .2057 .0864 .1827 .08546 .18109 Metetra
.964 .675 .435 r
.34747 .37025 .34828 .37534 .33857 .36635 .33777 .36049 Metetra
.962 .682 .459 r
.33777 .36049 .33857 .36635 .32873 .35738 .32793 .35191 Metetra
.96 .677 .454 r
.32793 .35191 .32873 .35738 .31872 .35004 .31794 .34399 Metetra
.957 .681 .47 r
.31794 .34399 .31872 .35004 .30857 .3428 .30778 .33741 Metetra
.95 .668 .469 r
.30778 .33741 .30857 .3428 .29802 .34419 .29739 .33373 Metetra
.941 .691 .529 r
.29739 .33373 .29802 .34419 .28728 .34621 .28654 .33942 Metetra
.949 .68 .492 r
.28654 .33942 .28728 .34621 .27667 .33953 .27579 .33692 Metetra
.941 .584 .304 r
.27579 .33692 .27667 .33953 .26507 .35576 .26507 .32915 Metetra
.951 .716 .548 r
.26507 .32915 .26507 .35576 .25373 .35943 .25379 .33228 Metetra
.944 .71 .554 r
.25379 .33228 .25373 .35943 .24269 .35101 .24177 .34917 Metetra
.766 .484 .508 r
.24177 .34917 .24269 .35101 .23049 .36637 .22883 .38234 Metetra
.91 .707 .616 r
.22883 .38234 .23049 .36637 .22008 .33528 .21949 .32574 Metetra
.974 .713 .475 r
.21949 .32574 .22008 .33528 .20832 .33218 .20855 .30484 Metetra
.962 .727 .536 r
.20855 .30484 .20832 .33218 .19686 .31874 .19743 .28517 Metetra
.957 .724 .545 r
.19743 .28517 .19686 .31874 .18604 .289 .18572 .27487 Metetra
.962 .715 .516 r
.18572 .27487 .18604 .289 .17478 .26632 .17402 .26138 Metetra
.959 .663 .43 r
.17402 .26138 .17478 .26632 .16269 .25704 .16194 .25194 Metetra
.959 .666 .433 r
.16194 .25194 .16269 .25704 .15066 .24319 .14969 .24225 Metetra
.529 .013 0 r
.14969 .24225 .15066 .24319 .13838 .23114 .13735 .23107 Metetra
.304 .711 .976 r
.13735 .23107 .13838 .23114 .12529 .22987 .12459 .22419 Metetra
.955 .669 .455 r
.12459 .22419 .12529 .22987 .11276 .2156 .11166 .21667 Metetra
.821 .816 .845 r
.11166 .21667 .11276 .2156 .09992 .20335 .09874 .2057 Metetra
.851 .732 .732 r
.09874 .2057 .09992 .20335 .08712 .18774 .0864 .1827 Metetra
.925 .774 .675 r
.34828 .37534 .34931 .37143 .33965 .36071 .33857 .36635 Metetra
.935 .765 .646 r
.33857 .36635 .33965 .36071 .3298 .35266 .32873 .35738 Metetra
.936 .776 .658 r
.32873 .35738 .3298 .35266 .3198 .34534 .31872 .35004 Metetra
.936 .777 .659 r
.31872 .35004 .3198 .34534 .30967 .33805 .30857 .3428 Metetra
.961 .808 .646 r
.30857 .3428 .30967 .33805 .2993 .33399 .29802 .34419 Metetra
.96 .77 .602 r
.29802 .34419 .2993 .33399 .2883 .3444 .28728 .34621 Metetra
.897 .825 .768 r
.28728 .34621 .2883 .3444 .27761 .34053 .27667 .33953 Metetra
.747 .408 .408 r
.27667 .33953 .27761 .34053 .26715 .32556 .26507 .35576 Metetra
.957 .746 .576 r
.26507 .35576 .26715 .32556 .25601 .32559 .25373 .35943 Metetra
.952 .74 .578 r
.25373 .35943 .25601 .32559 .24455 .32899 .24269 .35101 Metetra
.965 .759 .575 r
.24269 .35101 .24455 .32899 .2329 .33233 .23049 .36637 Metetra
.944 .731 .585 r
.23049 .36637 .2329 .33233 .222 .31392 .22008 .33528 Metetra
.954 .748 .585 r
.22008 .33528 .222 .31392 .21099 .2951 .20832 .33218 Metetra
.951 .737 .579 r
.20832 .33218 .21099 .2951 .19927 .28881 .19686 .31874 Metetra
.943 .731 .587 r
.19686 .31874 .19927 .28881 .18767 .27632 .18604 .289 Metetra
.934 .737 .612 r
.18604 .289 .18767 .27632 .17631 .25604 .17478 .26632 Metetra
.946 .756 .614 r
.17478 .26632 .17631 .25604 .16436 .2445 .16269 .25704 Metetra
.943 .747 .608 r
.16269 .25704 .16436 .2445 .15194 .23856 .15066 .24319 Metetra
.925 .77 .67 r
.15066 .24319 .15194 .23856 .13966 .22662 .13838 .23114 Metetra
.953 .809 .663 r
.13838 .23114 .13966 .22662 .12639 .22863 .12529 .22987 Metetra
.823 .78 .812 r
.12529 .22987 .12639 .22863 .11388 .21417 .11276 .2156 Metetra
.848 .8 .804 r
.11276 .2156 .11388 .21417 .1012 .19953 .09992 .20335 Metetra
.909 .765 .69 r
.09992 .20335 .1012 .19953 .08852 .18221 .08712 .18774 Metetra
.964 .651 .376 r
.34931 .37143 .35016 .37531 .34049 .3648 .33965 .36071 Metetra
.959 .654 .409 r
.33965 .36071 .34049 .3648 .33066 .35592 .3298 .35266 Metetra
.952 .625 .369 r
.3298 .35266 .33066 .35592 .32061 .35036 .3198 .34534 Metetra
.958 .669 .445 r
.3198 .34534 .32061 .35036 .31048 .34306 .30967 .33805 Metetra
.95 .664 .459 r
.30967 .33805 .31048 .34306 .29996 .34373 .2993 .33399 Metetra
.934 .682 .533 r
.2993 .33399 .29996 .34373 .2895 .33751 .2883 .3444 Metetra
.95 .774 .628 r
.2883 .3444 .2895 .33751 .27828 .34918 .27761 .34053 Metetra
.969 .706 .479 r
.27761 .34053 .27828 .34918 .2673 .34831 .26715 .32556 Metetra
.952 .716 .543 r
.26715 .32556 .2673 .34831 .25637 .34199 .25601 .32559 Metetra
.948 .707 .538 r
.25601 .32559 .25637 .34199 .24506 .34098 .24455 .32899 Metetra
.946 .697 .529 r
.24455 .32899 .24506 .34098 .23286 .35745 .2329 .33233 Metetra
.962 .726 .534 r
.2329 .33233 .23286 .35745 .22251 .3252 .222 .31392 Metetra
.97 .716 .494 r
.222 .31392 .22251 .3252 .21133 .30988 .21099 .2951 Metetra
.956 .711 .526 r
.21099 .2951 .21133 .30988 .19937 .30821 .19927 .28881 Metetra
.96 .72 .53 r
.19927 .28881 .19937 .30821 .188 .29044 .18767 .27632 Metetra
.968 .72 .508 r
.18767 .27632 .188 .29044 .17691 .26428 .17631 .25604 Metetra
.963 .697 .483 r
.17631 .25604 .17691 .26428 .16487 .25411 .16436 .2445 Metetra
.955 .696 .504 r
.16436 .2445 .16487 .25411 .15253 .24652 .15194 .23856 Metetra
.963 .695 .478 r
.15194 .23856 .15253 .24652 .14002 .23844 .13966 .22662 Metetra
.947 .696 .524 r
.13966 .22662 .14002 .23844 .12732 .23044 .12639 .22863 Metetra
.85 .415 0 r
.12639 .22863 .12732 .23044 .11409 .22786 .11388 .21417 Metetra
.963 .714 .513 r
.11388 .21417 .11409 .22786 .10191 .20493 .1012 .19953 Metetra
.971 .677 .409 r
.1012 .19953 .10191 .20493 .08945 .18395 .08852 .18221 Metetra
.915 .77 .686 r
.35016 .37531 .35118 .37181 .34149 .36279 .34049 .3648 Metetra
.892 .795 .747 r
.34049 .3648 .34149 .36279 .33169 .35297 .33066 .35592 Metetra
.929 .804 .702 r
.33066 .35592 .33169 .35297 .32171 .34502 .32061 .35036 Metetra
.939 .772 .648 r
.32061 .35036 .32171 .34502 .31154 .3395 .31048 .34306 Metetra
.957 .828 .674 r
.31048 .34306 .31154 .3395 .30106 .33915 .29996 .34373 Metetra
.939 .783 .66 r
.29996 .34373 .30106 .33915 .2904 .33952 .2895 .33751 Metetra
.847 .525 .443 r
.2895 .33751 .2904 .33952 .2795 .34208 .27828 .34918 Metetra
.956 .78 .623 r
.27828 .34918 .2795 .34208 .26869 .33719 .2673 .34831 Metetra
.95 .756 .607 r
.2673 .34831 .26869 .33719 .25772 .33221 .25637 .34199 Metetra
.956 .768 .608 r
.25637 .34199 .25772 .33221 .24609 .33994 .24506 .34098 Metetra
.24506 .34098 .24609 .33994 .23367 .36207 .23286 .35745 Metetra
.953 .651 .217 r
.23286 .35745 .23367 .36207 .22372 .32033 .22251 .3252 Metetra
.918 .755 .665 r
.22251 .3252 .22372 .32033 .21223 .31205 .21133 .30988 Metetra
.907 .54 .327 r
.21133 .30988 .21223 .31205 .20139 .28642 .19937 .30821 Metetra
.946 .738 .591 r
.19937 .30821 .20139 .28642 .18979 .27414 .188 .29044 Metetra
.936 .733 .603 r
.188 .29044 .18979 .27414 .17839 .25498 .17691 .26428 Metetra
.944 .757 .619 r
.17691 .26428 .17839 .25498 .16633 .24573 .16487 .25411 Metetra
.947 .764 .623 r
.16487 .25411 .16633 .24573 .15387 .24059 .15253 .24652 Metetra
.941 .774 .647 r
.15253 .24652 .15387 .24059 .14157 .22905 .14002 .23844 Metetra
.947 .761 .618 r
.14002 .23844 .14157 .22905 .12836 .23023 .12732 .23044 Metetra
.436 .847 .966 r
.12732 .23044 .12836 .23023 .11558 .22046 .11409 .22786 Metetra
.921 .74 .641 r
.11409 .22786 .11558 .22046 .10294 .20502 .10191 .20493 Metetra
.522 .612 .884 r
.10191 .20493 .10294 .20502 .09036 .18611 .08945 .18395 Metetra
.805 .805 .851 r
.35118 .37181 .35214 .37097 .34249 .36053 .34149 .36279 Metetra
.895 .785 .732 r
.34149 .36279 .34249 .36053 .33266 .35217 .33169 .35297 Metetra
.805 .825 .867 r
.33169 .35297 .33266 .35217 .32269 .34433 .32171 .34502 Metetra
.793 .87 .905 r
.32171 .34502 .32269 .34433 .31262 .33528 .31154 .3395 Metetra
.956 .81 .659 r
.31154 .3395 .31262 .33528 .30232 .3296 .30106 .33915 Metetra
.958 .77 .606 r
.30106 .33915 .30232 .3296 .29194 .32198 .2904 .33952 Metetra
.959 .755 .585 r
.2904 .33952 .29194 .32198 .28105 .32511 .2795 .34208 Metetra
.953 .749 .591 r
.2795 .34208 .28105 .32511 .27036 .31777 .26869 .33719 Metetra
.953 .747 .587 r
.26869 .33719 .27036 .31777 .25937 .31457 .25772 .33221 Metetra
.963 .759 .582 r
.25772 .33221 .25937 .31457 .24811 .31399 .24609 .33994 Metetra
.967 .758 .569 r
.24609 .33994 .24811 .31399 .23678 .31055 .23367 .36207 Metetra
.945 .729 .579 r
.23367 .36207 .23678 .31055 .22569 .29759 .22372 .32033 Metetra
.952 .744 .586 r
.22372 .32033 .22569 .29759 .21467 .27985 .21223 .31205 Metetra
.946 .733 .584 r
.21223 .31205 .21467 .27985 .20317 .26979 .20139 .28642 Metetra
.947 .745 .596 r
.20139 .28642 .20317 .26979 .19175 .25443 .18979 .27414 Metetra
.944 .738 .594 r
.18979 .27414 .19175 .25443 .17987 .24551 .17839 .25498 Metetra
.946 .758 .618 r
.17839 .25498 .17987 .24551 .16783 .2364 .16633 .24573 Metetra
.951 .765 .615 r
.16633 .24573 .16783 .2364 .15557 .228 .15387 .24059 Metetra
.946 .75 .606 r
.15387 .24059 .15557 .228 .14301 .22178 .14157 .22905 Metetra
.96 .787 .624 r
.14157 .22905 .14301 .22178 .13043 .21237 .12836 .23023 Metetra
.95 .747 .593 r
.12836 .23023 .13043 .21237 .1178 .20065 .11558 .22046 Metetra
.947 .742 .593 r
.11558 .22046 .1178 .20065 .10472 .19309 .10294 .20502 Metetra
.938 .743 .613 r
.10294 .20502 .10472 .19309 .09233 .17156 .09036 .18611 Metetra
.945 .748 .606 r
.35214 .37097 .35336 .35932 .3437 .34982 .34249 .36053 Metetra
.947 .752 .608 r
.34249 .36053 .3437 .34982 .33386 .34246 .33266 .35217 Metetra
.946 .755 .612 r
.33266 .35217 .33386 .34246 .3239 .33509 .32269 .34433 Metetra
.944 .755 .616 r
.32269 .34433 .3239 .33509 .3138 .32766 .31262 .33528 Metetra
.948 .766 .623 r
.31262 .33528 .3138 .32766 .30358 .32008 .30232 .3296 Metetra
.947 .757 .614 r
.30232 .3296 .30358 .32008 .29322 .31243 .29194 .32198 Metetra
.962 .774 .603 r
.29194 .32198 .29322 .31243 .28272 .30479 .28105 .32511 Metetra
.952 .745 .587 r
.28105 .32511 .28272 .30479 .27188 .30274 .27036 .31777 Metetra
.954 .753 .593 r
.27036 .31777 .27188 .30274 .26081 .30229 .25937 .31457 Metetra
.957 .761 .598 r
.25937 .31457 .26081 .30229 .24971 .29813 .24811 .31399 Metetra
.954 .752 .592 r
.24811 .31399 .24971 .29813 .23832 .29721 .23678 .31055 Metetra
.945 .746 .604 r
.23678 .31055 .23832 .29721 .22727 .28394 .22569 .29759 Metetra
.94 .741 .606 r
.22569 .29759 .22727 .28394 .21608 .27071 .21467 .27985 Metetra
.944 .756 .619 r
.21467 .27985 .21608 .27071 .20466 .25908 .20317 .26979 Metetra
.939 .746 .615 r
.20317 .26979 .20466 .25908 .19315 .24637 .19175 .25443 Metetra
.944 .762 .626 r
.19175 .25443 .19315 .24637 .18128 .23756 .17987 .24551 Metetra
.944 .762 .627 r
.17987 .24551 .18128 .23756 .16924 .22882 .16783 .2364 Metetra
.944 .765 .629 r
.16783 .2364 .16924 .22882 .15661 .22757 .15557 .228 Metetra
.684 .872 .97 r
.15557 .228 .15661 .22757 .14421 .2185 .14301 .22178 Metetra
.921 .793 .703 r
.14301 .22178 .14421 .2185 .13141 .21316 .13043 .21237 Metetra
0 .14 .626 r
.13043 .21237 .13141 .21316 .11878 .20152 .1178 .20065 Metetra
.625 .075 0 r
.1178 .20065 .11878 .20152 .10577 .19299 .10472 .19309 Metetra
.59 .641 .87 r
.10472 .19309 .10577 .19299 .09371 .16633 .09233 .17156 Metetra
.963 .7 .487 r
.35336 .35932 .3541 .36746 .34443 .35842 .3437 .34982 Metetra
.96 .699 .497 r
.3437 .34982 .34443 .35842 .33463 .34912 .33386 .34246 Metetra
.96 .687 .476 r
.33386 .34246 .33463 .34912 .32466 .34181 .3239 .33509 Metetra
.96 .688 .476 r
.3239 .33509 .32466 .34181 .31455 .33466 .3138 .32766 Metetra
.96 .69 .479 r
.3138 .32766 .31455 .33466 .30414 .33306 .30358 .32008 Metetra
.959 .711 .519 r
.30358 .32008 .30414 .33306 .29331 .33933 .29322 .31243 Metetra
.957 .722 .542 r
.29322 .31243 .29331 .33933 .28249 .33985 .28272 .30479 Metetra
.954 .722 .549 r
.28272 .30479 .28249 .33985 .27152 .34009 .27188 .30274 Metetra
.954 .722 .55 r
.27188 .30274 .27152 .34009 .26044 .3385 .26081 .30229 Metetra
.955 .723 .548 r
.26081 .30229 .26044 .3385 .24949 .32912 .24971 .29813 Metetra
.954 .72 .547 r
.24971 .29813 .24949 .32912 .23636 .36958 .23832 .29721 Metetra
.957 .729 .553 r
.23832 .29721 .23636 .36958 .22619 .33273 .22727 .28394 Metetra
.958 .728 .549 r
.22727 .28394 .22619 .33273 .21535 .30974 .21608 .27071 Metetra
.958 .726 .546 r
.21608 .27071 .21535 .30974 .20407 .29372 .20466 .25908 Metetra
.958 .726 .544 r
.20466 .25908 .20407 .29372 .19274 .27584 .19315 .24637 Metetra
.957 .723 .542 r
.19315 .24637 .19274 .27584 .18116 .26041 .18128 .23756 Metetra
.957 .72 .537 r
.18128 .23756 .18116 .26041 .16914 .25039 .16924 .22882 Metetra
.953 .714 .539 r
.16924 .22882 .16914 .25039 .15682 .24292 .15661 .22757 Metetra
.958 .713 .523 r
.15661 .22757 .15682 .24292 .14442 .23336 .14421 .2185 Metetra
.955 .709 .525 r
.14421 .2185 .14442 .23336 .13149 .22983 .13141 .21316 Metetra
.96 .716 .524 r
.13141 .21316 .13149 .22983 .11887 .21747 .11878 .20152 Metetra
.958 .712 .525 r
.11878 .20152 .11887 .21747 .10635 .20043 .10577 .19299 Metetra
.981 .706 .428 r
.10577 .19299 .10635 .20043 .09344 .18703 .09371 .16633 Metetra
.937 .566 .243 r
.3541 .36746 .35499 .36984 .34527 .36232 .34443 .35842 Metetra
.961 .65 .388 r
.34443 .35842 .34527 .36232 .33542 .35504 .33463 .34912 Metetra
.959 .681 .464 r
.33463 .34912 .33542 .35504 .32549 .34606 .32466 .34181 Metetra
.957 .655 .42 r
.32466 .34181 .32549 .34606 .31534 .34054 .31455 .33466 Metetra
.947 .671 .482 r
.31455 .33466 .31534 .34054 .30506 .33422 .30414 .33306 Metetra
.809 .422 .321 r
.30414 .33306 .30506 .33422 .29432 .33804 .29331 .33933 Metetra
.901 .94 .826 r
.29331 .33933 .29432 .33804 .28336 .34296 .28249 .33985 Metetra
.924 .605 .418 r
.28249 .33985 .28336 .34296 .27258 .33779 .27152 .34009 Metetra
.937 .856 .735 r
.27152 .34009 .27258 .33779 .26142 .33858 .26044 .3385 Metetra
.425 .701 .979 r
.26044 .3385 .26142 .33858 .25009 .33908 .24949 .32912 Metetra
.897 .652 .558 r
.24949 .32912 .25009 .33908 .23679 .38376 .23636 .36958 Metetra
.982 .733 .481 r
.23636 .36958 .23679 .38376 .22728 .33077 .22619 .33273 Metetra
.829 .716 .739 r
.22619 .33273 .22728 .33077 .21608 .31597 .21535 .30974 Metetra
.972 .689 .434 r
.21535 .30974 .21608 .31597 .2052 .29103 .20407 .29372 Metetra
.877 .75 .719 r
.20407 .29372 .2052 .29103 .19378 .2752 .19274 .27584 Metetra
.739 .744 .856 r
.19274 .27584 .19378 .2752 .18211 .26157 .18116 .26041 Metetra
.711 .205 0 r
.18116 .26041 .18211 .26157 .17004 .25281 .16914 .25039 Metetra
.929 .557 .278 r
.16914 .25039 .17004 .25281 .15778 .24404 .15682 .24292 Metetra
.707 .193 0 r
.15682 .24292 .15778 .24404 .14535 .2351 .14442 .23336 Metetra
.886 .475 .225 r
.14442 .23336 .14535 .2351 .13293 .22269 .13149 .22983 Metetra
.937 .76 .637 r
.13149 .22983 .13293 .22269 .11998 .21632 .11887 .21747 Metetra
.802 .756 .81 r
.11887 .21747 .11998 .21632 .10741 .20026 .10635 .20043 Metetra
.594 .738 .944 r
.10635 .20043 .10741 .20026 .09464 .18461 .09344 .18703 Metetra
.943 .587 .3 r
.35499 .36984 .35587 .37241 .34618 .36389 .34527 .36232 Metetra
.877 .439 .087 r
.34527 .36232 .34618 .36389 .33635 .35599 .33542 .35504 Metetra
.576 .061 0 r
.33542 .35504 .33635 .35599 .3264 .34767 .32549 .34606 Metetra
.888 .463 .158 r
.32549 .34606 .3264 .34767 .31625 .34215 .31534 .34054 Metetra
.886 .457 .136 r
.31534 .34054 .31625 .34215 .30583 .34044 .30506 .33422 Metetra
.936 .666 .501 r
.30506 .33422 .30583 .34044 .29526 .3388 .29432 .33804 Metetra
.744 .301 .201 r
.29432 .33804 .29526 .3388 .28422 .34645 .28336 .34296 Metetra
.946 .627 .397 r
.28336 .34296 .28422 .34645 .27289 .35651 .27258 .33779 Metetra
.952 .712 .538 r
.27258 .33779 .27289 .35651 .26202 .34883 .26142 .33858 Metetra
.949 .694 .518 r
.26142 .33858 .26202 .34883 .25067 .34982 .25009 .33908 Metetra
.897 .653 .562 r
.25009 .33908 .25067 .34982 .23722 .39794 .23679 .38376 Metetra
.991 .743 .45 r
.23679 .38376 .23722 .39794 .22804 .33634 .22728 .33077 Metetra
.971 .681 .421 r
.22728 .33077 .22804 .33634 .21599 .34074 .21608 .31597 Metetra
.966 .729 .528 r
.21608 .31597 .21599 .34074 .20487 .32025 .2052 .29103 Metetra
.96 .726 .539 r
.2052 .29103 .20487 .32025 .1941 .28978 .19378 .2752 Metetra
.963 .716 .516 r
.19378 .2752 .1941 .28978 .18308 .2625 .18211 .26157 Metetra
.619 .083 0 r
.18211 .26157 .18308 .2625 .17104 .25304 .17004 .25281 Metetra
.218 .62 .953 r
.17004 .25281 .17104 .25304 .15881 .24396 .15778 .24404 Metetra
.509 .77 .99 r
.15778 .24404 .15881 .24396 .14635 .2357 .14535 .2351 Metetra
0 .358 .817 r
.14535 .2351 .14635 .2357 .13345 .23174 .13293 .22269 Metetra
.956 .693 .498 r
.13293 .22269 .13345 .23174 .12084 .21938 .11998 .21632 Metetra
.951 .597 .252 r
.11998 .21632 .12084 .21938 .10842 .20073 .10741 .20026 Metetra
.183 .489 .901 r
.10741 .20026 .10842 .20073 .09553 .18708 .09464 .18461 Metetra
.872 .806 .782 r
.35587 .37241 .35685 .3709 .34715 .36283 .34618 .36389 Metetra
.84 .822 .831 r
.34618 .36389 .34715 .36283 .33732 .35523 .33635 .35599 Metetra
.795 .819 .871 r
.33635 .35599 .33732 .35523 .32735 .34791 .3264 .34767 Metetra
.069 .563 .893 r
.3264 .34767 .32735 .34791 .31724 .34111 .31625 .34215 Metetra
.868 .925 .862 r
.31625 .34215 .31724 .34111 .30684 .33902 .30583 .34044 Metetra
.906 .9 .81 r
.30583 .34044 .30684 .33902 .2962 .33991 .29526 .3388 Metetra
.795 .412 .329 r
.29526 .3388 .2962 .33991 .28494 .35406 .28422 .34645 Metetra
.929 .669 .522 r
.28422 .34645 .28494 .35406 .27443 .34077 .27289 .35651 Metetra
.951 .749 .594 r
.27289 .35651 .27443 .34077 .26329 .34125 .26202 .34883 Metetra
.96 .782 .617 r
.26202 .34883 .26329 .34125 .25175 .3475 .25067 .34982 Metetra
0 0 .217 r
.25067 .34982 .25175 .3475 .23899 .37888 .23722 .39794 Metetra
.915 .708 .61 r
.23722 .39794 .23899 .37888 .22947 .32615 .22804 .33634 Metetra
.964 .776 .601 r
.22804 .33634 .22947 .32615 .2181 .31562 .21599 .34074 Metetra
.946 .737 .588 r
.21599 .34074 .2181 .31562 .20712 .29317 .20487 .32025 Metetra
.942 .731 .589 r
.20487 .32025 .20712 .29317 .19544 .28294 .1941 .28978 Metetra
.909 .728 .646 r
.1941 .28978 .19544 .28294 .18415 .26149 .18308 .2625 Metetra
.822 .827 .852 r
.18308 .2625 .18415 .26149 .17229 .24872 .17104 .25304 Metetra
.932 .783 .673 r
.17104 .25304 .17229 .24872 .15998 .24121 .15881 .24396 Metetra
.917 .807 .723 r
.15881 .24396 .15998 .24121 .14779 .22816 .14635 .2357 Metetra
.952 .775 .626 r
.14635 .2357 .14779 .22816 .13458 .23001 .13345 .23174 Metetra
.866 .796 .78 r
.13345 .23174 .13458 .23001 .12186 .21972 .12084 .21938 Metetra
.366 .552 .903 r
.12084 .21938 .12186 .21972 .10937 .20225 .10842 .20073 Metetra
.784 .319 0 r
.10842 .20073 .10937 .20225 .09656 .18745 .09553 .18708 Metetra
.962 .688 .471 r
.35685 .3709 .35764 .37749 .34799 .36693 .34715 .36283 Metetra
.958 .653 .41 r
.34715 .36283 .34799 .36693 .33822 .35707 .33732 .35523 Metetra
.906 .495 .167 r
.33732 .35523 .33822 .35707 .32826 .34968 .32735 .34791 Metetra
.901 .487 .165 r
.32735 .34791 .32826 .34968 .31815 .3425 .31724 .34111 Metetra
.864 .435 .192 r
.31724 .34111 .31815 .3425 .30783 .33804 .30684 .33902 Metetra
.853 .972 .87 r
.30684 .33902 .30783 .33804 .29716 .34015 .2962 .33991 Metetra
.604 .216 .281 r
.2962 .33991 .29716 .34015 .28579 .35775 .28494 .35406 Metetra
.964 .64 .337 r
.28494 .35406 .28579 .35775 .27526 .34516 .27443 .34077 Metetra
.936 .642 .46 r
.27443 .34077 .27526 .34516 .26413 .34535 .26329 .34125 Metetra
.917 .624 .475 r
.26329 .34125 .26413 .34535 .25204 .36571 .25175 .3475 Metetra
.93 .691 .556 r
.25175 .3475 .25204 .36571 .23894 .40506 .23899 .37888 Metetra
.978 .742 .51 r
.23899 .37888 .23894 .40506 .23017 .33341 .22947 .32615 Metetra
.963 .691 .471 r
.22947 .32615 .23017 .33341 .2192 .31363 .2181 .31562 Metetra
.834 .72 .739 r
.2181 .31562 .2192 .31363 .20814 .29291 .20712 .29317 Metetra
.64 .784 .951 r
.20712 .29317 .20814 .29291 .19649 .28228 .19544 .28294 Metetra
.723 .688 .816 r
.19544 .28294 .19649 .28228 .18508 .26312 .18415 .26149 Metetra
.823 .373 0 r
.18415 .26149 .18508 .26312 .17307 .2533 .17229 .24872 Metetra
.954 .653 .424 r
.17229 .24872 .17307 .2533 .16074 .24619 .15998 .24121 Metetra
.966 .667 .411 r
.15998 .24121 .16074 .24619 .1483 .23772 .14779 .22816 Metetra
.946 .687 .513 r
.14779 .22816 .1483 .23772 .13556 .23099 .13458 .23001 Metetra
.599 .072 0 r
.13458 .23001 .13556 .23099 .12301 .21786 .12186 .21972 Metetra
.851 .76 .762 r
.12186 .21972 .12301 .21786 .11031 .20399 .10937 .20225 Metetra
.831 .389 0 r
.10937 .20225 .11031 .20399 .09759 .18769 .09656 .18745 Metetra
.915 .771 .687 r
.35764 .37749 .35866 .37402 .34894 .36686 .34799 .36693 Metetra
.573 .736 .952 r
.34799 .36693 .34894 .36686 .33913 .35878 .33822 .35707 Metetra
.894 .472 .132 r
.33822 .35707 .33913 .35878 .32921 .34981 .32826 .34968 Metetra
.331 .686 .98 r
.32826 .34968 .32921 .34981 .31916 .34093 .31815 .3425 Metetra
.9 .855 .789 r
.31815 .3425 .31916 .34093 .30891 .33441 .30783 .33804 Metetra
.963 .835 .669 r
.30783 .33804 .30891 .33441 .29845 .33007 .29716 .34015 Metetra
.981 .795 .58 r
.29716 .34015 .29845 .33007 .28787 .3246 .28579 .35775 Metetra
.952 .738 .579 r
.28579 .35775 .28787 .3246 .27709 .32086 .27526 .34516 Metetra
.957 .748 .579 r
.27526 .34516 .27709 .32086 .26626 .31411 .26413 .34535 Metetra
.965 .754 .567 r
.26413 .34535 .26626 .31411 .25459 .32521 .25204 .36571 Metetra
.969 .755 .56 r
.25204 .36571 .25459 .32521 .24307 .32695 .23894 .40506 Metetra
.944 .725 .577 r
.23894 .40506 .24307 .32695 .23218 .30927 .23017 .33341 Metetra
.946 .737 .588 r
.23017 .33341 .23218 .30927 .22143 .28545 .2192 .31363 Metetra
.947 .736 .585 r
.2192 .31363 .22143 .28545 .2101 .27189 .20814 .29291 Metetra
.951 .744 .588 r
.20814 .29291 .2101 .27189 .19856 .25983 .19649 .28228 Metetra
.946 .738 .59 r
.19649 .28228 .19856 .25983 .18679 .24905 .18508 .26312 Metetra
.949 .75 .6 r
.18508 .26312 .18679 .24905 .17466 .24221 .17307 .2533 Metetra
.95 .758 .608 r
.17307 .2533 .17466 .24221 .16243 .23364 .16074 .24619 Metetra
.95 .754 .604 r
.16074 .24619 .16243 .23364 .14993 .22672 .1483 .23772 Metetra
.951 .759 .608 r
.1483 .23772 .14993 .22672 .13737 .21735 .13556 .23099 Metetra
.946 .748 .603 r
.13556 .23099 .13737 .21735 .1246 .20848 .12301 .21786 Metetra
.941 .753 .621 r
.12301 .21786 .1246 .20848 .11179 .19677 .11031 .20399 Metetra
.932 .754 .639 r
.11031 .20399 .11179 .19677 .09886 .18414 .09759 .18769 Metetra
.935 .779 .663 r
.35866 .37402 .3597 .36963 .35003 .36109 .34894 .36686 Metetra
.939 .768 .642 r
.34894 .36686 .35003 .36109 .34028 .35086 .33913 .35878 Metetra
.943 .758 .623 r
.33913 .35878 .34028 .35086 .33033 .34346 .32921 .34981 Metetra
.939 .764 .637 r
.32921 .34981 .33033 .34346 .32026 .33593 .31916 .34093 Metetra
.941 .778 .652 r
.31916 .34093 .32026 .33593 .31006 .32827 .30891 .33441 Metetra
.949 .777 .635 r
.30891 .33441 .31006 .32827 .29971 .32074 .29845 .33007 Metetra
.951 .762 .612 r
.29845 .33007 .29971 .32074 .28916 .31523 .28787 .3246 Metetra
.953 .765 .611 r
.28787 .3246 .28916 .31523 .27831 .31387 .27709 .32086 Metetra
.946 .768 .63 r
.27709 .32086 .27831 .31387 .26742 .30925 .26626 .31411 Metetra
.984 .843 .623 r
.26626 .31411 .26742 .30925 .25633 .30545 .25459 .32521 Metetra
.959 .753 .582 r
.25459 .32521 .25633 .30545 .24485 .30738 .24307 .32695 Metetra
.946 .739 .593 r
.24307 .32695 .24485 .30738 .23379 .2946 .23218 .30927 Metetra
.937 .735 .605 r
.23218 .30927 .23379 .2946 .22264 .28052 .22143 .28545 Metetra
.924 .762 .663 r
.22143 .28545 .22264 .28052 .21127 .26822 .2101 .27189 Metetra
.916 .774 .689 r
.2101 .27189 .21127 .26822 .19982 .25441 .19856 .25983 Metetra
.934 .769 .654 r
.19856 .25983 .19982 .25441 .18805 .24396 .18679 .24905 Metetra
.942 .783 .656 r
.18679 .24905 .18805 .24396 .17597 .23643 .17466 .24221 Metetra
.94 .774 .648 r
.17466 .24221 .17597 .23643 .16342 .23428 .16243 .23364 Metetra
.444 0 0 r
.16243 .23364 .16342 .23428 .15097 .22658 .14993 .22672 Metetra
.549 .78 .984 r
.14993 .22672 .15097 .22658 .13827 .21973 .13737 .21735 Metetra
.927 .547 .249 r
.13737 .21735 .13827 .21973 .1255 .21087 .1246 .20848 Metetra
.928 .542 .207 r
.1246 .20848 .1255 .21087 .11257 .20122 .11179 .19677 Metetra
.962 .653 .391 r
.11179 .19677 .11257 .20122 .09988 .18466 .09886 .18414 Metetra
.585 .765 .964 r
.3597 .36963 .36064 .36952 .35095 .36201 .35003 .36109 Metetra
0 .026 .535 r
.35003 .36109 .35095 .36201 .34113 .35464 .34028 .35086 Metetra
.956 .643 .396 r
.34028 .35086 .34113 .35464 .33118 .34735 .33033 .34346 Metetra
.957 .646 .4 r
.33033 .34346 .33118 .34735 .32109 .34041 .32026 .33593 Metetra
.958 .659 .423 r
.32026 .33593 .32109 .34041 .31087 .3331 .31006 .32827 Metetra
.959 .665 .435 r
.31006 .32827 .31087 .3331 .30032 .33198 .29971 .32074 Metetra
.957 .705 .514 r
.29971 .32074 .30032 .33198 .28917 .34445 .28916 .31523 Metetra
.955 .72 .545 r
.28916 .31523 .28917 .34445 .27835 .34096 .27831 .31387 Metetra
.956 .721 .542 r
.27831 .31387 .27835 .34096 .26743 .33611 .26742 .30925 Metetra
.956 .72 .542 r
.26742 .30925 .26743 .33611 .25603 .33935 .25633 .30545 Metetra
.953 .721 .548 r
.25633 .30545 .25603 .33935 .24437 .34444 .24485 .30738 Metetra
.959 .727 .544 r
.24485 .30738 .24437 .34444 .23359 .32352 .23379 .2946 Metetra
.96 .725 .538 r
.23379 .2946 .23359 .32352 .22181 .32305 .22264 .28052 Metetra
.958 .727 .546 r
.22264 .28052 .22181 .32305 .20993 .32055 .21127 .26822 Metetra
.958 .729 .549 r
.21127 .26822 .20993 .32055 .19829 .30867 .19982 .25441 Metetra
.957 .728 .55 r
.19982 .25441 .19829 .30867 .18766 .27295 .18805 .24396 Metetra
.957 .722 .541 r
.18805 .24396 .18766 .27295 .17625 .25116 .17597 .23643 Metetra
.953 .707 .527 r
.17597 .23643 .17625 .25116 .16368 .24883 .16342 .23428 Metetra
.958 .711 .521 r
.16342 .23428 .16368 .24883 .1512 .2412 .15097 .22658 Metetra
.957 .71 .522 r
.15097 .22658 .1512 .2412 .13927 .2204 .13827 .21973 Metetra
0 .166 .601 r
.13827 .21973 .13927 .2204 .12653 .21104 .1255 .21087 Metetra
.291 .656 .97 r
.1255 .21087 .12653 .21104 .11378 .19853 .11257 .20122 Metetra
.886 .766 .725 r
.11257 .20122 .11378 .19853 .10094 .18442 .09988 .18466 Metetra
.96 .667 .434 r
.36064 .36952 .36148 .3743 .35185 .36406 .35095 .36201 Metetra
.922 .53 .215 r
.35095 .36201 .35185 .36406 .34203 .35674 .34113 .35464 Metetra
.924 .537 .228 r
.34113 .35464 .34203 .35674 .33209 .34899 .33118 .34735 Metetra
.886 .455 .117 r
.33118 .34735 .33209 .34899 .322 .34224 .32109 .34041 Metetra
.904 .492 .164 r
.32109 .34041 .322 .34224 .31158 .34184 .31087 .3331 Metetra
.95 .691 .508 r
.31087 .3331 .31158 .34184 .30097 .34228 .30032 .33198 Metetra
.934 .683 .535 r
.30032 .33198 .30097 .34228 .28986 .35294 .28917 .34445 Metetra
.954 .692 .501 r
.28917 .34445 .28986 .35294 .27871 .35894 .27835 .34096 Metetra
.956 .715 .532 r
.27835 .34096 .27871 .35894 .26768 .35644 .26743 .33611 Metetra
.951 .712 .541 r
.26743 .33611 .26768 .35644 .25675 .34663 .25603 .33935 Metetra
.937 .672 .508 r
.25603 .33935 .25675 .34663 .24511 .35121 .24437 .34444 Metetra
.979 .7 .424 r
.24437 .34444 .24511 .35121 .23432 .33027 .23359 .32352 Metetra
.946 .674 .49 r
.23359 .32352 .23432 .33027 .22273 .32512 .22181 .32305 Metetra
.906 .527 .298 r
.22181 .32305 .22273 .32512 .21112 .31661 .20993 .32055 Metetra
.92 .774 .682 r
.20993 .32055 .21112 .31661 .19959 .30268 .19829 .30867 Metetra
.887 .71 .657 r
.19829 .30867 .19959 .30268 .18737 .29998 .18766 .27295 Metetra
.964 .728 .532 r
.18766 .27295 .18737 .29998 .17663 .26383 .17625 .25116 Metetra
.953 .703 .52 r
.17625 .25116 .17663 .26383 .16429 .25695 .16368 .24883 Metetra
.958 .691 .486 r
.16368 .24883 .16429 .25695 .15167 .25159 .1512 .2412 Metetra
.972 .713 .481 r
.1512 .2412 .15167 .25159 .134 .33282 .13927 .2204 Metetra
.956 .73 .555 r
.13927 .2204 .134 .33282 .12492 .25658 .12653 .21104 Metetra
.958 .727 .547 r
.12653 .21104 .12492 .25658 .11417 .20944 .11378 .19853 Metetra
.964 .707 .497 r
.11378 .19853 .11417 .20944 .10172 .18883 .10094 .18442 Metetra
.961 .638 .353 r
.36148 .3743 .36234 .37783 .35272 .36713 .35185 .36406 Metetra
.95 .616 .35 r
.35185 .36406 .35272 .36713 .34298 .35669 .34203 .35674 Metetra
.524 .763 .984 r
.34203 .35674 .34298 .35669 .33304 .34925 .33209 .34899 Metetra
.128 .575 .923 r
.33209 .34899 .33304 .34925 .32292 .34372 .322 .34224 Metetra
.87 .462 .254 r
.322 .34224 .32292 .34372 .31251 .34287 .31158 .34184 Metetra
.807 .352 .155 r
.31158 .34184 .31251 .34287 .3021 .33726 .30097 .34228 Metetra
.984 .838 .619 r
.30097 .34228 .3021 .33726 .29106 .34634 .28986 .35294 Metetra
.971 .801 .616 r
.28986 .35294 .29106 .34634 .27968 .35951 .27871 .35894 Metetra
.566 0 0 r
.27871 .35894 .27968 .35951 .26879 .35303 .26768 .35644 Metetra
.92 .783 .693 r
.26768 .35644 .26879 .35303 .25771 .34742 .25675 .34663 Metetra
.743 .292 .18 r
.25675 .34663 .25771 .34742 .24595 .3551 .24511 .35121 Metetra
.964 .639 .269 r
.24511 .35121 .24595 .3551 .23523 .33236 .23432 .33027 Metetra
.914 .527 .26 r
.23432 .33027 .23523 .33236 .22386 .32219 .22273 .32512 Metetra
.919 .799 .712 r
.22273 .32512 .22386 .32219 .21228 .31339 .21112 .31661 Metetra
.904 .769 .703 r
.21112 .31661 .21228 .31339 .20083 .29794 .19959 .30268 Metetra
.951 .801 .658 r
.19959 .30268 .20083 .29794 .18939 .27922 .18737 .29998 Metetra
.935 .728 .598 r
.18737 .29998 .18939 .27922 .17788 .25943 .17663 .26383 Metetra
.939 .791 .67 r
.17663 .26383 .17788 .25943 .16562 .25112 .16429 .25695 Metetra
.948 .783 .645 r
.16429 .25695 .16562 .25112 .15322 .24219 .15167 .25159 Metetra
.945 .828 .386 r
.15167 .25159 .15322 .24219 .14044 .2365 .134 .33282 Metetra
.947 .727 .573 r
.134 .33282 .14044 .2365 .12817 .21855 .12492 .25658 Metetra
.942 .727 .584 r
.12492 .25658 .12817 .21855 .1157 .20136 .11417 .20944 Metetra
.928 .745 .634 r
.11417 .20944 .1157 .20136 .10275 .18907 .10172 .18883 Metetra
.88 .458 .046 r
.36234 .37783 .36325 .37965 .35366 .36787 .35272 .36713 Metetra
0 .217 .714 r
.35272 .36713 .35366 .36787 .34398 .35471 .34298 .35669 Metetra
.9 .811 .751 r
.34298 .35669 .34398 .35471 .33405 .34742 .33304 .34925 Metetra
.906 .834 .764 r
.33304 .34925 .33405 .34742 .32387 .34394 .32292 .34372 Metetra
.279 0 0 r
.32292 .34372 .32387 .34394 .31345 .34388 .31251 .34287 Metetra
.748 .231 0 r
.31251 .34287 .31345 .34388 .30289 .34296 .3021 .33726 Metetra
.923 .651 .507 r
.3021 .33726 .30289 .34296 .2917 .35651 .29106 .34634 Metetra
.933 .681 .534 r
.29106 .34634 .2917 .35651 .28076 .35662 .27968 .35951 Metetra
.926 .807 .709 r
.27968 .35951 .28076 .35662 .26986 .35074 .26879 .35303 Metetra
.919 .827 .74 r
.26879 .35303 .26986 .35074 .25868 .34813 .25771 .34742 Metetra
.723 .297 .236 r
.25771 .34742 .25868 .34813 .24606 .37803 .24595 .3551 Metetra
.966 .728 .525 r
.24595 .3551 .24606 .37803 .23608 .33615 .23523 .33236 Metetra
.958 .638 .371 r
.23523 .33236 .23608 .33615 .22478 .32438 .22386 .32219 Metetra
.922 .53 .213 r
.22386 .32219 .22478 .32438 .21323 .31481 .21228 .31339 Metetra
.649 .2 0 r
.21228 .31339 .21323 .31481 .20168 .3016 .20083 .29794 Metetra
.963 .631 .279 r
.20083 .29794 .20168 .3016 .19041 .2794 .18939 .27922 Metetra
.495 .596 .883 r
.18939 .27922 .19041 .2794 .17884 .26059 .17788 .25943 Metetra
.755 .248 0 r
.17788 .25943 .17884 .26059 .16659 .25224 .16562 .25112 Metetra
.722 .208 0 r
.16562 .25112 .16659 .25224 .15433 .2407 .15322 .24219 Metetra
.885 .864 .814 r
.15322 .24219 .15433 .2407 .14103 .24464 .14044 .2365 Metetra
.971 .702 .462 r
.14044 .2365 .14103 .24464 .12897 .22282 .12817 .21855 Metetra
.968 .652 .349 r
.12817 .21855 .12897 .22282 .11641 .20701 .1157 .20136 Metetra
.964 .674 .433 r
.1157 .20136 .11641 .20701 .10372 .19041 .10275 .18907 Metetra
.881 .773 .738 r
.36325 .37965 .36424 .37755 .35467 .36497 .35366 .36787 Metetra
.897 .762 .705 r
.35366 .36787 .35467 .36497 .34502 .35121 .34398 .35471 Metetra
.929 .789 .684 r
.34398 .35471 .34502 .35121 .3351 .34387 .33405 .34742 Metetra
.944 .808 .679 r
.33405 .34742 .3351 .34387 .32491 .34106 .32387 .34394 Metetra
.953 .844 .698 r
.32387 .34394 .32491 .34106 .31443 .34332 .31345 .34388 Metetra
.719 .957 .947 r
.31345 .34388 .31443 .34332 .30357 .35262 .30289 .34296 Metetra
.931 .678 .534 r
.30289 .34296 .30357 .35262 .29211 .37423 .2917 .35651 Metetra
.953 .711 .535 r
.2917 .35651 .29211 .37423 .28138 .36741 .28076 .35662 Metetra
.957 .703 .509 r
.28076 .35662 .28138 .36741 .27055 .35917 .26986 .35074 Metetra
.952 .69 .501 r
.26986 .35074 .27055 .35917 .25959 .35044 .25868 .34813 Metetra
.799 .515 .508 r
.25868 .34813 .25959 .35044 .24661 .38964 .24606 .37803 Metetra
.989 .734 .442 r
.24606 .37803 .24661 .38964 .23711 .33558 .23608 .33615 Metetra
.739 .783 .888 r
.23608 .33615 .23711 .33558 .2258 .32425 .22478 .32438 Metetra
.572 .771 .973 r
.22478 .32438 .2258 .32425 .21419 .31605 .21323 .31481 Metetra
.634 .157 0 r
.21323 .31481 .21419 .31605 .20306 .29362 .20168 .3016 Metetra
.924 .739 .634 r
.20168 .3016 .20306 .29362 .19165 .27471 .19041 .2794 Metetra
.91 .749 .67 r
.19041 .2794 .19165 .27471 .1799 .25995 .17884 .26059 Metetra
.761 .846 .915 r
.17884 .26059 .1799 .25995 .16756 .25349 .16659 .25224 Metetra
.712 .218 0 r
.16659 .25224 .16756 .25349 .15547 .23884 .15433 .2407 Metetra
.938 .939 .768 r
.15433 .2407 .15547 .23884 .14252 .23651 .14103 .24464 Metetra
.926 .742 .633 r
.14103 .24464 .14252 .23651 .13012 .22108 .12897 .22282 Metetra
.852 .772 .773 r
.12897 .22282 .13012 .22108 .11778 .20164 .11641 .20701 Metetra
.923 .758 .66 r
.11641 .20701 .11778 .20164 .10472 .19119 .10372 .19041 Metetra
.925 .757 .655 r
.36424 .37755 .36529 .37242 .3557 .36146 .35467 .36497 Metetra
.905 .758 .687 r
.35467 .36497 .3557 .36146 .34594 .35251 .34502 .35121 Metetra
.819 .344 0 r
.34502 .35121 .34594 .35251 .33602 .34503 .3351 .34387 Metetra
.828 .359 .086 r
.3351 .34387 .33602 .34503 .32604 .33497 .32491 .34106 Metetra
.964 .796 .625 r
.32491 .34106 .32604 .33497 .31578 .33032 .31443 .34332 Metetra
.968 .771 .584 r
.31443 .34332 .31578 .33032 .30541 .32428 .30357 .35262 Metetra
.968 .757 .565 r
.30357 .35262 .30541 .32428 .29477 .32225 .29211 .37423 Metetra
.955 .738 .57 r
.29211 .37423 .29477 .32225 .28408 .31703 .28138 .36741 Metetra
.955 .738 .571 r
.28138 .36741 .28408 .31703 .27297 .31923 .27055 .35917 Metetra
.954 .739 .574 r
.27055 .35917 .27297 .31923 .26197 .31345 .25959 .35044 Metetra
.971 .758 .558 r
.25959 .35044 .26197 .31345 .25013 .32517 .24661 .38964 Metetra
.946 .728 .576 r
.24661 .38964 .25013 .32517 .23975 .29538 .23711 .33558 Metetra
.954 .739 .574 r
.23711 .33558 .23975 .29538 .22856 .28296 .2258 .32425 Metetra
.955 .74 .573 r
.2258 .32425 .22856 .28296 .21704 .27452 .21419 .31605 Metetra
.95 .735 .577 r
.21419 .31605 .21704 .27452 .2058 .25626 .20306 .29362 Metetra
.951 .737 .578 r
.20306 .29362 .2058 .25626 .19392 .24868 .19165 .27471 Metetra
.951 .74 .583 r
.19165 .27471 .19392 .24868 .18194 .23956 .1799 .25995 Metetra
.954 .748 .586 r
.1799 .25995 .18194 .23956 .16977 .23066 .16756 .25349 Metetra
.95 .742 .587 r
.16756 .25349 .16977 .23066 .1574 .22193 .15547 .23884 Metetra
.957 .755 .589 r
.15547 .23884 .1574 .22193 .14484 .2135 .14252 .23651 Metetra
.95 .741 .587 r
.14252 .23651 .14484 .2135 .13202 .20609 .13012 .22108 Metetra
.943 .742 .602 r
.13012 .22108 .13202 .20609 .11952 .19001 .11778 .20164 Metetra
.948 .755 .608 r
.11778 .20164 .11952 .19001 .10665 .17697 .10472 .19119 Metetra
.929 .762 .655 r
.36529 .37242 .36635 .3674 .35673 .35775 .3557 .36146 Metetra
.925 .778 .679 r
.3557 .36146 .35673 .35775 .34699 .3486 .34594 .35251 Metetra
.932 .784 .674 r
.34594 .35251 .34699 .3486 .33708 .34128 .33602 .34503 Metetra
.922 .774 .68 r
.33602 .34503 .33708 .34128 .32703 .33386 .32604 .33497 Metetra
.864 .874 .844 r
.32604 .33497 .32703 .33386 .31685 .32666 .31578 .33032 Metetra
.936 .795 .68 r
.31578 .33032 .31685 .32666 .30654 .31923 .30541 .32428 Metetra
.954 .795 .646 r
.30541 .32428 .30654 .31923 .29604 .31329 .29477 .32225 Metetra
.952 .764 .613 r
.29477 .32225 .29604 .31329 .28546 .30511 .28408 .31703 Metetra
.962 .766 .594 r
.28408 .31703 .28546 .30511 .2746 .30104 .27297 .31923 Metetra
.954 .749 .587 r
.27297 .31923 .2746 .30104 .26364 .29511 .26197 .31345 Metetra
.967 .763 .576 r
.26197 .31345 .26364 .29511 .25229 .29528 .25013 .32517 Metetra
.944 .732 .585 r
.25013 .32517 .25229 .29528 .24139 .27967 .23975 .29538 Metetra
.948 .746 .596 r
.23975 .29538 .24139 .27967 .23 .27268 .22856 .28296 Metetra
.949 .757 .611 r
.22856 .28296 .23 .27268 .21863 .26129 .21704 .27452 Metetra
.941 .742 .606 r
.21704 .27452 .21863 .26129 .20703 .25147 .2058 .25626 Metetra
.939 .783 .661 r
.2058 .25626 .20703 .25147 .19519 .2434 .19392 .24868 Metetra
.938 .776 .654 r
.19392 .24868 .19519 .2434 .18309 .23696 .18194 .23956 Metetra
.912 .805 .728 r
.18194 .23956 .18309 .23696 .17089 .22874 .16977 .23066 Metetra
.893 .821 .769 r
.16977 .23066 .17089 .22874 .15868 .2173 .1574 .22193 Metetra
.937 .784 .667 r
.1574 .22193 .15868 .2173 .14553 .21972 .14484 .2135 Metetra
.957 .675 .46 r
.14484 .2135 .14553 .21972 .13305 .20638 .13202 .20609 Metetra
.356 .582 .928 r
.13202 .20609 .13305 .20638 .12043 .19229 .11952 .19001 Metetra
.917 .519 .155 r
.11952 .19001 .12043 .19229 .10766 .17764 .10665 .17697 Metetra
.512 .013 0 r
.36635 .3674 .36727 .36834 .35763 .35989 .35673 .35775 Metetra
.923 .533 .187 r
.35673 .35775 .35763 .35989 .34787 .35177 .34699 .3486 Metetra
.951 .62 .355 r
.34699 .3486 .34787 .35177 .33795 .34439 .33708 .34128 Metetra
.951 .616 .35 r
.33708 .34128 .33795 .34439 .32791 .33699 .32703 .33386 Metetra
.95 .616 .354 r
.32703 .33386 .32791 .33699 .31751 .33709 .31685 .32666 Metetra
.96 .705 .505 r
.31685 .32666 .31751 .33709 .30703 .33504 .30654 .31923 Metetra
.958 .714 .526 r
.30654 .31923 .30703 .33504 .29588 .34855 .29604 .31329 Metetra
.958 .725 .544 r
.29604 .31329 .29588 .34855 .28498 .34841 .28546 .30511 Metetra
.957 .725 .548 r
.28546 .30511 .28498 .34841 .27376 .35265 .2746 .30104 Metetra
.957 .727 .549 r
.2746 .30104 .27376 .35265 .26294 .3407 .26364 .29511 Metetra
.955 .725 .55 r
.26364 .29511 .26294 .3407 .25115 .35031 .25229 .29528 Metetra
.959 .73 .547 r
.25229 .29528 .25115 .35031 .24039 .32918 .24139 .27967 Metetra
.957 .727 .548 r
.24139 .27967 .24039 .32918 .2292 .31534 .23 .27268 Metetra
.959 .727 .545 r
.23 .27268 .2292 .31534 .21735 .31326 .21863 .26129 Metetra
.958 .728 .548 r
.21863 .26129 .21735 .31326 .20591 .29819 .20703 .25147 Metetra
.957 .727 .547 r
.20703 .25147 .20591 .29819 .19484 .27207 .19519 .2434 Metetra
.957 .722 .54 r
.19519 .2434 .19484 .27207 .18305 .25848 .18309 .23696 Metetra
.958 .719 .532 r
.18309 .23696 .18305 .25848 .17084 .24988 .17089 .22874 Metetra
.96 .72 .53 r
.17089 .22874 .17084 .24988 .15845 .24106 .15868 .2173 Metetra
.953 .715 .54 r
.15868 .2173 .15845 .24106 .14511 .24617 .14553 .21972 Metetra
.96 .723 .535 r
.14553 .21972 .14511 .24617 .13336 .21912 .13305 .20638 Metetra
.964 .712 .505 r
.13305 .20638 .13336 .21912 .12077 .20413 .12043 .19229 Metetra
.965 .71 .5 r
.12043 .19229 .12077 .20413 .10827 .18489 .10766 .17764 Metetra
.963 .698 .485 r
.36727 .36834 .36804 .37641 .35839 .36819 .35763 .35989 Metetra
.962 .699 .488 r
.35763 .35989 .35839 .36819 .34875 .3546 .34787 .35177 Metetra
.947 .601 .325 r
.34787 .35177 .34875 .3546 .33884 .34715 .33795 .34439 Metetra
.945 .596 .316 r
.33795 .34439 .33884 .34715 .32865 .34509 .32791 .33699 Metetra
.948 .686 .505 r
.32791 .33699 .32865 .34509 .31834 .34217 .31751 .33709 Metetra
.947 .66 .464 r
.31751 .33709 .31834 .34217 .30793 .33729 .30703 .33504 Metetra
.85 .538 .46 r
.30703 .33504 .30793 .33729 .2967 .35359 .29588 .34855 Metetra
.941 .655 .469 r
.29588 .34855 .2967 .35359 .28554 .36113 .28498 .34841 Metetra
.947 .699 .529 r
.28498 .34841 .28554 .36113 .27456 .35818 .27376 .35265 Metetra
.967 .678 .429 r
.27376 .35265 .27456 .35818 .26349 .3528 .26294 .3407 Metetra
.941 .692 .532 r
.26294 .3407 .26349 .3528 .25196 .35542 .25115 .35031 Metetra
.977 .678 .358 r
.25115 .35031 .25196 .35542 .24117 .33492 .24039 .32918 Metetra
.97 .681 .426 r
.24039 .32918 .24117 .33492 .22991 .3226 .2292 .31534 Metetra
.95 .68 .49 r
.2292 .31534 .22991 .3226 .21839 .31283 .21735 .31326 Metetra
.697 .734 .879 r
.21735 .31326 .21839 .31283 .20707 .2951 .20591 .29819 Metetra
.862 .719 .703 r
.20591 .29819 .20707 .2951 .19538 .28224 .19484 .27207 Metetra
.966 .707 .491 r
.19484 .27207 .19538 .28224 .18353 .26949 .18305 .25848 Metetra
.96 .704 .504 r
.18305 .25848 .18353 .26949 .17128 .26136 .17084 .24988 Metetra
.96 .705 .506 r
.17084 .24988 .17128 .26136 .15899 .25044 .15845 .24106 Metetra
.942 .683 .514 r
.15845 .24106 .15899 .25044 .14542 .25947 .14511 .24617 Metetra
.975 .723 .49 r
.14511 .24617 .14542 .25947 .13418 .2231 .13336 .21912 Metetra
.964 .641 .345 r
.13336 .21912 .13418 .2231 .12146 .21036 .12077 .20413 Metetra
.974 .688 .419 r
.12077 .20413 .12146 .21036 .10895 .19095 .10827 .18489 Metetra
.95 .605 .318 r
.36804 .37641 .36893 .3793 .3593 .37011 .35839 .36819 Metetra
.851 .438 0 r
.35839 .36819 .3593 .37011 .34954 .36117 .34875 .3546 Metetra
.961 .687 .47 r
.34875 .3546 .34954 .36117 .33963 .35377 .33884 .34715 Metetra
.95 .679 .487 r
.33884 .34715 .33963 .35377 .32952 .3484 .32865 .34509 Metetra
.939 .619 .403 r
.32865 .34509 .32952 .3484 .31929 .34265 .31834 .34217 Metetra
.34 0 0 r
.31834 .34217 .31929 .34265 .30885 .33887 .30793 .33729 Metetra
.801 .48 .446 r
.30793 .33729 .30885 .33887 .29694 .37668 .2967 .35359 Metetra
.95 .713 .544 r
.2967 .35359 .29694 .37668 .28634 .36681 .28554 .36113 Metetra
.95 .668 .469 r
.28554 .36113 .28634 .36681 .27542 .36173 .27456 .35818 Metetra
.947 .626 .392 r
.27456 .35818 .27542 .36173 .26454 .35153 .26349 .3528 Metetra
.891 .974 .826 r
.26349 .3528 .26454 .35153 .25256 .36591 .25196 .35542 Metetra
.974 .716 .479 r
.25196 .35542 .25256 .36591 .24197 .34007 .24117 .33492 Metetra
.967 .671 .415 r
.24117 .33492 .24197 .34007 .23079 .32565 .22991 .3226 Metetra
.949 .603 .315 r
.22991 .3226 .23079 .32565 .21947 .31131 .21839 .31283 Metetra
.828 .746 .774 r
.21839 .31283 .21947 .31131 .2079 .29922 .20707 .2951 Metetra
.964 .648 .367 r
.20707 .2951 .2079 .29922 .19658 .27854 .19538 .28224 Metetra
.916 .774 .689 r
.19538 .28224 .19658 .27854 .18467 .26722 .18353 .26949 Metetra
.908 .817 .747 r
.18353 .26949 .18467 .26722 .17292 .2494 .17128 .26136 Metetra
.948 .753 .606 r
.17128 .26136 .17292 .2494 .16027 .24582 .15899 .25044 Metetra
.979 .846 .641 r
.15899 .25044 .16027 .24582 .14622 .26396 .14542 .25947 Metetra
.936 .633 .173 r
.14542 .25947 .14622 .26396 .13528 .22223 .13418 .2231 Metetra
.787 .796 .86 r
.13418 .2231 .13528 .22223 .1228 .20533 .12146 .21036 Metetra
.914 .752 .666 r
.12146 .21036 .1228 .20533 .10981 .19423 .10895 .19095 Metetra
.181 .545 .928 r
.36893 .3793 .36987 .37966 .36023 .37085 .3593 .37011 Metetra
0 .15 .633 r
.3593 .37011 .36023 .37085 .3505 .36112 .34954 .36117 Metetra
.515 .767 .988 r
.34954 .36117 .3505 .36112 .34059 .35361 .33963 .35377 Metetra
.554 .83 .997 r
.33963 .35377 .34059 .35361 .33047 .34913 .32952 .3484 Metetra
.561 0 0 r
.32952 .3484 .33047 .34913 .32022 .34393 .31929 .34265 Metetra
.845 .387 .098 r
.31929 .34265 .32022 .34393 .30931 .35619 .30885 .33887 Metetra
.924 .686 .56 r
.30885 .33887 .30931 .35619 .29793 .37668 .29694 .37668 Metetra
.511 .727 .97 r
.29694 .37668 .29793 .37668 .28715 .37218 .28634 .36681 Metetra
.954 .667 .455 r
.28634 .36681 .28715 .37218 .27617 .36887 .27542 .36173 Metetra
.964 .691 .467 r
.27542 .36173 .27617 .36887 .26428 .38581 .26454 .35153 Metetra
.95 .717 .551 r
.26454 .35153 .26428 .38581 .24983 .46382 .25256 .36591 Metetra
.96 .733 .551 r
.25256 .36591 .24983 .46382 .2418 .36942 .24197 .34007 Metetra
.961 .726 .536 r
.24197 .34007 .2418 .36942 .23129 .33802 .23079 .32565 Metetra
.966 .713 .502 r
.23079 .32565 .23129 .33802 .21997 .32315 .21947 .31131 Metetra
.964 .71 .503 r
.21947 .31131 .21997 .32315 .209 .29754 .2079 .29922 Metetra
.825 .73 .759 r
.2079 .29922 .209 .29754 .19744 .28205 .19658 .27854 Metetra
.957 .624 .339 r
.19658 .27854 .19744 .28205 .18544 .27256 .18467 .26722 Metetra
.974 .677 .394 r
.18467 .26722 .18544 .27256 .17323 .26372 .17292 .2494 Metetra
.955 .707 .522 r
.17292 .2494 .17323 .26372 .16084 .25478 .16027 .24582 Metetra
.924 .666 .528 r
.16027 .24582 .16084 .25478 .14685 .27159 .14622 .26396 Metetra
.987 .714 .36 r
.14622 .26396 .14685 .27159 .1365 .21917 .13528 .22223 Metetra
.894 .764 .711 r
.13528 .22223 .1365 .21917 .12384 .2056 .1228 .20533 Metetra
.229 .596 .949 r
.1228 .20533 .12384 .2056 .11103 .19146 .10981 .19423 Metetra
0 .346 .799 r
.36987 .37966 .3708 .38022 .36119 .37051 .36023 .37085 Metetra
.69 .778 .918 r
.36023 .37085 .36119 .37051 .35152 .35843 .3505 .36112 Metetra
.918 .799 .713 r
.3505 .36112 .35152 .35843 .34162 .35081 .34059 .35361 Metetra
.934 .818 .707 r
.34059 .35361 .34162 .35081 .33148 .34744 .33047 .34913 Metetra
.902 .844 .777 r
.33047 .34913 .33148 .34744 .3212 .3436 .32022 .34393 Metetra
.28 0 .018 r
.32022 .34393 .3212 .3436 .31076 .34043 .30931 .35619 Metetra
.976 .776 .569 r
.30931 .35619 .31076 .34043 .29964 .35362 .29793 .37668 Metetra
.956 .747 .58 r
.29793 .37668 .29964 .35362 .28888 .34976 .28715 .37218 Metetra
.957 .748 .58 r
.28715 .37218 .28888 .34976 .27786 .34888 .27617 .36887 Metetra
.97 .764 .57 r
.27617 .36887 .27786 .34888 .26646 .3536 .26428 .38581 Metetra
.987 .777 .535 r
.26428 .38581 .26646 .3536 .25523 .34882 .24983 .46382 Metetra
.946 .726 .572 r
.24983 .46382 .25523 .34882 .24421 .33433 .2418 .36942 Metetra
.946 .732 .581 r
.2418 .36942 .24421 .33433 .23347 .31001 .23129 .33802 Metetra
.951 .74 .581 r
.23129 .33802 .23347 .31001 .22192 .3017 .21997 .32315 Metetra
.943 .735 .592 r
.21997 .32315 .22192 .3017 .21063 .2841 .209 .29754 Metetra
.945 .746 .603 r
.209 .29754 .21063 .2841 .19936 .26307 .19744 .28205 Metetra
.953 .747 .588 r
.19744 .28205 .19936 .26307 .18757 .25004 .18544 .27256 Metetra
.954 .745 .584 r
.18544 .27256 .18757 .25004 .17541 .24107 .17323 .26372 Metetra
.954 .745 .584 r
.17323 .26372 .17541 .24107 .16288 .23576 .16084 .25478 Metetra
.97 .766 .574 r
.16084 .25478 .16288 .23576 .1493 .24582 .14685 .27159 Metetra
.933 .722 .594 r
.14685 .27159 .1493 .24582 .1378 .21463 .1365 .21917 Metetra
.924 .77 .672 r
.1365 .21917 .1378 .21463 .12492 .2051 .12384 .2056 Metetra
.707 .767 .898 r
.12384 .2056 .12492 .2051 .11222 .18929 .11103 .19146 Metetra
.938 .763 .639 r
.3708 .38022 .37188 .37412 .36237 .36045 .36119 .37051 Metetra
.943 .749 .612 r
.36119 .37051 .36237 .36045 .35262 .35226 .35152 .35843 Metetra
.943 .769 .636 r
.35152 .35843 .35262 .35226 .34278 .34291 .34162 .35081 Metetra
.954 .771 .616 r
.34162 .35081 .34278 .34291 .33273 .3368 .33148 .34744 Metetra
.955 .761 .603 r
.33148 .34744 .33273 .3368 .32254 .33038 .3212 .3436 Metetra
.956 .757 .594 r
.3212 .3436 .32254 .33038 .31219 .32512 .31076 .34043 Metetra
.971 .77 .576 r
.31076 .34043 .31219 .32512 .30168 .32007 .29964 .35362 Metetra
.957 .743 .573 r
.29964 .35362 .30168 .32007 .29097 .31634 .28888 .34976 Metetra
.958 .744 .572 r
.28888 .34976 .29097 .31634 .27972 .32374 .27786 .34888 Metetra
.961 .751 .574 r
.27786 .34888 .27972 .32374 .26841 .32733 .26646 .3536 Metetra
.956 .745 .578 r
.26646 .3536 .26841 .32733 .25697 .32934 .25523 .34882 Metetra
.949 .742 .59 r
.25523 .34882 .25697 .32934 .24648 .30265 .24421 .33433 Metetra
.948 .735 .581 r
.24421 .33433 .24648 .30265 .23547 .28597 .23347 .31001 Metetra
.954 .745 .582 r
.23347 .31001 .23547 .28597 .2242 .27234 .22192 .3017 Metetra
.951 .738 .581 r
.22192 .3017 .2242 .27234 .21264 .26188 .21063 .2841 Metetra
.947 .738 .589 r
.21063 .2841 .21264 .26188 .20102 .2494 .19936 .26307 Metetra
.947 .748 .601 r
.19936 .26307 .20102 .2494 .189 .24168 .18757 .25004 Metetra
.947 .763 .622 r
.18757 .25004 .189 .24168 .17685 .23301 .17541 .24107 Metetra
.952 .771 .622 r
.17541 .24107 .17685 .23301 .16453 .224 .16288 .23576 Metetra
.97 .779 .59 r
.16288 .23576 .16453 .224 .15153 .22411 .1493 .24582 Metetra
.941 .733 .593 r
.1493 .24582 .15153 .22411 .13923 .20776 .1378 .21463 Metetra
.944 .77 .636 r
.1378 .21463 .13923 .20776 .12661 .19408 .12492 .2051 Metetra
.943 .75 .613 r
.12492 .2051 .12661 .19408 .11381 .18038 .11222 .18929 Metetra
.933 .75 .632 r
.37188 .37412 .37297 .36692 .36345 .35461 .36237 .36045 Metetra
.941 .768 .64 r
.36237 .36045 .36345 .35461 .35373 .34575 .35262 .35226 Metetra
.94 .763 .634 r
.35262 .35226 .35373 .34575 .34382 .33975 .34278 .34291 Metetra
.931 .801 .694 r
.34278 .34291 .34382 .33975 .33381 .33241 .33273 .3368 Metetra
.94 .785 .662 r
.33273 .3368 .33381 .33241 .32371 .3234 .32254 .33038 Metetra
.95 .772 .626 r
.32254 .33038 .32371 .3234 .31345 .31548 .31219 .32512 Metetra
.953 .763 .609 r
.31219 .32512 .31345 .31548 .30299 .30941 .30168 .32007 Metetra
.955 .762 .603 r
.30168 .32007 .30299 .30941 .29218 .30944 .29097 .31634 Metetra
.974 .803 .609 r
.29097 .31634 .29218 .30944 .28131 .30645 .27972 .32374 Metetra
.962 .758 .582 r
.27972 .32374 .28131 .30645 .27027 .30348 .26841 .32733 Metetra
.96 .75 .576 r
.26841 .32733 .27027 .30348 .2587 .31009 .25697 .32934 Metetra
.941 .734 .595 r
.25697 .32934 .2587 .31009 .24805 .28819 .24648 .30265 Metetra
.944 .743 .601 r
.24648 .30265 .24805 .28819 .23712 .27051 .23547 .28597 Metetra
.948 .746 .597 r
.23547 .28597 .23712 .27051 .22577 .25952 .2242 .27234 Metetra
.949 .751 .602 r
.2242 .27234 .22577 .25952 .21415 .25089 .21264 .26188 Metetra
.945 .752 .61 r
.21264 .26188 .21415 .25089 .20238 .24197 .20102 .2494 Metetra
.947 .769 .628 r
.20102 .2494 .20238 .24197 .19043 .23334 .189 .24168 Metetra
.947 .764 .622 r
.189 .24168 .19043 .23334 .17801 .23028 .17685 .23301 Metetra
.915 .805 .723 r
.17685 .23301 .17801 .23028 .16544 .22635 .16453 .224 Metetra
.904 .545 .347 r
.16453 .224 .16544 .22635 .15283 .21933 .15153 .22411 Metetra
.919 .76 .668 r
.15153 .22411 .15283 .21933 .14039 .20582 .13923 .20776 Metetra
.872 .787 .764 r
.13923 .20776 .14039 .20582 .12753 .19631 .12661 .19408 Metetra
.909 .507 .126 r
.12661 .19408 .12753 .19631 .11513 .17603 .11381 .18038 Metetra
.905 .508 .096 r
.37297 .36692 .37387 .36907 .36428 .35996 .36345 .35461 Metetra
.964 .676 .438 r
.36345 .35461 .36428 .35996 .35457 .35045 .35373 .34575 Metetra
.956 .662 .435 r
.35373 .34575 .35457 .35045 .34469 .34326 .34382 .33975 Metetra
.954 .632 .375 r
.34382 .33975 .34469 .34326 .33467 .33609 .33381 .33241 Metetra
.959 .639 .371 r
.33381 .33241 .33467 .33609 .32441 .33269 .32371 .3234 Metetra
.961 .701 .495 r
.32371 .3234 .32441 .33269 .3137 .33977 .31345 .31548 Metetra
.958 .721 .536 r
.31345 .31548 .3137 .33977 .30253 .35541 .30299 .30941 Metetra
.956 .725 .549 r
.30299 .30941 .30253 .35541 .2918 .35109 .29218 .30944 Metetra
.957 .725 .547 r
.29218 .30944 .2918 .35109 .28117 .33938 .28131 .30645 Metetra
.957 .723 .543 r
.28131 .30645 .28117 .33938 .26998 .33921 .27027 .30348 Metetra
.953 .72 .548 r
.27027 .30348 .26998 .33921 .25839 .3449 .2587 .31009 Metetra
.964 .73 .536 r
.2587 .31009 .25839 .3449 .24761 .32492 .24805 .28819 Metetra
.962 .729 .539 r
.24805 .28819 .24761 .32492 .23653 .30935 .23712 .27051 Metetra
.959 .727 .543 r
.23712 .27051 .23653 .30935 .22523 .2956 .22577 .25952 Metetra
.959 .725 .542 r
.22577 .25952 .22523 .2956 .21355 .28715 .21415 .25089 Metetra
.959 .725 .542 r
.21415 .25089 .21355 .28715 .20218 .26824 .20238 .24197 Metetra
.959 .722 .536 r
.20238 .24197 .20218 .26824 .19017 .25979 .19043 .23334 Metetra
.956 .719 .539 r
.19043 .23334 .19017 .25979 .17809 .24929 .17801 .23028 Metetra
.956 .714 .53 r
.17801 .23028 .17809 .24929 .16512 .25242 .16544 .22635 Metetra
.958 .721 .536 r
.16544 .22635 .16512 .25242 .1522 .25035 .15283 .21933 Metetra
.961 .725 .537 r
.15283 .21933 .1522 .25035 .14006 .23028 .14039 .20582 Metetra
.959 .721 .533 r
.14039 .20582 .14006 .23028 .12797 .20691 .12753 .19631 Metetra
.972 .712 .481 r
.12753 .19631 .12797 .20691 .11557 .18622 .11513 .17603 Metetra
.965 .679 .441 r
.37387 .36907 .37471 .37459 .36512 .36475 .36428 .35996 Metetra
.965 .668 .418 r
.36428 .35996 .36512 .36475 .35543 .35465 .35457 .35045 Metetra
.958 .653 .411 r
.35457 .35045 .35543 .35465 .34557 .34624 .34469 .34326 Metetra
.948 .609 .339 r
.34469 .34326 .34557 .34624 .33546 .34259 .33467 .33609 Metetra
.953 .679 .48 r
.33467 .33609 .33546 .34259 .32518 .34011 .32441 .33269 Metetra
.935 .672 .513 r
.32441 .33269 .32518 .34011 .31477 .33661 .3137 .33977 Metetra
.978 .915 .605 r
.3137 .33977 .31477 .33661 .30375 .3478 .30253 .35541 Metetra
.953 .772 .621 r
.30253 .35541 .30375 .3478 .29292 .34697 .2918 .35109 Metetra
.922 .77 .675 r
.2918 .35109 .29292 .34697 .28199 .34427 .28117 .33938 Metetra
.941 .651 .463 r
.28117 .33938 .28199 .34427 .27073 .34595 .26998 .33921 Metetra
.936 .666 .502 r
.26998 .33921 .27073 .34595 .25911 .35258 .25839 .3449 Metetra
.977 .705 .442 r
.25839 .3449 .25911 .35258 .24835 .33174 .24761 .32492 Metetra
.972 .694 .442 r
.24761 .32492 .24835 .33174 .23745 .31164 .23653 .30935 Metetra
.911 .516 .119 r
.23653 .30935 .23745 .31164 .22603 .30074 .22523 .2956 Metetra
.959 .665 .432 r
.22523 .2956 .22603 .30074 .21472 .28389 .21355 .28715 Metetra
.889 .749 .701 r
.21355 .28715 .21472 .28389 .2033 .26616 .20218 .26824 Metetra
.901 .819 .757 r
.20218 .26824 .2033 .26616 .19146 .25446 .19017 .25979 Metetra
.936 .773 .655 r
.19017 .25979 .19146 .25446 .17931 .24563 .17809 .24929 Metetra
.966 .848 .675 r
.17809 .24929 .17931 .24563 .16629 .24993 .16512 .25242 Metetra
.938 .858 .735 r
.16512 .25242 .16629 .24993 .15379 .24014 .1522 .25035 Metetra
.936 .744 .619 r
.1522 .25035 .15379 .24014 .14145 .22427 .14006 .23028 Metetra
.914 .741 .654 r
.14006 .23028 .14145 .22427 .1293 .20214 .12797 .20691 Metetra
.909 .749 .671 r
.12797 .20691 .1293 .20214 .11667 .18546 .11557 .18622 Metetra
.504 .706 .961 r
.37471 .37459 .37565 .37463 .36611 .36301 .36512 .36475 Metetra
.876 .791 .762 r
.36512 .36475 .36611 .36301 .35643 .35252 .35543 .35465 Metetra
.9 .802 .741 r
.35543 .35465 .35643 .35252 .34656 .34521 .34557 .34624 Metetra
.861 .894 .858 r
.34557 .34624 .34656 .34521 .33651 .33956 .33546 .34259 Metetra
.945 .826 .696 r
.33546 .34259 .33651 .33956 .32621 .33792 .32518 .34011 Metetra
.928 .845 .741 r
.32518 .34011 .32621 .33792 .31567 .3391 .31477 .33661 Metetra
.869 .556 .455 r
.31477 .33661 .31567 .3391 .30503 .33825 .30375 .3478 Metetra
.959 .77 .605 r
.30375 .3478 .30503 .33825 .29382 .34981 .29292 .34697 Metetra
.931 .593 .371 r
.29292 .34697 .29382 .34981 .2829 .34685 .28199 .34427 Metetra
.909 .571 .391 r
.28199 .34427 .2829 .34685 .27174 .3458 .27073 .34595 Metetra
.209 0 0 r
.27073 .34595 .27174 .3458 .25966 .36462 .25911 .35258 Metetra
.973 .719 .488 r
.25911 .35258 .25966 .36462 .24939 .33099 .24835 .33174 Metetra
.74 .7 .813 r
.24835 .33174 .24939 .33099 .23827 .31618 .23745 .31164 Metetra
.963 .657 .398 r
.23745 .31164 .23827 .31618 .22696 .30279 .22603 .30074 Metetra
.843 .433 0 r
.22603 .30074 .22696 .30279 .21544 .2906 .21472 .28389 Metetra
.975 .694 .432 r
.21472 .28389 .21544 .2906 .20414 .2702 .2033 .26616 Metetra
.962 .643 .369 r
.2033 .26616 .20414 .2702 .1925 .25423 .19146 .25446 Metetra
.603 .805 .977 r
.19146 .25446 .1925 .25423 .18029 .2466 .17931 .24563 Metetra
.771 .326 .193 r
.17931 .24563 .18029 .2466 .16718 .25287 .16629 .24993 Metetra
.944 .59 .3 r
.16629 .24993 .16718 .25287 .15447 .24703 .15379 .24014 Metetra
.971 .691 .443 r
.15379 .24014 .15447 .24703 .14326 .21059 .14145 .22427 Metetra
.94 .741 .606 r
.14145 .22427 .14326 .21059 .13057 .19837 .1293 .20214 Metetra
.908 .764 .691 r
.1293 .20214 .13057 .19837 .11791 .18246 .11667 .18546 Metetra
.744 .287 0 r
.37565 .37463 .37657 .37607 .36702 .36506 .36611 .36301 Metetra
.909 .506 .123 r
.36611 .36301 .36702 .36506 .35734 .35454 .35643 .35252 Metetra
.918 .521 .2 r
.35643 .35252 .35734 .35454 .34752 .34511 .34656 .34521 Metetra
.505 .805 .999 r
.34656 .34521 .34752 .34511 .33738 .34319 .33651 .33956 Metetra
.939 .628 .424 r
.33651 .33956 .33738 .34319 .32711 .3403 .32621 .33792 Metetra
.908 .563 .379 r
.32621 .33792 .32711 .3403 .31663 .3397 .31567 .3391 Metetra
.639 .084 0 r
.31567 .3391 .31663 .3397 .30573 .34755 .30503 .33825 Metetra
.934 .678 .527 r
.30503 .33825 .30573 .34755 .29457 .35716 .29382 .34981 Metetra
.953 .684 .488 r
.29382 .34981 .29457 .35716 .28359 .35567 .2829 .34685 Metetra
.951 .69 .504 r
.2829 .34685 .28359 .35567 .27186 .37066 .27174 .3458 Metetra
.945 .708 .549 r
.27174 .3458 .27186 .37066 .25557 .50184 .25966 .36462 Metetra
.96 .734 .551 r
.25966 .36462 .25557 .50184 .24959 .35186 .24939 .33099 Metetra
.964 .723 .525 r
.24939 .33099 .24959 .35186 .23907 .32142 .23827 .31618 Metetra
.969 .673 .41 r
.23827 .31618 .23907 .32142 .22776 .3078 .22696 .30279 Metetra
.966 .667 .408 r
.22696 .30279 .22776 .3078 .21616 .29734 .21544 .2906 Metetra
.978 .697 .422 r
.21544 .2906 .21616 .29734 .20463 .28195 .20414 .2702 Metetra
.968 .713 .495 r
.20414 .2702 .20463 .28195 .1927 .27162 .1925 .25423 Metetra
.959 .715 .524 r
.1925 .25423 .1927 .27162 .18053 .26264 .18029 .2466 Metetra
.949 .703 .532 r
.18029 .2466 .18053 .26264 .16789 .25927 .16718 .25287 Metetra
.955 .675 .465 r
.16718 .25287 .16789 .25927 .15329 .28853 .15447 .24703 Metetra
.967 .734 .535 r
.15447 .24703 .15329 .28853 .14354 .22431 .14326 .21059 Metetra
.963 .712 .509 r
.14326 .21059 .14354 .22431 .13155 .19963 .13057 .19837 Metetra
.576 .114 0 r
.13057 .19837 .13155 .19963 .11892 .18319 .11791 .18246 Metetra
.51 .685 .946 r
.37657 .37607 .37752 .37613 .36809 .35948 .36702 .36506 Metetra
.934 .763 .646 r
.36702 .36506 .36809 .35948 .35843 .34882 .35734 .35454 Metetra
.938 .766 .643 r
.35734 .35454 .35843 .34882 .34857 .34137 .34752 .34511 Metetra
.952 .814 .671 r
.34752 .34511 .34857 .34137 .3385 .33724 .33738 .34319 Metetra
.954 .784 .633 r
.33738 .34319 .3385 .33724 .3281 .33975 .32711 .3403 Metetra
.698 .959 .946 r
.32711 .3403 .3281 .33975 .31769 .33684 .31663 .3397 Metetra
.977 .899 .672 r
.31663 .3397 .31769 .33684 .30668 .34848 .30573 .34755 Metetra
.762 .376 .324 r
.30573 .34755 .30668 .34848 .2958 .34972 .29457 .35716 Metetra
.958 .779 .619 r
.29457 .35716 .2958 .34972 .28506 .3418 .28359 .35567 Metetra
.974 .777 .576 r
.28359 .35567 .28506 .3418 .2741 .3356 .27186 .37066 Metetra
.997 .79 .501 r
.27186 .37066 .2741 .3356 .26234 .34693 .25557 .50184 Metetra
.945 .723 .572 r
.25557 .50184 .26234 .34693 .25161 .32569 .24959 .35186 Metetra
.944 .732 .587 r
.24959 .35186 .25161 .32569 .24056 .3099 .23907 .32142 Metetra
.945 .75 .608 r
.23907 .32142 .24056 .3099 .22941 .29302 .22776 .3078 Metetra
.951 .75 .596 r
.22776 .3078 .22941 .29302 .21775 .28455 .21616 .29734 Metetra
.945 .747 .605 r
.21616 .29734 .21775 .28455 .20642 .26527 .20463 .28195 Metetra
.952 .749 .592 r
.20463 .28195 .20642 .26527 .19434 .25871 .1927 .27162 Metetra
.952 .754 .6 r
.1927 .27162 .19434 .25871 .18216 .25073 .18053 .26264 Metetra
.957 .763 .6 r
.18053 .26264 .18216 .25073 .16942 .24972 .16789 .25927 Metetra
.992 .819 .567 r
.16789 .25927 .16942 .24972 .1567 .24447 .15329 .28853 Metetra
.94 .724 .582 r
.15329 .28853 .1567 .24447 .14476 .22124 .14354 .22431 Metetra
.869 .731 .707 r
.14354 .22431 .14476 .22124 .13263 .19913 .13155 .19963 Metetra
.703 .739 .879 r
.13155 .19963 .13263 .19913 .11985 .18536 .11892 .18319 Metetra
.884 .745 .703 r
.37752 .37613 .37853 .37322 .36901 .36118 .36809 .35948 Metetra
.851 .415 0 r
.36809 .35948 .36901 .36118 .35933 .3515 .35843 .34882 Metetra
.944 .589 .302 r
.35843 .34882 .35933 .3515 .3495 .34291 .34857 .34137 Metetra
.881 .453 .167 r
.34857 .34137 .3495 .34291 .33951 .33539 .3385 .33724 Metetra
.946 .921 .754 r
.3385 .33724 .33951 .33539 .32937 .32861 .3281 .33975 Metetra
.957 .762 .599 r
.3281 .33975 .32937 .32861 .31911 .32127 .31769 .33684 Metetra
.97 .768 .576 r
.31769 .33684 .31911 .32127 .3085 .32094 .30668 .34848 Metetra
.96 .748 .573 r
.30668 .34848 .3085 .32094 .29767 .32238 .2958 .34972 Metetra
.955 .743 .577 r
.2958 .34972 .29767 .32238 .28661 .3251 .28506 .3418 Metetra
.955 .751 .588 r
.28506 .3418 .28661 .3251 .27559 .32165 .2741 .3356 Metetra
.971 .773 .58 r
.2741 .3356 .27559 .32165 .26397 .33005 .26234 .34693 Metetra
.943 .738 .597 r
.26234 .34693 .26397 .33005 .25353 .30224 .25161 .32569 Metetra
.95 .741 .584 r
.25161 .32569 .25353 .30224 .2426 .28432 .24056 .3099 Metetra
.951 .74 .583 r
.24056 .3099 .2426 .28432 .23121 .27438 .22941 .29302 Metetra
.954 .748 .587 r
.22941 .29302 .23121 .27438 .21976 .26192 .21775 .28455 Metetra
.948 .739 .587 r
.21775 .28455 .21976 .26192 .20814 .24994 .20642 .26527 Metetra
.955 .753 .592 r
.20642 .26527 .20814 .24994 .19601 .2453 .19434 .25871 Metetra
.953 .755 .598 r
.19434 .25871 .19601 .2453 .18388 .23681 .18216 .25073 Metetra
.959 .761 .592 r
.18216 .25073 .18388 .23681 .17157 .22817 .16942 .24972 Metetra
.957 .749 .582 r
.16942 .24972 .17157 .22817 .15909 .21927 .1567 .24447 Metetra
.948 .737 .585 r
.1567 .24447 .15909 .21927 .14662 .20659 .14476 .22124 Metetra
.942 .741 .603 r
.14476 .22124 .14662 .20659 .13395 .19447 .13263 .19913 Metetra
.925 .77 .67 r
.13263 .19913 .13395 .19447 .12149 .17539 .11985 .18536 Metetra
.938 .754 .627 r
.37853 .37322 .37962 .36573 .37013 .35332 .36901 .36118 Metetra
.943 .758 .622 r
.36901 .36118 .37013 .35332 .36046 .34374 .35933 .3515 Metetra
.945 .761 .622 r
.35933 .3515 .36046 .34374 .35061 .33635 .3495 .34291 Metetra
.945 .768 .631 r
.3495 .34291 .35061 .33635 .34064 .32888 .33951 .33539 Metetra
.947 .771 .631 r
.33951 .33539 .34064 .32888 .33054 .32135 .32937 .32861 Metetra
.947 .766 .625 r
.32937 .32861 .33054 .32135 .32031 .31357 .31911 .32127 Metetra
.96 .78 .614 r
.31911 .32127 .32031 .31357 .30986 .30828 .3085 .32094 Metetra
.962 .764 .591 r
.3085 .32094 .30986 .30828 .29919 .30538 .29767 .32238 Metetra
.962 .758 .582 r
.29767 .32238 .29919 .30538 .28827 .30506 .28661 .3251 Metetra
.957 .75 .582 r
.28661 .3251 .28827 .30506 .27732 .30093 .27559 .32165 Metetra
.965 .758 .574 r
.27559 .32165 .27732 .30093 .26607 .30026 .26397 .33005 Metetra
.947 .734 .583 r
.26397 .33005 .26607 .30026 .25521 .28481 .25353 .30224 Metetra
.946 .741 .594 r
.25353 .30224 .25521 .28481 .24413 .27151 .2426 .28432 Metetra
.95 .752 .601 r
.2426 .28432 .24413 .27151 .23288 .25858 .23121 .27438 Metetra
.95 .747 .594 r
.23121 .27438 .23288 .25858 .22132 .24974 .21976 .26192 Metetra
.948 .751 .604 r
.21976 .26192 .22132 .24974 .20962 .23989 .20814 .24994 Metetra
.955 .765 .608 r
.20814 .24994 .20962 .23989 .19739 .23788 .19601 .2453 Metetra
.947 .768 .628 r
.19601 .2453 .19739 .23788 .18511 .23276 .18388 .23681 Metetra
.934 .79 .678 r
.18388 .23681 .18511 .23276 .17265 .22743 .17157 .22817 Metetra
.778 .843 .901 r
.17157 .22817 .17265 .22743 .16008 .22017 .15909 .21927 Metetra
0 .085 .588 r
.15909 .21927 .16008 .22017 .14768 .20637 .14662 .20659 Metetra
.611 .762 .952 r
.14662 .20659 .14768 .20637 .13522 .1906 .13395 .19447 Metetra
.903 .755 .688 r
.13395 .19447 .13522 .1906 .12273 .17243 .12149 .17539 Metetra
.912 .521 .115 r
.37962 .36573 .38053 .36798 .371 .35702 .37013 .35332 Metetra
.961 .641 .364 r
.37013 .35332 .371 .35702 .3613 .34859 .36046 .34374 Metetra
.96 .666 .43 r
.36046 .34374 .3613 .34859 .35146 .34095 .35061 .33635 Metetra
.96 .661 .422 r
.35061 .33635 .35146 .34095 .34149 .33342 .34064 .32888 Metetra
.959 .659 .419 r
.34064 .32888 .34149 .33342 .33129 .32956 .33054 .32135 Metetra
.962 .696 .485 r
.33054 .32135 .33129 .32956 .32032 .3474 .32031 .31357 Metetra
.958 .724 .542 r
.32031 .31357 .32032 .3474 .3096 .34974 .30986 .30828 Metetra
.958 .725 .545 r
.30986 .30828 .3096 .34974 .29901 .34223 .29919 .30538 Metetra
.956 .723 .545 r
.29919 .30538 .29901 .34223 .28828 .33452 .28827 .30506 Metetra
.958 .722 .54 r
.28827 .30506 .28828 .33452 .27741 .32671 .27732 .30093 Metetra
.956 .719 .539 r
.27732 .30093 .27741 .32671 .26508 .35454 .26607 .30026 Metetra
.961 .73 .545 r
.26607 .30026 .26508 .35454 .25489 .31944 .25521 .28481 Metetra
.961 .727 .538 r
.25521 .28481 .25489 .31944 .24361 .30961 .24413 .27151 Metetra
.961 .727 .54 r
.24413 .27151 .24361 .30961 .23241 .29419 .23288 .25858 Metetra
.959 .726 .541 r
.23288 .25858 .23241 .29419 .22077 .2857 .22132 .24974 Metetra
.96 .726 .54 r
.22132 .24974 .22077 .2857 .20917 .27234 .20962 .23989 Metetra
.957 .722 .542 r
.20962 .23989 .20917 .27234 .19747 .25808 .19739 .23788 Metetra
.958 .716 .53 r
.19739 .23788 .19747 .25808 .18533 .24936 .18511 .23276 Metetra
.958 .712 .523 r
.18511 .23276 .18533 .24936 .1728 .24486 .17265 .22743 Metetra
.959 .714 .523 r
.17265 .22743 .1728 .24486 .15947 .2514 .16008 .22017 Metetra
.961 .726 .536 r
.16008 .22017 .15947 .2514 .1478 .22343 .14768 .20637 Metetra
.965 .719 .515 r
.14768 .20637 .1478 .22343 .13556 .20319 .13522 .1906 Metetra
.969 .715 .496 r
.13522 .1906 .13556 .20319 .12293 .18695 .12273 .17243 Metetra
.968 .696 .462 r
.38053 .36798 .38134 .37508 .37189 .36014 .371 .35702 Metetra
.954 .616 .332 r
.371 .35702 .37189 .36014 .36221 .35102 .3613 .34859 Metetra
.937 .568 .265 r
.3613 .34859 .36221 .35102 .35236 .34376 .35146 .34095 Metetra
.946 .597 .314 r
.35146 .34095 .35236 .34376 .34235 .33787 .34149 .33342 Metetra
.95 .652 .437 r
.34149 .33342 .34235 .33787 .33197 .34046 .33129 .32956 Metetra
.93 .681 .539 r
.33129 .32956 .33197 .34046 .32147 .34143 .32032 .3474 Metetra
.966 .8 .625 r
.32032 .3474 .32147 .34143 .31065 .34755 .3096 .34974 Metetra
.908 .815 .743 r
.3096 .34974 .31065 .34755 .29976 .34967 .29901 .34223 Metetra
.961 .69 .475 r
.29901 .34223 .29976 .34967 .28886 .34711 .28828 .33452 Metetra
.961 .709 .51 r
.28828 .33452 .28886 .34711 .27805 .33696 .27741 .32671 Metetra
.916 .666 .545 r
.27741 .32671 .27805 .33696 .26674 .33674 .26508 .35454 Metetra
.934 .728 .601 r
.26508 .35454 .26674 .33674 .25562 .3266 .25489 .31944 Metetra
.964 .689 .465 r
.25489 .31944 .25562 .3266 .24456 .31128 .24361 .30961 Metetra
.759 .322 0 r
.24361 .30961 .24456 .31128 .23315 .30086 .23241 .29419 Metetra
.961 .683 .461 r
.23241 .29419 .23315 .30086 .22173 .28713 .22077 .2857 Metetra
.729 .262 0 r
.22077 .2857 .22173 .28713 .21061 .26326 .20917 .27234 Metetra
.941 .753 .62 r
.20917 .27234 .21061 .26326 .19867 .25452 .19747 .25808 Metetra
.929 .795 .691 r
.19747 .25808 .19867 .25452 .18614 .25393 .18533 .24936 Metetra
.949 .646 .429 r
.18533 .24936 .18614 .25393 .1736 .24953 .1728 .24486 Metetra
.922 .63 .471 r
.1728 .24486 .1736 .24953 .16048 .25232 .15947 .2514 Metetra
.192 .344 .788 r
.15947 .2514 .16048 .25232 .1489 .2224 .1478 .22343 Metetra
.776 .728 .808 r
.1478 .22343 .1489 .2224 .13658 .20369 .13556 .20319 Metetra
.181 .478 .895 r
.13556 .20319 .13658 .20369 .12382 .18977 .12293 .18695 Metetra
.347 .532 .894 r
.38134 .37508 .38228 .37551 .37278 .36306 .37189 .36014 Metetra
.951 .604 .302 r
.37189 .36014 .37278 .36306 .36314 .35197 .36221 .35102 Metetra
.65 .122 0 r
.36221 .35102 .36314 .35197 .35332 .344 .35236 .34376 Metetra
.103 .577 .91 r
.35236 .34376 .35332 .344 .34329 .33883 .34235 .33787 Metetra
.791 .347 .192 r
.34235 .33787 .34329 .33883 .33296 .33984 .33197 .34046 Metetra
.698 .976 .914 r
.33197 .34046 .33296 .33984 .32247 .34048 .32147 .34143 Metetra
.721 .978 .757 r
.32147 .34143 .32247 .34048 .31155 .3501 .31065 .34755 Metetra
.908 .57 .393 r
.31065 .34755 .31155 .3501 .30089 .34525 .29976 .34967 Metetra
.953 .804 .659 r
.29976 .34967 .30089 .34525 .29002 .34228 .28886 .34711 Metetra
.933 .773 .66 r
.28886 .34711 .29002 .34228 .27896 .33974 .27805 .33696 Metetra
.921 .584 .385 r
.27805 .33696 .27896 .33974 .26773 .33724 .26674 .33674 Metetra
0 .424 .855 r
.26674 .33674 .26773 .33724 .25698 .31758 .25562 .3266 Metetra
.939 .75 .621 r
.25562 .3266 .25698 .31758 .24581 .30527 .24456 .31128 Metetra
.939 .768 .643 r
.24456 .31128 .24581 .30527 .23434 .29686 .23315 .30086 Metetra
.917 .768 .681 r
.23315 .30086 .23434 .29686 .22327 .27523 .22173 .28713 Metetra
.935 .738 .612 r
.22173 .28713 .22327 .27523 .21178 .26007 .21061 .26326 Metetra
.924 .799 .703 r
.21061 .26326 .21178 .26007 .19975 .25332 .19867 .25452 Metetra
.877 .945 .855 r
.19867 .25452 .19975 .25332 .18734 .25069 .18614 .25393 Metetra
.94 .822 .7 r
.18614 .25393 .18734 .25069 .17438 .2547 .1736 .24953 Metetra
.935 .645 .468 r
.1736 .24953 .17438 .2547 .16125 .25748 .16048 .25232 Metetra
.974 .673 .299 r
.16048 .25232 .16125 .25748 .1504 .2143 .1489 .2224 Metetra
.933 .749 .631 r
.1489 .2224 .1504 .2143 .13788 .19945 .13658 .20369 Metetra
.922 .773 .679 r
.13658 .20369 .13788 .19945 .12506 .18677 .12382 .18977 Metetra
.156 .458 .885 r
.38228 .37551 .38322 .37604 .37371 .36409 .37278 .36306 Metetra
0 0 .495 r
.37278 .36306 .37371 .36409 .36414 .35007 .36314 .35197 Metetra
.896 .81 .756 r
.36314 .35197 .36414 .35007 .35434 .34152 .35332 .344 Metetra
.927 .822 .722 r
.35332 .344 .35434 .34152 .34427 .33824 .34329 .33883 Metetra
.68 .972 .913 r
.34329 .33883 .34427 .33824 .33394 .33935 .33296 .33984 Metetra
.623 .954 .923 r
.33296 .33984 .33394 .33935 .32354 .33731 .32247 .34048 Metetra
.983 .894 .651 r
.32247 .34048 .32354 .33731 .31253 .35056 .31155 .3501 Metetra
.323 0 0 r
.31155 .3501 .31253 .35056 .30174 .34977 .30089 .34525 Metetra
.947 .649 .44 r
.30089 .34525 .30174 .34977 .29099 .34306 .29002 .34228 Metetra
.696 .155 0 r
.29002 .34228 .29099 .34306 .27997 .33949 .27896 .33974 Metetra
.507 .877 .979 r
.27896 .33974 .27997 .33949 .26832 .3488 .26773 .33724 Metetra
.973 .717 .485 r
.26773 .33724 .26832 .3488 .25784 .32149 .25698 .31758 Metetra
.963 .641 .352 r
.25698 .31758 .25784 .32149 .24667 .30924 .24581 .30527 Metetra
.956 .64 .386 r
.24581 .30527 .24667 .30924 .23546 .29445 .23434 .29686 Metetra
.856 .733 .726 r
.23434 .29686 .23546 .29445 .22412 .27906 .22327 .27523 Metetra
.964 .637 .321 r
.22327 .27523 .22412 .27906 .21245 .26805 .21178 .26007 Metetra
.959 .69 .482 r
.21178 .26007 .21245 .26805 .2008 .25292 .19975 .25332 Metetra
.616 .917 .978 r
.19975 .25332 .2008 .25292 .18846 .24903 .18734 .25069 Metetra
.925 .958 .784 r
.18734 .25069 .18846 .24903 .17513 .26048 .17438 .2547 Metetra
.938 .655 .478 r
.17438 .2547 .17513 .26048 .1627 .25004 .16125 .25748 Metetra
.892 .707 .645 r
.16125 .25748 .1627 .25004 .15126 .21774 .1504 .2143 Metetra
.957 .616 .294 r
.1504 .2143 .15126 .21774 .13897 .1988 .13788 .19945 Metetra
.747 .795 .891 r
.13788 .19945 .13897 .1988 .12618 .1857 .12506 .18677 Metetra
.821 .773 .807 r
.38322 .37604 .38419 .37493 .37472 .3618 .37371 .36409 Metetra
.878 .76 .728 r
.37371 .36409 .37472 .3618 .36511 .34952 .36414 .35007 Metetra
.752 .814 .902 r
.36414 .35007 .36511 .34952 .35528 .34213 .35434 .34152 Metetra
.57 0 0 r
.35434 .34152 .35528 .34213 .34526 .3374 .34427 .33824 Metetra
.809 .986 .887 r
.34427 .33824 .34526 .3374 .33493 .3389 .33394 .33935 Metetra
.671 .933 .969 r
.33394 .33935 .33493 .3389 .32453 .33693 .32354 .33731 Metetra
.266 0 .03 r
.32354 .33731 .32453 .33693 .31343 .35332 .31253 .35056 Metetra
.924 .586 .381 r
.31253 .35056 .31343 .35332 .30299 .34167 .30174 .34977 Metetra
.95 .766 .619 r
.30174 .34977 .30299 .34167 .29208 .34008 .29099 .34306 Metetra
.941 .826 .703 r
.29099 .34306 .29208 .34008 .28098 .33926 .27997 .33949 Metetra
.246 0 0 r
.27997 .33949 .28098 .33926 .26935 .34821 .26832 .3488 Metetra
.698 .638 .786 r
.26832 .3488 .26935 .34821 .25896 .31858 .25784 .32149 Metetra
.906 .78 .711 r
.25784 .32149 .25896 .31858 .2481 .29883 .24667 .30924 Metetra
.943 .75 .613 r
.24667 .30924 .2481 .29883 .23691 .28387 .23546 .29445 Metetra
.942 .749 .612 r
.23546 .29445 .23691 .28387 .2256 .26863 .22412 .27906 Metetra
.948 .756 .61 r
.22412 .27906 .2256 .26863 .21391 .25836 .21245 .26805 Metetra
.942 .751 .617 r
.21245 .26805 .21391 .25836 .20191 .25127 .2008 .25292 Metetra
.905 .877 .798 r
.2008 .25292 .20191 .25127 .18963 .24619 .18846 .24903 Metetra
.974 .923 .669 r
.18846 .24903 .18963 .24619 .17637 .25672 .17513 .26048 Metetra
.926 .787 .688 r
.17513 .26048 .17637 .25672 .1639 .24707 .1627 .25004 Metetra
.844 .701 .705 r
.1627 .25004 .1639 .24707 .15195 .22442 .15126 .21774 Metetra
.975 .692 .426 r
.15126 .21774 .15195 .22442 .13996 .20001 .13897 .1988 Metetra
.645 .152 0 r
.13897 .1988 .13996 .20001 .12725 .18548 .12618 .1857 Metetra
.942 .749 .613 r
.38419 .37493 .38533 .36521 .37583 .35377 .37472 .3618 Metetra
.94 .753 .623 r
.37472 .3618 .37583 .35377 .36614 .34635 .36511 .34952 Metetra
.927 .795 .694 r
.36511 .34952 .36614 .34635 .35632 .33892 .35528 .34213 Metetra
.939 .81 .691 r
.35528 .34213 .35632 .33892 .34639 .33093 .34526 .3374 Metetra
.965 .792 .62 r
.34526 .3374 .34639 .33093 .33629 .32404 .33493 .3389 Metetra
.959 .757 .587 r
.33493 .3389 .33629 .32404 .32595 .32087 .32453 .33693 Metetra
.974 .772 .57 r
.32453 .33693 .32595 .32087 .31538 .32054 .31343 .35332 Metetra
.955 .74 .574 r
.31343 .35332 .31538 .32054 .30465 .31983 .30299 .34167 Metetra
.959 .75 .578 r
.30299 .34167 .30465 .31983 .29369 .32117 .29208 .34008 Metetra
.96 .753 .581 r
.29208 .34008 .29369 .32117 .2827 .31836 .28098 .33926 Metetra
.966 .758 .573 r
.28098 .33926 .2827 .31836 .27067 .33952 .26935 .34821 Metetra
.917 .727 .631 r
.26935 .34821 .27067 .33952 .26067 .3001 .25896 .31858 Metetra
.946 .74 .592 r
.25896 .31858 .26067 .3001 .2495 .28883 .2481 .29883 Metetra
.942 .75 .615 r
.2481 .29883 .2495 .28883 .23834 .27385 .23691 .28387 Metetra
.942 .75 .615 r
.23691 .28387 .23834 .27385 .22696 .26052 .2256 .26863 Metetra
.946 .762 .623 r
.2256 .26863 .22696 .26052 .21542 .24763 .21391 .25836 Metetra
.953 .761 .606 r
.21391 .25836 .21542 .24763 .20338 .24192 .20191 .25127 Metetra
.955 .768 .611 r
.20191 .25127 .20338 .24192 .19126 .23404 .18963 .24619 Metetra
.972 .779 .586 r
.18963 .24619 .19126 .23404 .17884 .22839 .17637 .25672 Metetra
.956 .744 .577 r
.17637 .25672 .17884 .22839 .16636 .22017 .1639 .24707 Metetra
.95 .738 .583 r
.1639 .24707 .16636 .22017 .15405 .20508 .15195 .22442 Metetra
.945 .738 .593 r
.15195 .22442 .15405 .20508 .14164 .18888 .13996 .20001 Metetra
.946 .752 .61 r
.13996 .20001 .14164 .18888 .12902 .17336 .12725 .18548 Metetra
.939 .757 .63 r
.38533 .36521 .38641 .35813 .37688 .34929 .37583 .35377 Metetra
.938 .78 .659 r
.37583 .35377 .37688 .34929 .36724 .33961 .36614 .34635 Metetra
.946 .768 .629 r
.36614 .34635 .36724 .33961 .35744 .33203 .35632 .33892 Metetra
.946 .766 .628 r
.35632 .33892 .35744 .33203 .34751 .32458 .34639 .33093 Metetra
.947 .772 .633 r
.34639 .33093 .34751 .32458 .33746 .31661 .33629 .32404 Metetra
.956 .775 .618 r
.33629 .32404 .33746 .31661 .32723 .30987 .32595 .32087 Metetra
.961 .767 .596 r
.32595 .32087 .32723 .30987 .31683 .30459 .31538 .32054 Metetra
.96 .757 .584 r
.31538 .32054 .31683 .30459 .30622 .30112 .30465 .31983 Metetra
.961 .755 .579 r
.30465 .31983 .30622 .30112 .29548 .29666 .29369 .32117 Metetra
.959 .748 .576 r
.29369 .32117 .29548 .29666 .28448 .29529 .2827 .31836 Metetra
.972 .763 .564 r
.2827 .31836 .28448 .29529 .27336 .29237 .27067 .33952 Metetra
.948 .731 .575 r
.27067 .33952 .27336 .29237 .2627 .27277 .26067 .3001 Metetra
.955 .743 .578 r
.26067 .3001 .2627 .27277 .2514 .26629 .2495 .28883 Metetra
.952 .742 .584 r
.2495 .28883 .2514 .26629 .24015 .25446 .23834 .27385 Metetra
.952 .745 .587 r
.23834 .27385 .24015 .25446 .22874 .24282 .22696 .26052 Metetra
.951 .746 .59 r
.22696 .26052 .22874 .24282 .2171 .2329 .21542 .24763 Metetra
.956 .755 .592 r
.21542 .24763 .2171 .2329 .20501 .22892 .20338 .24192 Metetra
.954 .756 .598 r
.20338 .24192 .20501 .22892 .19277 .22423 .19126 .23404 Metetra
.954 .766 .609 r
.19126 .23404 .19277 .22423 .1801 .22408 .17884 .22839 Metetra
.937 .791 .672 r
.17884 .22839 .1801 .22408 .16768 .21495 .16636 .22017 Metetra
.927 .763 .66 r
.16636 .22017 .16768 .21495 .1552 .20324 .15405 .20508 Metetra
.857 .771 .766 r
.15405 .20508 .1552 .20324 .14292 .18486 .14164 .18888 Metetra
.915 .768 .684 r
.14164 .18888 .14292 .18486 .13029 .16968 .12902 .17336 Metetra
.766 .808 .886 r
.38641 .35813 .38737 .35752 .37782 .35001 .37688 .34929 Metetra
0 .222 .71 r
.37688 .34929 .37782 .35001 .36814 .34269 .36724 .33961 Metetra
.951 .613 .337 r
.36724 .33961 .36814 .34269 .35833 .33531 .35744 .33203 Metetra
.953 .622 .354 r
.35744 .33203 .35833 .33531 .34847 .32466 .34751 .32458 Metetra
.411 .712 .985 r
.34751 .32458 .34847 .32466 .33834 .31985 .33746 .31661 Metetra
.95 .618 .358 r
.33746 .31661 .33834 .31985 .32793 .32001 .32723 .30987 Metetra
.959 .701 .502 r
.32723 .30987 .32793 .32001 .31694 .33447 .31683 .30459 Metetra
.958 .723 .539 r
.31683 .30459 .31694 .33447 .30636 .32863 .30622 .30112 Metetra
.959 .722 .537 r
.30622 .30112 .30636 .32863 .29569 .32088 .29548 .29666 Metetra
.957 .719 .536 r
.29548 .29666 .29569 .32088 .28403 .33798 .28448 .29529 Metetra
.958 .726 .544 r
.28448 .29529 .28403 .33798 .27259 .3424 .27336 .29237 Metetra
.963 .731 .541 r
.27336 .29237 .27259 .3424 .26184 .32275 .2627 .27277 Metetra
.959 .728 .545 r
.2627 .27277 .26184 .32275 .25132 .29428 .2514 .26629 Metetra
.962 .725 .533 r
.2514 .26629 .25132 .29428 .24012 .28008 .24015 .25446 Metetra
.962 .724 .531 r
.24015 .25446 .24012 .28008 .22876 .26647 .22874 .24282 Metetra
.961 .722 .53 r
.22874 .24282 .22876 .26647 .21727 .25204 .2171 .2329 Metetra
.958 .715 .528 r
.2171 .2329 .21727 .25204 .20531 .24479 .20501 .22892 Metetra
.958 .711 .521 r
.20501 .22892 .20531 .24479 .19296 .24169 .19277 .22423 Metetra
.955 .71 .528 r
.19277 .22423 .19296 .24169 .18044 .23811 .1801 .22408 Metetra
.962 .711 .511 r
.1801 .22408 .18044 .23811 .16775 .23373 .16768 .21495 Metetra
.963 .719 .521 r
.16768 .21495 .16775 .23373 .15594 .209 .1552 .20324 Metetra
.974 .681 .401 r
.1552 .20324 .15594 .209 .14336 .1958 .14292 .18486 Metetra
.968 .709 .488 r
.14292 .18486 .14336 .1958 .13088 .17772 .13029 .16968 Metetra
.91 .505 .167 r
.38737 .35752 .38828 .35945 .37878 .34941 .37782 .35001 Metetra
.766 .836 .906 r
.37782 .35001 .37878 .34941 .36915 .34 .36814 .34269 Metetra
.92 .802 .712 r
.36814 .34269 .36915 .34 .35937 .33212 .35833 .33531 Metetra
.915 .778 .696 r
.35833 .33531 .35937 .33212 .34948 .32292 .34847 .32466 Metetra
.908 .849 .774 r
.34847 .32466 .34948 .32292 .3394 .3164 .33834 .31985 Metetra
.959 .833 .676 r
.33834 .31985 .3394 .3164 .32913 .31195 .32793 .32001 Metetra
.984 .807 .585 r
.32793 .32001 .32913 .31195 .31859 .31139 .31694 .33447 Metetra
.957 .747 .578 r
.31694 .33447 .31859 .31139 .30796 .30858 .30636 .32863 Metetra
.955 .747 .583 r
.30636 .32863 .30796 .30858 .29692 .31351 .29569 .32088 Metetra
.989 .82 .584 r
.29569 .32088 .29692 .31351 .28607 .30725 .28403 .33798 Metetra
.962 .749 .569 r
.28403 .33798 .28607 .30725 .27332 .35012 .27259 .3424 Metetra
.978 .704 .44 r
.27259 .3424 .27332 .35012 .26405 .29046 .26184 .32275 Metetra
.948 .734 .58 r
.26184 .32275 .26405 .29046 .25287 .28042 .25132 .29428 Metetra
.948 .747 .599 r
.25132 .29428 .25287 .28042 .24159 .26911 .24012 .28008 Metetra
.946 .751 .609 r
.24012 .28008 .24159 .26911 .23005 .25995 .22876 .26647 Metetra
.934 .758 .641 r
.22876 .26647 .23005 .25995 .21857 .24587 .21727 .25204 Metetra
.947 .778 .639 r
.21727 .25204 .21857 .24587 .20654 .24056 .20531 .24479 Metetra
.951 .81 .668 r
.20531 .24479 .20654 .24056 .19406 .24046 .19296 .24169 Metetra
.874 .905 .85 r
.19296 .24169 .19406 .24046 .18066 .25461 .18044 .23811 Metetra
.958 .711 .522 r
.18044 .23811 .18066 .25461 .16932 .22357 .16775 .23373 Metetra
.932 .739 .62 r
.16775 .23373 .16932 .22357 .15712 .20665 .15594 .209 Metetra
.891 .789 .742 r
.15594 .209 .15712 .20665 .14462 .19218 .14336 .1958 Metetra
.902 .76 .694 r
.14336 .1958 .14462 .19218 .13186 .17916 .13088 .17772 Metetra
.92 .527 .158 r
.38828 .35945 .38919 .36162 .3797 .35117 .37878 .34941 Metetra
.878 .448 .052 r
.37878 .34941 .3797 .35117 .37005 .34299 .36915 .34 Metetra
.95 .608 .324 r
.36915 .34 .37005 .34299 .36025 .33556 .35937 .33212 Metetra
.958 .629 .346 r
.35937 .33212 .36025 .33556 .35034 .32746 .34948 .32292 Metetra
.958 .657 .422 r
.34948 .32292 .35034 .32746 .34017 .32434 .3394 .3164 Metetra
.957 .691 .488 r
.3394 .3164 .34017 .32434 .33006 .31379 .32913 .31195 Metetra
.893 .51 .297 r
.32913 .31195 .33006 .31379 .31878 .33917 .31859 .31139 Metetra
.958 .722 .538 r
.31859 .31139 .31878 .33917 .30766 .35115 .30796 .30858 Metetra
.956 .724 .547 r
.30796 .30858 .30766 .35115 .29693 .34439 .29692 .31351 Metetra
.96 .724 .538 r
.29692 .31351 .29693 .34439 .28604 .33798 .28607 .30725 Metetra
.938 .704 .558 r
.28607 .30725 .28604 .33798 .27464 .3414 .27332 .35012 Metetra
.876 .685 .64 r
.27332 .35012 .27464 .3414 .26406 .31765 .26405 .29046 Metetra
.961 .724 .533 r
.26405 .29046 .26406 .31765 .25269 .31128 .25287 .28042 Metetra
.962 .726 .535 r
.25287 .28042 .25269 .31128 .24171 .29116 .24159 .26911 Metetra
.961 .721 .528 r
.24159 .26911 .24171 .29116 .23047 .27436 .23005 .25995 Metetra
.966 .716 .507 r
.23005 .25995 .23047 .27436 .21922 .25454 .21857 .24587 Metetra
.958 .692 .49 r
.21857 .24587 .21922 .25454 .20744 .24342 .20654 .24056 Metetra
.919 .58 .38 r
.20654 .24056 .20744 .24342 .19525 .23722 .19406 .24046 Metetra
.98 .914 .641 r
.19406 .24046 .19525 .23722 .1813 .26274 .18066 .25461 Metetra
.985 .713 .411 r
.18066 .25461 .1813 .26274 .1701 .22879 .16932 .22357 Metetra
.972 .672 .387 r
.16932 .22357 .1701 .22879 .15772 .21513 .15712 .20665 Metetra
.969 .699 .467 r
.15712 .20665 .15772 .21513 .14508 .20303 .14462 .19218 Metetra
.966 .706 .491 r
.14462 .19218 .14508 .20303 .13266 .18364 .13186 .17916 Metetra
.966 .711 .497 r
.38919 .36162 .38995 .37256 .38058 .35523 .3797 .35117 Metetra
.961 .65 .392 r
.3797 .35117 .38058 .35523 .37096 .34496 .37005 .34299 Metetra
.913 .51 .179 r
.37005 .34299 .37096 .34496 .36117 .33763 .36025 .33556 Metetra
.918 .521 .185 r
.36025 .33556 .36117 .33763 .35119 .33248 .35034 .32746 Metetra
.951 .661 .452 r
.35034 .32746 .35119 .33248 .34095 .33204 .34017 .32434 Metetra
.967 .697 .469 r
.34017 .32434 .34095 .33204 .33043 .33614 .33006 .31379 Metetra
.941 .703 .551 r
.33006 .31379 .33043 .33614 .31986 .33583 .31878 .33917 Metetra
.986 .898 .633 r
.31878 .33917 .31986 .33583 .30909 .33659 .30766 .35115 Metetra
.955 .753 .591 r
.30766 .35115 .30909 .33659 .2985 .32633 .29693 .34439 Metetra
.956 .75 .585 r
.29693 .34439 .2985 .32633 .28754 .32308 .28604 .33798 Metetra
.964 .763 .583 r
.28604 .33798 .28754 .32308 .27622 .3253 .27464 .3414 Metetra
.941 .737 .598 r
.27464 .3414 .27622 .3253 .26545 .30738 .26406 .31765 Metetra
.954 .762 .606 r
.26406 .31765 .26545 .30738 .25446 .29187 .25269 .31128 Metetra
.947 .74 .59 r
.25269 .31128 .25446 .29187 .24318 .28006 .24171 .29116 Metetra
.942 .747 .61 r
.24171 .29116 .24318 .28006 .23172 .26908 .23047 .27436 Metetra
.915 .747 .66 r
.23047 .27436 .23172 .26908 .22017 .25624 .21922 .25454 Metetra
.853 .407 0 r
.21922 .25454 .22017 .25624 .2083 .2471 .20744 .24342 Metetra
.948 .624 .383 r
.20744 .24342 .2083 .2471 .19609 .24143 .19525 .23722 Metetra
.87 .589 .509 r
.19525 .23722 .19609 .24143 .18281 .25346 .1813 .26274 Metetra
.917 .725 .629 r
.1813 .26274 .18281 .25346 .17161 .2199 .1701 .22879 Metetra
.943 .757 .621 r
.1701 .22879 .17161 .2199 .15898 .21139 .15772 .21513 Metetra
.922 .783 .69 r
.15772 .21513 .15898 .21139 .14648 .19678 .14508 .20303 Metetra
.925 .752 .648 r
.14508 .20303 .14648 .19678 .1337 .18417 .13266 .18364 Metetra
.926 .744 .638 r
.38995 .37256 .39102 .36583 .38153 .35532 .38058 .35523 Metetra
.48 .688 .958 r
.38058 .35523 .38153 .35532 .37191 .34577 .37096 .34496 Metetra
.531 0 0 r
.37096 .34496 .37191 .34577 .36212 .3381 .36117 .33763 Metetra
0 .275 .653 r
.36117 .33763 .36212 .3381 .35216 .33231 .35119 .33248 Metetra
.312 .798 .885 r
.35119 .33248 .35216 .33231 .34191 .33237 .34095 .33204 Metetra
.576 .056 0 r
.34095 .33204 .34191 .33237 .33152 .33201 .33043 .33614 Metetra
.96 .817 .659 r
.33043 .33614 .33152 .33201 .32082 .33658 .31986 .33583 Metetra
.724 .219 .026 r
.31986 .33583 .32082 .33658 .31024 .33154 .30909 .33659 Metetra
.935 .772 .655 r
.30909 .33659 .31024 .33154 .2995 .32625 .2985 .32633 Metetra
.358 .793 .966 r
.2985 .32633 .2995 .32625 .28859 .32164 .28754 .32308 Metetra
.912 .957 .806 r
.28754 .32308 .28859 .32164 .27664 .34204 .27622 .3253 Metetra
.969 .723 .509 r
.27622 .3253 .27664 .34204 .26654 .3052 .26545 .30738 Metetra
.872 .764 .741 r
.26545 .30738 .26654 .3052 .25578 .28388 .25446 .29187 Metetra
.943 .759 .624 r
.25446 .29187 .25578 .28388 .24437 .2759 .24318 .28006 Metetra
.928 .778 .675 r
.24318 .28006 .24437 .2759 .23295 .26398 .23172 .26908 Metetra
.93 .768 .658 r
.23172 .26908 .23295 .26398 .22131 .25379 .22017 .25624 Metetra
.91 .808 .735 r
.22017 .25624 .22131 .25379 .20937 .24634 .2083 .2471 Metetra
.789 .892 .918 r
.2083 .2471 .20937 .24634 .19738 .23613 .19609 .24143 Metetra
.985 .843 .619 r
.19609 .24143 .19738 .23613 .18425 .2456 .18281 .25346 Metetra
.91 .724 .638 r
.18281 .25346 .18425 .2456 .17272 .2187 .17161 .2199 Metetra
.848 .847 .842 r
.17161 .2199 .17272 .2187 .16018 .20858 .15898 .21139 Metetra
.898 .778 .721 r
.15898 .21139 .16018 .20858 .14738 .19972 .14648 .19678 Metetra
.945 .583 .26 r
.14648 .19678 .14738 .19972 .13477 .18408 .1337 .18417 Metetra
.723 .773 .892 r
.39102 .36583 .39198 .36537 .38249 .35508 .38153 .35532 Metetra
.647 .77 .938 r
.38153 .35532 .38249 .35508 .37284 .34729 .37191 .34577 Metetra
.855 .403 .023 r
.37191 .34577 .37284 .34729 .36305 .33969 .36212 .3381 Metetra
.881 .446 .122 r
.36212 .3381 .36305 .33969 .35312 .33285 .35216 .33231 Metetra
.627 .074 0 r
.35216 .33231 .35312 .33285 .34309 .32458 .34191 .33237 Metetra
.962 .78 .611 r
.34191 .33237 .34309 .32458 .33285 .31908 .33152 .33201 Metetra
.966 .768 .585 r
.33152 .33201 .33285 .31908 .32247 .31336 .32082 .33658 Metetra
.958 .747 .577 r
.32082 .33658 .32247 .31336 .31164 .31779 .31024 .33154 Metetra
.956 .756 .592 r
.31024 .33154 .31164 .31779 .30076 .31795 .2995 .32625 Metetra
.955 .771 .614 r
.2995 .32625 .30076 .31795 .28982 .31476 .28859 .32164 Metetra
.994 .834 .576 r
.28859 .32164 .28982 .31476 .27864 .31381 .27664 .34204 Metetra
.943 .73 .585 r
.27664 .34204 .27864 .31381 .26793 .29481 .26654 .3052 Metetra
.935 .741 .616 r
.26654 .3052 .26793 .29481 .25688 .28164 .25578 .28388 Metetra
.909 .817 .745 r
.25578 .28388 .25688 .28164 .24561 .27037 .24437 .2759 Metetra
.935 .768 .651 r
.24437 .2759 .24561 .27037 .23415 .25977 .23295 .26398 Metetra
.931 .782 .674 r
.23295 .26398 .23415 .25977 .22271 .24533 .22131 .25379 Metetra
.951 .767 .618 r
.22131 .25379 .22271 .24533 .21074 .239 .20937 .24634 Metetra
.945 .766 .629 r
.20937 .24634 .21074 .239 .19849 .23458 .19738 .23613 Metetra
.871 .989 .724 r
.19738 .23613 .19849 .23458 .18609 .22948 .18425 .2456 Metetra
.941 .736 .599 r
.18425 .2456 .18609 .22948 .17386 .21689 .17272 .2187 Metetra
.883 .818 .779 r
.17272 .2187 .17386 .21689 .1615 .2035 .16018 .20858 Metetra
.941 .784 .658 r
.16018 .20858 .1615 .2035 .14889 .19146 .14738 .19972 Metetra
.94 .756 .627 r
.14738 .19972 .14889 .19146 .13624 .17691 .13477 .18408 Metetra
.94 .761 .632 r
.39198 .36537 .39305 .35874 .38358 .34833 .38249 .35508 Metetra
.946 .767 .628 r
.38249 .35508 .38358 .34833 .37394 .34034 .37284 .34729 Metetra
.947 .767 .626 r
.37284 .34729 .37394 .34034 .36419 .33154 .36305 .33969 Metetra
.951 .765 .616 r
.36305 .33969 .36419 .33154 .35429 .32428 .35312 .33285 Metetra
.949 .761 .615 r
.35312 .33285 .35429 .32428 .34423 .31786 .34309 .32458 Metetra
.951 .774 .627 r
.34309 .32458 .34423 .31786 .33403 .31125 .33285 .31908 Metetra
.953 .769 .618 r
.33285 .31908 .33403 .31125 .32364 .30682 .32247 .31336 Metetra
.971 .801 .614 r
.32247 .31336 .32364 .30682 .31317 .29964 .31164 .31779 Metetra
.961 .755 .58 r
.31164 .31779 .31317 .29964 .30247 .29542 .30076 .31795 Metetra
.959 .749 .577 r
.30076 .31795 .30247 .29542 .29159 .29152 .28982 .31476 Metetra
.96 .75 .575 r
.28982 .31476 .29159 .29152 .28035 .29344 .27864 .31381 Metetra
.949 .74 .588 r
.27864 .31381 .28035 .29344 .26966 .2749 .26793 .29481 Metetra
.952 .745 .585 r
.26793 .29481 .26966 .2749 .25851 .26544 .25688 .28164 Metetra
.952 .749 .591 r
.25688 .28164 .25851 .26544 .24724 .25501 .24561 .27037 Metetra
.953 .75 .592 r
.24561 .27037 .24724 .25501 .23575 .2461 .23415 .25977 Metetra
.948 .748 .599 r
.23415 .25977 .23575 .2461 .22418 .23502 .22271 .24533 Metetra
.955 .763 .606 r
.22271 .24533 .22418 .23502 .21236 .22605 .21074 .239 Metetra
.958 .76 .595 r
.21074 .239 .21236 .22605 .20011 .22235 .19849 .23458 Metetra
.957 .761 .598 r
.19849 .23458 .20011 .22235 .18748 .22232 .18609 .22948 Metetra
.941 .763 .633 r
.18609 .22948 .18748 .22232 .17511 .21291 .17386 .21689 Metetra
.921 .775 .683 r
.17386 .21689 .17511 .21291 .16257 .20326 .1615 .2035 Metetra
.621 .768 .95 r
.1615 .2035 .16257 .20326 .1503 .18518 .14889 .19146 Metetra
.935 .763 .645 r
.14889 .19146 .1503 .18518 .13774 .16924 .13624 .17691 Metetra
.968 .672 .412 r
.39305 .35874 .39391 .36374 .38444 .35335 .38358 .34833 Metetra
.963 .669 .427 r
.38358 .34833 .38444 .35335 .37484 .34338 .37394 .34034 Metetra
.953 .61 .314 r
.37394 .34034 .37484 .34338 .36506 .33592 .36419 .33154 Metetra
.959 .655 .41 r
.36419 .33154 .36506 .33592 .35511 .33062 .35429 .32428 Metetra
.961 .682 .462 r
.35429 .32428 .35511 .33062 .34506 .32355 .34423 .31786 Metetra
.96 .675 .45 r
.34423 .31786 .34506 .32355 .33443 .33343 .33403 .31125 Metetra
.959 .719 .531 r
.33403 .31125 .33443 .33343 .32396 .33051 .32364 .30682 Metetra
.961 .722 .531 r
.32364 .30682 .32396 .33051 .31307 .3364 .31317 .29964 Metetra
.959 .725 .541 r
.31317 .29964 .31307 .3364 .3016 .35491 .30247 .29542 Metetra
.959 .729 .546 r
.30247 .29542 .3016 .35491 .29083 .34499 .29159 .29152 Metetra
.958 .727 .547 r
.29159 .29152 .29083 .34499 .27962 .3437 .28035 .29344 Metetra
.963 .731 .54 r
.28035 .29344 .27962 .3437 .26863 .33143 .26966 .2749 Metetra
.96 .729 .544 r
.26966 .2749 .26863 .33143 .2577 .31361 .25851 .26544 Metetra
.961 .729 .542 r
.25851 .26544 .2577 .31361 .24619 .30713 .24724 .25501 Metetra
.96 .729 .543 r
.24724 .25501 .24619 .30713 .23583 .26869 .23575 .2461 Metetra
.963 .722 .526 r
.23575 .2461 .23583 .26869 .22434 .2551 .22418 .23502 Metetra
.962 .719 .524 r
.22418 .23502 .22434 .2551 .21254 .24486 .21236 .22605 Metetra
.958 .714 .526 r
.21236 .22605 .21254 .24486 .20049 .23644 .20011 .22235 Metetra
.955 .704 .52 r
.20011 .22235 .20049 .23644 .18683 .25709 .18748 .22232 Metetra
.961 .726 .537 r
.18748 .22232 .18683 .25709 .1758 .22007 .17511 .21291 Metetra
.963 .686 .461 r
.17511 .21291 .1758 .22007 .1634 .20752 .16257 .20326 Metetra
.969 .649 .328 r
.16257 .20326 .1634 .20752 .15071 .19693 .1503 .18518 Metetra
.969 .711 .491 r
.1503 .18518 .15071 .19693 .13796 .1841 .13774 .16924 Metetra
.968 .704 .48 r
.39391 .36374 .39471 .37259 .38525 .36078 .38444 .35335 Metetra
.967 .696 .466 r
.38444 .35335 .38525 .36078 .37564 .35121 .37484 .34338 Metetra
.963 .695 .478 r
.37484 .34338 .37564 .35121 .36585 .3439 .36506 .33592 Metetra
.96 .693 .486 r
.36506 .33592 .36585 .3439 .35594 .33648 .35511 .33062 Metetra
.961 .678 .451 r
.35511 .33062 .35594 .33648 .34576 .33456 .34506 .32355 Metetra
.941 .689 .527 r
.34506 .32355 .34576 .33456 .33521 .34101 .33443 .33343 Metetra
.955 .686 .487 r
.33443 .33343 .33521 .34101 .32419 .3577 .32396 .33051 Metetra
.954 .717 .541 r
.32396 .33051 .32419 .3577 .31408 .33592 .31307 .3364 Metetra
.314 0 .159 r
.31307 .3364 .31408 .33592 .30339 .32954 .3016 .35491 Metetra
.956 .744 .577 r
.3016 .35491 .30339 .32954 .29254 .32351 .29083 .34499 Metetra
.96 .752 .577 r
.29083 .34499 .29254 .32351 .28044 .34938 .27962 .3437 Metetra
.969 .678 .422 r
.27962 .3437 .28044 .34938 .27036 .31144 .26863 .33143 Metetra
.95 .742 .587 r
.26863 .33143 .27036 .31144 .25944 .29447 .2577 .31361 Metetra
.957 .75 .583 r
.2577 .31361 .25944 .29447 .24835 .27828 .24619 .30713 Metetra
.943 .73 .585 r
.24619 .30713 .24835 .27828 .23694 .26664 .23583 .26869 Metetra
.877 .782 .753 r
.23583 .26869 .23694 .26664 .22514 .26048 .22434 .2551 Metetra
.964 .669 .423 r
.22434 .2551 .22514 .26048 .2133 .25094 .21254 .24486 Metetra
.961 .675 .447 r
.21254 .24486 .2133 .25094 .20095 .24884 .20049 .23644 Metetra
.933 .682 .535 r
.20049 .23644 .20095 .24884 .18838 .24673 .18683 .25709 Metetra
.918 .723 .624 r
.18683 .25709 .18838 .24673 .17626 .23172 .1758 .22007 Metetra
.966 .709 .495 r
.1758 .22007 .17626 .23172 .16413 .21361 .1634 .20752 Metetra
.964 .676 .439 r
.1634 .20752 .16413 .21361 .15142 .20331 .15071 .19693 Metetra
.967 .681 .437 r
.15071 .19693 .15142 .20331 .13895 .18527 .13796 .1841 Metetra
.901 .773 .711 r
.39471 .37259 .39571 .36987 .38621 .36064 .38525 .36078 Metetra
.605 .755 .95 r
.38525 .36078 .38621 .36064 .37664 .3494 .37564 .35121 Metetra
.897 .82 .764 r
.37564 .35121 .37664 .3494 .36685 .34277 .36585 .3439 Metetra
.851 .835 .83 r
.36585 .3439 .36685 .34277 .35689 .33749 .35594 .33648 Metetra
.791 .301 .038 r
.35594 .33648 .35689 .33749 .34664 .33845 .34576 .33456 Metetra
.917 .62 .468 r
.34576 .33456 .34664 .33845 .33631 .33654 .33521 .34101 Metetra
.994 .873 .59 r
.33521 .34101 .33631 .33654 .32548 .34674 .32419 .3577 Metetra
.935 .739 .613 r
.32419 .3577 .32548 .34674 .31401 .37211 .31408 .33592 Metetra
.96 .726 .539 r
.31408 .33592 .31401 .37211 .30331 .36451 .30339 .32954 Metetra
.96 .725 .539 r
.30339 .32954 .30331 .36451 .29246 .35684 .29254 .32351 Metetra
.947 .713 .551 r
.29254 .32351 .29246 .35684 .28096 .36368 .28044 .34938 Metetra
.985 .734 .467 r
.28044 .34938 .28096 .36368 .27031 .34108 .27036 .31144 Metetra
.965 .728 .53 r
.27036 .31144 .27031 .34108 .25901 .33304 .25944 .29447 Metetra
.963 .729 .536 r
.25944 .29447 .25901 .33304 .24844 .30205 .24835 .27828 Metetra
.963 .723 .527 r
.24835 .27828 .24844 .30205 .23753 .27731 .23694 .26664 Metetra
.96 .701 .5 r
.23694 .26664 .23753 .27731 .22611 .26189 .22514 .26048 Metetra
.803 .325 0 r
.22514 .26048 .22611 .26189 .21413 .25569 .2133 .25094 Metetra
.945 .646 .441 r
.2133 .25094 .21413 .25569 .20193 .2501 .20095 .24884 Metetra
.824 .358 .106 r
.20095 .24884 .20193 .2501 .18832 .26952 .18838 .24673 Metetra
.965 .724 .523 r
.18838 .24673 .18832 .26952 .17772 .22363 .17626 .23172 Metetra
.935 .751 .629 r
.17626 .23172 .17772 .22363 .16551 .20755 .16413 .21361 Metetra
.942 .774 .644 r
.16413 .21361 .16551 .20755 .15278 .19786 .15142 .20331 Metetra
.923 .757 .658 r
.15142 .20331 .15278 .19786 .14 .1857 .13895 .18527 Metetra
.908 .791 .721 r
.39571 .36987 .39671 .36738 .38723 .35754 .38621 .36064 Metetra
.911 .775 .698 r
.38621 .36064 .38723 .35754 .37762 .34834 .37664 .3494 Metetra
.848 .847 .842 r
.37664 .3494 .37762 .34834 .36791 .33838 .36685 .34277 Metetra
.946 .792 .659 r
.36685 .34277 .36791 .33838 .35791 .3354 .35689 .33749 Metetra
.949 .893 .739 r
.35689 .33749 .35791 .3354 .34781 .33059 .34664 .33845 Metetra
.96 .777 .612 r
.34664 .33845 .34781 .33059 .33782 .31607 .33631 .33654 Metetra
.968 .76 .569 r
.33631 .33654 .33782 .31607 .32684 .33354 .32548 .34674 Metetra
.986 .791 .559 r
.32548 .34674 .32684 .33354 .31589 .34202 .31401 .37211 Metetra
.958 .744 .573 r
.31401 .37211 .31589 .34202 .30517 .33671 .30331 .36451 Metetra
.957 .745 .574 r
.30331 .36451 .30517 .33671 .29404 .33915 .29246 .35684 Metetra
.967 .762 .575 r
.29246 .35684 .29404 .33915 .28207 .36088 .28096 .36368 Metetra
.865 .729 .711 r
.28096 .36368 .28207 .36088 .27222 .31631 .27031 .34108 Metetra
.957 .746 .577 r
.27031 .34108 .27222 .31631 .26097 .30801 .25901 .33304 Metetra
.945 .733 .586 r
.25901 .33304 .26097 .30801 .24976 .29458 .24844 .30205 Metetra
.92 .737 .637 r
.24844 .30205 .24976 .29458 .23881 .27126 .23753 .27731 Metetra
.931 .758 .646 r
.23753 .27731 .23881 .27126 .22678 .27034 .22611 .26189 Metetra
.959 .692 .484 r
.22611 .26189 .22678 .27034 .21508 .25764 .21413 .25569 Metetra
.901 .494 .207 r
.21413 .25569 .21508 .25764 .20269 .25627 .20193 .2501 Metetra
.909 .637 .513 r
.20193 .2501 .20269 .25627 .19018 .25294 .18832 .26952 Metetra
.927 .722 .605 r
.18832 .26952 .19018 .25294 .17875 .22405 .17772 .22363 Metetra
.261 .524 .912 r
.17772 .22363 .17875 .22405 .16657 .20741 .16551 .20755 Metetra
.548 .78 .985 r
.16551 .20755 .16657 .20741 .15399 .1952 .15278 .19786 Metetra
.904 .795 .729 r
.15278 .19786 .15399 .1952 .1418 .17258 .14 .1857 Metetra
.767 .793 .875 r
.39671 .36738 .39768 .36674 .38829 .35216 .38723 .35754 Metetra
.939 .77 .646 r
.38723 .35754 .38829 .35216 .37868 .34371 .37762 .34834 Metetra
.933 .772 .659 r
.37762 .34834 .37868 .34371 .36892 .33631 .36791 .33838 Metetra
.93 .855 .746 r
.36791 .33838 .36892 .33631 .359 .33002 .35791 .3354 Metetra
.951 .785 .641 r
.35791 .3354 .359 .33002 .34888 .32686 .34781 .33059 Metetra
.91 .76 .683 r
.34781 .33059 .34888 .32686 .33843 .3306 .33782 .31607 Metetra
.939 .694 .54 r
.33782 .31607 .33843 .3306 .3276 .34158 .32684 .33354 Metetra
.937 .674 .513 r
.32684 .33354 .3276 .34158 .31687 .34239 .31589 .34202 Metetra
0 .401 .756 r
.31589 .34202 .31687 .34239 .30617 .33665 .30517 .33671 Metetra
.093 0 0 r
.30517 .33671 .30617 .33665 .29538 .32895 .29404 .33915 Metetra
.988 .804 .568 r
.29404 .33915 .29538 .32895 .28446 .32041 .28207 .36088 Metetra
.946 .729 .578 r
.28207 .36088 .28446 .32041 .27344 .31049 .27222 .31631 Metetra
.944 .776 .642 r
.27222 .31631 .27344 .31049 .26224 .30122 .26097 .30801 Metetra
.937 .76 .636 r
.26097 .30801 .26224 .30122 .25112 .28603 .24976 .29458 Metetra
.928 .739 .628 r
.24976 .29458 .25112 .28603 .23971 .27435 .23881 .27126 Metetra
.927 .594 .387 r
.23881 .27126 .23971 .27435 .2282 .26134 .22678 .27034 Metetra
.945 .757 .618 r
.22678 .27034 .2282 .26134 .21613 .25723 .21508 .25764 Metetra
.578 .921 .962 r
.21508 .25764 .21613 .25723 .20379 .25498 .20269 .25627 Metetra
.88 .907 .843 r
.20269 .25627 .20379 .25498 .1913 .25141 .19018 .25294 Metetra
.787 .686 .752 r
.19018 .25294 .1913 .25141 .17966 .22687 .17875 .22405 Metetra
.934 .563 .176 r
.17875 .22405 .17966 .22687 .16778 .20452 .16657 .20741 Metetra
.909 .791 .718 r
.16657 .20741 .16778 .20452 .1549 .19788 .15399 .1952 Metetra
.882 .509 .034 r
.15399 .1952 .1549 .19788 .14241 .18069 .1418 .17258 Metetra
.914 .755 .672 r
.39768 .36674 .3987 .3626 .38927 .3507 .38829 .35216 Metetra
.872 .814 .79 r
.38829 .35216 .38927 .3507 .3799 .33026 .37868 .34371 Metetra
.955 .753 .593 r
.37868 .34371 .3799 .33026 .37019 .32207 .36892 .33631 Metetra
.956 .754 .59 r
.36892 .33631 .37019 .32207 .36033 .3145 .359 .33002 Metetra
.959 .755 .585 r
.359 .33002 .36033 .3145 .35008 .3177 .34888 .32686 Metetra
.968 .781 .597 r
.34888 .32686 .35008 .3177 .33975 .31751 .33843 .3306 Metetra
.973 .776 .576 r
.33843 .3306 .33975 .31751 .32945 .31019 .3276 .34158 Metetra
.961 .747 .568 r
.3276 .34158 .32945 .31019 .31888 .30732 .31687 .34239 Metetra
.959 .743 .569 r
.31687 .34239 .31888 .30732 .30824 .30176 .30617 .33665 Metetra
.958 .743 .57 r
.30617 .33665 .30824 .30176 .29754 .29296 .29538 .32895 Metetra
.958 .742 .57 r
.29538 .32895 .29754 .29296 .28652 .28955 .28446 .32041 Metetra
.957 .743 .573 r
.28446 .32041 .28652 .28955 .27555 .27962 .27344 .31049 Metetra
.957 .743 .573 r
.27344 .31049 .27555 .27962 .26468 .26309 .26224 .30122 Metetra
.956 .74 .571 r
.26224 .30122 .26468 .26309 .25343 .25283 .25112 .28603 Metetra
.957 .742 .572 r
.25112 .28603 .25343 .25283 .24196 .24436 .23971 .27435 Metetra
.956 .742 .575 r
.23971 .27435 .24196 .24436 .23033 .23533 .2282 .26134 Metetra
.959 .748 .574 r
.2282 .26134 .23033 .23533 .21851 .22712 .21613 .25723 Metetra
.96 .747 .571 r
.21613 .25723 .21851 .22712 .20612 .2271 .20379 .25498 Metetra
.96 .748 .573 r
.20379 .25498 .20612 .2271 .19313 .23534 .1913 .25141 Metetra
.943 .739 .598 r
.1913 .25141 .19313 .23534 .18185 .20414 .17966 .22687 Metetra
.949 .74 .585 r
.17966 .22687 .18185 .20414 .1695 .19168 .16778 .20452 Metetra
.956 .759 .597 r
.16778 .20452 .1695 .19168 .15694 .17985 .1549 .19788 Metetra
.95 .745 .59 r
.1549 .19788 .15694 .17985 .14423 .16725 .14241 .18069 Metetra
.949 .748 .596 r
.3987 .3626 .39988 .34933 .39051 .33507 .38927 .3507 Metetra
.943 .738 .596 r
.38927 .3507 .39051 .33507 .38095 .3259 .3799 .33026 Metetra
.937 .78 .662 r
.3799 .33026 .38095 .3259 .37125 .31754 .37019 .32207 Metetra
.94 .782 .658 r
.37019 .32207 .37125 .31754 .3614 .31001 .36033 .3145 Metetra
.971 .825 .641 r
.36033 .3145 .3614 .31001 .35143 .30191 .35008 .3177 Metetra
.962 .758 .582 r
.35008 .3177 .35143 .30191 .34115 .30099 .33975 .31751 Metetra
.956 .751 .586 r
.33975 .31751 .34115 .30099 .33079 .29705 .32945 .31019 Metetra
.96 .76 .59 r
.32945 .31019 .33079 .29705 .32029 .29291 .31888 .30732 Metetra
.957 .755 .589 r
.31888 .30732 .32029 .29291 .30971 .28606 .30824 .30176 Metetra
.955 .751 .589 r
.30824 .30176 .30971 .28606 .29885 .28338 .29754 .29296 Metetra
.958 .769 .605 r
.29754 .29296 .29885 .28338 .28766 .2855 .28652 .28955 Metetra
.93 .782 .675 r
.28652 .28955 .28766 .2855 .27673 .27479 .27555 .27962 Metetra
.919 .756 .664 r
.27555 .27962 .27673 .27479 .26588 .25803 .26468 .26309 Metetra
.937 .775 .655 r
.26468 .26309 .26588 .25803 .2547 .2465 .25343 .25283 Metetra
.946 .774 .636 r
.25343 .25283 .2547 .2465 .24327 .23713 .24196 .24436 Metetra
.947 .769 .628 r
.24196 .24436 .24327 .23713 .23158 .23033 .23033 .23533 Metetra
.942 .784 .656 r
.23033 .23533 .23158 .23033 .21973 .22275 .21851 .22712 Metetra
.961 .821 .659 r
.21851 .22712 .21973 .22275 .20768 .21583 .20612 .2271 Metetra
.972 .781 .588 r
.20612 .2271 .20768 .21583 .1951 .21604 .19313 .23534 Metetra
.942 .734 .594 r
.19313 .23534 .1951 .21604 .18317 .19867 .18185 .20414 Metetra
.935 .771 .653 r
.18185 .20414 .18317 .19867 .17069 .18916 .1695 .19168 Metetra
.902 .797 .734 r
.1695 .19168 .17069 .18916 .15792 .18134 .15694 .17985 Metetra
.776 .304 0 r
.15694 .17985 .15792 .18134 .14546 .16413 .14423 .16725 Metetra
.973 .71 .474 r
.39988 .34933 .40067 .35882 .3912 .34987 .39051 .33507 Metetra
.964 .717 .512 r
.39051 .33507 .3912 .34987 .38163 .34029 .38095 .3259 Metetra
.964 .715 .512 r
.38095 .3259 .38163 .34029 .3719 .33262 .37125 .31754 Metetra
.963 .715 .515 r
.37125 .31754 .3719 .33262 .36202 .32547 .3614 .31001 Metetra
.963 .716 .515 r
.3614 .31001 .36202 .32547 .35195 .32103 .35143 .30191 Metetra
.958 .715 .529 r
.35143 .30191 .35195 .32103 .34166 .3194 .34115 .30099 Metetra
.96 .716 .525 r
.34115 .30099 .34166 .3194 .33093 .32856 .33079 .29705 Metetra
.96 .724 .537 r
.33079 .29705 .33093 .32856 .32042 .32281 .32029 .29291 Metetra
.961 .724 .535 r
.32029 .29291 .32042 .32281 .30976 .31737 .30971 .28606 Metetra
.959 .723 .537 r
.30971 .28606 .30976 .31737 .29873 .31859 .29885 .28338 Metetra
.958 .723 .541 r
.29885 .28338 .29873 .31859 .28754 .31925 .28766 .2855 Metetra
.962 .727 .535 r
.28766 .2855 .28754 .31925 .27687 .29977 .27673 .27479 Metetra
.966 .727 .524 r
.27673 .27479 .27687 .29977 .26591 .2848 .26588 .25803 Metetra
.963 .725 .529 r
.26588 .25803 .26591 .2848 .25474 .27194 .2547 .2465 Metetra
.962 .723 .529 r
.2547 .2465 .25474 .27194 .24352 .25642 .24327 .23713 Metetra
.961 .717 .523 r
.24327 .23713 .24352 .25642 .23191 .24683 .23158 .23033 Metetra
.962 .715 .517 r
.23158 .23033 .23191 .24683 .22014 .23704 .21973 .22275 Metetra
.961 .711 .512 r
.21973 .22275 .22014 .23704 .20777 .23658 .20768 .21583 Metetra
.957 .714 .53 r
.20768 .21583 .20777 .23658 .19532 .23343 .1951 .21604 Metetra
.968 .721 .51 r
.1951 .21604 .19532 .23343 .18305 .22237 .18317 .19867 Metetra
.962 .721 .527 r
.18317 .19867 .18305 .22237 .17145 .19473 .17069 .18916 Metetra
.959 .666 .435 r
.17069 .18916 .17145 .19473 .15861 .18825 .15792 .18134 Metetra
.973 .691 .431 r
.15792 .18134 .15861 .18825 .1462 .16996 .14546 .16413 Metetra
.864 .424 .022 r
.40067 .35882 .4016 .36049 .39215 .35057 .3912 .34987 Metetra
0 .246 .73 r
.3912 .34987 .39215 .35057 .38258 .34082 .38163 .34029 Metetra
0 .33 .766 r
.38163 .34029 .38258 .34082 .37285 .33343 .3719 .33262 Metetra
.541 0 0 r
.3719 .33262 .37285 .33343 .36293 .3285 .36202 .32547 Metetra
.942 .606 .361 r
.36202 .32547 .36293 .3285 .35285 .32422 .35195 .32103 Metetra
.935 .609 .395 r
.35195 .32103 .35285 .32422 .34235 .33093 .34166 .3194 Metetra
.944 .692 .526 r
.34166 .3194 .34235 .33093 .33109 .35946 .33093 .32856 Metetra
.961 .724 .536 r
.33093 .32856 .33109 .35946 .32045 .35679 .32042 .32281 Metetra
.961 .725 .537 r
.32042 .32281 .32045 .35679 .3102 .33608 .30976 .31737 Metetra
.956 .713 .529 r
.30976 .31737 .3102 .33608 .29895 .34332 .29873 .31859 Metetra
.957 .718 .535 r
.29873 .31859 .29895 .34332 .28719 .36013 .28754 .31925 Metetra
.965 .731 .535 r
.28754 .31925 .28719 .36013 .27692 .32723 .27687 .29977 Metetra
.965 .727 .528 r
.27687 .29977 .27692 .32723 .2667 .29098 .26591 .2848 Metetra
.97 .684 .43 r
.26591 .2848 .2667 .29098 .25549 .27887 .25474 .27194 Metetra
.973 .693 .436 r
.25474 .27194 .25549 .27887 .24428 .26297 .24352 .25642 Metetra
.964 .683 .45 r
.24352 .25642 .24428 .26297 .23263 .25429 .23191 .24683 Metetra
.965 .69 .463 r
.23191 .24683 .23263 .25429 .22081 .24543 .22014 .23704 Metetra
.952 .684 .493 r
.22014 .23704 .22081 .24543 .20851 .24328 .20777 .23658 Metetra
.953 .674 .47 r
.20777 .23658 .20851 .24328 .19544 .25293 .19532 .23343 Metetra
.964 .719 .52 r
.19532 .23343 .19544 .25293 .18325 .23964 .18305 .22237 Metetra
.975 .728 .499 r
.18305 .22237 .18325 .23964 .17253 .19428 .17145 .19473 Metetra
.681 .876 .972 r
.17145 .19473 .17253 .19428 .15955 .19039 .15861 .18825 Metetra
.846 .436 0 r
.15861 .18825 .15955 .19039 .14722 .17084 .1462 .16996 Metetra
.968 .684 .438 r
.4016 .36049 .40246 .36644 .39305 .35392 .39215 .35057 Metetra
.958 .625 .326 r
.39215 .35057 .39305 .35392 .38345 .3459 .38258 .34082 Metetra
.962 .669 .429 r
.38258 .34082 .38345 .3459 .37371 .33853 .37285 .33343 Metetra
.957 .665 .442 r
.37285 .33343 .37371 .33853 .3638 .33278 .36293 .3285 Metetra
.952 .648 .422 r
.36293 .3285 .3638 .33278 .3537 .32977 .35285 .32422 Metetra
.931 .653 .492 r
.35285 .32422 .3537 .32977 .34348 .32519 .34235 .33093 Metetra
.993 .863 .522 r
.34235 .33093 .34348 .32519 .3326 .33997 .33109 .35946 Metetra
.96 .752 .578 r
.33109 .35946 .3326 .33997 .32223 .32917 .32045 .35679 Metetra
.951 .738 .579 r
.32045 .35679 .32223 .32917 .31147 .32703 .3102 .33608 Metetra
.974 .789 .593 r
.3102 .33608 .31147 .32703 .30028 .33321 .29895 .34332 Metetra
.984 .798 .576 r
.29895 .34332 .30028 .33321 .28862 .34767 .28719 .36013 Metetra
.928 .728 .613 r
.28719 .36013 .28862 .34767 .2784 .31397 .27692 .32723 Metetra
.927 .725 .611 r
.27692 .32723 .2784 .31397 .26788 .28663 .2667 .29098 Metetra
.927 .774 .671 r
.2667 .29098 .26788 .28663 .25686 .26998 .25549 .27887 Metetra
.94 .752 .62 r
.25549 .27887 .25686 .26998 .24537 .26159 .24428 .26297 Metetra
.865 .834 .814 r
.24428 .26297 .24537 .26159 .23395 .2473 .23263 .25429 Metetra
.948 .771 .63 r
.23263 .25429 .23395 .2473 .22214 .2386 .22081 .24543 Metetra
.96 .787 .625 r
.22081 .24543 .22214 .2386 .20976 .23868 .20851 .24328 Metetra
.983 .852 .634 r
.20851 .24328 .20976 .23868 .19709 .2402 .19544 .25293 Metetra
.95 .752 .601 r
.19544 .25293 .19709 .2402 .1847 .23165 .18325 .23964 Metetra
.895 .707 .64 r
.18325 .23964 .1847 .23165 .17305 .20482 .17253 .19428 Metetra
.957 .697 .499 r
.17253 .19428 .17305 .20482 .16035 .19543 .15955 .19039 Metetra
.974 .668 .359 r
.15955 .19039 .16035 .19543 .14768 .18189 .14722 .17084 Metetra
.971 .663 .37 r
.40246 .36644 .40334 .37092 .39398 .35572 .39305 .35392 Metetra
.893 .471 .108 r
.39305 .35392 .39398 .35572 .38444 .34468 .38345 .3459 Metetra
.86 .834 .819 r
.38345 .3459 .38444 .34468 .3747 .33733 .37371 .33853 Metetra
.869 .858 .828 r
.37371 .33853 .3747 .33733 .36479 .33212 .3638 .33278 Metetra
.779 .927 .932 r
.3638 .33278 .36479 .33212 .35474 .32702 .3537 .32977 Metetra
.936 .824 .71 r
.3537 .32977 .35474 .32702 .34447 .32508 .34348 .32519 Metetra
.469 .069 .199 r
.34348 .32519 .34447 .32508 .33374 .33452 .3326 .33997 Metetra
.937 .769 .648 r
.3326 .33997 .33374 .33452 .3232 .33025 .32223 .32917 Metetra
.801 .317 .052 r
.32223 .32917 .3232 .33025 .31261 .32235 .31147 .32703 Metetra
.978 .835 .633 r
.31147 .32703 .31261 .32235 .30162 .32279 .30028 .33321 Metetra
.981 .793 .578 r
.30028 .33321 .30162 .32279 .28947 .35256 .28862 .34767 Metetra
.943 .643 .192 r
.28862 .34767 .28947 .35256 .27973 .305 .2784 .31397 Metetra
.923 .733 .627 r
.2784 .31397 .27973 .305 .26861 .29464 .26788 .28663 Metetra
.974 .702 .45 r
.26788 .28663 .26861 .29464 .25762 .27676 .25686 .26998 Metetra
.963 .683 .457 r
.25686 .26998 .25762 .27676 .24639 .26183 .24537 .26159 Metetra
.388 .609 .937 r
.24537 .26159 .24639 .26183 .235 .24695 .23395 .2473 Metetra
.663 .824 .961 r
.23395 .2473 .235 .24695 .22312 .23996 .22214 .2386 Metetra
.84 .404 .192 r
.22214 .2386 .22312 .23996 .21052 .24491 .20976 .23868 Metetra
.944 .663 .476 r
.20976 .23868 .21052 .24491 .1975 .25381 .19709 .2402 Metetra
.963 .71 .507 r
.19709 .2402 .1975 .25381 .18623 .22194 .1847 .23165 Metetra
.929 .737 .622 r
.1847 .23165 .18623 .22194 .17396 .20761 .17305 .20482 Metetra
.939 .574 .276 r
.17305 .20482 .17396 .20761 .16149 .19387 .16035 .19543 Metetra
.853 .796 .794 r
.16035 .19543 .16149 .19387 .14882 .18046 .14768 .18189 Metetra
.928 .751 .641 r
.40334 .37092 .40439 .36481 .39496 .35442 .39398 .35572 Metetra
.845 .787 .796 r
.39398 .35572 .39496 .35442 .38538 .34588 .38444 .34468 Metetra
.768 .272 0 r
.38444 .34468 .38538 .34588 .37565 .33821 .3747 .33733 Metetra
.681 .141 0 r
.3747 .33733 .37565 .33821 .36576 .33255 .36479 .33212 Metetra
0 .33 .699 r
.36479 .33212 .36576 .33255 .35563 .33098 .35474 .32702 Metetra
.944 .636 .425 r
.35474 .32702 .35563 .33098 .34547 .32437 .34447 .32508 Metetra
.34447 .32508 .34547 .32437 .33438 .34772 .33374 .33452 Metetra
.96 .709 .512 r
.33374 .33452 .33438 .34772 .3242 .33024 .3232 .33025 Metetra
.471 .752 .991 r
.3232 .33025 .3242 .33024 .3137 .31928 .31261 .32235 Metetra
.959 .85 .691 r
.31261 .32235 .3137 .31928 .30259 .32396 .30162 .32279 Metetra
.725 .427 .473 r
.30162 .32279 .30259 .32396 .29043 .35447 .28947 .35256 Metetra
.163 .21 .664 r
.28947 .35256 .29043 .35447 .28102 .2971 .27973 .305 Metetra
.947 .763 .622 r
.27973 .305 .28102 .2971 .27001 .2842 .26861 .29464 Metetra
.941 .747 .613 r
.26861 .29464 .27001 .2842 .25886 .27124 .25762 .27676 Metetra
.929 .761 .652 r
.25762 .27676 .25886 .27124 .24746 .26072 .24639 .26183 Metetra
.808 .769 .816 r
.24639 .26183 .24746 .26072 .23606 .24637 .235 .24695 Metetra
.741 .868 .94 r
.235 .24695 .23606 .24637 .22422 .23854 .22312 .23996 Metetra
.894 .986 .794 r
.22312 .23996 .22422 .23854 .21187 .23819 .21052 .24491 Metetra
.979 .814 .61 r
.21052 .24491 .21187 .23819 .19876 .24949 .1975 .25381 Metetra
.877 .716 .677 r
.1975 .25381 .19876 .24949 .18709 .22602 .18623 .22194 Metetra
.964 .641 .34 r
.18623 .22194 .18709 .22602 .17508 .20653 .17396 .20761 Metetra
.811 .791 .834 r
.17396 .20761 .17508 .20653 .16249 .19517 .16149 .19387 Metetra
.667 .182 0 r
.16149 .19387 .16249 .19517 .14996 .17923 .14882 .18046 Metetra
.954 .606 .283 r
.40439 .36481 .4053 .36783 .39592 .35439 .39496 .35442 Metetra
.525 .745 .975 r
.39496 .35442 .39592 .35439 .38632 .34697 .38538 .34588 Metetra
.706 .194 0 r
.38538 .34588 .38632 .34697 .37659 .33958 .37565 .33821 Metetra
.843 .378 .034 r
.37565 .33821 .37659 .33958 .36674 .33212 .36576 .33255 Metetra
.642 .935 .967 r
.36576 .33255 .36674 .33212 .35675 .32463 .35563 .33098 Metetra
.95 .775 .631 r
.35563 .33098 .35675 .32463 .34658 .3191 .34547 .32437 Metetra
.995 .867 .548 r
.34547 .32437 .34658 .3191 .33626 .31391 .33438 .34772 Metetra
.955 .739 .573 r
.33438 .34772 .33626 .31391 .32584 .30697 .3242 .33024 Metetra
.956 .745 .578 r
.3242 .33024 .32584 .30697 .31517 .30352 .3137 .31928 Metetra
.967 .764 .578 r
.3137 .31928 .31517 .30352 .30399 .31121 .30259 .32396 Metetra
.991 .799 .551 r
.30259 .32396 .30399 .31121 .29313 .30317 .29043 .35447 Metetra
.946 .728 .575 r
.29043 .35447 .29313 .30317 .28232 .28877 .28102 .2971 Metetra
.944 .757 .621 r
.28102 .2971 .28232 .28877 .27167 .26651 .27001 .2842 Metetra
.953 .747 .587 r
.27001 .2842 .27167 .26651 .2604 .25762 .25886 .27124 Metetra
.953 .753 .595 r
.25886 .27124 .2604 .25762 .24895 .24908 .24746 .26072 Metetra
.948 .751 .605 r
.24746 .26072 .24895 .24908 .2374 .23902 .23606 .24637 Metetra
.951 .772 .625 r
.23606 .24637 .2374 .23902 .22538 .23574 .22422 .23854 Metetra
.952 .861 .712 r
.22422 .23854 .22538 .23574 .21321 .23171 .21187 .23819 Metetra
.983 .823 .607 r
.21187 .23819 .21321 .23171 .20083 .22779 .19876 .24949 Metetra
.949 .739 .586 r
.19876 .24949 .20083 .22779 .18891 .21024 .18709 .22602 Metetra
.948 .744 .595 r
.18709 .22602 .18891 .21024 .17654 .19861 .17508 .20653 Metetra
.947 .765 .625 r
.17508 .20653 .17654 .19861 .16416 .18369 .16249 .19517 Metetra
.947 .752 .607 r
.16249 .19517 .16416 .18369 .15144 .17169 .14996 .17923 Metetra
.939 .753 .625 r
.4053 .36783 .40638 .36021 .39694 .3508 .39592 .35439 Metetra
.934 .791 .679 r
.39592 .35439 .39694 .3508 .38737 .34255 .38632 .34697 Metetra
.94 .784 .66 r
.38632 .34697 .38737 .34255 .37766 .33496 .37659 .33958 Metetra
.941 .783 .656 r
.37659 .33958 .37766 .33496 .36782 .32729 .36674 .33212 Metetra
.942 .781 .653 r
.36674 .33212 .36782 .32729 .35785 .3197 .35675 .32463 Metetra
.948 .788 .649 r
.35675 .32463 .35785 .3197 .34774 .31204 .34658 .3191 Metetra
.954 .775 .622 r
.34658 .3191 .34774 .31204 .33753 .3032 .33626 .31391 Metetra
.955 .76 .601 r
.33626 .31391 .33753 .3032 .32709 .29792 .32584 .30697 Metetra
.959 .771 .606 r
.32584 .30697 .32709 .29792 .31655 .29047 .31517 .30352 Metetra
.971 .773 .58 r
.31517 .30352 .31655 .29047 .30581 .28509 .30399 .31121 Metetra
.958 .746 .574 r
.30399 .31121 .30581 .28509 .29465 .28735 .29313 .30317 Metetra
.951 .747 .592 r
.29313 .30317 .29465 .28735 .28403 .26862 .28232 .28877 Metetra
.948 .739 .587 r
.28232 .28877 .28403 .26862 .27296 .25887 .27167 .26651 Metetra
.949 .767 .623 r
.27167 .26651 .27296 .25887 .26173 .24952 .2604 .25762 Metetra
.95 .767 .619 r
.2604 .25762 .26173 .24952 .25031 .24075 .24895 .24908 Metetra
.949 .764 .619 r
.24895 .24908 .25031 .24075 .23872 .23193 .2374 .23902 Metetra
.958 .783 .623 r
.2374 .23902 .23872 .23193 .22693 .22391 .22538 .23574 Metetra
.959 .764 .596 r
.22538 .23574 .22693 .22391 .21457 .22466 .21321 .23171 Metetra
.957 .783 .625 r
.21321 .23171 .21457 .22466 .20215 .22192 .20083 .22779 Metetra
.927 .756 .65 r
.20083 .22779 .20215 .22192 .19 .20959 .18891 .21024 Metetra
.749 .806 .898 r
.18891 .21024 .19 .20959 .17786 .1935 .17654 .19861 Metetra
.928 .767 .661 r
.17654 .19861 .17786 .1935 .16533 .18173 .16416 .18369 Metetra
.883 .805 .768 r
.16416 .18369 .16533 .18173 .15251 .17167 .15144 .17169 Metetra
.781 .311 0 r
.40638 .36021 .40731 .3616 .39792 .34966 .39694 .3508 Metetra
.848 .822 .823 r
.39694 .3508 .39792 .34966 .38834 .34225 .38737 .34255 Metetra
.667 .817 .955 r
.38737 .34255 .38834 .34225 .37863 .33493 .37766 .33496 Metetra
.503 .759 .988 r
.37766 .33496 .37863 .33493 .36876 .32873 .36782 .32729 Metetra
.835 .37 0 r
.36782 .32729 .36876 .32873 .35871 .3247 .35785 .3197 Metetra
.962 .666 .423 r
.35785 .3197 .35871 .3247 .34836 .32688 .34774 .31204 Metetra
.964 .715 .511 r
.34774 .31204 .34836 .32688 .33689 .36578 .33753 .3032 Metetra
.961 .73 .544 r
.33753 .3032 .33689 .36578 .32696 .33849 .32709 .29792 Metetra
.962 .728 .538 r
.32709 .29792 .32696 .33849 .316 .34373 .31655 .29047 Metetra
.961 .729 .542 r
.31655 .29047 .316 .34373 .30514 .33935 .30581 .28509 Metetra
.959 .727 .544 r
.30581 .28509 .30514 .33935 .29372 .34713 .29465 .28735 Metetra
.964 .732 .54 r
.29465 .28735 .29372 .34713 .28316 .32379 .28403 .26862 Metetra
.962 .73 .541 r
.28403 .26862 .28316 .32379 .27199 .31445 .27296 .25887 Metetra
.962 .73 .541 r
.27296 .25887 .27199 .31445 .26117 .29168 .26173 .24952 Metetra
.962 .728 .538 r
.26173 .24952 .26117 .29168 .25038 .26502 .25031 .24075 Metetra
.963 .722 .527 r
.25031 .24075 .25038 .26502 .23881 .255 .23872 .23193 Metetra
.962 .721 .526 r
.23872 .23193 .23881 .255 .22731 .23915 .22693 .22391 Metetra
.956 .707 .52 r
.22693 .22391 .22731 .23915 .21503 .23775 .21457 .22466 Metetra
.958 .705 .511 r
.21457 .22466 .21503 .23775 .20108 .26756 .20215 .22192 Metetra
.963 .729 .538 r
.20215 .22192 .20108 .26756 .18948 .24202 .19 .20959 Metetra
.965 .728 .53 r
.19 .20959 .18948 .24202 .17803 .21105 .17786 .1935 Metetra
.965 .718 .514 r
.17786 .1935 .17803 .21105 .16581 .19281 .16533 .18173 Metetra
.964 .704 .492 r
.16533 .18173 .16581 .19281 .15367 .17006 .15251 .17167 Metetra
.971 .705 .472 r
.40731 .3616 .40813 .37042 .3988 .35458 .39792 .34966 Metetra
.962 .666 .423 r
.39792 .34966 .3988 .35458 .38923 .34639 .38834 .34225 Metetra
.96 .65 .395 r
.38834 .34225 .38923 .34639 .37952 .33895 .37863 .33493 Metetra
.956 .645 .398 r
.37863 .33493 .37952 .33895 .36965 .33292 .36876 .32873 Metetra
.951 .645 .419 r
.36876 .32873 .36965 .33292 .35949 .33329 .35871 .3247 Metetra
.949 .686 .503 r
.35871 .3247 .35949 .33329 .34919 .3335 .34836 .32688 Metetra
.876 .622 .55 r
.34836 .32688 .34919 .3335 .33836 .34752 .33689 .36578 Metetra
.942 .735 .593 r
.33689 .36578 .33836 .34752 .32802 .33619 .32696 .33849 Metetra
.964 .92 .711 r
.32696 .33849 .32802 .33619 .31736 .33134 .316 .34373 Metetra
.959 .761 .593 r
.316 .34373 .31736 .33134 .30615 .33927 .30514 .33935 Metetra
.328 0 0 r
.30514 .33935 .30615 .33927 .29445 .35618 .29372 .34713 Metetra
.981 .713 .442 r
.29372 .34713 .29445 .35618 .28443 .3164 .28316 .32379 Metetra
.948 .767 .625 r
.28316 .32379 .28443 .3164 .27365 .29653 .27199 .31445 Metetra
.946 .739 .592 r
.27199 .31445 .27365 .29653 .26225 .29015 .26117 .29168 Metetra
.793 .691 .752 r
.26117 .29168 .26225 .29015 .25125 .26922 .25038 .26502 Metetra
.961 .644 .376 r
.25038 .26502 .25125 .26922 .2398 .25604 .23881 .255 Metetra
0 .1 .64 r
.23881 .255 .2398 .25604 .22801 .24728 .22731 .23915 Metetra
.953 .684 .488 r
.22731 .23915 .22801 .24728 .21561 .24807 .21503 .23775 Metetra
.918 .663 .537 r
.21503 .23775 .21561 .24807 .20264 .25673 .20108 .26756 Metetra
.934 .739 .615 r
.20108 .26756 .20264 .25673 .19076 .23738 .18948 .24202 Metetra
.885 .721 .673 r
.18948 .24202 .19076 .23738 .17893 .21429 .17803 .21105 Metetra
.947 .594 .215 r
.17803 .21105 .17893 .21429 .16646 .20064 .16581 .19281 Metetra
.979 .703 .428 r
.16581 .19281 .16646 .20064 .15402 .18324 .15367 .17006 Metetra
.223 .441 .862 r
.40813 .37042 .40908 .37105 .39973 .35664 .3988 .35458 Metetra
.915 .515 .168 r
.3988 .35458 .39973 .35664 .3902 .34627 .38923 .34639 Metetra
.565 .787 .983 r
.38923 .34639 .3902 .34627 .38049 .33887 .37952 .33895 Metetra
.495 .794 .998 r
.37952 .33895 .38049 .33887 .37061 .33355 .36965 .33292 Metetra
.679 .148 0 r
.36965 .33292 .37061 .33355 .36049 .33279 .35949 .33329 Metetra
.635 .955 .932 r
.35949 .33329 .36049 .33279 .35031 .32807 .34919 .3335 Metetra
.992 .844 .594 r
.34919 .3335 .35031 .32807 .33952 .34118 .33836 .34752 Metetra
.94 .764 .637 r
.33836 .34752 .33952 .34118 .32907 .33451 .32802 .33619 Metetra
.905 .859 .785 r
.32802 .33619 .32907 .33451 .31853 .32562 .31736 .33134 Metetra
.981 .823 .614 r
.31736 .33134 .31853 .32562 .30769 .32216 .30615 .33927 Metetra
.976 .772 .565 r
.30615 .33927 .30769 .32216 .29548 .356 .29445 .35618 Metetra
.624 .551 .752 r
.29445 .35618 .29548 .356 .28585 .30463 .28443 .3164 Metetra
.941 .744 .607 r
.28443 .3164 .28585 .30463 .27484 .29205 .27365 .29653 Metetra
.945 .794 .662 r
.27365 .29653 .27484 .29205 .26366 .28005 .26225 .29015 Metetra
.937 .744 .616 r
.26225 .29015 .26366 .28005 .25249 .26368 .25125 .26922 Metetra
.934 .767 .651 r
.25125 .26922 .25249 .26368 .24112 .24908 .2398 .25604 Metetra
.948 .772 .63 r
.2398 .25604 .24112 .24908 .22919 .24395 .22801 .24728 Metetra
.961 .85 .687 r
.22801 .24728 .22919 .24395 .21633 .25554 .21561 .24807 Metetra
.936 .666 .501 r
.21561 .24807 .21633 .25554 .2035 .26079 .20264 .25673 Metetra
.965 .638 .289 r
.20264 .25673 .2035 .26079 .1927 .21924 .19076 .23738 Metetra
.947 .741 .591 r
.19076 .23738 .1927 .21924 .18034 .20729 .17893 .21429 Metetra
.941 .764 .635 r
.17893 .21429 .18034 .20729 .16772 .19705 .16646 .20064 Metetra
.906 .765 .695 r
.16646 .20064 .16772 .19705 .15509 .18322 .15402 .18324 Metetra
0 .273 .778 r
.40908 .37105 .41003 .37191 .40065 .35909 .39973 .35664 Metetra
.933 .555 .196 r
.39973 .35664 .40065 .35909 .39117 .34599 .3902 .34627 Metetra
.654 .818 .962 r
.3902 .34627 .39117 .34599 .38147 .33861 .38049 .33887 Metetra
.617 .854 .988 r
.38049 .33887 .38147 .33861 .37152 .3365 .37061 .33355 Metetra
.929 .597 .388 r
.37061 .33355 .37152 .3365 .36143 .3345 .36049 .33279 Metetra
.892 .471 .175 r
.36049 .33279 .36143 .3345 .35132 .32675 .35031 .32807 Metetra
.613 .851 .483 r
.35031 .32807 .35132 .32675 .34046 .34326 .33952 .34118 Metetra
.915 .518 .207 r
.33952 .34118 .34046 .34326 .32999 .33727 .32907 .33451 Metetra
.943 .582 .273 r
.32907 .33451 .32999 .33727 .31943 .3294 .31853 .32562 Metetra
.945 .629 .403 r
.31853 .32562 .31943 .3294 .30852 .32809 .30769 .32216 Metetra
.878 .616 .539 r
.30769 .32216 .30852 .32809 .29658 .35344 .29548 .356 Metetra
.78 .63 .694 r
.29548 .356 .29658 .35344 .28685 .30523 .28585 .30463 Metetra
.019 .4 .853 r
.28585 .30463 .28685 .30523 .27574 .29539 .27484 .29205 Metetra
.956 .613 .297 r
.27484 .29205 .27574 .29539 .26454 .28389 .26366 .28005 Metetra
.964 .634 .296 r
.26366 .28005 .26454 .28389 .25355 .26314 .25249 .26368 Metetra
.722 .752 .876 r
.25249 .26368 .25355 .26314 .24208 .25092 .24112 .24908 Metetra
.893 .475 .186 r
.24112 .24908 .24208 .25092 .23016 .2456 .22919 .24395 Metetra
.823 .466 .381 r
.22919 .24395 .23016 .2456 .21692 .26584 .21633 .25554 Metetra
.948 .688 .51 r
.21633 .25554 .21692 .26584 .20443 .26358 .2035 .26079 Metetra
0 0 .385 r
.2035 .26079 .20443 .26358 .19364 .22172 .1927 .21924 Metetra
.926 .539 .188 r
.1927 .21924 .19364 .22172 .18146 .2062 .18034 .20729 Metetra
.827 .832 .851 r
.18034 .20729 .18146 .2062 .16882 .19632 .16772 .19705 Metetra
.759 .786 .875 r
.16772 .19705 .16882 .19632 .15634 .17995 .15509 .18322 Metetra
.75 .75 .852 r
.41003 .37191 .411 .37129 .40164 .35724 .40065 .35909 Metetra
.867 .769 .752 r
.40065 .35909 .40164 .35724 .39221 .34201 .39117 .34599 Metetra
.938 .788 .669 r
.39117 .34599 .39221 .34201 .38252 .33433 .38147 .33861 Metetra
.957 .808 .655 r
.38147 .33861 .38252 .33433 .37252 .33559 .37152 .3365 Metetra
.843 .937 .887 r
.37152 .3365 .37252 .33559 .36239 .3357 .36143 .3345 Metetra
.756 .257 0 r
.36143 .3345 .36239 .3357 .3522 .33131 .35132 .32675 Metetra
.897 .618 .505 r
.35132 .32675 .3522 .33131 .34167 .33474 .34046 .34326 Metetra
.955 .768 .612 r
.34046 .34326 .34167 .33474 .33103 .33599 .32999 .33727 Metetra
.862 .837 .82 r
.32999 .33727 .33103 .33599 .32033 .33301 .31943 .3294 Metetra
.938 .62 .41 r
.31943 .3294 .32033 .33301 .30925 .33708 .30852 .32809 Metetra
.917 .661 .536 r
.30852 .32809 .30925 .33708 .29757 .35449 .29658 .35344 Metetra
.416 .389 .721 r
.29658 .35344 .29757 .35449 .28753 .31531 .28685 .30523 Metetra
.966 .704 .486 r
.28685 .30523 .28753 .31531 .27689 .29179 .27574 .29539 Metetra
.922 .782 .689 r
.27574 .29539 .27689 .29179 .26584 .27653 .26454 .28389 Metetra
.928 .745 .635 r
.26454 .28389 .26584 .27653 .25461 .26245 .25355 .26314 Metetra
.76 .79 .877 r
.25355 .26314 .25461 .26245 .2431 .25124 .24208 .25092 Metetra
0 .45 .78 r
.24208 .25092 .2431 .25124 .23122 .24514 .23016 .2456 Metetra
.314 0 .138 r
.23016 .2456 .23122 .24514 .2184 .25624 .21692 .26584 Metetra
.961 .774 .605 r
.21692 .26584 .2184 .25624 .20536 .26636 .20443 .26358 Metetra
0 0 .389 r
.20443 .26358 .20536 .26636 .19475 .22059 .19364 .22172 Metetra
.807 .773 .821 r
.19364 .22172 .19475 .22059 .18243 .20816 .18146 .2062 Metetra
.891 .467 .11 r
.18146 .2062 .18243 .20816 .16979 .19831 .16882 .19632 Metetra
.84 .416 0 r
.16882 .19632 .16979 .19831 .15735 .18115 .15634 .17995 Metetra
0 .191 .72 r
.411 .37129 .41194 .37224 .40255 .36078 .40164 .35724 Metetra
.961 .626 .264 r
.40164 .35724 .40255 .36078 .39313 .34464 .39221 .34201 Metetra
.942 .58 .277 r
.39221 .34201 .39313 .34464 .38344 .33671 .38252 .33433 Metetra
.909 .562 .371 r
.38252 .33433 .38344 .33671 .37362 .3295 .37252 .33559 Metetra
.965 .795 .623 r
.37252 .33559 .37362 .3295 .36358 .32629 .36239 .3357 Metetra
.958 .767 .604 r
.36239 .3357 .36358 .32629 .35344 .32069 .3522 .33131 Metetra
.969 .776 .589 r
.3522 .33131 .35344 .32069 .34303 .32019 .34167 .33474 Metetra
.965 .763 .581 r
.34167 .33474 .34303 .32019 .33266 .31233 .33103 .33599 Metetra
.961 .75 .572 r
.33103 .33599 .33266 .31233 .32202 .30899 .32033 .33301 Metetra
.965 .754 .568 r
.32033 .33301 .32202 .30899 .3112 .30617 .30925 .33708 Metetra
.97 .756 .559 r
.30925 .33708 .3112 .30617 .29954 .32444 .29757 .35449 Metetra
.945 .731 .582 r
.29757 .35449 .29954 .32444 .28939 .29014 .28753 .31531 Metetra
.95 .738 .581 r
.28753 .31531 .28939 .29014 .27854 .27407 .27689 .29179 Metetra
.952 .746 .587 r
.27689 .29179 .27854 .27407 .26738 .26276 .26584 .27653 Metetra
.951 .75 .596 r
.26584 .27653 .26738 .26276 .25596 .25403 .25461 .26245 Metetra
.948 .762 .619 r
.25461 .26245 .25596 .25403 .24437 .2455 .2431 .25124 Metetra
.951 .786 .641 r
.2431 .25124 .24437 .2455 .23256 .23815 .23122 .24514 Metetra
.982 .816 .602 r
.23122 .24514 .23256 .23815 .22019 .23933 .2184 .25624 Metetra
.971 .768 .573 r
.2184 .25624 .22019 .23933 .20708 .25196 .20536 .26636 Metetra
.924 .72 .61 r
.20536 .26636 .20708 .25196 .19604 .21562 .19475 .22059 Metetra
.934 .775 .661 r
.19475 .22059 .19604 .21562 .18378 .20237 .18243 .20816 Metetra
.944 .778 .646 r
.18243 .20816 .18378 .20237 .17124 .19086 .16979 .19831 Metetra
.937 .756 .633 r
.16979 .19831 .17124 .19086 .1587 .17589 .15735 .18115 Metetra
.95 .751 .599 r
.41194 .37224 .41308 .36028 .40371 .3487 .40255 .36078 Metetra
.945 .745 .602 r
.40255 .36078 .40371 .3487 .39415 .34139 .39313 .34464 Metetra
.929 .794 .691 r
.39313 .34464 .39415 .34139 .38447 .33392 .38344 .33671 Metetra
.925 .805 .708 r
.38344 .33671 .38447 .33392 .37466 .3264 .37362 .3295 Metetra
.947 .825 .692 r
.37362 .3295 .37466 .3264 .36472 .31877 .36358 .32629 Metetra
.954 .772 .618 r
.36358 .32629 .36472 .31877 .35466 .31105 .35344 .32069 Metetra
.964 .773 .598 r
.35344 .32069 .35466 .31105 .34445 .30332 .34303 .32019 Metetra
.957 .751 .584 r
.34303 .32019 .34445 .30332 .33406 .29737 .33266 .31233 Metetra
.961 .758 .584 r
.33266 .31233 .33406 .29737 .32352 .29145 .32202 .30899 Metetra
.961 .755 .579 r
.32202 .30899 .32352 .29145 .31274 .28815 .3112 .30617 Metetra
.976 .771 .563 r
.3112 .30617 .31274 .28815 .3017 .2882 .29954 .32444 Metetra
.95 .733 .575 r
.29954 .32444 .3017 .2882 .29104 .27111 .28939 .29014 Metetra
.952 .744 .585 r
.28939 .29014 .29104 .27111 .28008 .25917 .27854 .27407 Metetra
.954 .751 .591 r
.27854 .27407 .28008 .25917 .26881 .2517 .26738 .26276 Metetra
.954 .759 .602 r
.26738 .26276 .26881 .2517 .25746 .24187 .25596 .25403 Metetra
.955 .758 .597 r
.25596 .25403 .25746 .24187 .24596 .23186 .24437 .2455 Metetra
.957 .757 .592 r
.24437 .2455 .24596 .23186 .2336 .23824 .23256 .23815 Metetra
.206 0 0 r
.23256 .23815 .2336 .23824 .22105 .24366 .22019 .23933 Metetra
.906 .612 .477 r
.22019 .23933 .22105 .24366 .20914 .22996 .20708 .25196 Metetra
.942 .732 .589 r
.20708 .25196 .20914 .22996 .19733 .21076 .19604 .21562 Metetra
.931 .773 .663 r
.19604 .21562 .19733 .21076 .18497 .19973 .18378 .20237 Metetra
.908 .8 .729 r
.18378 .20237 .18497 .19973 .17248 .18759 .17124 .19086 Metetra
.908 .777 .704 r
.17124 .19086 .17248 .18759 .15982 .17507 .1587 .17589 Metetra
.969 .716 .498 r
.41308 .36028 .41385 .37307 .40459 .35346 .40371 .3487 Metetra
.962 .663 .417 r
.40371 .3487 .40459 .35346 .395 .34824 .39415 .34139 Metetra
.965 .688 .46 r
.39415 .34139 .395 .34824 .38531 .34089 .38447 .33392 Metetra
.965 .689 .462 r
.38447 .33392 .38531 .34089 .37546 .33533 .37466 .3264 Metetra
.965 .7 .482 r
.37466 .3264 .37546 .33533 .36534 .33541 .36472 .31877 Metetra
.964 .717 .515 r
.36472 .31877 .36534 .33541 .35514 .33266 .35466 .31105 Metetra
.963 .722 .524 r
.35466 .31105 .35514 .33266 .34384 .36742 .34445 .30332 Metetra
.962 .73 .542 r
.34445 .30332 .34384 .36742 .33355 .35408 .33406 .29737 Metetra
.962 .73 .541 r
.33406 .29737 .33355 .35408 .32294 .34765 .32352 .29145 Metetra
.961 .729 .542 r
.32352 .29145 .32294 .34765 .31221 .33986 .31274 .28815 Metetra
.96 .728 .542 r
.31274 .28815 .31221 .33986 .30063 .35446 .3017 .2882 Metetra
.964 .733 .54 r
.3017 .2882 .30063 .35446 .29035 .32267 .29104 .27111 Metetra
.963 .73 .538 r
.29104 .27111 .29035 .32267 .27936 .30941 .28008 .25917 Metetra
.962 .729 .539 r
.28008 .25917 .27936 .30941 .26839 .29124 .26881 .2517 Metetra
.963 .728 .535 r
.26881 .2517 .26839 .29124 .25715 .27699 .25746 .24187 Metetra
.963 .727 .533 r
.25746 .24187 .25715 .27699 .24569 .26427 .24596 .23186 Metetra
.957 .72 .538 r
.24596 .23186 .24569 .26427 .23296 .27831 .2336 .23824 Metetra
.958 .723 .54 r
.2336 .23824 .23296 .27831 .22043 .28189 .22105 .24366 Metetra
.964 .729 .533 r
.22105 .24366 .22043 .28189 .20859 .26539 .20914 .22996 Metetra
.966 .73 .529 r
.20914 .22996 .20859 .26539 .19712 .23758 .19733 .21076 Metetra
.964 .724 .526 r
.19733 .21076 .19712 .23758 .18526 .21543 .18497 .19973 Metetra
.966 .716 .507 r
.18497 .19973 .18526 .21543 .1726 .20593 .17248 .18759 Metetra
.966 .719 .513 r
.17248 .18759 .1726 .20593 .16055 .18151 .15982 .17507 Metetra
.813 .715 .757 r
.41385 .37307 .41483 .37159 .40554 .35432 .40459 .35346 Metetra
.659 .114 0 r
.40459 .35346 .40554 .35432 .396 .34645 .395 .34824 Metetra
.897 .823 .765 r
.395 .34824 .396 .34645 .38634 .33803 .38531 .34089 Metetra
.934 .815 .704 r
.38531 .34089 .38634 .33803 .37644 .33476 .37546 .33533 Metetra
.689 .968 .931 r
.37546 .33533 .37644 .33476 .36637 .33316 .36534 .33541 Metetra
.937 .855 .736 r
.36534 .33541 .36637 .33316 .35633 .32362 .35514 .33266 Metetra
1 .829 .522 r
.35514 .33266 .35633 .32362 .34555 .33868 .34384 .36742 Metetra
.957 .742 .573 r
.34384 .36742 .34555 .33868 .33492 .34035 .33355 .35408 Metetra
.958 .757 .59 r
.33355 .35408 .33492 .34035 .32437 .33251 .32294 .34765 Metetra
.957 .754 .587 r
.32294 .34765 .32437 .33251 .31327 .33835 .31221 .33986 Metetra
.677 .878 .501 r
.31221 .33986 .31327 .33835 .30179 .35023 .30063 .35446 Metetra
.873 .709 .677 r
.30063 .35446 .30179 .35023 .29171 .31267 .29035 .32267 Metetra
.947 .755 .61 r
.29035 .32267 .29171 .31267 .2805 .30619 .27936 .30941 Metetra
.893 .754 .701 r
.27936 .30941 .2805 .30619 .26947 .28999 .26839 .29124 Metetra
.825 .776 .806 r
.26839 .29124 .26947 .28999 .25834 .27284 .25715 .27699 Metetra
.925 .776 .676 r
.25715 .27699 .25834 .27284 .24708 .25558 .24569 .26427 Metetra
.983 .806 .586 r
.24569 .26427 .24708 .25558 .23489 .25726 .23296 .27831 Metetra
.966 .757 .572 r
.23296 .27831 .23489 .25726 .22192 .27186 .22043 .28189 Metetra
.944 .752 .613 r
.22043 .28189 .22192 .27186 .21041 .24861 .20859 .26539 Metetra
.943 .737 .596 r
.20859 .26539 .21041 .24861 .19888 .2228 .19712 .23758 Metetra
.945 .743 .598 r
.19712 .23758 .19888 .2228 .18665 .20876 .18526 .21543 Metetra
.948 .775 .634 r
.18526 .21543 .18665 .20876 .17398 .19993 .1726 .20593 Metetra
.916 .743 .652 r
.1726 .20593 .17398 .19993 .16197 .17501 .16055 .18151 Metetra
.83 .734 .758 r
.41483 .37159 .41582 .37002 .40647 .35698 .40554 .35432 Metetra
.943 .581 .274 r
.40554 .35432 .40647 .35698 .39698 .34552 .396 .34645 Metetra
.821 .824 .851 r
.396 .34645 .39698 .34552 .38731 .33788 .38634 .33803 Metetra
.456 .837 .987 r
.38634 .33803 .38731 .33788 .37744 .33401 .37644 .33476 Metetra
.801 .952 .917 r
.37644 .33476 .37744 .33401 .36745 .32887 .36637 .33316 Metetra
.934 .779 .665 r
.36637 .33316 .36745 .32887 .3574 .32012 .35633 .32362 Metetra
.985 .902 .598 r
.35633 .32362 .3574 .32012 .34683 .32745 .34555 .33868 Metetra
.967 .772 .589 r
.34555 .33868 .34683 .32745 .33631 .32521 .33492 .34035 Metetra
.957 .753 .587 r
.33492 .34035 .33631 .32521 .32573 .31968 .32437 .33251 Metetra
.97 .772 .581 r
.32437 .33251 .32573 .31968 .315 .31403 .31327 .33835 Metetra
.97 .759 .563 r
.31327 .33835 .315 .31403 .30391 .3147 .30179 .35023 Metetra
.949 .732 .576 r
.30179 .35023 .30391 .3147 .29327 .29632 .29171 .31267 Metetra
.959 .754 .584 r
.29171 .31267 .29327 .29632 .28217 .28735 .2805 .30619 Metetra
.952 .745 .585 r
.2805 .30619 .28217 .28735 .27131 .26747 .26947 .28999 Metetra
.954 .743 .58 r
.26947 .28999 .27131 .26747 .25993 .25827 .25834 .27284 Metetra
.949 .746 .595 r
.25834 .27284 .25993 .25827 .2483 .25095 .24708 .25558 Metetra
.968 .825 .648 r
.24708 .25558 .2483 .25095 .23588 .25861 .23489 .25726 Metetra
.786 .429 .38 r
.23489 .25726 .23588 .25861 .22367 .2559 .22192 .27186 Metetra
.946 .741 .595 r
.22192 .27186 .22367 .2559 .21177 .24189 .21041 .24861 Metetra
.918 .738 .644 r
.21041 .24861 .21177 .24189 .1998 .22573 .19888 .2228 Metetra
.942 .576 .223 r
.19888 .2228 .1998 .22573 .18776 .20787 .18665 .20876 Metetra
.804 .853 .887 r
.18665 .20876 .18776 .20787 .17521 .1968 .17398 .19993 Metetra
.874 .735 .706 r
.17398 .19993 .17521 .1968 .16265 .18241 .16197 .17501 Metetra
.872 .769 .745 r
.41582 .37002 .41681 .36807 .40748 .35415 .40647 .35698 Metetra
.907 .777 .707 r
.40647 .35698 .40748 .35415 .39796 .34515 .39698 .34552 Metetra
.695 .823 .944 r
.39698 .34552 .39796 .34515 .38829 .33764 .38731 .33788 Metetra
.567 .869 .995 r
.38731 .33788 .38829 .33764 .37849 .33018 .37744 .33401 Metetra
.945 .802 .671 r
.37744 .33401 .37849 .33018 .36836 .33251 .36745 .32887 Metetra
.959 .632 .352 r
.36745 .32887 .36836 .33251 .35802 .33629 .3574 .32012 Metetra
.952 .706 .529 r
.3574 .32012 .35802 .33629 .34774 .33091 .34683 .32745 Metetra
.94 .618 .397 r
.34683 .32745 .34774 .33091 .33743 .32099 .33631 .32521 Metetra
.947 .798 .664 r
.33631 .32521 .33743 .32099 .32689 .31407 .32573 .31968 Metetra
.952 .785 .639 r
.32573 .31968 .32689 .31407 .31567 .32565 .315 .31403 Metetra
.955 .7 .51 r
.315 .31403 .31567 .32565 .30422 .33756 .30391 .3147 Metetra
.969 .727 .516 r
.30391 .3147 .30422 .33756 .29348 .32105 .29327 .29632 Metetra
.964 .723 .525 r
.29327 .29632 .29348 .32105 .28207 .32011 .28217 .28735 Metetra
.967 .73 .526 r
.28217 .28735 .28207 .32011 .27214 .27315 .27131 .26747 Metetra
.964 .672 .428 r
.27131 .26747 .27214 .27315 .26077 .26336 .25993 .25827 Metetra
.959 .66 .421 r
.25993 .25827 .26077 .26336 .24901 .25938 .2483 .25095 Metetra
.941 .675 .505 r
.2483 .25095 .24901 .25938 .22897 .45118 .23588 .25861 Metetra
.961 .733 .548 r
.23588 .25861 .22897 .45118 .22105 .34088 .22367 .2559 Metetra
.963 .733 .542 r
.22367 .2559 .22105 .34088 .2123 .2535 .21177 .24189 Metetra
.971 .712 .483 r
.21177 .24189 .2123 .2535 .20111 .22041 .1998 .22573 Metetra
.924 .759 .658 r
.1998 .22573 .20111 .22041 .18869 .21058 .18776 .20787 Metetra
.936 .561 .234 r
.18776 .20787 .18869 .21058 .17613 .19965 .17521 .1968 Metetra
.938 .567 .208 r
.17521 .1968 .17613 .19965 .16357 .18532 .16265 .18241 Metetra
.942 .584 .196 r
.41681 .36807 .41773 .37099 .40836 .35961 .40748 .35415 Metetra
.967 .676 .425 r
.40748 .35415 .40836 .35961 .39887 .34859 .39796 .34515 Metetra
.955 .626 .352 r
.39796 .34515 .39887 .34859 .3892 .34088 .38829 .33764 Metetra
.953 .616 .336 r
.38829 .33764 .3892 .34088 .37933 .33714 .37849 .33018 Metetra
.947 .675 .49 r
.37849 .33018 .37933 .33714 .36928 .33544 .36836 .33251 Metetra
.912 .589 .419 r
.36836 .33251 .36928 .33544 .35917 .3293 .35802 .33629 Metetra
.955 .776 .622 r
.35802 .33629 .35917 .3293 .34865 .33426 .34774 .33091 Metetra
.956 .617 .317 r
.34774 .33091 .34865 .33426 .33814 .33184 .33743 .32099 Metetra
.964 .705 .495 r
.33743 .32099 .33814 .33184 .32774 .31989 .32689 .31407 Metetra
.923 .647 .5 r
.32689 .31407 .32774 .31989 .31726 .30598 .31567 .32565 Metetra
.972 .764 .566 r
.31567 .32565 .31726 .30598 .30619 .3067 .30422 .33756 Metetra
.956 .741 .572 r
.30422 .33756 .30619 .3067 .29557 .2882 .29348 .32105 Metetra
.963 .747 .565 r
.29348 .32105 .29557 .2882 .28446 .28051 .28207 .32011 Metetra
.947 .73 .576 r
.28207 .32011 .28446 .28051 .27341 .26644 .27214 .27315 Metetra
.947 .771 .632 r
.27214 .27315 .27341 .26644 .26204 .25708 .26077 .26336 Metetra
.957 .788 .631 r
.26077 .26336 .26204 .25708 .25045 .24913 .24901 .25938 Metetra
0 0 .273 r
.24901 .25938 .25045 .24913 .23737 .27337 .22897 .45118 Metetra
.954 .73 .56 r
.22897 .45118 .23737 .27337 .22563 .25924 .22105 .34088 Metetra
.949 .727 .568 r
.22105 .34088 .22563 .25924 .21456 .2267 .2123 .2535 Metetra
.948 .735 .581 r
.2123 .2535 .21456 .2267 .20247 .21399 .20111 .22041 Metetra
.947 .775 .637 r
.20111 .22041 .20247 .21399 .19003 .20503 .18869 .21058 Metetra
.941 .777 .65 r
.18869 .21058 .19003 .20503 .17722 .19935 .17613 .19965 Metetra
.646 .748 .924 r
.17613 .19965 .17722 .19935 .16456 .18693 .16357 .18532 Metetra
.616 .149 0 r
.41773 .37099 .41867 .37223 .40928 .36238 .40836 .35961 Metetra
.945 .582 .232 r
.40836 .35961 .40928 .36238 .39974 .35457 .39887 .34859 Metetra
.965 .68 .443 r
.39887 .34859 .39974 .35457 .39007 .34688 .3892 .34088 Metetra
.957 .675 .46 r
.3892 .34088 .39007 .34688 .38026 .33977 .37933 .33714 Metetra
.927 .579 .354 r
.37933 .33714 .38026 .33977 .37034 .33191 .36928 .33544 Metetra
.94 .803 .681 r
.36928 .33544 .37034 .33191 .36027 .32436 .35917 .3293 Metetra
.977 .827 .628 r
.35917 .3293 .36027 .32436 .34993 .32266 .34865 .33426 Metetra
.962 .765 .592 r
.34865 .33426 .34993 .32266 .33949 .31856 .33814 .33184 Metetra
.952 .751 .595 r
.33814 .33184 .33949 .31856 .32868 .32225 .32774 .31989 Metetra
.905 .512 .093 r
.32774 .31989 .32868 .32225 .3181 .31162 .31726 .30598 Metetra
.945 .66 .467 r
.31726 .30598 .3181 .31162 .30757 .29492 .30619 .3067 Metetra
.944 .746 .605 r
.30619 .3067 .30757 .29492 .29637 .29507 .29557 .2882 Metetra
.963 .684 .456 r
.29557 .2882 .29637 .29507 .28554 .27867 .28446 .28051 Metetra
.865 .779 .763 r
.28446 .28051 .28554 .27867 .27446 .26575 .27341 .26644 Metetra
.77 .83 .899 r
.27341 .26644 .27446 .26575 .2631 .25636 .26204 .25708 Metetra
.779 .855 .907 r
.26204 .25708 .2631 .25636 .25144 .25054 .25045 .24913 Metetra
.759 .439 .444 r
.25045 .24913 .25144 .25054 .23905 .25788 .23737 .27337 Metetra
.953 .749 .591 r
.23737 .27337 .23905 .25788 .22724 .24634 .22563 .25924 Metetra
.933 .732 .609 r
.22563 .25924 .22724 .24634 .21525 .23501 .21456 .2267 Metetra
.969 .697 .46 r
.21456 .2267 .21525 .23501 .2035 .21479 .20247 .21399 Metetra
.477 0 0 r
.20247 .21399 .2035 .21479 .19111 .20472 .19003 .20503 Metetra
.601 .871 .993 r
.19003 .20503 .19111 .20472 .1786 .19326 .17722 .19935 Metetra
.941 .772 .644 r
.17722 .19935 .1786 .19326 .16617 .17667 .16456 .18693 Metetra
.951 .756 .603 r
.41867 .37223 .41977 .36196 .41035 .35574 .40928 .36238 Metetra
.949 .77 .627 r
.40928 .36238 .41035 .35574 .40088 .34444 .39974 .35457 Metetra
.954 .76 .602 r
.39974 .35457 .40088 .34444 .39122 .33692 .39007 .34688 Metetra
.955 .762 .603 r
.39007 .34688 .39122 .33692 .38147 .32811 .38026 .33977 Metetra
.955 .757 .596 r
.38026 .33977 .38147 .32811 .37154 .32175 .37034 .33191 Metetra
.955 .761 .602 r
.37034 .33191 .37154 .32175 .36154 .312 .36027 .32436 Metetra
.963 .764 .588 r
.36027 .32436 .36154 .312 .35137 .30426 .34993 .32266 Metetra
.961 .753 .578 r
.34993 .32266 .35137 .30426 .34102 .298 .33949 .31856 Metetra
.966 .757 .57 r
.33949 .31856 .34102 .298 .33047 .29351 .32868 .32225 Metetra
.958 .744 .571 r
.32868 .32225 .33047 .29351 .31976 .28914 .3181 .31162 Metetra
.954 .743 .58 r
.3181 .31162 .31976 .28914 .30884 .28664 .30757 .29492 Metetra
.966 .783 .606 r
.30757 .29492 .30884 .28664 .29816 .27112 .29637 .29507 Metetra
.955 .743 .578 r
.29637 .29507 .29816 .27112 .28712 .26233 .28554 .27867 Metetra
.954 .749 .588 r
.28554 .27867 .28712 .26233 .2761 .24869 .27446 .26575 Metetra
.957 .752 .584 r
.27446 .26575 .2761 .24869 .26469 .24142 .2631 .25636 Metetra
.96 .757 .586 r
.2631 .25636 .26469 .24142 .25317 .23291 .25144 .25054 Metetra
.969 .765 .572 r
.25144 .25054 .25317 .23291 .24085 .23941 .23905 .25788 Metetra
.956 .749 .583 r
.23905 .25788 .24085 .23941 .22882 .23393 .22724 .24634 Metetra
.954 .756 .598 r
.22724 .24634 .22882 .23393 .21692 .2212 .21525 .23501 Metetra
.946 .745 .599 r
.21525 .23501 .21692 .2212 .20489 .20763 .2035 .21479 Metetra
.948 .771 .629 r
.2035 .21479 .20489 .20763 .19266 .19478 .19111 .20472 Metetra
.951 .761 .61 r
.19111 .20472 .19266 .19478 .17985 .18969 .1786 .19326 Metetra
.909 .77 .695 r
.1786 .19326 .17985 .18969 .16784 .1654 .16617 .17667 Metetra
.935 .805 .693 r
.41977 .36196 .42078 .35885 .4114 .34991 .41035 .35574 Metetra
.938 .764 .64 r
.41035 .35574 .4114 .34991 .4019 .34091 .40088 .34444 Metetra
.934 .794 .681 r
.40088 .34444 .4019 .34091 .39226 .33374 .39122 .33692 Metetra
.925 .792 .694 r
.39122 .33692 .39226 .33374 .38249 .32609 .38147 .32811 Metetra
.912 .829 .751 r
.38147 .32811 .38249 .32609 .37253 .32106 .37154 .32175 Metetra
.774 .807 .879 r
.37154 .32175 .37253 .32106 .36232 .32155 .36154 .312 Metetra
.965 .702 .485 r
.36154 .312 .36232 .32155 .35193 .32221 .35137 .30426 Metetra
.963 .718 .518 r
.35137 .30426 .35193 .32221 .34111 .33333 .34102 .298 Metetra
.962 .726 .534 r
.34102 .298 .34111 .33333 .33033 .33591 .33047 .29351 Metetra
.962 .728 .537 r
.33047 .29351 .33033 .33591 .31967 .32771 .31976 .28914 Metetra
.961 .726 .536 r
.31976 .28914 .31967 .32771 .30867 .32559 .30884 .28664 Metetra
.966 .73 .531 r
.30884 .28664 .30867 .32559 .29773 .31651 .29816 .27112 Metetra
.963 .729 .536 r
.29816 .27112 .29773 .31651 .28672 .30479 .28712 .26233 Metetra
.965 .73 .533 r
.28712 .26233 .28672 .30479 .27593 .28257 .2761 .24869 Metetra
.963 .726 .532 r
.2761 .24869 .27593 .28257 .26478 .2668 .26469 .24142 Metetra
.964 .723 .525 r
.26469 .24142 .26478 .2668 .2528 .26894 .25317 .23291 Metetra
.958 .722 .538 r
.25317 .23291 .2528 .26894 .23999 .28623 .24085 .23941 Metetra
.962 .728 .537 r
.24085 .23941 .23999 .28623 .2282 .27325 .22882 .23393 Metetra
.964 .729 .532 r
.22882 .23393 .2282 .27325 .21711 .24067 .21692 .2212 Metetra
.967 .721 .513 r
.21692 .2212 .21711 .24067 .20587 .20938 .20489 .20763 Metetra
.83 .381 0 r
.20489 .20763 .20587 .20938 .19337 .20195 .19266 .19478 Metetra
.958 .679 .465 r
.19266 .19478 .19337 .20195 .18081 .19194 .17985 .18969 Metetra
.745 .369 0 r
.17985 .18969 .18081 .19194 .16891 .16538 .16784 .1654 Metetra
.968 .703 .479 r
.42078 .35885 .42162 .36798 .41231 .35334 .4114 .34991 Metetra
.958 .626 .332 r
.4114 .34991 .41231 .35334 .40282 .3441 .4019 .34091 Metetra
.952 .614 .335 r
.4019 .34091 .40282 .3441 .39318 .3367 .39226 .33374 Metetra
.949 .6 .308 r
.39226 .33374 .39318 .3367 .38335 .33188 .38249 .32609 Metetra
.959 .674 .45 r
.38249 .32609 .38335 .33188 .37347 .32332 .37253 .32106 Metetra
.908 .55 .347 r
.37253 .32106 .37347 .32332 .36325 .32386 .36232 .32155 Metetra
.908 .552 .351 r
.36232 .32155 .36325 .32386 .35218 .35362 .35193 .32221 Metetra
.955 .719 .54 r
.35193 .32221 .35218 .35362 .34195 .33977 .34111 .33333 Metetra
.945 .668 .483 r
.34111 .33333 .34195 .33977 .33135 .33532 .33033 .33591 Metetra
.753 .838 .916 r
.33033 .33591 .33135 .33532 .32061 .33034 .31967 .32771 Metetra
.925 .571 .341 r
.31967 .32771 .32061 .33034 .30975 .32367 .30867 .32559 Metetra
.894 .817 .764 r
.30867 .32559 .30975 .32367 .29882 .31431 .29773 .31651 Metetra
.892 .794 .745 r
.29773 .31651 .29882 .31431 .28777 .30398 .28672 .30479 Metetra
.741 .691 .803 r
.28672 .30479 .28777 .30398 .27666 .29111 .27593 .28257 Metetra
.974 .703 .454 r
.27593 .28257 .27666 .29111 .26537 .27909 .26478 .2668 Metetra
.954 .699 .512 r
.26478 .2668 .26537 .27909 .25399 .26522 .2528 .26894 Metetra
.984 .904 .601 r
.2528 .26894 .25399 .26522 .24127 .28076 .23999 .28623 Metetra
.936 .77 .652 r
.23999 .28623 .24127 .28076 .22939 .27019 .2282 .27325 Metetra
.847 .702 .702 r
.2282 .27325 .22939 .27019 .21767 .25204 .21711 .24067 Metetra
.984 .723 .45 r
.21711 .24067 .21767 .25204 .20668 .21491 .20587 .20938 Metetra
.96 .664 .429 r
.20587 .20938 .20668 .21491 .19443 .20222 .19337 .20195 Metetra
.199 .595 .945 r
.19337 .20195 .19443 .20222 .18185 .19259 .18081 .19194 Metetra
.31 .438 .829 r
.18081 .19194 .18185 .19259 .16931 .17845 .16891 .16538 Metetra
.89 .759 .711 r
.42162 .36798 .42261 .36527 .41328 .35333 .41231 .35334 Metetra
.522 .729 .968 r
.41231 .35334 .41328 .35333 .40378 .34471 .40282 .3441 Metetra
0 .245 .69 r
.40282 .3441 .40378 .34471 .39414 .33758 .39318 .3367 Metetra
.688 .148 0 r
.39318 .3367 .39414 .33758 .38431 .3334 .38335 .33188 Metetra
.833 .373 0 r
.38335 .33188 .38431 .3334 .37432 .32997 .37347 .32332 Metetra
.95 .674 .481 r
.37347 .32332 .37432 .32997 .36432 .32051 .36325 .32386 Metetra
.808 .824 .347 r
.36325 .32386 .36432 .32051 .35374 .3298 .35218 .35362 Metetra
.956 .744 .576 r
.35218 .35362 .35374 .3298 .34327 .32758 .34195 .33977 Metetra
.96 .762 .591 r
.34195 .33977 .34327 .32758 .33249 .33066 .33135 .33532 Metetra
.951 .797 .654 r
.33135 .33532 .33249 .33066 .32179 .32429 .32061 .33034 Metetra
.951 .781 .635 r
.32061 .33034 .32179 .32429 .31085 .32112 .30975 .32367 Metetra
.913 .805 .726 r
.30975 .32367 .31085 .32112 .29992 .31204 .29882 .31431 Metetra
.901 .803 .742 r
.29882 .31431 .29992 .31204 .2888 .30401 .28777 .30398 Metetra
.511 .69 .949 r
.28777 .30398 .2888 .30401 .27771 .29069 .27666 .29111 Metetra
.694 .776 .914 r
.27666 .29111 .27771 .29069 .26631 .28171 .26537 .27909 Metetra
.927 .546 .162 r
.26537 .27909 .26631 .28171 .25452 .27857 .25399 .26522 Metetra
.942 .691 .528 r
.25399 .26522 .25452 .27857 .24254 .27522 .24127 .28076 Metetra
.942 .777 .649 r
.24127 .28076 .24254 .27522 .23047 .26966 .22939 .27019 Metetra
.708 .719 .857 r
.22939 .27019 .23047 .26966 .2189 .2481 .21767 .25204 Metetra
.859 .699 .683 r
.21767 .25204 .2189 .2481 .20791 .21111 .20668 .21491 Metetra
.924 .783 .687 r
.20668 .21491 .20791 .21111 .19553 .20139 .19443 .20222 Metetra
.792 .842 .889 r
.19443 .20222 .19553 .20139 .18296 .19181 .18185 .19259 Metetra
.767 .785 .868 r
.18185 .19259 .18296 .19181 .1707 .17228 .16931 .17845 Metetra
0 .058 .594 r
.42261 .36527 .42356 .36629 .41431 .34873 .41328 .35333 Metetra
.939 .779 .656 r
.41328 .35333 .41431 .34873 .40484 .33964 .40378 .34471 Metetra
.946 .782 .646 r
.40378 .34471 .40484 .33964 .39521 .33192 .39414 .33758 Metetra
.956 .787 .633 r
.39414 .33758 .39521 .33192 .38536 .32975 .38431 .3334 Metetra
.951 .814 .673 r
.38431 .3334 .38536 .32975 .37531 .32987 .37432 .32997 Metetra
.573 .756 .964 r
.37432 .32997 .37531 .32987 .36526 .32294 .36432 .32051 Metetra
.876 .551 .431 r
.36432 .32051 .36526 .32294 .35478 .32818 .35374 .3298 Metetra
.917 .893 .79 r
.35374 .3298 .35478 .32818 .34445 .3202 .34327 .32758 Metetra
.971 .794 .606 r
.34327 .32758 .34445 .3202 .33396 .31341 .33249 .33066 Metetra
.96 .753 .581 r
.33249 .33066 .33396 .31341 .32324 .30903 .32179 .32429 Metetra
.962 .759 .582 r
.32179 .32429 .32324 .30903 .3123 .30677 .31085 .32112 Metetra
.957 .754 .589 r
.31085 .32112 .3123 .30677 .30153 .29353 .29992 .31204 Metetra
.959 .751 .58 r
.29992 .31204 .30153 .29353 .29045 .28547 .2888 .30401 Metetra
.955 .748 .583 r
.2888 .30401 .29045 .28547 .27955 .26769 .27771 .29069 Metetra
.959 .748 .575 r
.27771 .29069 .27955 .26769 .2683 .25571 .26631 .28171 Metetra
.963 .75 .569 r
.26631 .28171 .2683 .25571 .25651 .25399 .25452 .27857 Metetra
.962 .751 .571 r
.25452 .27857 .25651 .25399 .24377 .27088 .24254 .27522 Metetra
.949 .804 .666 r
.24254 .27522 .24377 .27088 .23251 .24614 .23047 .26966 Metetra
.953 .741 .58 r
.23047 .26966 .23251 .24614 .22085 .228 .2189 .2481 Metetra
.941 .732 .591 r
.2189 .2481 .22085 .228 .20895 .21156 .20791 .21111 Metetra
0 .447 .854 r
.20791 .21111 .20895 .21156 .19656 .20222 .19553 .20139 Metetra
.474 0 0 r
.19553 .20139 .19656 .20222 .184 .19251 .18296 .19181 Metetra
.117 .389 .844 r
.18296 .19181 .184 .19251 .1718 .17187 .1707 .17228 Metetra
.051 .301 .789 r
.42356 .36629 .42452 .36721 .41517 .35669 .41431 .34873 Metetra
.968 .698 .466 r
.41431 .34873 .41517 .35669 .40572 .34533 .40484 .33964 Metetra
.965 .677 .435 r
.40484 .33964 .40572 .34533 .39611 .33646 .39521 .33192 Metetra
.949 .65 .436 r
.39521 .33192 .39611 .33646 .38624 .33509 .38536 .32975 Metetra
.947 .66 .462 r
.38536 .32975 .38624 .33509 .37629 .33004 .37531 .32987 Metetra
.257 .655 .965 r
.37531 .32987 .37629 .33004 .36611 .32912 .36526 .32294 Metetra
.939 .662 .488 r
.36526 .32294 .36611 .32912 .35553 .33872 .35478 .32818 Metetra
.966 .705 .49 r
.35478 .32818 .35553 .33872 .3454 .32262 .34445 .3202 Metetra
.93 .553 .254 r
.34445 .3202 .3454 .32262 .33485 .31786 .33396 .31341 Metetra
.953 .647 .417 r
.33396 .31341 .33485 .31786 .32401 .31771 .32324 .30903 Metetra
.957 .69 .488 r
.32324 .30903 .32401 .31771 .31282 .32356 .3123 .30677 Metetra
.968 .72 .506 r
.3123 .30677 .31282 .32356 .3024 .29825 .30153 .29353 Metetra
.961 .655 .404 r
.30153 .29353 .3024 .29825 .29158 .28241 .29045 .28547 Metetra
.892 .757 .705 r
.29045 .28547 .29158 .28241 .28062 .26664 .27955 .26769 Metetra
.817 .8 .835 r
.27955 .26769 .28062 .26664 .26931 .25643 .2683 .25571 Metetra
.657 .104 0 r
.2683 .25571 .26931 .25643 .25737 .25885 .25651 .25399 Metetra
.903 .618 .495 r
.25651 .25399 .25737 .25885 .2446 .27636 .24377 .27088 Metetra
.977 .677 .33 r
.24377 .27088 .2446 .27636 .23267 .26747 .23251 .24614 Metetra
.969 .725 .512 r
.23251 .24614 .23267 .26747 .22146 .23826 .22085 .228 Metetra
.973 .709 .47 r
.22085 .228 .22146 .23826 .20984 .21539 .20895 .21156 Metetra
.955 .627 .354 r
.20895 .21156 .20984 .21539 .19759 .203 .19656 .20222 Metetra
0 .117 .572 r
.19656 .20222 .19759 .203 .18475 .19892 .184 .19251 Metetra
.978 .688 .396 r
.184 .19251 .18475 .19892 .17232 .1827 .1718 .17187 Metetra
0 0 .515 r
.42452 .36721 .42547 .36823 .41609 .35949 .41517 .35669 Metetra
.944 .582 .225 r
.41517 .35669 .41609 .35949 .40669 .34516 .40572 .34533 Metetra
.609 .774 .959 r
.40572 .34533 .40669 .34516 .39708 .33686 .39611 .33646 Metetra
.455 0 0 r
.39611 .33646 .39708 .33686 .38729 .33117 .38624 .33509 Metetra
.947 .802 .668 r
.38624 .33509 .38729 .33117 .37742 .32297 .37629 .33004 Metetra
.964 .786 .613 r
.37629 .33004 .37742 .32297 .36746 .31279 .36611 .32912 Metetra
.973 .768 .568 r
.36611 .32912 .36746 .31279 .3572 .31009 .35553 .33872 Metetra
.956 .742 .572 r
.35553 .33872 .3572 .31009 .34679 .30673 .3454 .32262 Metetra
.961 .756 .582 r
.3454 .32262 .34679 .30673 .33617 .30601 .33485 .31786 Metetra
.965 .769 .588 r
.33485 .31786 .33617 .30601 .32555 .29896 .32401 .31771 Metetra
.969 .762 .57 r
.32401 .31771 .32555 .29896 .31481 .29058 .31282 .32356 Metetra
.954 .738 .573 r
.31282 .32356 .31481 .29058 .30394 .28176 .3024 .29825 Metetra
.952 .746 .588 r
.3024 .29825 .30394 .28176 .29306 .26857 .29158 .28241 Metetra
.95 .748 .595 r
.29158 .28241 .29306 .26857 .28195 .25786 .28062 .26664 Metetra
.951 .764 .614 r
.28062 .26664 .28195 .25786 .27064 .24837 .26931 .25643 Metetra
.97 .79 .605 r
.26931 .25643 .27064 .24837 .25899 .24373 .25737 .25885 Metetra
.979 .779 .566 r
.25737 .25885 .25899 .24373 .24695 .24406 .2446 .27636 Metetra
.961 .745 .567 r
.2446 .27636 .24695 .24406 .23505 .23598 .23267 .26747 Metetra
.952 .737 .575 r
.23267 .26747 .23505 .23598 .22296 .22809 .22146 .23826 Metetra
.938 .744 .615 r
.22146 .23826 .22296 .22809 .21125 .20777 .20984 .21539 Metetra
.946 .765 .626 r
.20984 .21539 .21125 .20777 .19888 .19833 .19759 .203 Metetra
.955 .807 .659 r
.19759 .203 .19888 .19833 .18645 .18633 .18475 .19892 Metetra
.95 .752 .601 r
.18475 .19892 .18645 .18633 .17409 .1692 .17232 .1827 Metetra
.953 .758 .602 r
.42547 .36823 .42656 .35806 .41719 .35061 .41609 .35949 Metetra
.943 .752 .615 r
.41609 .35949 .41719 .35061 .4077 .34286 .40669 .34516 Metetra
.91 .806 .732 r
.40669 .34516 .4077 .34286 .3981 .33423 .39708 .33686 Metetra
.931 .82 .714 r
.39708 .33686 .3981 .33423 .3884 .3241 .38729 .33117 Metetra
.95 .769 .623 r
.38729 .33117 .3884 .3241 .37861 .31273 .37742 .32297 Metetra
.952 .757 .604 r
.37742 .32297 .37861 .31273 .36869 .30155 .36746 .31279 Metetra
.962 .766 .592 r
.36746 .31279 .36869 .30155 .35849 .29696 .3572 .31009 Metetra
.962 .761 .587 r
.3572 .31009 .35849 .29696 .34809 .29459 .34679 .30673 Metetra
.965 .767 .587 r
.34679 .30673 .34809 .29459 .33761 .28924 .33617 .30601 Metetra
.959 .753 .582 r
.33617 .30601 .33761 .28924 .32678 .29114 .32555 .29896 Metetra
.952 .768 .618 r
.32555 .29896 .32678 .29114 .31605 .28302 .31481 .29058 Metetra
.951 .769 .621 r
.31481 .29058 .31605 .28302 .30512 .27673 .30394 .28176 Metetra
.932 .768 .657 r
.30394 .28176 .30512 .27673 .2945 .25585 .29306 .26857 Metetra
.955 .755 .595 r
.29306 .26857 .2945 .25585 .28335 .24708 .28195 .25786 Metetra
.954 .76 .602 r
.28195 .25786 .28335 .24708 .27205 .23824 .27064 .24837 Metetra
.96 .769 .601 r
.27064 .24837 .27205 .23824 .26056 .22979 .25899 .24373 Metetra
.966 .766 .583 r
.25899 .24373 .26056 .22979 .24792 .24596 .24695 .24406 Metetra
.891 .466 .125 r
.24695 .24406 .24792 .24596 .23606 .23699 .23505 .23598 Metetra
.658 .122 0 r
.23505 .23598 .23606 .23699 .22404 .22773 .22296 .22809 Metetra
.667 .684 .857 r
.22296 .22809 .22404 .22773 .2122 .2102 .21125 .20777 Metetra
.925 .536 .211 r
.21125 .20777 .2122 .2102 .20012 .19471 .19888 .19833 Metetra
.924 .788 .692 r
.19888 .19833 .20012 .19471 .18756 .18549 .18645 .18633 Metetra
.764 .754 .844 r
.18645 .18633 .18756 .18549 .17535 .16572 .17409 .1692 Metetra
.956 .627 .349 r
.42656 .35806 .42748 .36152 .41813 .35259 .41719 .35061 Metetra
.907 .498 .146 r
.41719 .35061 .41813 .35259 .40866 .3434 .4077 .34286 Metetra
0 .374 .817 r
.4077 .34286 .40866 .3434 .39904 .33601 .3981 .33423 Metetra
.862 .429 .009 r
.3981 .33423 .39904 .33601 .3893 .32855 .3884 .3241 Metetra
.968 .657 .37 r
.3884 .3241 .3893 .32855 .37937 .32411 .37861 .31273 Metetra
.969 .711 .488 r
.37861 .31273 .37937 .32411 .36903 .33189 .36869 .30155 Metetra
.963 .725 .531 r
.36869 .30155 .36903 .33189 .35854 .33843 .35849 .29696 Metetra
.962 .727 .536 r
.35849 .29696 .35854 .33843 .34803 .33792 .34809 .29459 Metetra
.963 .728 .536 r
.34809 .29459 .34803 .33792 .33743 .33501 .33761 .28924 Metetra
.961 .727 .539 r
.33761 .28924 .33743 .33501 .3268 .32689 .32678 .29114 Metetra
.964 .727 .531 r
.32678 .29114 .3268 .32689 .31577 .3275 .31605 .28302 Metetra
.963 .729 .535 r
.31605 .28302 .31577 .3275 .3051 .31031 .30512 .27673 Metetra
.969 .731 .524 r
.30512 .27673 .3051 .31031 .29402 .30207 .2945 .25585 Metetra
.964 .729 .535 r
.2945 .25585 .29402 .30207 .28291 .2902 .28335 .24708 Metetra
.964 .729 .534 r
.28335 .24708 .28291 .2902 .27157 .28021 .27205 .23824 Metetra
.964 .728 .534 r
.27205 .23824 .27157 .28021 .25978 .27785 .26056 .22979 Metetra
.957 .723 .543 r
.26056 .22979 .25978 .27785 .2476 .28045 .24792 .24596 Metetra
.964 .727 .53 r
.24792 .24596 .2476 .28045 .23568 .27157 .23606 .23699 Metetra
.964 .727 .53 r
.23606 .23699 .23568 .27157 .22406 .25169 .22404 .22773 Metetra
.969 .726 .516 r
.22404 .22773 .22406 .25169 .21302 .21575 .2122 .2102 Metetra
.972 .673 .391 r
.2122 .2102 .21302 .21575 .20066 .20584 .20012 .19471 Metetra
.965 .704 .488 r
.20012 .19471 .20066 .20584 .1882 .19442 .18756 .18549 Metetra
.977 .705 .448 r
.18756 .18549 .1882 .19442 .17614 .17118 .17535 .16572 Metetra
.967 .712 .496 r
.42748 .36152 .42829 .37363 .41896 .3623 .41813 .35259 Metetra
.968 .706 .481 r
.41813 .35259 .41896 .3623 .40949 .3525 .40866 .3434 Metetra
.966 .701 .481 r
.40866 .3434 .40949 .3525 .39987 .34511 .39904 .33601 Metetra
.966 .701 .48 r
.39904 .33601 .39987 .34511 .39007 .34041 .3893 .32855 Metetra
.962 .707 .502 r
.3893 .32855 .39007 .34041 .38011 .33651 .37937 .32411 Metetra
.949 .697 .521 r
.37937 .32411 .38011 .33651 .36999 .33352 .36903 .33189 Metetra
.85 .483 .357 r
.36903 .33189 .36999 .33352 .35922 .35235 .35854 .33843 Metetra
.959 .707 .514 r
.35854 .33843 .35922 .35235 .34924 .32968 .34803 .33792 Metetra
.962 .777 .608 r
.34803 .33792 .34924 .32968 .33878 .32195 .33743 .33501 Metetra
.957 .757 .591 r
.33743 .33501 .33878 .32195 .32781 .32714 .3268 .32689 Metetra
.379 0 0 r
.3268 .32689 .32781 .32714 .31694 .32253 .31577 .3275 Metetra
.921 .756 .66 r
.31577 .3275 .31694 .32253 .30643 .30075 .3051 .31031 Metetra
.955 .764 .607 r
.3051 .31031 .30643 .30075 .29533 .29348 .29402 .30207 Metetra
.948 .761 .616 r
.29402 .30207 .29533 .29348 .28425 .28119 .28291 .2902 Metetra
.952 .764 .612 r
.28291 .2902 .28425 .28119 .27244 .28497 .27157 .28021 Metetra
.948 .646 .431 r
.27157 .28021 .27244 .28497 .26134 .26437 .25978 .27785 Metetra
.968 .769 .582 r
.25978 .27785 .26134 .26437 .24833 .28868 .2476 .28045 Metetra
.965 .692 .466 r
.2476 .28045 .24833 .28868 .23693 .26696 .23568 .27157 Metetra
.913 .753 .67 r
.23568 .27157 .23693 .26696 .22575 .23704 .22406 .25169 Metetra
.935 .731 .603 r
.22406 .25169 .22575 .23704 .21397 .21831 .21302 .21575 Metetra
.93 .549 .224 r
.21302 .21575 .21397 .21831 .20177 .20513 .20066 .20584 Metetra
.761 .815 .896 r
.20066 .20584 .20177 .20513 .18921 .19567 .1882 .19442 Metetra
0 .115 .667 r
.1882 .19442 .18921 .19567 .17676 .18022 .17614 .17118 Metetra
.871 .785 .764 r
.42829 .37363 .42928 .37192 .41994 .36184 .41896 .3623 Metetra
.724 .79 .904 r
.41896 .3623 .41994 .36184 .4105 .35022 .40949 .3525 Metetra
.915 .814 .733 r
.40949 .3525 .4105 .35022 .40089 .34284 .39987 .34511 Metetra
.929 .838 .734 r
.39987 .34511 .40089 .34284 .39107 .33959 .39007 .34041 Metetra
.822 .909 .899 r
.39007 .34041 .39107 .33959 .38109 .33685 .38011 .33651 Metetra
.27 0 0 r
.38011 .33651 .38109 .33685 .371 .33292 .36999 .33352 Metetra
.27 0 .152 r
.36999 .33352 .371 .33292 .36043 .34354 .35922 .35235 Metetra
.931 .74 .623 r
.35922 .35235 .36043 .34354 .35003 .33854 .34924 .32968 Metetra
.965 .698 .476 r
.34924 .32968 .35003 .33854 .33955 .33132 .33878 .32195 Metetra
.948 .686 .506 r
.33878 .32195 .33955 .33132 .32877 .32936 .32781 .32714 Metetra
.918 .533 .258 r
.32781 .32714 .32877 .32936 .31791 .3241 .31694 .32253 Metetra
0 0 .534 r
.31694 .32253 .31791 .3241 .30715 .3106 .30643 .30075 Metetra
.964 .701 .484 r
.30643 .30075 .30715 .3106 .29595 .30634 .29533 .29348 Metetra
.969 .713 .492 r
.29533 .29348 .29595 .30634 .28495 .29117 .28425 .28119 Metetra
.951 .689 .504 r
.28425 .28119 .28495 .29117 .27361 .28151 .27244 .28497 Metetra
.892 .748 .695 r
.27244 .28497 .27361 .28151 .26151 .28767 .26134 .26437 Metetra
.947 .705 .54 r
.26134 .26437 .26151 .28767 .24926 .29199 .24833 .28868 Metetra
.929 .579 .146 r
.24833 .28868 .24926 .29199 .2376 .27643 .23693 .26696 Metetra
.985 .717 .424 r
.23693 .26696 .2376 .27643 .22615 .2524 .22575 .23704 Metetra
.972 .721 .494 r
.22575 .23704 .22615 .2524 .21403 .24057 .21397 .21831 Metetra
.967 .723 .516 r
.21397 .21831 .21403 .24057 .20257 .21077 .20177 .20513 Metetra
.963 .667 .421 r
.20177 .20513 .20257 .21077 .18993 .20304 .18921 .19567 Metetra
.973 .692 .436 r
.18921 .19567 .18993 .20304 .17756 .18583 .17676 .18022 Metetra
.939 .77 .645 r
.42928 .37192 .43031 .36661 .42098 .35676 .41994 .36184 Metetra
.934 .767 .651 r
.41994 .36184 .42098 .35676 .4115 .34899 .4105 .35022 Metetra
.862 .837 .82 r
.4105 .35022 .4115 .34899 .40189 .34138 .40089 .34284 Metetra
.905 .886 .803 r
.40089 .34284 .40189 .34138 .39213 .33503 .39107 .33959 Metetra
.958 .804 .649 r
.39107 .33959 .39213 .33503 .38224 .32894 .38109 .33685 Metetra
.96 .776 .61 r
.38109 .33685 .38224 .32894 .37207 .32931 .371 .33292 Metetra
.988 .885 .626 r
.371 .33292 .37207 .32931 .36132 .3482 .36043 .34354 Metetra
.956 .653 .419 r
.36043 .34354 .36132 .3482 .35108 .33681 .35003 .33854 Metetra
.896 .835 .778 r
.35003 .33854 .35108 .33681 .3406 .32953 .33955 .33132 Metetra
.926 .89 .775 r
.33955 .33132 .3406 .32953 .32983 .32758 .32877 .32936 Metetra
.909 .857 .778 r
.32877 .32936 .32983 .32758 .31898 .32257 .31791 .3241 Metetra
.851 .782 .784 r
.31791 .3241 .31898 .32257 .30815 .31149 .30715 .3106 Metetra
.695 .153 0 r
.30715 .3106 .30815 .31149 .2971 .30274 .29595 .30634 Metetra
.912 .768 .69 r
.29595 .30634 .2971 .30274 .28588 .29413 .28495 .29117 Metetra
.945 .586 .276 r
.28495 .29117 .28588 .29413 .27452 .28521 .27361 .28151 Metetra
.916 .605 .441 r
.27361 .28151 .27452 .28521 .26291 .27821 .26151 .28767 Metetra
.972 .786 .594 r
.26151 .28767 .26291 .27821 .25068 .28279 .24926 .29199 Metetra
.945 .756 .616 r
.24926 .29199 .25068 .28279 .23858 .27847 .2376 .27643 Metetra
0 0 .307 r
.2376 .27643 .23858 .27847 .22723 .25222 .22615 .2524 Metetra
.595 .76 .957 r
.22615 .2524 .22723 .25222 .21629 .21408 .21403 .24057 Metetra
.951 .737 .579 r
.21403 .24057 .21629 .21408 .20392 .2048 .20257 .21077 Metetra
.951 .785 .64 r
.20257 .21077 .20392 .2048 .19138 .1953 .18993 .20304 Metetra
.94 .757 .629 r
.18993 .20304 .19138 .1953 .1789 .18073 .17756 .18583 Metetra
.276 .586 .945 r
.43031 .36661 .43127 .36693 .42192 .35874 .42098 .35676 Metetra
.907 .497 .144 r
.42098 .35676 .42192 .35874 .41246 .34995 .4115 .34899 Metetra
.61 .084 0 r
.4115 .34899 .41246 .34995 .40285 .34252 .40189 .34138 Metetra
.761 .255 0 r
.40189 .34138 .40285 .34252 .39309 .33653 .39213 .33503 Metetra
.857 .402 .052 r
.39213 .33503 .39309 .33653 .3832 .33008 .38224 .32894 Metetra
.818 .365 .153 r
.38224 .32894 .3832 .33008 .37309 .32782 .37207 .32931 Metetra
.37207 .32931 .37309 .32782 .36231 .34891 .36132 .3482 Metetra
0 .295 .779 r
.36132 .3482 .36231 .34891 .35197 .34173 .35108 .33681 Metetra
.961 .66 .413 r
.35108 .33681 .35197 .34173 .34144 .33668 .3406 .32953 Metetra
.955 .68 .474 r
.3406 .32953 .34144 .33668 .3308 .32953 .32983 .32758 Metetra
.904 .497 .205 r
.32983 .32758 .3308 .32953 .31968 .33394 .31898 .32257 Metetra
.969 .709 .486 r
.31898 .32257 .31968 .33394 .3092 .31072 .30815 .31149 Metetra
.791 .839 .888 r
.30815 .31149 .3092 .31072 .29817 .30156 .2971 .30274 Metetra
.848 .84 .837 r
.2971 .30274 .29817 .30156 .28722 .28531 .28588 .29413 Metetra
.954 .766 .612 r
.28588 .29413 .28722 .28531 .27585 .27695 .27452 .28521 Metetra
.956 .772 .614 r
.27452 .28521 .27585 .27695 .26401 .27693 .26291 .27821 Metetra
.864 .995 .806 r
.26291 .27821 .26401 .27693 .25165 .28488 .25068 .28279 Metetra
.905 .507 .235 r
.25068 .28279 .25165 .28488 .23976 .27556 .23858 .27847 Metetra
.862 .725 .71 r
.23858 .27847 .23976 .27556 .22836 .25068 .22723 .25222 Metetra
.761 .646 .734 r
.22723 .25222 .22836 .25068 .21706 .22072 .21629 .21408 Metetra
.965 .679 .442 r
.21629 .21408 .21706 .22072 .2049 .20687 .20392 .2048 Metetra
.899 .482 .133 r
.20392 .2048 .2049 .20687 .19222 .2002 .19138 .1953 Metetra
.969 .658 .37 r
.19138 .1953 .19222 .2002 .17976 .18494 .1789 .18073 Metetra
.968 .698 .469 r
.43127 .36693 .43214 .37507 .42287 .36049 .42192 .35874 Metetra
.872 .438 .04 r
.42192 .35874 .42287 .36049 .41344 .34959 .41246 .34995 Metetra
.684 .826 .952 r
.41246 .34995 .41344 .34959 .40373 .34845 .40285 .34252 Metetra
.962 .676 .445 r
.40285 .34252 .40373 .34845 .39406 .33721 .39309 .33653 Metetra
.443 0 0 r
.39309 .33653 .39406 .33721 .3842 .32955 .3832 .33008 Metetra
.711 .94 .959 r
.3832 .33008 .3842 .32955 .37416 .32414 .37309 .32782 Metetra
.964 .899 .528 r
.37309 .32782 .37416 .32414 .36394 .32068 .36231 .34891 Metetra
.961 .747 .567 r
.36231 .34891 .36394 .32068 .35353 .31853 .35197 .34173 Metetra
.962 .75 .571 r
.35197 .34173 .35353 .31853 .34307 .3121 .34144 .33668 Metetra
.961 .748 .57 r
.34144 .33668 .34307 .3121 .33231 .31138 .3308 .32953 Metetra
.969 .762 .57 r
.3308 .32953 .33231 .31138 .32156 .3041 .31968 .33394 Metetra
.954 .739 .573 r
.31968 .33394 .32156 .3041 .31119 .27894 .3092 .31072 Metetra
.961 .745 .566 r
.3092 .31072 .31119 .27894 .30033 .26611 .29817 .30156 Metetra
.959 .742 .567 r
.29817 .30156 .30033 .26611 .28931 .25402 .28722 .28531 Metetra
.961 .746 .566 r
.28722 .28531 .28931 .25402 .27779 .25149 .27585 .27695 Metetra
.965 .753 .567 r
.27585 .27695 .27779 .25149 .2663 .24333 .26401 .27693 Metetra
.968 .752 .559 r
.26401 .27693 .2663 .24333 .25326 .27069 .25165 .28488 Metetra
.958 .756 .589 r
.25165 .28488 .25326 .27069 .24138 .26182 .23976 .27556 Metetra
.943 .741 .601 r
.23976 .27556 .24138 .26182 .23064 .22207 .22836 .25068 Metetra
.952 .737 .576 r
.22836 .25068 .23064 .22207 .21885 .20446 .21706 .22072 Metetra
.955 .751 .587 r
.21706 .22072 .21885 .20446 .20629 .20006 .2049 .20687 Metetra
.955 .782 .629 r
.2049 .20687 .20629 .20006 .194 .1856 .19222 .2002 Metetra
.953 .751 .592 r
.19222 .2002 .194 .1856 .1817 .1679 .17976 .18494 Metetra
.952 .746 .588 r
.43214 .37507 .43329 .35974 .42394 .353 .42287 .36049 Metetra
.946 .761 .621 r
.42287 .36049 .42394 .353 .41455 .34014 .41344 .34959 Metetra
.965 .774 .596 r
.41344 .34959 .41455 .34014 .40497 .33217 .40373 .34845 Metetra
.956 .749 .584 r
.40373 .34845 .40497 .33217 .39526 .32512 .39406 .33721 Metetra
.957 .758 .592 r
.39406 .33721 .39526 .32512 .38545 .31572 .3842 .32955 Metetra
.961 .758 .585 r
.3842 .32955 .38545 .31572 .37554 .30531 .37416 .32414 Metetra
.963 .754 .574 r
.37416 .32414 .37554 .30531 .36541 .29925 .36394 .32068 Metetra
.964 .753 .57 r
.36394 .32068 .36541 .29925 .35506 .29624 .35353 .31853 Metetra
.961 .75 .572 r
.35353 .31853 .35506 .29624 .34443 .29814 .34307 .3121 Metetra
.965 .764 .581 r
.34307 .3121 .34443 .29814 .33371 .29704 .33231 .31138 Metetra
.959 .757 .586 r
.33231 .31138 .33371 .29704 .32246 .30836 .32156 .3041 Metetra
.952 .632 .21 r
.32156 .3041 .32246 .30836 .31171 .29571 .31119 .27894 Metetra
.969 .72 .505 r
.31119 .27894 .31171 .29571 .30119 .27141 .30033 .26611 Metetra
.969 .669 .398 r
.30033 .26611 .30119 .27141 .29016 .25933 .28931 .25402 Metetra
.952 .657 .443 r
.28931 .25402 .29016 .25933 .27885 .25101 .27779 .25149 Metetra
.709 .844 .947 r
.27779 .25149 .27885 .25101 .26718 .24781 .2663 .24333 Metetra
.873 .593 .511 r
.2663 .24333 .26718 .24781 .25486 .25662 .25326 .27069 Metetra
.958 .757 .589 r
.25326 .27069 .25486 .25662 .24302 .2476 .24138 .26182 Metetra
.93 .727 .606 r
.24138 .26182 .24302 .2476 .23116 .23477 .23064 .22207 Metetra
.973 .716 .482 r
.23064 .22207 .23116 .23477 .21935 .21709 .21885 .20446 Metetra
.961 .705 .501 r
.21885 .20446 .21935 .21709 .20692 .20942 .20629 .20006 Metetra
.972 .702 .463 r
.20629 .20006 .20692 .20942 .19455 .1965 .194 .1856 Metetra
.974 .711 .47 r
.194 .1856 .19455 .1965 .18239 .17577 .1817 .1679 Metetra
.965 .682 .447 r
.43329 .35974 .43418 .36593 .42483 .35863 .42394 .353 Metetra
.974 .681 .402 r
.42394 .353 .42483 .35863 .41543 .34685 .41455 .34014 Metetra
.967 .687 .45 r
.41455 .34014 .41543 .34685 .40584 .33938 .40497 .33217 Metetra
.965 .69 .461 r
.40497 .33217 .40584 .33938 .39605 .3364 .39526 .32512 Metetra
.968 .71 .489 r
.39526 .32512 .39605 .3364 .38619 .32904 .38545 .31572 Metetra
.969 .715 .497 r
.38545 .31572 .38619 .32904 .37607 .32813 .37554 .30531 Metetra
.964 .722 .522 r
.37554 .30531 .37607 .32813 .36526 .35189 .36541 .29925 Metetra
.963 .729 .537 r
.36541 .29925 .36526 .35189 .35499 .34204 .35506 .29624 Metetra
.962 .727 .537 r
.35506 .29624 .35499 .34204 .34448 .33674 .34443 .29814 Metetra
.962 .726 .534 r
.34443 .29814 .34448 .33674 .33389 .32833 .33371 .29704 Metetra
.957 .719 .537 r
.33371 .29704 .33389 .32833 .32302 .32467 .32246 .30836 Metetra
.969 .719 .503 r
.32246 .30836 .32302 .32467 .31225 .312 .31171 .29571 Metetra
.977 .727 .488 r
.31171 .29571 .31225 .312 .3012 .30385 .30119 .27141 Metetra
.966 .728 .526 r
.30119 .27141 .3012 .30385 .29007 .29329 .29016 .25933 Metetra
.965 .727 .529 r
.29016 .25933 .29007 .29329 .27871 .2847 .27885 .25101 Metetra
.963 .725 .531 r
.27885 .25101 .27871 .2847 .26711 .27815 .26718 .24781 Metetra
.958 .719 .535 r
.26718 .24781 .26711 .27815 .25483 .28458 .25486 .25662 Metetra
.965 .725 .524 r
.25486 .25662 .25483 .28458 .24296 .27521 .24302 .2476 Metetra
.967 .726 .522 r
.24302 .2476 .24296 .27521 .23158 .25008 .23116 .23477 Metetra
.972 .72 .494 r
.23116 .23477 .23158 .25008 .22038 .218 .21935 .21709 Metetra
.605 .057 0 r
.21935 .21709 .22038 .218 .20826 .20365 .20692 .20942 Metetra
.94 .773 .647 r
.20692 .20942 .20826 .20365 .19557 .19773 .19455 .1965 Metetra
0 .078 .635 r
.19455 .1965 .19557 .19773 .18325 .18014 .18239 .17577 Metetra
.868 .425 .05 r
.43418 .36593 .43513 .36757 .42579 .3594 .42483 .35863 Metetra
0 .271 .77 r
.42483 .35863 .42579 .3594 .41635 .35035 .41543 .34685 Metetra
.956 .626 .348 r
.41543 .34685 .41635 .35035 .40676 .34313 .40584 .33938 Metetra
.947 .631 .401 r
.40584 .33938 .40676 .34313 .39704 .33562 .39605 .3364 Metetra
.802 .847 .885 r
.39605 .3364 .39704 .33562 .38715 .33047 .38619 .32904 Metetra
.861 .432 .196 r
.38619 .32904 .38715 .33047 .37719 .32208 .37607 .32813 Metetra
.998 .854 .542 r
.37607 .32813 .37719 .32208 .36623 .35329 .36526 .35189 Metetra
.766 .288 0 r
.36526 .35189 .36623 .35329 .35617 .33486 .35499 .34204 Metetra
.957 .778 .619 r
.35499 .34204 .35617 .33486 .34569 .32894 .34448 .33674 Metetra
.953 .769 .617 r
.34448 .33674 .34569 .32894 .33506 .32276 .33389 .32833 Metetra
.958 .794 .636 r
.33389 .32833 .33506 .32276 .32403 .32524 .32302 .32467 Metetra
.063 .425 .869 r
.32302 .32467 .32403 .32524 .31348 .30523 .31225 .312 Metetra
.952 .775 .627 r
.31225 .312 .31348 .30523 .30244 .29734 .3012 .30385 Metetra
.946 .771 .633 r
.3012 .30385 .30244 .29734 .29129 .2879 .29007 .29329 Metetra
.947 .783 .647 r
.29007 .29329 .29129 .2879 .28005 .27636 .27871 .2847 Metetra
.957 .773 .613 r
.27871 .2847 .28005 .27636 .2685 .26893 .26711 .27815 Metetra
.975 .791 .592 r
.26711 .27815 .2685 .26893 .25606 .28035 .25483 .28458 Metetra
.938 .792 .672 r
.25483 .28458 .25606 .28035 .24379 .28112 .24296 .27521 Metetra
.979 .683 .345 r
.24296 .27521 .24379 .28112 .23284 .24555 .23158 .25008 Metetra
.883 .719 .673 r
.23158 .25008 .23284 .24555 .22131 .22104 .22038 .218 Metetra
.943 .58 .222 r
.22038 .218 .22131 .22104 .20929 .20466 .20826 .20365 Metetra
.709 .175 0 r
.20826 .20365 .20929 .20466 .19697 .19112 .19557 .19773 Metetra
.935 .759 .64 r
.19557 .19773 .19697 .19112 .18483 .1702 .18325 .18014 Metetra
.943 .579 .261 r
.43513 .36757 .43607 .37025 .42672 .36296 .42579 .3594 Metetra
.96 .629 .334 r
.42579 .3594 .42672 .36296 .41725 .35566 .41635 .35035 Metetra
.964 .67 .424 r
.41635 .35035 .41725 .35566 .40766 .3483 .40676 .34313 Metetra
.964 .668 .419 r
.40676 .34313 .40766 .3483 .39794 .34082 .39704 .33562 Metetra
.959 .665 .432 r
.39704 .33562 .39794 .34082 .38809 .33329 .38715 .33047 Metetra
.945 .586 .275 r
.38715 .33047 .38809 .33329 .37805 .32879 .37719 .32208 Metetra
.892 .632 .538 r
.37719 .32208 .37805 .32879 .36725 .35281 .36623 .35329 Metetra
.704 .692 .836 r
.36623 .35329 .36725 .35281 .35716 .33576 .35617 .33486 Metetra
.65 .104 0 r
.35617 .33486 .35716 .33576 .34674 .3275 .34569 .32894 Metetra
.885 .858 .81 r
.34569 .32894 .34674 .3275 .33582 .33251 .33506 .32276 Metetra
.953 .691 .501 r
.33506 .32276 .33582 .33251 .32508 .32457 .32403 .32524 Metetra
.73 .698 .82 r
.32403 .32524 .32508 .32457 .31419 .31632 .31348 .30523 Metetra
.966 .705 .489 r
.31348 .30523 .31419 .31632 .30319 .30634 .30244 .29734 Metetra
.967 .699 .471 r
.30244 .29734 .30319 .30634 .29204 .29663 .29129 .2879 Metetra
.97 .699 .463 r
.29129 .2879 .29204 .29663 .28097 .27991 .28005 .27636 Metetra
.951 .616 .347 r
.28005 .27636 .28097 .27991 .26945 .27159 .2685 .26893 Metetra
.875 .549 .43 r
.2685 .26893 .26945 .27159 .25648 .29705 .25606 .28035 Metetra
.959 .71 .517 r
.25606 .28035 .25648 .29705 .24506 .27596 .24379 .28112 Metetra
.884 .713 .664 r
.24379 .28112 .24506 .27596 .23345 .25638 .23284 .24555 Metetra
.98 .717 .454 r
.23284 .24555 .23345 .25638 .22123 .24727 .22131 .22104 Metetra
.968 .727 .517 r
.22131 .22104 .22123 .24727 .20987 .21554 .20929 .20466 Metetra
.97 .707 .477 r
.20929 .20466 .20987 .21554 .19742 .2042 .19697 .19112 Metetra
.975 .718 .479 r
.19697 .19112 .19742 .2042 .18542 .18011 .18483 .1702 Metetra
0 .424 .837 r
.43607 .37025 .43703 .3707 .42769 .36273 .42672 .36296 Metetra
.63 .812 .97 r
.42672 .36296 .42769 .36273 .41828 .35197 .41725 .35566 Metetra
.938 .795 .676 r
.41725 .35566 .41828 .35197 .4087 .34438 .40766 .3483 Metetra
.94 .792 .67 r
.40766 .3483 .4087 .34438 .39896 .33862 .39794 .34082 Metetra
.913 .818 .74 r
.39794 .34082 .39896 .33862 .38909 .33316 .38809 .33329 Metetra
.477 .825 .998 r
.38809 .33329 .38909 .33316 .37907 .32756 .37805 .32879 Metetra
.017 0 .09 r
.37805 .32879 .37907 .32756 .36833 .34915 .36725 .35281 Metetra
.905 .756 .685 r
.36725 .35281 .36833 .34915 .35805 .34083 .35716 .33576 Metetra
.964 .664 .41 r
.35716 .33576 .35805 .34083 .34756 .33536 .34674 .3275 Metetra
.946 .677 .496 r
.34674 .3275 .34756 .33536 .33682 .33328 .33582 .33251 Metetra
.447 0 0 r
.33582 .33251 .33682 .33328 .32598 .32916 .32508 .32457 Metetra
.961 .652 .393 r
.32508 .32457 .32598 .32916 .31519 .31724 .31419 .31632 Metetra
.483 0 0 r
.31419 .31632 .31519 .31724 .30424 .3059 .30319 .30634 Metetra
.702 .813 .934 r
.30319 .30634 .30424 .3059 .29322 .29228 .29204 .29663 Metetra
.918 .762 .672 r
.29204 .29663 .29322 .29228 .28188 .28368 .28097 .27991 Metetra
.955 .626 .353 r
.28097 .27991 .28188 .28368 .27037 .27516 .26945 .27159 Metetra
.858 .569 .497 r
.26945 .27159 .27037 .27516 .25777 .29083 .25648 .29705 Metetra
.925 .749 .646 r
.25648 .29705 .25777 .29083 .24619 .27427 .24506 .27596 Metetra
.835 .747 .768 r
.24506 .27596 .24619 .27427 .23433 .26077 .23345 .25638 Metetra
.959 .642 .377 r
.23345 .25638 .23433 .26077 .22366 .21624 .22123 .24727 Metetra
.953 .737 .574 r
.22123 .24727 .22366 .21624 .21147 .204 .20987 .21554 Metetra
.955 .759 .6 r
.20987 .21554 .21147 .204 .19884 .19704 .19742 .2042 Metetra
.927 .745 .638 r
.19742 .2042 .19884 .19704 .18649 .18032 .18542 .18011 Metetra
.928 .544 .207 r
.43703 .3707 .43797 .37302 .42864 .36462 .42769 .36273 Metetra
.867 .443 .013 r
.42769 .36273 .42864 .36462 .41919 .35665 .41828 .35197 Metetra
.963 .66 .403 r
.41828 .35197 .41919 .35665 .40968 .34437 .4087 .34438 Metetra
.417 .765 .996 r
.4087 .34438 .40968 .34437 .39993 .34001 .39896 .33862 Metetra
.84 .373 .027 r
.39896 .33862 .39993 .34001 .39004 .33545 .38909 .33316 Metetra
.925 .543 .25 r
.38909 .33316 .39004 .33545 .37996 .33306 .37907 .32756 Metetra
.899 .628 .518 r
.37907 .32756 .37996 .33306 .36942 .34529 .36833 .34915 Metetra
.937 .793 .675 r
.36833 .34915 .36942 .34529 .35919 .33511 .35805 .34083 Metetra
.955 .787 .635 r
.35805 .34083 .35919 .33511 .34873 .3288 .34756 .33536 Metetra
.963 .79 .62 r
.34756 .33536 .34873 .3288 .33815 .32165 .33682 .33328 Metetra
.962 .765 .591 r
.33682 .33328 .33815 .32165 .32724 .32068 .32598 .32916 Metetra
.949 .761 .616 r
.32598 .32916 .32724 .32068 .31659 .30461 .31519 .31724 Metetra
.955 .755 .594 r
.31519 .31724 .31659 .30461 .30574 .29117 .30424 .3059 Metetra
.954 .751 .59 r
.30424 .3059 .30574 .29117 .29473 .2779 .29322 .29228 Metetra
.959 .756 .587 r
.29322 .29228 .29473 .2779 .28347 .26805 .28188 .28368 Metetra
.959 .755 .584 r
.28188 .28368 .28347 .26805 .27191 .26181 .27037 .27516 Metetra
.981 .784 .568 r
.27037 .27516 .27191 .26181 .25894 .28793 .25777 .29083 Metetra
.895 .769 .715 r
.25777 .29083 .25894 .28793 .24787 .25897 .24619 .27427 Metetra
.955 .752 .588 r
.24619 .27427 .24787 .25897 .23616 .24245 .23433 .26077 Metetra
.935 .727 .596 r
.23433 .26077 .23616 .24245 .22455 .2204 .22366 .21624 Metetra
.962 .638 .345 r
.22366 .21624 .22455 .2204 .2121 .21377 .21147 .204 Metetra
.964 .697 .48 r
.21147 .204 .2121 .21377 .19951 .20568 .19884 .19704 Metetra
.974 .701 .448 r
.19884 .19704 .19951 .20568 .1874 .18394 .18649 .18032 Metetra
.717 .221 0 r
.43797 .37302 .43893 .37422 .42962 .36444 .42864 .36462 Metetra
.612 .792 .968 r
.42864 .36462 .42962 .36444 .42019 .35513 .41919 .35665 Metetra
.855 .78 .777 r
.41919 .35665 .42019 .35513 .41064 .34628 .40968 .34437 Metetra
.906 .502 .213 r
.40968 .34437 .41064 .34628 .40091 .34033 .39993 .34001 Metetra
0 .45 .784 r
.39993 .34001 .40091 .34033 .39108 .33272 .39004 .33545 Metetra
.948 .845 .707 r
.39004 .33545 .39108 .33272 .3812 .32078 .37996 .33306 Metetra
.98 .783 .568 r
.37996 .33306 .3812 .32078 .37098 .31921 .36942 .34529 Metetra
.96 .746 .569 r
.36942 .34529 .37098 .31921 .36057 .31879 .35919 .33511 Metetra
.961 .755 .58 r
.35919 .33511 .36057 .31879 .35005 .31651 .34873 .3288 Metetra
.959 .76 .591 r
.34873 .3288 .35005 .31651 .33931 .31613 .33815 .32165 Metetra
.965 .803 .632 r
.33815 .32165 .33931 .31613 .3286 .30853 .32724 .32068 Metetra
.949 .75 .599 r
.32724 .32068 .3286 .30853 .31767 .30303 .31659 .30461 Metetra
.855 .785 .781 r
.31659 .30461 .31767 .30303 .30666 .29475 .30574 .29117 Metetra
.959 .619 .289 r
.30574 .29117 .30666 .29475 .29613 .26679 .29473 .2779 Metetra
.956 .76 .599 r
.29473 .2779 .29613 .26679 .28485 .25816 .28347 .26805 Metetra
.959 .768 .602 r
.28347 .26805 .28485 .25816 .27315 .25643 .27191 .26181 Metetra
.992 .874 .544 r
.27191 .26181 .27315 .25643 .26036 .27861 .25894 .28793 Metetra
.928 .736 .623 r
.25894 .28793 .26036 .27861 .2485 .26975 .24787 .25897 Metetra
.974 .71 .469 r
.24787 .25897 .2485 .26975 .23755 .23481 .23616 .24245 Metetra
.932 .748 .631 r
.23616 .24245 .23755 .23481 .22581 .21601 .22455 .2204 Metetra
.948 .803 .667 r
.22455 .2204 .22581 .21601 .21351 .20639 .2121 .21377 Metetra
.954 .777 .624 r
.2121 .21377 .21351 .20639 .20117 .19334 .19951 .20568 Metetra
.946 .747 .603 r
.19951 .20568 .20117 .19334 .18864 .18083 .1874 .18394 Metetra
.958 .751 .583 r
.43893 .37422 .44007 .35852 .43076 .35041 .42962 .36444 Metetra
.957 .753 .587 r
.42962 .36444 .43076 .35041 .42136 .3412 .42019 .35513 Metetra
.958 .754 .587 r
.42019 .35513 .42136 .3412 .41181 .33366 .41064 .34628 Metetra
.96 .76 .588 r
.41064 .34628 .41181 .33366 .40217 .32385 .40091 .34033 Metetra
.96 .753 .58 r
.40091 .34033 .40217 .32385 .39239 .31513 .39108 .33272 Metetra
.957 .749 .581 r
.39108 .33272 .39239 .31513 .38244 .30824 .3812 .32078 Metetra
.965 .766 .584 r
.3812 .32078 .38244 .30824 .37233 .30236 .37098 .31921 Metetra
.966 .76 .574 r
.37098 .31921 .37233 .30236 .36212 .29497 .36057 .31879 Metetra
.965 .752 .567 r
.36057 .31879 .36212 .29497 .35159 .29453 .35005 .31651 Metetra
.966 .755 .568 r
.35005 .31651 .35159 .29453 .34097 .29109 .33931 .31613 Metetra
.962 .748 .569 r
.33931 .31613 .34097 .29109 .33037 .28099 .3286 .30853 Metetra
.963 .749 .566 r
.3286 .30853 .33037 .28099 .31958 .27256 .31767 .30303 Metetra
.962 .746 .565 r
.31767 .30303 .31958 .27256 .30873 .26085 .30666 .29475 Metetra
.955 .738 .571 r
.30666 .29475 .30873 .26085 .29766 .25155 .29613 .26679 Metetra
.959 .755 .584 r
.29613 .26679 .29766 .25155 .2864 .24328 .28485 .25816 Metetra
.965 .763 .58 r
.28485 .25816 .2864 .24328 .27478 .24016 .27315 .25643 Metetra
.982 .781 .557 r
.27315 .25643 .27478 .24016 .26284 .24061 .26036 .27861 Metetra
.962 .745 .562 r
.26036 .27861 .26284 .24061 .25101 .23302 .2485 .26975 Metetra
.953 .736 .571 r
.2485 .26975 .25101 .23302 .23917 .22145 .23755 .23481 Metetra
.949 .748 .597 r
.23755 .23481 .23917 .22145 .2269 .21564 .22581 .21601 Metetra
.663 .82 .959 r
.22581 .21601 .2269 .21564 .2146 .20604 .21351 .20639 Metetra
.662 .77 .93 r
.21351 .20639 .2146 .20604 .20224 .19361 .20117 .19334 Metetra
.284 .604 .953 r
.20117 .19334 .20224 .19361 .18986 .17798 .18864 .18083 Metetra
.968 .714 .498 r
.44007 .35852 .44089 .37155 .43161 .36078 .43076 .35041 Metetra
.969 .708 .482 r
.43076 .35041 .43161 .36078 .42217 .35362 .42136 .3412 Metetra
.967 .711 .496 r
.42136 .3412 .42217 .35362 .41261 .34603 .41181 .33366 Metetra
.969 .713 .492 r
.41181 .33366 .41261 .34603 .40292 .33807 .40217 .32385 Metetra
.968 .715 .501 r
.40217 .32385 .40292 .33807 .39307 .33218 .39239 .31513 Metetra
.966 .718 .511 r
.39239 .31513 .39307 .33218 .383 .33074 .38244 .30824 Metetra
.965 .722 .52 r
.38244 .30824 .383 .33074 .37219 .35741 .37233 .30236 Metetra
.965 .731 .535 r
.37233 .30236 .37219 .35741 .36201 .34486 .36212 .29497 Metetra
.963 .729 .536 r
.36212 .29497 .36201 .34486 .35159 .33703 .35159 .29453 Metetra
.964 .728 .533 r
.35159 .29453 .35159 .33703 .34102 .32924 .34097 .29109 Metetra
.966 .729 .529 r
.34097 .29109 .34102 .32924 .33011 .3285 .33037 .28099 Metetra
.965 .73 .533 r
.33037 .28099 .33011 .3285 .3193 .31787 .31958 .27256 Metetra
.966 .731 .531 r
.31958 .27256 .3193 .31787 .30833 .30799 .30873 .26085 Metetra
.965 .73 .532 r
.30873 .26085 .30833 .30799 .29728 .29566 .29766 .25155 Metetra
.965 .729 .532 r
.29766 .25155 .29728 .29566 .28593 .28783 .2864 .24328 Metetra
.964 .728 .533 r
.2864 .24328 .28593 .28783 .27443 .27937 .27478 .24016 Metetra
.962 .726 .533 r
.27478 .24016 .27443 .27937 .26182 .29608 .26284 .24061 Metetra
.965 .731 .535 r
.26284 .24061 .26182 .29608 .25045 .27446 .25101 .23302 Metetra
.966 .729 .529 r
.25101 .23302 .25045 .27446 .23894 .25273 .23917 .22145 Metetra
.964 .725 .526 r
.23917 .22145 .23894 .25273 .22671 .24487 .2269 .21564 Metetra
.966 .725 .523 r
.2269 .21564 .22671 .24487 .21564 .20673 .2146 .20604 Metetra
0 .302 .774 r
.2146 .20604 .21564 .20673 .20239 .21357 .20224 .19361 Metetra
.97 .723 .507 r
.20224 .19361 .20239 .21357 .19049 .18736 .18986 .17798 Metetra
.834 .792 .812 r
.44089 .37155 .44188 .3704 .43258 .36144 .43161 .36078 Metetra
0 .19 .639 r
.43161 .36078 .43258 .36144 .42318 .35078 .42217 .35362 Metetra
.927 .805 .705 r
.42217 .35362 .42318 .35078 .41361 .34447 .41261 .34603 Metetra
.883 .826 .786 r
.41261 .34603 .41361 .34447 .40389 .33909 .40292 .33807 Metetra
.712 .186 0 r
.40292 .33807 .40389 .33909 .39405 .33337 .39307 .33218 Metetra
.824 .357 .102 r
.39307 .33218 .39405 .33337 .384 .33053 .383 .33074 Metetra
.514 .2 .372 r
.383 .33074 .384 .33053 .37352 .34187 .37219 .35741 Metetra
.956 .75 .586 r
.37219 .35741 .37352 .34187 .36322 .33589 .36201 .34486 Metetra
.956 .767 .607 r
.36201 .34486 .36322 .33589 .35281 .32851 .35159 .33703 Metetra
.956 .768 .61 r
.35159 .33703 .35281 .32851 .34223 .32169 .34102 .32924 Metetra
.967 .787 .609 r
.34102 .32924 .34223 .32169 .33124 .32466 .33011 .3285 Metetra
.93 .786 .68 r
.33011 .3285 .33124 .32466 .32039 .31613 .3193 .31787 Metetra
.883 .817 .778 r
.3193 .31787 .32039 .31613 .3094 .30691 .30833 .30799 Metetra
.818 .796 .831 r
.30833 .30799 .3094 .30691 .29857 .28801 .29728 .29566 Metetra
.955 .773 .618 r
.29728 .29566 .29857 .28801 .28734 .27713 .28593 .28783 Metetra
.957 .763 .6 r
.28593 .28783 .28734 .27713 .2758 .27044 .27443 .27937 Metetra
.988 .81 .575 r
.27443 .27937 .2758 .27044 .26356 .27795 .26182 .29608 Metetra
.951 .744 .586 r
.26182 .29608 .26356 .27795 .25181 .26687 .25045 .27446 Metetra
.932 .748 .631 r
.25045 .27446 .25181 .26687 .24047 .24149 .23894 .25273 Metetra
.959 .764 .598 r
.23894 .25273 .24047 .24149 .22865 .22467 .22671 .24487 Metetra
.943 .732 .589 r
.22671 .24487 .22865 .22467 .21655 .21053 .21564 .20673 Metetra
.915 .602 .436 r
.21564 .20673 .21655 .21053 .20403 .20156 .20239 .21357 Metetra
.941 .742 .607 r
.20239 .21357 .20403 .20156 .19179 .18286 .19049 .18736 Metetra
.662 .787 .94 r
.44188 .3704 .44285 .37012 .43355 .36141 .43258 .36144 Metetra
.555 .716 .948 r
.43258 .36144 .43355 .36141 .42415 .35213 .42318 .35078 Metetra
.821 .345 0 r
.42318 .35078 .42415 .35213 .4146 .34442 .41361 .34447 Metetra
.448 .789 .998 r
.41361 .34447 .4146 .34442 .40486 .34068 .40389 .33909 Metetra
.872 .429 .092 r
.40389 .33909 .40486 .34068 .39504 .33312 .39405 .33337 Metetra
.524 .877 .985 r
.39405 .33337 .39504 .33312 .38501 .33033 .384 .33053 Metetra
.356 0 .04 r
.384 .33053 .38501 .33033 .37425 .35541 .37352 .34187 Metetra
.965 .711 .502 r
.37352 .34187 .37425 .35541 .36426 .33458 .36322 .33589 Metetra
.868 .847 .82 r
.36322 .33589 .36426 .33458 .35382 .32865 .35281 .32851 Metetra
.281 .681 .972 r
.35281 .32851 .35382 .32865 .34305 .32965 .34223 .32169 Metetra
.95 .68 .49 r
.34223 .32169 .34305 .32965 .33223 .32612 .33124 .32466 Metetra
.811 .336 0 r
.33124 .32466 .33223 .32612 .32149 .31375 .32039 .31613 Metetra
.911 .812 .736 r
.32039 .31613 .32149 .31375 .31046 .3063 .3094 .30691 Metetra
.723 .708 .836 r
.3094 .30691 .31046 .3063 .29969 .28568 .29857 .28801 Metetra
.903 .803 .74 r
.29857 .28801 .29969 .28568 .28844 .27546 .28734 .27713 Metetra
.896 .854 .793 r
.28734 .27713 .28844 .27546 .27655 .27913 .2758 .27044 Metetra
.944 .677 .5 r
.2758 .27044 .27655 .27913 .26438 .28454 .26356 .27795 Metetra
.969 .682 .431 r
.26356 .27795 .26438 .28454 .25272 .27093 .25181 .26687 Metetra
.947 .619 .195 r
.25181 .26687 .25272 .27093 .24169 .23793 .24047 .24149 Metetra
.909 .768 .694 r
.24047 .24149 .24169 .23793 .22937 .23304 .22865 .22467 Metetra
.972 .697 .449 r
.22865 .22467 .22937 .23304 .21775 .20771 .21655 .21053 Metetra
.924 .816 .721 r
.21655 .21053 .21775 .20771 .20538 .1959 .20403 .20156 Metetra
.928 .76 .652 r
.20403 .20156 .20538 .1959 .1931 .17822 .19179 .18286 Metetra
.9 .807 .748 r
.44285 .37012 .44384 .36811 .4346 .35539 .43355 .36141 Metetra
.946 .771 .633 r
.43355 .36141 .4346 .35539 .4252 .34609 .42415 .35213 Metetra
.95 .776 .631 r
.42415 .35213 .4252 .34609 .41566 .33918 .4146 .34442 Metetra
.958 .794 .637 r
.4146 .34442 .41566 .33918 .40595 .33441 .40486 .34068 Metetra
.951 .776 .629 r
.40486 .34068 .40595 .33441 .39608 .33088 .39504 .33312 Metetra
.939 .859 .736 r
.39504 .33312 .39608 .33088 .38605 .3278 .38501 .33033 Metetra
.689 .781 .303 r
.38501 .33033 .38605 .3278 .37524 .35603 .37425 .35541 Metetra
.328 .465 .846 r
.37425 .35541 .37524 .35603 .36479 .3564 .36426 .33458 Metetra
.965 .721 .518 r
.36426 .33458 .36479 .3564 .35433 .35041 .35382 .32865 Metetra
.961 .717 .524 r
.35382 .32865 .35433 .35041 .34376 .34237 .34305 .32965 Metetra
.962 .707 .501 r
.34305 .32965 .34376 .34237 .33282 .34257 .33223 .32612 Metetra
.97 .719 .501 r
.33223 .32612 .33282 .34257 .32229 .32192 .32149 .31375 Metetra
.965 .692 .465 r
.32149 .31375 .32229 .32192 .31127 .31407 .31046 .3063 Metetra
.981 .702 .417 r
.31046 .3063 .31127 .31407 .30016 .30371 .29969 .28568 Metetra
.968 .719 .508 r
.29969 .28568 .30016 .30371 .28886 .29431 .28844 .27546 Metetra
.958 .712 .521 r
.28844 .27546 .28886 .29431 .27726 .28887 .27655 .27913 Metetra
.95 .686 .501 r
.27655 .27913 .27726 .28887 .26513 .29281 .26438 .28454 Metetra
.972 .697 .449 r
.26438 .28454 .26513 .29281 .25328 .28405 .25272 .27093 Metetra
.985 .727 .454 r
.25272 .27093 .25328 .28405 .24168 .26439 .24169 .23793 Metetra
.964 .722 .523 r
.24169 .23793 .24168 .26439 .23037 .23478 .22937 .23304 Metetra
0 0 .489 r
.22937 .23304 .23037 .23478 .21751 .2374 .21775 .20771 Metetra
.967 .726 .522 r
.21775 .20771 .21751 .2374 .20599 .20602 .20538 .1959 Metetra
.975 .708 .46 r
.20538 .1959 .20599 .20602 .19407 .1808 .1931 .17822 Metetra
.929 .765 .658 r
.44384 .36811 .44486 .36344 .43562 .35126 .4346 .35539 Metetra
.936 .782 .666 r
.4346 .35539 .43562 .35126 .42626 .34039 .4252 .34609 Metetra
.951 .78 .634 r
.4252 .34609 .42626 .34039 .41671 .33395 .41566 .33918 Metetra
.955 .791 .638 r
.41566 .33918 .41671 .33395 .40697 .3324 .40595 .33441 Metetra
.929 .86 .752 r
.40595 .33441 .40697 .3324 .39709 .32944 .39608 .33088 Metetra
.904 .894 .809 r
.39608 .33088 .39709 .32944 .38718 .32117 .38605 .3278 Metetra
.997 .85 .519 r
.38605 .3278 .38718 .32117 .37651 .3431 .37524 .35603 Metetra
.968 .768 .581 r
.37524 .35603 .37651 .3431 .36608 .34402 .36479 .3564 Metetra
.961 .762 .589 r
.36479 .3564 .36608 .34402 .35583 .32985 .35433 .35041 Metetra
.961 .751 .573 r
.35433 .35041 .35583 .32985 .34509 .33002 .34376 .34237 Metetra
.968 .77 .583 r
.34376 .34237 .34509 .33002 .33413 .33201 .33282 .34257 Metetra
.942 .746 .609 r
.33282 .34257 .33413 .33201 .32348 .31655 .32229 .32192 Metetra
.949 .785 .645 r
.32229 .32192 .32348 .31655 .31305 .28911 .31127 .31407 Metetra
.961 .748 .57 r
.31127 .31407 .31305 .28911 .3023 .26889 .30016 .30371 Metetra
.962 .745 .563 r
.30016 .30371 .3023 .26889 .29107 .25957 .28886 .29431 Metetra
.964 .747 .561 r
.28886 .29431 .29107 .25957 .27932 .26038 .27726 .28887 Metetra
.968 .754 .561 r
.27726 .28887 .27932 .26038 .26673 .27827 .26513 .29281 Metetra
.96 .757 .586 r
.26513 .29281 .26673 .27827 .25527 .2601 .25328 .28405 Metetra
.956 .744 .576 r
.25328 .28405 .25527 .2601 .2444 .22372 .24168 .26439 Metetra
.957 .738 .566 r
.24168 .26439 .2444 .22372 .23235 .21342 .23037 .23478 Metetra
.968 .759 .568 r
.23037 .23478 .23235 .21342 .22005 .20454 .21751 .2374 Metetra
.954 .738 .571 r
.21751 .2374 .22005 .20454 .20758 .19517 .20599 .20602 Metetra
.939 .744 .611 r
.20599 .20602 .20758 .19517 .19528 .17821 .19407 .1808 Metetra
.919 .535 .13 r
.44486 .36344 .4458 .36592 .43655 .35471 .43562 .35126 Metetra
.959 .621 .297 r
.43562 .35126 .43655 .35471 .42716 .34582 .42626 .34039 Metetra
.963 .671 .429 r
.42626 .34039 .42716 .34582 .41763 .33833 .41671 .33395 Metetra
.948 .645 .428 r
.41671 .33395 .41763 .33833 .40798 .33095 .40697 .3324 Metetra
.906 .894 .806 r
.40697 .3324 .40798 .33095 .39819 .3234 .39709 .32944 Metetra
.95 .776 .632 r
.39709 .32944 .39819 .3234 .38829 .31518 .38718 .32117 Metetra
.998 .853 .548 r
.38718 .32117 .38829 .31518 .37834 .30261 .37651 .3431 Metetra
.966 .747 .556 r
.37651 .3431 .37834 .30261 .36806 .29935 .36608 .34402 Metetra
.961 .742 .56 r
.36608 .34402 .36806 .29935 .35762 .29628 .35583 .32985 Metetra
.966 .749 .559 r
.35583 .32985 .35762 .29628 .34671 .30586 .34509 .33002 Metetra
.968 .755 .563 r
.34509 .33002 .34671 .30586 .33605 .29831 .33413 .33201 Metetra
.96 .743 .565 r
.33413 .33201 .33605 .29831 .32533 .28747 .32348 .31655 Metetra
.954 .738 .573 r
.32348 .31655 .32533 .28747 .3147 .26844 .31305 .28911 Metetra
.954 .743 .58 r
.31305 .28911 .3147 .26844 .30375 .25587 .3023 .26889 Metetra
.958 .758 .59 r
.3023 .26889 .30375 .25587 .29257 .24568 .29107 .25957 Metetra
.968 .768 .58 r
.29107 .25957 .29257 .24568 .28119 .23684 .27932 .26038 Metetra
.976 .765 .555 r
.27932 .26038 .28119 .23684 .26857 .25711 .26673 .27827 Metetra
.956 .745 .578 r
.26673 .27827 .26857 .25711 .25713 .23938 .25527 .2601 Metetra
.944 .733 .587 r
.25527 .2601 .25713 .23938 .24604 .20944 .2444 .22372 Metetra
.959 .757 .588 r
.2444 .22372 .24604 .20944 .23398 .20008 .23235 .21342 Metetra
.959 .76 .59 r
.23235 .21342 .23398 .20008 .22174 .19045 .22005 .20454 Metetra
.959 .758 .588 r
.22005 .20454 .22174 .19045 .20932 .18078 .20758 .19517 Metetra
.953 .751 .592 r
.20758 .19517 .20932 .18078 .1971 .16286 .19528 .17821 Metetra
.95 .758 .608 r
.4458 .36592 .44686 .35683 .43759 .34949 .43655 .35471 Metetra
.944 .777 .644 r
.43655 .35471 .43759 .34949 .4282 .34173 .42716 .34582 Metetra
.942 .791 .664 r
.42716 .34582 .4282 .34173 .4187 .33234 .41763 .33833 Metetra
.951 .778 .631 r
.41763 .33833 .4187 .33234 .40906 .32481 .40798 .33095 Metetra
.951 .777 .63 r
.40798 .33095 .40906 .32481 .39929 .31713 .39819 .3234 Metetra
.95 .775 .629 r
.39819 .3234 .39929 .31713 .38949 .30405 .38829 .31518 Metetra
.952 .754 .599 r
.38829 .31518 .38949 .30405 .37946 .29649 .37834 .30261 Metetra
.961 .79 .625 r
.37834 .30261 .37946 .29649 .36903 .301 .36806 .29935 Metetra
.88 .454 .179 r
.36806 .29935 .36903 .301 .35867 .29475 .35762 .29628 Metetra
.84 .975 .669 r
.35762 .29628 .35867 .29475 .34803 .29389 .34671 .30586 Metetra
.959 .761 .592 r
.34671 .30586 .34803 .29389 .33724 .29202 .33605 .29831 Metetra
.946 .771 .634 r
.33605 .29831 .33724 .29202 .32643 .28491 .32533 .28747 Metetra
.875 .75 .722 r
.32533 .28747 .32643 .28491 .31581 .26587 .3147 .26844 Metetra
.902 .788 .726 r
.3147 .26844 .31581 .26587 .30489 .25274 .30375 .25587 Metetra
.924 .798 .703 r
.30375 .25587 .30489 .25274 .29367 .24399 .29257 .24568 Metetra
.887 .832 .787 r
.29257 .24568 .29367 .24399 .28213 .23998 .28119 .23684 Metetra
.861 .559 .476 r
.28119 .23684 .28213 .23998 .26967 .25592 .26857 .25711 Metetra
.804 .752 .804 r
.26857 .25711 .26967 .25592 .25803 .24367 .25713 .23938 Metetra
.933 .615 .16 r
.25713 .23938 .25803 .24367 .24608 .23492 .24604 .20944 Metetra
.966 .724 .519 r
.24604 .20944 .24608 .23492 .23431 .21765 .23398 .20008 Metetra
.967 .717 .506 r
.23398 .20008 .23431 .21765 .2222 .20467 .22174 .19045 Metetra
.967 .712 .496 r
.22174 .19045 .2222 .20467 .20965 .19724 .20932 .18078 Metetra
.972 .721 .494 r
.20932 .18078 .20965 .19724 .19751 .17713 .1971 .16286 Metetra
.963 .653 .389 r
.44686 .35683 .44779 .36119 .43859 .34708 .43759 .34949 Metetra
.918 .81 .725 r
.43759 .34949 .43859 .34708 .4292 .33958 .4282 .34173 Metetra
.902 .803 .74 r
.4282 .34173 .4292 .33958 .41969 .33214 .4187 .33234 Metetra
.606 .804 .976 r
.4187 .33234 .41969 .33214 .41002 .32644 .40906 .32481 Metetra
.861 .414 .031 r
.40906 .32481 .41002 .32644 .40017 .32384 .39929 .31713 Metetra
.975 .691 .424 r
.39929 .31713 .40017 .32384 .39004 .32846 .38949 .30405 Metetra
.966 .724 .519 r
.38949 .30405 .39004 .32846 .37988 .3259 .37946 .29649 Metetra
.961 .721 .531 r
.37946 .29649 .37988 .3259 .36927 .33726 .36903 .301 Metetra
.965 .728 .528 r
.36903 .301 .36927 .33726 .35881 .33296 .35867 .29475 Metetra
.963 .726 .531 r
.35867 .29475 .35881 .33296 .3481 .33279 .34803 .29389 Metetra
.964 .727 .531 r
.34803 .29389 .3481 .33279 .33718 .33369 .33724 .29202 Metetra
.965 .729 .53 r
.33724 .29202 .33718 .33369 .3264 .3233 .32643 .28491 Metetra
.969 .732 .523 r
.32643 .28491 .3264 .3233 .3151 .32546 .31581 .26587 Metetra
.967 .733 .533 r
.31581 .26587 .3151 .32546 .30465 .29398 .30489 .25274 Metetra
.966 .729 .529 r
.30489 .25274 .30465 .29398 .29339 .28462 .29367 .24399 Metetra
.964 .728 .53 r
.29367 .24399 .29339 .28462 .28162 .28528 .28213 .23998 Metetra
.959 .723 .538 r
.28213 .23998 .28162 .28528 .26943 .29178 .26967 .25592 Metetra
.967 .729 .525 r
.26967 .25592 .26943 .29178 .2576 .28296 .25803 .24367 Metetra
.966 .728 .528 r
.25803 .24367 .2576 .28296 .24659 .24912 .24608 .23492 Metetra
.973 .718 .486 r
.24608 .23492 .24659 .24912 .23514 .22352 .23431 .21765 Metetra
.97 .673 .405 r
.23431 .21765 .23514 .22352 .2223 .22689 .2222 .20467 Metetra
.966 .72 .516 r
.2222 .20467 .2223 .22689 .21039 .20486 .20965 .19724 Metetra
.978 .697 .418 r
.20965 .19724 .21039 .20486 .19826 .1842 .19751 .17713 Metetra
.977 .696 .423 r
.44779 .36119 .44869 .36818 .43944 .35837 .43859 .34708 Metetra
.968 .709 .489 r
.43859 .34708 .43944 .35837 .43009 .34679 .4292 .33958 Metetra
.967 .69 .455 r
.4292 .33958 .43009 .34679 .42057 .33934 .41969 .33214 Metetra
.964 .688 .461 r
.41969 .33214 .42057 .33934 .41087 .33571 .41002 .32644 Metetra
.961 .696 .487 r
.41002 .32644 .41087 .33571 .40105 .33108 .40017 .32384 Metetra
.946 .674 .49 r
.40017 .32384 .40105 .33108 .3911 .32547 .39004 .32846 Metetra
.952 .839 .695 r
.39004 .32846 .3911 .32547 .38036 .35287 .37988 .3259 Metetra
.957 .717 .533 r
.37988 .3259 .38036 .35287 .37046 .32894 .36927 .33726 Metetra
.962 .776 .606 r
.36927 .33726 .37046 .32894 .36005 .32338 .35881 .33296 Metetra
.968 .778 .594 r
.35881 .33296 .36005 .32338 .3493 .32551 .3481 .33279 Metetra
.97 .793 .608 r
.3481 .33279 .3493 .32551 .33859 .31927 .33718 .33369 Metetra
.958 .755 .586 r
.33718 .33369 .33859 .31927 .32785 .30821 .3264 .3233 Metetra
.969 .766 .575 r
.3264 .3233 .32785 .30821 .31693 .29834 .3151 .32546 Metetra
.951 .736 .576 r
.3151 .32546 .31693 .29834 .30614 .27949 .30465 .29398 Metetra
.959 .756 .586 r
.30465 .29398 .30614 .27949 .29484 .2723 .29339 .28462 Metetra
.969 .772 .584 r
.29339 .28462 .29484 .2723 .2832 .26982 .28162 .28528 Metetra
.973 .77 .571 r
.28162 .28528 .2832 .26982 .27132 .26888 .26943 .29178 Metetra
.962 .75 .571 r
.26943 .29178 .27132 .26888 .25966 .25676 .2576 .28296 Metetra
.95 .736 .578 r
.2576 .28296 .25966 .25676 .24822 .23511 .24659 .24912 Metetra
.945 .742 .598 r
.24659 .24912 .24822 .23511 .2363 .22153 .23514 .22352 Metetra
.943 .939 .756 r
.23514 .22352 .2363 .22153 .22347 .22483 .2223 .22689 Metetra
.847 .742 .748 r
.2223 .22689 .22347 .22483 .21143 .20583 .21039 .20486 Metetra
0 .248 .762 r
.21039 .20486 .21143 .20583 .19944 .18215 .19826 .1842 Metetra
0 .206 .702 r
.44869 .36818 .44966 .36895 .4404 .36006 .43944 .35837 Metetra
.798 .357 0 r
.43944 .35837 .4404 .36006 .43101 .35159 .43009 .34679 Metetra
.964 .661 .404 r
.43009 .34679 .43101 .35159 .4215 .34373 .42057 .33934 Metetra
.954 .647 .414 r
.42057 .33934 .4215 .34373 .41183 .33754 .41087 .33571 Metetra
.898 .484 .183 r
.41087 .33571 .41183 .33754 .40203 .33187 .40105 .33108 Metetra
.575 .017 0 r
.40105 .33108 .40203 .33187 .39195 .33373 .3911 .32547 Metetra
.912 .654 .534 r
.3911 .32547 .39195 .33373 .38122 .36066 .38036 .35287 Metetra
.984 .706 .397 r
.38036 .35287 .38122 .36066 .37127 .33839 .37046 .32894 Metetra
.964 .698 .48 r
.37046 .32894 .37127 .33839 .36086 .33257 .36005 .32338 Metetra
.954 .689 .495 r
.36005 .32338 .36086 .33257 .34963 .35442 .3493 .32551 Metetra
.966 .725 .523 r
.3493 .32551 .34963 .35442 .33892 .34656 .33859 .31927 Metetra
.968 .726 .519 r
.33859 .31927 .33892 .34656 .32806 .33851 .32785 .30821 Metetra
.967 .727 .522 r
.32785 .30821 .32806 .33851 .31704 .33038 .31693 .29834 Metetra
.97 .731 .518 r
.31693 .29834 .31704 .33038 .30687 .28969 .30614 .27949 Metetra
.966 .701 .481 r
.30614 .27949 .30687 .28969 .2956 .28108 .29484 .2723 Metetra
.959 .689 .48 r
.29484 .2723 .2956 .28108 .28305 .30526 .2832 .26982 Metetra
.963 .725 .529 r
.2832 .26982 .28305 .30526 .27138 .2969 .27132 .26888 Metetra
.968 .726 .519 r
.27132 .26888 .27138 .2969 .25954 .28816 .25966 .25676 Metetra
.971 .731 .516 r
.25966 .25676 .25954 .28816 .24879 .24773 .24822 .23511 Metetra
.971 .712 .483 r
.24822 .23511 .24879 .24773 .23738 .22129 .2363 .22153 Metetra
.2363 .22153 .23738 .22129 .22488 .21739 .22347 .22483 Metetra
.937 .756 .631 r
.22347 .22483 .22488 .21739 .21259 .20421 .21143 .20583 Metetra
.816 .726 .766 r
.21143 .20583 .21259 .20421 .20054 .1821 .19944 .18215 Metetra
.467 .71 .975 r
.44966 .36895 .45063 .36902 .44136 .36175 .4404 .36006 Metetra
.86 .417 .015 r
.4404 .36006 .44136 .36175 .43199 .35198 .43101 .35159 Metetra
.071 .506 .898 r
.43101 .35159 .43199 .35198 .42247 .34456 .4215 .34373 Metetra
.575 .025 0 r
.4215 .34373 .42247 .34456 .4128 .33953 .41183 .33754 Metetra
.909 .504 .191 r
.41183 .33754 .4128 .33953 .40302 .33198 .40203 .33187 Metetra
.285 0 0 r
.40203 .33187 .40302 .33198 .39289 .33731 .39195 .33373 Metetra
.853 .574 .515 r
.39195 .33373 .39289 .33731 .38243 .35034 .38122 .36066 Metetra
.939 .742 .611 r
.38122 .36066 .38243 .35034 .37225 .34028 .37127 .33839 Metetra
.898 .48 .162 r
.37127 .33839 .37225 .34028 .36191 .33111 .36086 .33257 Metetra
.36086 .33257 .36191 .33111 .35132 .32683 .34963 .35442 Metetra
.963 .748 .565 r
.34963 .35442 .35132 .32683 .34052 .32457 .33892 .34656 Metetra
.962 .751 .571 r
.33892 .34656 .34052 .32457 .32987 .31032 .32806 .33851 Metetra
.963 .748 .565 r
.32806 .33851 .32987 .31032 .31901 .29843 .31704 .33038 Metetra
.95 .733 .575 r
.31704 .33038 .31901 .29843 .30801 .28656 .30687 .28969 Metetra
.93 .807 .702 r
.30687 .28969 .30801 .28656 .29675 .27815 .2956 .28108 Metetra
.86 .89 .463 r
.2956 .28108 .29675 .27815 .28507 .27708 .28305 .30526 Metetra
.963 .748 .565 r
.28305 .30526 .28507 .27708 .27302 .28083 .27138 .2969 Metetra
.961 .756 .582 r
.27138 .2969 .27302 .28083 .26155 .26332 .25954 .28816 Metetra
.946 .732 .582 r
.25954 .28816 .26155 .26332 .25031 .23635 .24879 .24773 Metetra
.939 .741 .609 r
.24879 .24773 .25031 .23635 .2388 .21305 .23738 .22129 Metetra
.963 .781 .61 r
.23738 .22129 .2388 .21305 .22612 .21373 .22488 .21739 Metetra
.923 .786 .691 r
.22488 .21739 .22612 .21373 .21396 .19796 .21259 .20421 Metetra
.926 .751 .646 r
.21259 .20421 .21396 .19796 .20164 .1817 .20054 .1821 Metetra
.922 .812 .72 r
.45063 .36902 .45163 .36652 .44237 .35812 .44136 .36175 Metetra
.93 .785 .679 r
.44136 .36175 .44237 .35812 .43299 .35022 .43199 .35198 Metetra
.898 .828 .769 r
.43199 .35198 .43299 .35022 .42349 .34272 .42247 .34456 Metetra
.915 .852 .765 r
.42247 .34456 .42349 .34272 .41385 .33516 .4128 .33953 Metetra
.944 .79 .659 r
.4128 .33953 .41385 .33516 .40406 .32939 .40302 .33198 Metetra
.973 .907 .685 r
.40302 .33198 .40406 .32939 .39404 .32881 .39289 .33731 Metetra
.987 .806 .574 r
.39289 .33731 .39404 .32881 .38387 .3279 .38243 .35034 Metetra
.961 .749 .571 r
.38243 .35034 .38387 .3279 .37383 .31309 .37225 .34028 Metetra
.962 .747 .566 r
.37225 .34028 .37383 .31309 .36353 .30432 .36191 .33111 Metetra
.965 .75 .564 r
.36191 .33111 .36353 .30432 .35303 .29834 .35132 .32683 Metetra
.966 .75 .562 r
.35132 .32683 .35303 .29834 .34245 .28896 .34052 .32457 Metetra
.961 .743 .563 r
.34052 .32457 .34245 .28896 .33171 .28058 .32987 .31032 Metetra
.962 .746 .565 r
.32987 .31032 .33171 .28058 .32076 .27384 .31901 .29843 Metetra
.961 .747 .57 r
.31901 .29843 .32076 .27384 .3102 .24913 .30801 .28656 Metetra
.964 .745 .56 r
.30801 .28656 .3102 .24913 .29906 .239 .29675 .27815 Metetra
.966 .748 .557 r
.29675 .27815 .29906 .239 .28728 .24302 .28507 .27708 Metetra
.968 .751 .557 r
.28507 .27708 .28728 .24302 .27549 .24138 .27302 .28083 Metetra
.961 .742 .562 r
.27302 .28083 .27549 .24138 .26394 .22808 .26155 .26332 Metetra
.957 .739 .567 r
.26155 .26332 .26394 .22808 .25193 .22239 .25031 .23635 Metetra
.947 .744 .596 r
.25031 .23635 .25193 .22239 .23999 .21015 .2388 .21305 Metetra
.96 .872 .705 r
.2388 .21305 .23999 .21015 .22779 .20003 .22612 .21373 Metetra
.954 .753 .593 r
.22612 .21373 .22779 .20003 .21528 .19266 .21396 .19796 Metetra
.932 .768 .656 r
.21396 .19796 .21528 .19266 .20279 .18056 .20164 .1817 Metetra
0 .421 .85 r
.45163 .36652 .4526 .36702 .44333 .35963 .44237 .35812 Metetra
.83 .368 0 r
.44237 .35812 .44333 .35963 .434 .34823 .43299 .35022 Metetra
.907 .822 .752 r
.43299 .35022 .434 .34823 .4245 .34074 .42349 .34272 Metetra
.906 .823 .753 r
.42349 .34272 .4245 .34074 .41487 .33322 .41385 .33516 Metetra
.915 .842 .758 r
.41385 .33516 .41487 .33322 .40512 .32581 .40406 .32939 Metetra
.963 .835 .668 r
.40406 .32939 .40512 .32581 .39527 .31579 .39404 .32881 Metetra
.967 .766 .58 r
.39404 .32881 .39527 .31579 .38523 .30952 .38387 .3279 Metetra
.957 .747 .58 r
.38387 .3279 .38523 .30952 .37485 .31272 .37383 .31309 Metetra
.685 .815 .945 r
.37383 .31309 .37485 .31272 .36444 .30938 .36353 .30432 Metetra
.96 .66 .417 r
.36353 .30432 .36444 .30938 .35383 .30749 .35303 .29834 Metetra
.969 .7 .468 r
.35303 .29834 .35383 .30749 .34323 .29911 .34245 .28896 Metetra
.968 .703 .478 r
.34245 .28896 .34323 .29911 .33254 .28794 .33171 .28058 Metetra
.965 .686 .456 r
.33171 .28058 .33254 .28794 .32185 .27218 .32076 .27384 Metetra
.811 .708 .751 r
.32076 .27384 .32185 .27218 .31086 .2615 .3102 .24913 Metetra
.969 .711 .487 r
.3102 .24913 .31086 .2615 .29962 .25409 .29906 .239 Metetra
.957 .705 .514 r
.29906 .239 .29962 .25409 .28813 .24909 .28728 .24302 Metetra
.953 .665 .452 r
.28728 .24302 .28813 .24909 .27569 .26553 .27549 .24138 Metetra
.969 .725 .513 r
.27549 .24138 .27569 .26553 .26394 .25665 .26394 .22808 Metetra
.965 .724 .522 r
.26394 .22808 .26394 .25665 .25261 .23233 .25193 .22239 Metetra
.971 .703 .467 r
.25193 .22239 .25261 .23233 .24137 .20269 .23999 .21015 Metetra
.953 .773 .623 r
.23999 .21015 .24137 .20269 .22917 .19309 .22779 .20003 Metetra
.956 .782 .626 r
.22779 .20003 .22917 .19309 .21674 .18428 .21528 .19266 Metetra
.952 .767 .617 r
.21528 .19266 .21674 .18428 .20445 .16844 .20279 .18056 Metetra
.953 .774 .621 r
.4526 .36702 .45363 .36029 .4444 .35092 .44333 .35963 Metetra
.95 .759 .61 r
.44333 .35963 .4444 .35092 .43504 .34343 .434 .34823 Metetra
.947 .786 .649 r
.434 .34823 .43504 .34343 .42555 .33594 .4245 .34074 Metetra
.947 .786 .649 r
.4245 .34074 .42555 .33594 .41593 .32837 .41487 .33322 Metetra
.948 .787 .649 r
.41487 .33322 .41593 .32837 .40619 .32068 .40512 .32581 Metetra
.942 .776 .647 r
.40512 .32581 .40619 .32068 .3964 .30818 .39527 .31579 Metetra
.958 .774 .613 r
.39527 .31579 .3964 .30818 .38641 .30023 .38523 .30952 Metetra
.973 .785 .589 r
.38523 .30952 .38641 .30023 .3761 .30119 .37485 .31272 Metetra
.965 .767 .588 r
.37485 .31272 .3761 .30119 .36573 .29702 .36444 .30938 Metetra
.966 .767 .584 r
.36444 .30938 .36573 .29702 .35515 .29499 .35383 .30749 Metetra
.96 .76 .59 r
.35383 .30749 .35515 .29499 .34455 .28756 .34323 .29911 Metetra
.956 .758 .596 r
.34323 .29911 .34455 .28756 .33383 .27858 .33254 .28794 Metetra
.947 .755 .611 r
.33254 .28794 .33383 .27858 .32312 .26371 .32185 .27218 Metetra
.953 .766 .613 r
.32185 .27218 .32312 .26371 .3122 .25179 .31086 .2615 Metetra
.959 .768 .602 r
.31086 .2615 .3122 .25179 .30102 .24297 .29962 .25409 Metetra
.963 .768 .593 r
.29962 .25409 .30102 .24297 .28937 .24364 .28813 .24909 Metetra
.994 .857 .588 r
.28813 .24909 .28937 .24364 .2773 .2502 .27569 .26553 Metetra
.961 .757 .583 r
.27569 .26553 .2773 .2502 .26558 .2412 .26394 .25665 Metetra
.948 .743 .592 r
.26394 .25665 .26558 .2412 .25407 .22242 .25261 .23233 Metetra
.931 .737 .618 r
.25261 .23233 .25407 .22242 .24236 .20478 .24137 .20269 Metetra
.897 .478 .12 r
.24137 .20269 .24236 .20478 .23018 .19475 .22917 .19309 Metetra
.847 .388 .012 r
.22917 .19309 .23018 .19475 .2177 .18714 .21674 .18428 Metetra
.929 .553 .162 r
.21674 .18428 .2177 .18714 .20527 .17404 .20445 .16844 Metetra
.957 .618 .306 r
.45363 .36029 .45457 .36366 .44538 .35073 .4444 .35092 Metetra
.607 .802 .974 r
.4444 .35092 .44538 .35073 .43602 .34328 .43504 .34343 Metetra
.579 .794 .981 r
.43504 .34343 .43602 .34328 .42654 .33579 .42555 .33594 Metetra
.578 .794 .981 r
.42555 .33594 .42654 .33579 .41693 .32824 .41593 .32837 Metetra
.564 .788 .983 r
.41593 .32837 .41693 .32824 .40715 .32312 .40619 .32068 Metetra
.913 .524 .117 r
.40619 .32068 .40715 .32312 .39714 .32358 .3964 .30818 Metetra
.968 .716 .502 r
.3964 .30818 .39714 .32358 .38655 .34648 .38641 .30023 Metetra
.964 .728 .533 r
.38641 .30023 .38655 .34648 .37644 .33406 .3761 .30119 Metetra
.965 .726 .526 r
.3761 .30119 .37644 .33406 .366 .33099 .36573 .29702 Metetra
.964 .726 .528 r
.36573 .29702 .366 .33099 .35548 .32473 .35515 .29499 Metetra
.967 .726 .522 r
.35515 .29499 .35548 .32473 .34479 .31877 .34455 .28756 Metetra
.967 .727 .522 r
.34455 .28756 .34479 .31877 .33406 .30856 .33383 .27858 Metetra
.97 .729 .518 r
.33383 .27858 .33406 .30856 .32318 .29843 .32312 .26371 Metetra
.968 .729 .523 r
.32312 .26371 .32318 .29843 .31222 .28568 .3122 .25179 Metetra
.967 .728 .524 r
.3122 .25179 .31222 .28568 .30099 .27713 .30102 .24297 Metetra
.963 .724 .528 r
.30102 .24297 .30099 .27713 .28933 .27626 .28937 .24364 Metetra
.961 .721 .53 r
.28937 .24364 .28933 .27626 .27739 .27768 .2773 .2502 Metetra
.967 .725 .519 r
.2773 .2502 .27739 .27768 .26592 .26096 .26558 .2412 Metetra
.973 .725 .5 r
.26558 .2412 .26592 .26096 .25425 .2454 .25407 .22242 Metetra
.971 .726 .508 r
.25407 .22242 .25425 .2454 .24236 .23116 .24236 .20478 Metetra
.967 .725 .517 r
.24236 .20478 .24236 .23116 .23053 .21183 .23018 .19475 Metetra
.966 .715 .505 r
.23018 .19475 .23053 .21183 .21819 .20043 .2177 .18714 Metetra
.971 .713 .486 r
.2177 .18714 .21819 .20043 .20612 .17933 .20527 .17404 Metetra
.838 .771 .788 r
.45457 .36366 .45556 .36233 .44631 .35496 .44538 .35073 Metetra
.962 .648 .379 r
.44538 .35073 .44631 .35496 .43697 .34567 .43602 .34328 Metetra
.93 .547 .22 r
.43602 .34328 .43697 .34567 .42749 .33821 .42654 .33579 Metetra
.931 .55 .224 r
.42654 .33579 .42749 .33821 .41786 .33265 .41693 .32824 Metetra
.957 .649 .403 r
.41693 .32824 .41786 .33265 .40812 .32514 .40715 .32312 Metetra
.899 .522 .31 r
.40715 .32312 .40812 .32514 .39812 .32506 .39714 .32358 Metetra
.771 .461 .463 r
.39714 .32358 .39812 .32506 .38771 .33846 .38655 .34648 Metetra
.948 .761 .617 r
.38655 .34648 .38771 .33846 .37748 .33318 .37644 .33406 Metetra
.828 .93 .899 r
.37644 .33406 .37748 .33318 .36713 .32611 .366 .33099 Metetra
.952 .794 .649 r
.366 .33099 .36713 .32611 .35653 .32372 .35548 .32473 Metetra
.843 .88 .868 r
.35548 .32473 .35653 .32372 .34582 .31912 .34479 .31877 Metetra
.186 .556 .933 r
.34479 .31877 .34582 .31912 .33511 .30827 .33406 .30856 Metetra
.648 .79 .95 r
.33406 .30856 .33511 .30827 .32419 .2995 .32318 .29843 Metetra
0 .016 .541 r
.32318 .29843 .32419 .2995 .31319 .28842 .31222 .28568 Metetra
.937 .566 .252 r
.31222 .28568 .31319 .28842 .30189 .28185 .30099 .27713 Metetra
.946 .642 .428 r
.30099 .27713 .30189 .28185 .2904 .27593 .28933 .27626 Metetra
.352 .828 .832 r
.28933 .27626 .2904 .27593 .27841 .27911 .27739 .27768 Metetra
0 0 .431 r
.27739 .27768 .27841 .27911 .26697 .2615 .26592 .26096 Metetra
.174 .472 .892 r
.26592 .26096 .26697 .2615 .25531 .24563 .25425 .2454 Metetra
.382 .621 .946 r
.25425 .2454 .25531 .24563 .24373 .22409 .24236 .23116 Metetra
.936 .756 .634 r
.24236 .23116 .24373 .22409 .23174 .20893 .23053 .21183 Metetra
.918 .803 .718 r
.23053 .21183 .23174 .20893 .21941 .19756 .21819 .20043 Metetra
.882 .754 .716 r
.21819 .20043 .21941 .19756 .20736 .17619 .20612 .17933 Metetra
.925 .537 .202 r
.45556 .36233 .45651 .3646 .44731 .35284 .44631 .35496 Metetra
.902 .804 .742 r
.44631 .35496 .44731 .35284 .43799 .34246 .43697 .34567 Metetra
.934 .802 .69 r
.43697 .34567 .43799 .34246 .42852 .3351 .42749 .33821 Metetra
.941 .816 .692 r
.42749 .33821 .42852 .3351 .41888 .33024 .41786 .33265 Metetra
.92 .817 .727 r
.41786 .33265 .41888 .33024 .4091 .32595 .40812 .32514 Metetra
.732 .219 0 r
.40812 .32514 .4091 .32595 .39912 .3249 .39812 .32506 Metetra
.426 .008 .14 r
.39812 .32506 .39912 .3249 .38893 .32698 .38771 .33846 Metetra
.963 .765 .59 r
.38771 .33846 .38893 .32698 .37881 .31717 .37748 .33318 Metetra
.962 .756 .578 r
.37748 .33318 .37881 .31717 .36835 .31685 .36713 .32611 Metetra
.966 .776 .597 r
.36713 .32611 .36835 .31685 .35782 .31215 .35653 .32372 Metetra
.964 .766 .589 r
.35653 .32372 .35782 .31215 .34718 .30562 .34582 .31912 Metetra
.958 .756 .588 r
.34582 .31912 .34718 .30562 .3366 .29117 .33511 .30827 Metetra
.962 .754 .578 r
.33511 .30827 .3366 .29117 .32569 .28319 .32419 .2995 Metetra
.959 .753 .581 r
.32419 .2995 .32569 .28319 .3148 .26932 .31319 .28842 Metetra
.964 .755 .573 r
.31319 .28842 .3148 .26932 .3036 .261 .30189 .28185 Metetra
.964 .754 .57 r
.30189 .28185 .3036 .261 .2919 .26248 .2904 .27593 Metetra
.972 .772 .577 r
.2904 .27593 .2919 .26248 .28007 .26208 .27841 .27911 Metetra
.955 .748 .584 r
.27841 .27911 .28007 .26208 .26869 .24373 .26697 .2615 Metetra
.957 .749 .581 r
.26697 .2615 .26869 .24373 .25713 .22627 .25531 .24563 Metetra
.954 .745 .581 r
.25531 .24563 .25713 .22627 .24522 .21391 .24373 .22409 Metetra
.951 .758 .607 r
.24373 .22409 .24522 .21391 .23309 .20244 .23174 .20893 Metetra
.948 .776 .634 r
.23174 .20893 .23309 .20244 .22073 .1924 .21941 .19756 Metetra
.919 .754 .661 r
.21941 .19756 .22073 .1924 .20886 .16738 .20736 .17619 Metetra
.84 .415 0 r
.45651 .3646 .45747 .36649 .44828 .35391 .44731 .35284 Metetra
0 0 .48 r
.44731 .35284 .44828 .35391 .43894 .34526 .43799 .34246 Metetra
.944 .585 .278 r
.43799 .34246 .43894 .34526 .42947 .33779 .42852 .3351 Metetra
.938 .579 .304 r
.42852 .3351 .42947 .33779 .41981 .33501 .41888 .33024 Metetra
.957 .655 .419 r
.41888 .33024 .41981 .33501 .41005 .32938 .4091 .32595 Metetra
.939 .614 .393 r
.4091 .32595 .41005 .32938 .40007 .32822 .39912 .3249 Metetra
.927 .604 .41 r
.39912 .3249 .40007 .32822 .38996 .3262 .38893 .32698 Metetra
.789 .816 .874 r
.38893 .32698 .38996 .3262 .37954 .33153 .37881 .31717 Metetra
.961 .708 .508 r
.37881 .31717 .37954 .33153 .36921 .32442 .36835 .31685 Metetra
.963 .686 .464 r
.36835 .31685 .36921 .32442 .35866 .32043 .35782 .31215 Metetra
.966 .693 .466 r
.35782 .31215 .35866 .32043 .34802 .31363 .34718 .30562 Metetra
.976 .699 .438 r
.34718 .30562 .34802 .31363 .33731 .30356 .3366 .29117 Metetra
.968 .709 .49 r
.3366 .29117 .33731 .30356 .32666 .28569 .32569 .28319 Metetra
.91 .519 .107 r
.32569 .28319 .32666 .28569 .31566 .27589 .3148 .26932 Metetra
.966 .68 .437 r
.3148 .26932 .31566 .27589 .30422 .27481 .3036 .261 Metetra
.959 .704 .507 r
.3036 .261 .30422 .27481 .29271 .27011 .2919 .26248 Metetra
.955 .679 .473 r
.2919 .26248 .29271 .27011 .28092 .2681 .28007 .26208 Metetra
.977 .68 .377 r
.28007 .26208 .28092 .2681 .26941 .2532 .26869 .24373 Metetra
.977 .706 .449 r
.26869 .24373 .26941 .2532 .25803 .23081 .25713 .22627 Metetra
.965 .647 .355 r
.25713 .22627 .25803 .23081 .24629 .21416 .24522 .21391 Metetra
.288 .618 .959 r
.24522 .21391 .24629 .21416 .23419 .20211 .23309 .20244 Metetra
.642 .811 .964 r
.23309 .20244 .23419 .20211 .22184 .19179 .22073 .1924 Metetra
.703 .673 .819 r
.22073 .1924 .22184 .19179 .20972 .1724 .20886 .16738 Metetra
.575 .69 .919 r
.45747 .36649 .45844 .36647 .44925 .3548 .44828 .35391 Metetra
0 .042 .53 r
.44828 .35391 .44925 .3548 .43993 .34502 .43894 .34526 Metetra
.63 .812 .97 r
.43894 .34526 .43993 .34502 .43046 .3376 .42947 .33779 Metetra
.477 .857 .982 r
.42947 .33779 .43046 .3376 .4208 .3353 .41981 .33501 Metetra
.022 .526 .87 r
.41981 .33501 .4208 .3353 .41105 .32916 .41005 .32938 Metetra
.413 .85 .935 r
.41005 .32938 .41105 .32916 .40117 .32237 .40007 .32822 Metetra
.965 .797 .625 r
.40007 .32822 .40117 .32237 .39069 .34122 .38996 .3262 Metetra
.957 .706 .516 r
.38996 .3262 .39069 .34122 .38043 .33813 .37954 .33153 Metetra
.966 .681 .443 r
.37954 .33153 .38043 .33813 .37008 .33172 .36921 .32442 Metetra
.961 .683 .462 r
.36921 .32442 .37008 .33172 .35955 .32633 .35866 .32043 Metetra
.964 .672 .43 r
.35866 .32043 .35955 .32633 .34894 .31842 .34802 .31363 Metetra
.966 .656 .381 r
.34802 .31363 .34894 .31842 .33819 .30936 .33731 .30356 Metetra
.977 .679 .369 r
.33731 .30356 .33819 .30936 .32733 .2991 .32666 .28569 Metetra
.969 .713 .491 r
.32666 .28569 .32733 .2991 .31651 .28246 .31566 .27589 Metetra
.954 .671 .46 r
.31566 .27589 .31651 .28246 .3053 .27399 .30422 .27481 Metetra
.806 .913 .912 r
.30422 .27481 .3053 .27399 .29364 .27397 .29271 .27011 Metetra
.942 .62 .393 r
.29271 .27011 .29364 .27397 .28124 .28977 .28092 .2681 Metetra
.971 .725 .507 r
.28092 .2681 .28124 .28977 .27028 .25881 .26941 .2532 Metetra
.977 .674 .337 r
.26941 .2532 .27028 .25881 .25897 .23439 .25803 .23081 Metetra
.954 .607 .242 r
.25803 .23081 .25897 .23439 .24737 .21389 .24629 .21416 Metetra
.63 .773 .949 r
.24629 .21416 .24737 .21389 .23518 .2044 .23419 .20211 Metetra
.91 .503 .147 r
.23419 .20211 .23518 .2044 .22281 .1944 .22184 .19179 Metetra
.882 .496 .034 r
.22184 .19179 .22281 .1944 .21054 .1783 .20972 .1724 Metetra
.668 .743 .906 r
.45844 .36647 .45942 .36619 .45021 .35646 .44925 .3548 Metetra
.83 .383 0 r
.44925 .3548 .45021 .35646 .44089 .34761 .43993 .34502 Metetra
.938 .568 .25 r
.43993 .34502 .44089 .34761 .43144 .33824 .43046 .3376 Metetra
.604 .033 0 r
.43046 .3376 .43144 .33824 .42185 .33128 .4208 .3353 Metetra
.948 .8 .665 r
.4208 .3353 .42185 .33128 .41212 .32432 .41105 .32916 Metetra
.95 .79 .648 r
.41105 .32916 .41212 .32432 .40231 .31451 .40117 .32237 Metetra
.995 .823 .558 r
.40117 .32237 .40231 .31451 .39231 .30798 .39069 .34122 Metetra
.966 .748 .558 r
.39069 .34122 .39231 .30798 .382 .30969 .38043 .33813 Metetra
.965 .749 .562 r
.38043 .33813 .382 .30969 .37165 .30585 .37008 .33172 Metetra
.965 .75 .564 r
.37008 .33172 .37165 .30585 .36123 .29771 .35955 .32633 Metetra
.964 .748 .563 r
.35955 .32633 .36123 .29771 .35067 .28955 .34894 .31842 Metetra
.964 .748 .563 r
.34894 .31842 .35067 .28955 .33996 .28111 .33819 .30936 Metetra
.963 .747 .564 r
.33819 .30936 .33996 .28111 .32912 .27216 .32733 .2991 Metetra
.96 .745 .568 r
.32733 .2991 .32912 .27216 .31822 .25997 .31651 .28246 Metetra
.963 .751 .569 r
.31651 .28246 .31822 .25997 .30705 .25124 .3053 .27399 Metetra
.968 .756 .564 r
.3053 .27399 .30705 .25124 .2956 .24664 .29364 .27397 Metetra
.975 .761 .552 r
.29364 .27397 .2956 .24664 .28356 .25352 .28124 .28977 Metetra
.957 .738 .567 r
.28124 .28977 .28356 .25352 .27193 .24277 .27028 .25881 Metetra
.949 .743 .59 r
.27028 .25881 .27193 .24277 .26061 .21934 .25897 .23439 Metetra
.952 .747 .59 r
.25897 .23439 .26061 .21934 .24861 .20991 .24737 .21389 Metetra
.939 .799 .678 r
.24737 .21389 .24861 .20991 .2368 .19158 .23518 .2044 Metetra
.96 .761 .591 r
.23518 .2044 .2368 .19158 .22445 .18191 .22281 .1944 Metetra
.954 .755 .596 r
.22281 .1944 .22445 .18191 .21215 .16688 .21054 .1783 Metetra
.942 .776 .647 r
.45942 .36619 .46044 .36118 .45124 .35206 .45021 .35646 Metetra
.941 .784 .658 r
.45021 .35646 .45124 .35206 .44194 .34074 .44089 .34761 Metetra
.951 .769 .622 r
.44089 .34761 .44194 .34074 .43253 .32989 .43144 .33824 Metetra
.958 .77 .607 r
.43144 .33824 .43253 .32989 .42293 .32484 .42185 .33128 Metetra
.955 .778 .624 r
.42185 .33128 .42293 .32484 .41326 .31469 .41212 .32432 Metetra
.955 .762 .602 r
.41212 .32432 .41326 .31469 .40357 .29868 .40231 .31451 Metetra
.963 .757 .577 r
.40231 .31451 .40357 .29868 .39362 .29084 .39231 .30798 Metetra
.97 .762 .568 r
.39231 .30798 .39362 .29084 .38316 .30238 .382 .30969 Metetra
.963 .783 .612 r
.382 .30969 .38316 .30238 .37289 .29517 .37165 .30585 Metetra
.959 .763 .596 r
.37165 .30585 .37289 .29517 .36245 .28911 .36123 .29771 Metetra
.957 .769 .608 r
.36123 .29771 .36245 .28911 .35191 .28091 .35067 .28955 Metetra
.957 .769 .608 r
.35067 .28955 .35191 .28091 .34116 .27493 .33996 .28111 Metetra
.951 .778 .632 r
.33996 .28111 .34116 .27493 .33039 .26388 .32912 .27216 Metetra
.951 .764 .615 r
.32912 .27216 .33039 .26388 .31942 .25433 .31822 .25997 Metetra
.95 .783 .64 r
.31822 .25997 .31942 .25433 .30825 .24647 .30705 .25124 Metetra
.957 .805 .651 r
.30705 .25124 .30825 .24647 .29688 .23964 .2956 .24664 Metetra
.981 .812 .6 r
.2956 .24664 .29688 .23964 .28517 .23756 .28356 .25352 Metetra
.96 .755 .581 r
.28356 .25352 .28517 .23756 .27347 .22969 .27193 .24277 Metetra
.947 .745 .598 r
.27193 .24277 .27347 .22969 .26162 .22119 .26061 .21934 Metetra
.871 .431 .054 r
.26061 .21934 .26162 .22119 .24977 .2079 .24861 .20991 Metetra
.86 .764 .755 r
.24861 .20991 .24977 .2079 .23762 .19782 .2368 .19158 Metetra
.966 .674 .423 r
.2368 .19158 .23762 .19782 .22511 .19167 .22445 .18191 Metetra
.974 .704 .457 r
.22445 .18191 .22511 .19167 .21281 .17636 .21215 .16688 Metetra
.971 .684 .427 r
.46044 .36118 .46136 .36741 .45216 .35863 .45124 .35206 Metetra
.974 .689 .424 r
.45124 .35206 .45216 .35863 .44282 .35122 .44194 .34074 Metetra
.973 .709 .473 r
.44194 .34074 .44282 .35122 .43335 .34381 .43253 .32989 Metetra
.966 .712 .5 r
.43253 .32989 .43335 .34381 .42377 .33629 .42293 .32484 Metetra
.971 .711 .481 r
.42293 .32484 .42377 .33629 .41405 .3288 .41326 .31469 Metetra
.975 .721 .483 r
.41326 .31469 .41405 .3288 .40409 .32822 .40357 .29868 Metetra
.968 .727 .52 r
.40357 .29868 .40409 .32822 .39388 .33297 .39362 .29084 Metetra
.961 .724 .535 r
.39362 .29084 .39388 .33297 .3834 .34263 .38316 .30238 Metetra
.967 .729 .526 r
.38316 .30238 .3834 .34263 .3731 .3342 .37289 .29517 Metetra
.967 .729 .526 r
.37289 .29517 .3731 .3342 .36253 .3314 .36245 .28911 Metetra
.967 .73 .527 r
.36245 .28911 .36253 .3314 .35142 .34422 .35191 .28091 Metetra
.966 .732 .532 r
.35191 .28091 .35142 .34422 .34075 .33144 .34116 .27493 Metetra
.968 .732 .529 r
.34116 .27493 .34075 .33144 .32977 .32497 .33039 .26388 Metetra
.967 .732 .531 r
.33039 .26388 .32977 .32497 .31882 .31137 .31942 .25433 Metetra
.967 .732 .53 r
.31942 .25433 .31882 .31137 .30763 .30117 .30825 .24647 Metetra
.967 .731 .53 r
.30825 .24647 .30763 .30117 .29589 .30291 .29688 .23964 Metetra
.966 .731 .533 r
.29688 .23964 .29589 .30291 .2843 .29434 .28517 .23756 Metetra
.967 .731 .53 r
.28517 .23756 .2843 .29434 .27253 .28556 .27347 .22969 Metetra
.967 .731 .53 r
.27347 .22969 .27253 .28556 .2606 .27674 .26162 .22119 Metetra
.968 .732 .528 r
.26162 .22119 .2606 .27674 .25033 .22106 .24977 .2079 Metetra
.969 .711 .488 r
.24977 .2079 .25033 .22106 .23815 .21119 .23762 .19782 Metetra
.966 .708 .494 r
.23762 .19782 .23815 .21119 .22588 .19911 .22511 .19167 Metetra
.974 .691 .426 r
.22511 .19167 .22588 .19911 .21362 .18271 .21281 .17636 Metetra
.971 .703 .467 r
.46136 .36741 .46227 .37654 .45307 .36656 .45216 .35863 Metetra
.968 .695 .46 r
.45216 .35863 .45307 .36656 .44372 .35914 .44282 .35122 Metetra
.968 .695 .459 r
.44282 .35122 .44372 .35914 .43425 .35172 .43335 .34381 Metetra
.968 .694 .459 r
.43335 .34381 .43425 .35172 .42466 .3443 .42377 .33629 Metetra
.968 .694 .46 r
.42377 .33629 .42466 .3443 .41492 .33786 .41405 .3288 Metetra
.959 .692 .487 r
.41405 .3288 .41492 .33786 .40507 .33015 .40409 .32822 Metetra
.876 .511 .352 r
.40409 .32822 .40507 .33015 .39415 .37517 .39388 .33297 Metetra
.962 .725 .534 r
.39388 .33297 .39415 .37517 .38385 .37246 .3834 .34263 Metetra
.968 .727 .52 r
.3834 .34263 .38385 .37246 .37349 .36486 .3731 .3342 Metetra
.965 .725 .524 r
.3731 .3342 .37349 .36486 .36299 .35708 .36253 .3314 Metetra
.957 .715 .53 r
.36253 .3314 .36299 .35708 .35235 .34909 .35142 .34422 Metetra
.97 .659 .363 r
.35142 .34422 .35235 .34909 .34145 .3451 .34075 .33144 Metetra
.967 .711 .495 r
.34075 .33144 .34145 .3451 .3305 .33661 .32977 .32497 Metetra
.973 .711 .474 r
.32977 .32497 .3305 .33661 .3194 .32794 .31882 .31137 Metetra
.969 .718 .499 r
.31882 .31137 .3194 .32794 .30792 .3266 .30763 .30117 Metetra
.963 .719 .522 r
.30763 .30117 .30792 .3266 .29649 .3175 .29589 .30291 Metetra
.968 .713 .495 r
.29589 .30291 .29649 .3175 .28476 .31226 .2843 .29434 Metetra
.968 .718 .504 r
.2843 .29434 .28476 .31226 .27341 .2913 .27253 .28556 Metetra
.965 .667 .414 r
.27253 .28556 .27341 .2913 .26149 .28185 .2606 .27674 Metetra
.737 .498 0 r
.2606 .27674 .26149 .28185 .25078 .23707 .25033 .22106 Metetra
.969 .716 .498 r
.25033 .22106 .25078 .23707 .23848 .22958 .23815 .21119 Metetra
.97 .72 .501 r
.23815 .21119 .23848 .22958 .22703 .19777 .22588 .19911 Metetra
.826 .777 .806 r
.22588 .19911 .22703 .19777 .21481 .18068 .21362 .18271 Metetra
.897 .798 .742 r
.46227 .37654 .46326 .37445 .45405 .36644 .45307 .36656 Metetra
.562 .788 .984 r
.45307 .36656 .45405 .36644 .44478 .35218 .44372 .35914 Metetra
.955 .774 .618 r
.44372 .35914 .44478 .35218 .43534 .34369 .43425 .35172 Metetra
.957 .77 .609 r
.43425 .35172 .43534 .34369 .42571 .3401 .42466 .3443 Metetra
.948 .798 .66 r
.42466 .3443 .42571 .3401 .41593 .3374 .41492 .33786 Metetra
.717 .837 .938 r
.41492 .33786 .41593 .3374 .40603 .33293 .40507 .33015 Metetra
.785 .521 .538 r
.40507 .33015 .40603 .33293 .39539 .36276 .39415 .37517 Metetra
.967 .767 .583 r
.39415 .37517 .39539 .36276 .38502 .36487 .38385 .37246 Metetra
.957 .774 .615 r
.38385 .37246 .38502 .36487 .37468 .3572 .37349 .36486 Metetra
.957 .774 .615 r
.37349 .36486 .37468 .3572 .3642 .34937 .36299 .35708 Metetra
.957 .773 .615 r
.36299 .35708 .3642 .34937 .35357 .34148 .35235 .34909 Metetra
.963 .783 .611 r
.35235 .34909 .35357 .34148 .34279 .33341 .34145 .3451 Metetra
.96 .762 .592 r
.34145 .3451 .34279 .33341 .33186 .32522 .3305 .33661 Metetra
.96 .763 .594 r
.3305 .33661 .33186 .32522 .32077 .31697 .3194 .32794 Metetra
.968 .774 .588 r
.3194 .32794 .32077 .31697 .30952 .30857 .30792 .3266 Metetra
.962 .754 .576 r
.30792 .3266 .30952 .30857 .29811 .30012 .29649 .3175 Metetra
.965 .758 .574 r
.29649 .3175 .29811 .30012 .28654 .29153 .28476 .31226 Metetra
.956 .745 .578 r
.28476 .31226 .28654 .29153 .27479 .28266 .27341 .2913 Metetra
.957 .771 .611 r
.27341 .2913 .27479 .28266 .26288 .27368 .26149 .28185 Metetra
.902 .712 .636 r
.26149 .28185 .26288 .27368 .25222 .22792 .25078 .23707 Metetra
.96 .773 .606 r
.25078 .23707 .25222 .22792 .24002 .21858 .23848 .22958 Metetra
.934 .736 .612 r
.23848 .22958 .24002 .21858 .22794 .20203 .22703 .19777 Metetra
.965 .636 .299 r
.22703 .19777 .22794 .20203 .21588 .18126 .21481 .18068 Metetra
.953 .774 .624 r
.46326 .37445 .46429 .36801 .45512 .3565 .45405 .36644 Metetra
.949 .753 .604 r
.45405 .36644 .45512 .3565 .4458 .34873 .44478 .35218 Metetra
.934 .795 .683 r
.44478 .35218 .4458 .34873 .43636 .34127 .43534 .34369 Metetra
.941 .847 .723 r
.43534 .34369 .43636 .34127 .42678 .33423 .42571 .3401 Metetra
.964 .794 .624 r
.42571 .3401 .42678 .33423 .41702 .33137 .41593 .3374 Metetra
.96 .789 .625 r
.41593 .3374 .41702 .33137 .40709 .32953 .40603 .33293 Metetra
.788 .807 .321 r
.40603 .33293 .40709 .32953 .39685 .33691 .39539 .36276 Metetra
.969 .755 .558 r
.39539 .36276 .39685 .33691 .38656 .33737 .38502 .36487 Metetra
.964 .749 .563 r
.38502 .36487 .38656 .33737 .3762 .33322 .37468 .3572 Metetra
.964 .75 .566 r
.37468 .3572 .3762 .33322 .36575 .32557 .3642 .34937 Metetra
.964 .751 .566 r
.3642 .34937 .36575 .32557 .35521 .31588 .35357 .34148 Metetra
.964 .75 .565 r
.35357 .34148 .35521 .31588 .34451 .30635 .34279 .33341 Metetra
.964 .749 .564 r
.34279 .33341 .34451 .30635 .3336 .29951 .33186 .32522 Metetra
.964 .75 .565 r
.33186 .32522 .3336 .29951 .3227 .28632 .32077 .31697 Metetra
.965 .748 .561 r
.32077 .31697 .3227 .28632 .31146 .27954 .30952 .30857 Metetra
.964 .749 .562 r
.30952 .30857 .31146 .27954 .29992 .27684 .29811 .30012 Metetra
.964 .751 .568 r
.29811 .30012 .29992 .27684 .28829 .27123 .28654 .29153 Metetra
.963 .753 .572 r
.28654 .29153 .28829 .27123 .27676 .25765 .27479 .28266 Metetra
.964 .75 .566 r
.27479 .28266 .27676 .25765 .26513 .2421 .26288 .27368 Metetra
.95 .732 .574 r
.26288 .27368 .26513 .2421 .25356 .22124 .25222 .22792 Metetra
.953 .78 .629 r
.25222 .22792 .25356 .22124 .24139 .2117 .24002 .21858 Metetra
.941 .763 .634 r
.24002 .21858 .24139 .2117 .2292 .1979 .22794 .20203 Metetra
.909 .758 .681 r
.22794 .20203 .2292 .1979 .21746 .17032 .21588 .18126 Metetra
.766 .32 0 r
.46429 .36801 .46525 .36963 .45606 .36127 .45512 .3565 Metetra
.965 .66 .394 r
.45512 .3565 .45606 .36127 .44673 .35392 .4458 .34873 Metetra
.966 .667 .41 r
.4458 .34873 .44673 .35392 .43729 .34637 .43636 .34127 Metetra
.965 .664 .409 r
.43636 .34127 .43729 .34637 .42772 .33889 .42678 .33423 Metetra
.954 .651 .421 r
.42678 .33423 .42772 .33889 .41802 .33126 .41702 .33137 Metetra
.304 .782 .922 r
.41702 .33137 .41802 .33126 .40816 .32514 .40709 .32953 Metetra
.987 .852 .621 r
.40709 .32953 .40816 .32514 .39807 .32486 .39685 .33691 Metetra
.97 .772 .58 r
.39685 .33691 .39807 .32486 .38775 .32811 .38656 .33737 Metetra
.964 .774 .598 r
.38656 .33737 .38775 .32811 .37747 .32105 .3762 .33322 Metetra
.961 .762 .588 r
.3762 .33322 .37747 .32105 .36705 .31352 .36575 .32557 Metetra
.959 .76 .591 r
.36575 .32557 .36705 .31352 .35652 .30413 .35521 .31588 Metetra
.959 .761 .592 r
.35521 .31588 .35652 .30413 .34581 .29596 .34451 .30635 Metetra
.962 .768 .596 r
.34451 .30635 .34581 .29596 .33497 .28742 .3336 .29951 Metetra
.956 .756 .594 r
.3336 .29951 .33497 .28742 .32431 .26633 .3227 .28632 Metetra
.965 .754 .57 r
.3227 .28632 .32431 .26633 .31305 .2616 .31146 .27954 Metetra
.967 .759 .571 r
.31146 .27954 .31305 .2616 .30151 .26011 .29992 .27684 Metetra
.965 .759 .575 r
.29992 .27684 .30151 .26011 .28989 .2553 .28829 .27123 Metetra
.959 .753 .583 r
.28829 .27123 .28989 .2553 .27883 .22935 .27676 .25765 Metetra
.961 .746 .566 r
.27676 .25765 .27883 .22935 .26713 .21732 .26513 .2421 Metetra
.958 .744 .572 r
.26513 .2421 .26713 .21732 .2551 .20963 .25356 .22124 Metetra
.96 .764 .594 r
.25356 .22124 .2551 .20963 .24298 .19935 .24139 .2117 Metetra
.956 .757 .595 r
.24139 .2117 .24298 .19935 .23035 .19677 .2292 .1979 Metetra
.761 .687 .78 r
.2292 .1979 .23035 .19677 .21819 .17849 .21746 .17032 Metetra
.821 .36 0 r
.46525 .36963 .46622 .37116 .45703 .36274 .45606 .36127 Metetra
.825 .358 0 r
.45606 .36127 .45703 .36274 .44772 .354 .44673 .35392 Metetra
.398 .713 .986 r
.44673 .35392 .44772 .354 .43834 .34141 .43729 .34637 Metetra
.949 .786 .645 r
.43729 .34637 .43834 .34141 .42878 .33372 .42772 .33889 Metetra
.95 .785 .642 r
.42772 .33889 .42878 .33372 .41913 .32322 .41802 .33126 Metetra
.96 .774 .607 r
.41802 .33126 .41913 .32322 .40935 .3133 .40816 .32514 Metetra
.97 .771 .581 r
.40816 .32514 .40935 .3133 .39938 .30745 .39807 .32486 Metetra
.972 .764 .565 r
.39807 .32486 .39938 .30745 .38911 .30992 .38775 .32811 Metetra
.964 .755 .572 r
.38775 .32811 .38911 .30992 .3788 .30552 .37747 .32105 Metetra
.963 .757 .578 r
.37747 .32105 .3788 .30552 .36842 .29746 .36705 .31352 Metetra
.962 .755 .579 r
.36705 .31352 .36842 .29746 .3579 .28924 .35652 .30413 Metetra
.962 .758 .581 r
.35652 .30413 .3579 .28924 .34722 .28109 .34581 .29596 Metetra
.962 .757 .581 r
.34581 .29596 .34722 .28109 .33641 .27215 .33497 .28742 Metetra
.951 .745 .589 r
.33497 .28742 .33641 .27215 .32553 .26028 .32431 .26633 Metetra
.961 .792 .629 r
.32431 .26633 .32553 .26028 .3144 .25197 .31305 .2616 Metetra
.968 .779 .594 r
.31305 .2616 .3144 .25197 .303 .24672 .30151 .26011 Metetra
.965 .765 .583 r
.30151 .26011 .303 .24672 .29149 .23927 .28989 .2553 Metetra
.949 .742 .59 r
.28989 .2553 .29149 .23927 .27993 .2284 .27883 .22935 Metetra
.802 .81 .858 r
.27883 .22935 .27993 .2284 .26815 .21894 .26713 .21732 Metetra
.848 .387 .024 r
.26713 .21732 .26815 .21894 .25617 .20991 .2551 .20963 Metetra
.22 .6 .95 r
.2551 .20963 .25617 .20991 .24401 .20071 .24298 .19935 Metetra
.825 .355 .081 r
.24298 .19935 .24401 .20071 .23171 .19049 .23035 .19677 Metetra
.935 .761 .642 r
.23035 .19677 .23171 .19049 .21931 .17816 .21819 .17849 Metetra
.956 .766 .605 r
.46622 .37116 .46726 .36256 .45808 .35377 .45703 .36274 Metetra
.957 .765 .603 r
.45703 .36274 .45808 .35377 .44878 .3463 .44772 .354 Metetra
.947 .761 .618 r
.44772 .354 .44878 .3463 .43941 .33359 .43834 .34141 Metetra
.957 .771 .611 r
.43834 .34141 .43941 .33359 .42987 .32599 .42878 .33372 Metetra
.952 .766 .615 r
.42878 .33372 .42987 .32599 .42023 .31587 .41913 .32322 Metetra
.952 .768 .618 r
.41913 .32322 .42023 .31587 .41056 .30039 .40935 .3133 Metetra
.964 .762 .583 r
.40935 .3133 .41056 .30039 .40056 .29746 .39938 .30745 Metetra
.973 .781 .584 r
.39938 .30745 .40056 .29746 .39047 .29137 .38911 .30992 Metetra
.966 .756 .57 r
.38911 .30992 .39047 .29137 .38 .29684 .3788 .30552 Metetra
.958 .769 .606 r
.3788 .30552 .38 .29684 .36955 .29265 .36842 .29746 Metetra
.948 .789 .652 r
.36842 .29746 .36955 .29265 .35902 .28526 .3579 .28924 Metetra
.943 .798 .671 r
.3579 .28924 .35902 .28526 .34838 .27646 .34722 .28109 Metetra
.945 .79 .657 r
.34722 .28109 .34838 .27646 .33774 .26127 .33641 .27215 Metetra
.956 .76 .598 r
.33641 .27215 .33774 .26127 .32679 .25262 .32553 .26028 Metetra
.957 .775 .616 r
.32553 .26028 .32679 .25262 .31569 .24373 .3144 .25197 Metetra
.963 .779 .608 r
.3144 .25197 .31569 .24373 .30433 .23815 .303 .24672 Metetra
.96 .774 .608 r
.303 .24672 .30433 .23815 .29276 .23311 .29149 .23927 Metetra
.949 .777 .636 r
.29149 .23927 .29276 .23311 .28115 .22408 .27993 .2284 Metetra
.942 .795 .668 r
.27993 .2284 .28115 .22408 .26938 .21472 .26815 .21894 Metetra
.943 .798 .671 r
.26815 .21894 .26938 .21472 .25742 .20546 .25617 .20991 Metetra
.944 .796 .666 r
.25617 .20991 .25742 .20546 .24529 .19592 .24401 .20071 Metetra
.944 .79 .66 r
.24401 .20071 .24529 .19592 .23281 .19014 .23171 .19049 Metetra
.66 .784 .94 r
.23171 .19049 .23281 .19014 .22069 .17164 .21931 .17816 Metetra
.942 .784 .656 r
.46726 .36256 .46827 .35812 .45909 .35071 .45808 .35377 Metetra
.933 .805 .695 r
.45808 .35377 .45909 .35071 .44982 .34096 .44878 .3463 Metetra
.937 .767 .645 r
.44878 .3463 .44982 .34096 .44041 .33339 .43941 .33359 Metetra
.606 .804 .976 r
.43941 .33359 .44041 .33339 .43087 .32577 .42987 .32599 Metetra
.636 .767 .942 r
.42987 .32599 .43087 .32577 .42121 .31799 .42023 .31587 Metetra
.815 .411 0 r
.42023 .31587 .42121 .31799 .41165 .29437 .41056 .30039 Metetra
.964 .793 .622 r
.41056 .30039 .41165 .29437 .40166 .29201 .40056 .29746 Metetra
.956 .789 .636 r
.40056 .29746 .40166 .29201 .39159 .28548 .39047 .29137 Metetra
.981 .819 .607 r
.39047 .29137 .39159 .28548 .38132 .28146 .38 .29684 Metetra
.966 .76 .575 r
.38 .29684 .38132 .28146 .37084 .2807 .36955 .29265 Metetra
.962 .763 .589 r
.36955 .29265 .37084 .2807 .36009 .284 .35902 .28526 Metetra
.857 .837 .825 r
.35902 .28526 .36009 .284 .34943 .27558 .34838 .27646 Metetra
.779 .759 .835 r
.34838 .27646 .34943 .27558 .33901 .25261 .33774 .26127 Metetra
.958 .77 .608 r
.33774 .26127 .33901 .25261 .32808 .2439 .32679 .25262 Metetra
.958 .77 .608 r
.32679 .25262 .32808 .2439 .317 .23499 .31569 .24373 Metetra
.963 .776 .604 r
.31569 .24373 .317 .23499 .30555 .23275 .30433 .23815 Metetra
.959 .798 .639 r
.30433 .23815 .30555 .23275 .29383 .23298 .29276 .23311 Metetra
.543 .784 .987 r
.29276 .23311 .29383 .23298 .28222 .22395 .28115 .22408 Metetra
.546 .782 .986 r
.28115 .22408 .28222 .22395 .27046 .21459 .26938 .21472 Metetra
.543 .785 .988 r
.26938 .21472 .27046 .21459 .25856 .20403 .25742 .20546 Metetra
.866 .841 .819 r
.25742 .20546 .25856 .20403 .24644 .19441 .24529 .19592 Metetra
.89 .882 .819 r
.24529 .19592 .24644 .19441 .23412 .18508 .23281 .19014 Metetra
.926 .764 .661 r
.23281 .19014 .23412 .18508 .22171 .17332 .22069 .17164 Metetra
.96 .636 .354 r
.46827 .35812 .46922 .36195 .46007 .35054 .45909 .35071 Metetra
.616 .759 .947 r
.45909 .35071 .46007 .35054 .45081 .34079 .44982 .34096 Metetra
.593 .798 .978 r
.44982 .34096 .45081 .34079 .4414 .33324 .44041 .33339 Metetra
.579 .794 .981 r
.44041 .33339 .4414 .33324 .43187 .32561 .43087 .32577 Metetra
.579 .793 .98 r
.43087 .32577 .43187 .32561 .42221 .31781 .42121 .31799 Metetra
.635 .617 .815 r
.42121 .31799 .42221 .31781 .41261 .29735 .41165 .29437 Metetra
.936 .593 .351 r
.41165 .29437 .41261 .29735 .40268 .29156 .40166 .29201 Metetra
.706 .861 .956 r
.40166 .29201 .40268 .29156 .39261 .28534 .39159 .28548 Metetra
.454 .828 .991 r
.39159 .28548 .39261 .28534 .38235 .28117 .38132 .28146 Metetra
.446 .872 .929 r
.38132 .28146 .38235 .28117 .37182 .28259 .37084 .2807 Metetra
.878 .499 .32 r
.37084 .2807 .37182 .28259 .36112 .284 .36009 .284 Metetra
.457 .744 .99 r
.36009 .284 .36112 .284 .35057 .27162 .34943 .27558 Metetra
.896 .74 .68 r
.34943 .27558 .35057 .27162 .33999 .25492 .33901 .25261 Metetra
.917 .519 .173 r
.33901 .25261 .33999 .25492 .32914 .24365 .32808 .2439 Metetra
.619 .807 .972 r
.32808 .2439 .32914 .24365 .31806 .23472 .317 .23499 Metetra
.492 .879 .967 r
.317 .23499 .31806 .23472 .30654 .23511 .30555 .23275 Metetra
.907 .537 .318 r
.30555 .23275 .30654 .23511 .29508 .22743 .29383 .23298 Metetra
.95 .786 .643 r
.29383 .23298 .29508 .22743 .28331 .22366 .28222 .22395 Metetra
.629 .812 .97 r
.28222 .22395 .28331 .22366 .27155 .21417 .27046 .21459 Metetra
.685 .811 .943 r
.27046 .21459 .27155 .21417 .25977 .20054 .25856 .20403 Metetra
.935 .805 .693 r
.25856 .20403 .25977 .20054 .24753 .19432 .24644 .19441 Metetra
.506 .773 .992 r
.24644 .19441 .24753 .19432 .23519 .18566 .23412 .18508 Metetra
0 .381 .826 r
.23412 .18508 .23519 .18566 .22279 .17379 .22171 .17332 Metetra
.757 .774 .867 r
.46922 .36195 .4702 .36133 .46106 .35021 .46007 .35054 Metetra
.681 .782 .926 r
.46007 .35054 .46106 .35021 .45179 .34062 .45081 .34079 Metetra
.593 .798 .978 r
.45081 .34079 .45179 .34062 .44239 .33309 .4414 .33324 Metetra
.579 .794 .981 r
.4414 .33324 .44239 .33309 .43287 .32537 .43187 .32561 Metetra
.631 .81 .969 r
.43187 .32561 .43287 .32537 .42321 .31764 .42221 .31781 Metetra
.636 .64 .838 r
.42221 .31781 .42321 .31764 .4135 .30486 .41261 .29735 Metetra
.966 .688 .457 r
.41261 .29735 .4135 .30486 .40359 .2971 .40268 .29156 Metetra
.964 .668 .422 r
.40268 .29156 .40359 .2971 .39313 .31271 .39261 .28534 Metetra
.967 .724 .519 r
.39261 .28534 .39313 .31271 .38291 .30487 .38235 .28117 Metetra
.963 .719 .52 r
.38235 .28117 .38291 .30487 .37242 .30297 .37182 .28259 Metetra
.963 .716 .516 r
.37182 .28259 .37242 .30297 .36185 .29749 .36112 .284 Metetra
.973 .715 .484 r
.36112 .284 .36185 .29749 .35125 .28647 .35057 .27162 Metetra
.975 .721 .483 r
.35057 .27162 .35125 .28647 .3404 .27941 .33999 .25492 Metetra
.97 .726 .511 r
.33999 .25492 .3404 .27941 .32965 .26318 .32914 .24365 Metetra
.969 .721 .505 r
.32914 .24365 .32965 .26318 .31854 .25435 .31806 .23472 Metetra
.963 .715 .514 r
.31806 .23472 .31854 .25435 .30705 .25288 .30654 .23511 Metetra
.968 .718 .503 r
.30654 .23511 .30705 .25288 .29514 .25814 .29508 .22743 Metetra
.966 .725 .521 r
.29508 .22743 .29514 .25814 .2835 .24913 .28331 .22366 Metetra
.969 .725 .513 r
.28331 .22366 .2835 .24913 .272 .23134 .27155 .21417 Metetra
.972 .72 .495 r
.27155 .21417 .272 .23134 .26054 .20871 .25977 .20054 Metetra
.965 .687 .459 r
.25977 .20054 .26054 .20871 .24842 .19918 .24753 .19432 Metetra
.961 .649 .386 r
.24753 .19432 .24842 .19918 .23611 .1897 .23519 .18566 Metetra
.96 .628 .325 r
.23519 .18566 .23611 .1897 .22385 .17469 .22279 .17379 Metetra
.404 .631 .947 r
.4702 .36133 .47118 .36155 .46205 .34968 .46106 .35021 Metetra
.743 .801 .898 r
.46106 .35021 .46205 .34968 .45278 .34038 .45179 .34062 Metetra
.631 .812 .969 r
.45179 .34062 .45278 .34038 .44339 .3328 .44239 .33309 Metetra
.654 .817 .962 r
.44239 .33309 .44339 .3328 .43386 .32526 .43287 .32537 Metetra
.549 .782 .985 r
.43287 .32537 .43386 .32526 .42418 .32048 .42321 .31764 Metetra
.935 .566 .179 r
.42321 .31764 .42418 .32048 .41446 .30844 .4135 .30486 Metetra
.956 .622 .334 r
.4135 .30486 .41446 .30844 .40434 .31326 .40359 .2971 Metetra
.95 .701 .526 r
.40359 .2971 .40434 .31326 .39422 .30898 .39313 .31271 Metetra
.941 .801 .676 r
.39313 .31271 .39422 .30898 .38401 .3011 .38291 .30487 Metetra
.962 .829 .666 r
.38291 .30487 .38401 .3011 .37362 .29509 .37242 .30297 Metetra
.962 .778 .609 r
.37242 .30297 .37362 .29509 .36309 .28849 .36185 .29749 Metetra
.955 .764 .607 r
.36185 .29749 .36309 .28849 .35243 .28081 .35125 .28647 Metetra
.955 .788 .636 r
.35125 .28647 .35243 .28081 .34166 .27136 .3404 .27941 Metetra
.945 .758 .62 r
.3404 .27941 .34166 .27136 .33079 .25991 .32965 .26318 Metetra
.933 .806 .696 r
.32965 .26318 .33079 .25991 .31971 .25041 .31854 .25435 Metetra
.963 .831 .665 r
.31854 .25435 .31971 .25041 .30836 .24469 .30705 .25288 Metetra
.978 .799 .593 r
.30705 .25288 .30836 .24469 .2966 .24597 .29514 .25814 Metetra
.961 .763 .59 r
.29514 .25814 .2966 .24597 .28499 .23696 .2835 .24913 Metetra
.952 .753 .597 r
.2835 .24913 .28499 .23696 .27321 .22772 .272 .23134 Metetra
.895 .748 .692 r
.272 .23134 .27321 .22772 .26158 .20988 .26054 .20871 Metetra
.677 .161 0 r
.26054 .20871 .26158 .20988 .24952 .19886 .24842 .19918 Metetra
.639 .82 .97 r
.24842 .19918 .24952 .19886 .23717 .19039 .23611 .1897 Metetra
0 .359 .829 r
.23611 .1897 .23717 .19039 .22491 .17551 .22385 .17469 Metetra
.779 .774 .848 r
.47118 .36155 .47216 .36079 .46304 .3477 .46205 .34968 Metetra
.898 .807 .75 r
.46205 .34968 .46304 .3477 .45377 .34016 .45278 .34038 Metetra
.619 .807 .972 r
.45278 .34038 .45377 .34016 .44438 .33256 .44339 .3328 Metetra
.63 .813 .971 r
.44339 .3328 .44438 .33256 .43486 .32495 .43386 .32526 Metetra
.631 .875 .987 r
.43386 .32526 .43486 .32495 .42528 .31262 .42418 .32048 Metetra
.95 .763 .615 r
.42418 .32048 .42528 .31262 .4155 .30609 .41446 .30844 Metetra
.968 .921 .699 r
.41446 .30844 .4155 .30609 .40549 .30486 .40434 .31326 Metetra
.964 .777 .602 r
.40434 .31326 .40549 .30486 .39533 .30377 .39422 .30898 Metetra
.951 .787 .643 r
.39422 .30898 .39533 .30377 .38504 .30074 .38401 .3011 Metetra
.656 .865 .978 r
.38401 .3011 .38504 .30074 .3747 .29265 .37362 .29509 Metetra
.927 .831 .73 r
.37362 .29509 .3747 .29265 .36413 .28793 .36309 .28849 Metetra
.74 .854 .933 r
.36309 .28849 .36413 .28793 .35351 .27892 .35243 .28081 Metetra
.895 .822 .768 r
.35243 .28081 .35351 .27892 .34275 .26937 .34166 .27136 Metetra
.89 .805 .759 r
.34166 .27136 .34275 .26937 .33187 .25874 .33079 .25991 Metetra
.843 .835 .838 r
.33079 .25991 .33187 .25874 .32078 .24999 .31971 .25041 Metetra
.674 .884 .976 r
.31971 .25041 .32078 .24999 .30953 .24118 .30836 .24469 Metetra
.969 .856 .673 r
.30836 .24469 .30953 .24118 .29799 .23611 .2966 .24597 Metetra
.96 .768 .601 r
.2966 .24597 .29799 .23611 .28633 .22925 .28499 .23696 Metetra
.956 .775 .617 r
.28499 .23696 .28633 .22925 .27466 .21753 .27321 .22772 Metetra
.949 .755 .607 r
.27321 .22772 .27466 .21753 .26281 .20583 .26158 .20988 Metetra
.936 .793 .677 r
.26158 .20988 .26281 .20583 .25071 .19642 .24952 .19886 Metetra
.92 .83 .741 r
.24952 .19886 .25071 .19642 .23834 .18871 .23717 .19039 Metetra
.859 .793 .785 r
.23717 .19039 .23834 .18871 .22602 .1752 .22491 .17551 Metetra
.966 .638 .298 r
.47216 .36079 .47312 .36476 .46398 .35407 .46304 .3477 Metetra
.969 .683 .434 r
.46304 .3477 .46398 .35407 .45473 .34341 .45377 .34016 Metetra
.953 .609 .31 r
.45377 .34016 .45473 .34341 .44535 .33477 .44438 .33256 Metetra
.918 .521 .176 r
.44438 .33256 .44535 .33477 .43586 .32496 .43486 .32495 Metetra
.544 .69 .935 r
.43486 .32495 .43586 .32496 .42622 .31729 .42528 .31262 Metetra
.962 .654 .396 r
.42528 .31262 .42622 .31729 .41656 .30196 .4155 .30609 Metetra
.965 .823 .652 r
.4155 .30609 .41656 .30196 .40659 .29956 .40549 .30486 Metetra
.968 .807 .629 r
.40549 .30486 .40659 .29956 .39636 .30292 .39533 .30377 Metetra
.823 .934 .903 r
.39533 .30377 .39636 .30292 .38606 .30065 .38504 .30074 Metetra
.527 .777 .989 r
.38504 .30074 .38606 .30065 .37571 .29336 .3747 .29265 Metetra
.546 0 0 r
.3747 .29265 .37571 .29336 .36518 .2874 .36413 .28793 Metetra
.733 .829 .925 r
.36413 .28793 .36518 .2874 .35457 .27824 .35351 .27892 Metetra
.769 .829 .899 r
.35351 .27892 .35457 .27824 .34376 .27087 .34275 .26937 Metetra
.773 .3 0 r
.34275 .26937 .34376 .27087 .33292 .25871 .33187 .25874 Metetra
.476 .753 .991 r
.33187 .25874 .33292 .25871 .32184 .24996 .32078 .24999 Metetra
.474 .754 .991 r
.32078 .24999 .32184 .24996 .31056 .2422 .30953 .24118 Metetra
.719 .187 0 r
.30953 .24118 .31056 .2422 .29894 .23974 .29799 .23611 Metetra
.951 .614 .341 r
.29799 .23611 .29894 .23974 .28735 .23077 .28633 .22925 Metetra
.76 .286 0 r
.28633 .22925 .28735 .23077 .27574 .21745 .27466 .21753 Metetra
.543 .742 .968 r
.27466 .21753 .27574 .21745 .26391 .20549 .26281 .20583 Metetra
.651 .823 .966 r
.26281 .20583 .26391 .20549 .25182 .19584 .25071 .19642 Metetra
.732 .871 .946 r
.25071 .19642 .25182 .19584 .23953 .18627 .23834 .18871 Metetra
.899 .799 .74 r
.23834 .18871 .23953 .18627 .22713 .17508 .22602 .1752 Metetra
.953 .762 .608 r
.47312 .36476 .47414 .35626 .46501 .34733 .46398 .35407 Metetra
.949 .768 .624 r
.46398 .35407 .46501 .34733 .45575 .33975 .45473 .34341 Metetra
.937 .793 .676 r
.45473 .34341 .45575 .33975 .44638 .33087 .44535 .33477 Metetra
.935 .786 .671 r
.44535 .33477 .44638 .33087 .4369 .32131 .43586 .32496 Metetra
.941 .799 .676 r
.43586 .32496 .4369 .32131 .42729 .31221 .42622 .31729 Metetra
.93 .761 .652 r
.42622 .31729 .42729 .31221 .41761 .29919 .41656 .30196 Metetra
.952 .849 .703 r
.41656 .30196 .41761 .29919 .40765 .2962 .40659 .29956 Metetra
.976 .866 .662 r
.40659 .29956 .40765 .2962 .3975 .29586 .39636 .30292 Metetra
.967 .789 .61 r
.39636 .30292 .3975 .29586 .38724 .29279 .38606 .30065 Metetra
.959 .774 .61 r
.38606 .30065 .38724 .29279 .37686 .28739 .37571 .29336 Metetra
.958 .788 .629 r
.37571 .29336 .37686 .28739 .36626 .28516 .36518 .2874 Metetra
.91 .817 .743 r
.36518 .2874 .36626 .28516 .35564 .27684 .35457 .27824 Metetra
.877 .855 .817 r
.35457 .27824 .35564 .27684 .34497 .26432 .34376 .27087 Metetra
.947 .771 .63 r
.34376 .27087 .34497 .26432 .33414 .25225 .33292 .25871 Metetra
.954 .78 .628 r
.33292 .25871 .33414 .25225 .32307 .24368 .32184 .24996 Metetra
.956 .784 .629 r
.32184 .24996 .32307 .24368 .31166 .24079 .31056 .2422 Metetra
.898 .921 .827 r
.31056 .2422 .31166 .24079 .30014 .23554 .29894 .23974 Metetra
.943 .798 .67 r
.29894 .23974 .30014 .23554 .28857 .22641 .28735 .23077 Metetra
.932 .781 .67 r
.28735 .23077 .28857 .22641 .27696 .2133 .27574 .21745 Metetra
.935 .788 .674 r
.27574 .21745 .27696 .2133 .26513 .20191 .26391 .20549 Metetra
.936 .804 .69 r
.26391 .20549 .26513 .20191 .25319 .1887 .25182 .19584 Metetra
.955 .778 .623 r
.25182 .19584 .25319 .1887 .2407 .1846 .23953 .18627 Metetra
.876 .825 .794 r
.23953 .18627 .2407 .1846 .22824 .17475 .22713 .17508 Metetra
.968 .662 .384 r
.47414 .35626 .4751 .36107 .46596 .35277 .46501 .34733 Metetra
.967 .671 .412 r
.46501 .34733 .46596 .35277 .45671 .34304 .45575 .33975 Metetra
.955 .61 .296 r
.45575 .33975 .45671 .34304 .44741 .32761 .44638 .33087 Metetra
.929 .793 .69 r
.44638 .33087 .44741 .32761 .43793 .31876 .4369 .32131 Metetra
.918 .805 .72 r
.4369 .32131 .43793 .31876 .42845 .30016 .42729 .31221 Metetra
.956 .755 .592 r
.42729 .31221 .42845 .30016 .41872 .29218 .41761 .29919 Metetra
.966 .787 .611 r
.41761 .29919 .41872 .29218 .40885 .28425 .40765 .2962 Metetra
.97 .771 .579 r
.40765 .2962 .40885 .28425 .39894 .27095 .3975 .29586 Metetra
.968 .753 .56 r
.3975 .29586 .39894 .27095 .38861 .27413 .38724 .29279 Metetra
.966 .756 .569 r
.38724 .29279 .38861 .27413 .37826 .26911 .37686 .28739 Metetra
.968 .759 .567 r
.37686 .28739 .37826 .26911 .36778 .26333 .36626 .28516 Metetra
.965 .752 .567 r
.36626 .28516 .36778 .26333 .35708 .25966 .35564 .27684 Metetra
.961 .752 .577 r
.35564 .27684 .35708 .25966 .34642 .24826 .34497 .26432 Metetra
.961 .754 .579 r
.34497 .26432 .34642 .24826 .33559 .23744 .33414 .25225 Metetra
.963 .759 .58 r
.33414 .25225 .33559 .23744 .32456 .22856 .32307 .24368 Metetra
.968 .764 .575 r
.32307 .24368 .32456 .22856 .31328 .22246 .31166 .24079 Metetra
.966 .758 .57 r
.31166 .24079 .31328 .22246 .3017 .22019 .30014 .23554 Metetra
.963 .758 .579 r
.30014 .23554 .3017 .22019 .29004 .21459 .28857 .22641 Metetra
.957 .759 .594 r
.28857 .22641 .29004 .21459 .27842 .20267 .27696 .2133 Metetra
.958 .763 .599 r
.27696 .2133 .27842 .20267 .26635 .19813 .26513 .20191 Metetra
.927 .787 .686 r
.26513 .20191 .26635 .19813 .25412 .19268 .25319 .1887 Metetra
.947 .621 .376 r
.25319 .1887 .25412 .19268 .2418 .18434 .2407 .1846 Metetra
.603 .805 .977 r
.2407 .1846 .2418 .18434 .22945 .17219 .22824 .17475 Metetra
.966 .654 .375 r
.4751 .36107 .47605 .36555 .46692 .35667 .46596 .35277 Metetra
.963 .637 .331 r
.46596 .35277 .46692 .35667 .45768 .34548 .45671 .34304 Metetra
.868 .481 .004 r
.45671 .34304 .45768 .34548 .44833 .33514 .44741 .32761 Metetra
.971 .693 .445 r
.44741 .32761 .44833 .33514 .43883 .32723 .43793 .31876 Metetra
.982 .707 .422 r
.43793 .31876 .43883 .32723 .42915 .32394 .42845 .30016 Metetra
.969 .725 .512 r
.42845 .30016 .42915 .32394 .41935 .31856 .41872 .29218 Metetra
.969 .726 .514 r
.41872 .29218 .41935 .31856 .4093 .32088 .40885 .28425 Metetra
.971 .731 .518 r
.40885 .28425 .4093 .32088 .39927 .31173 .39894 .27095 Metetra
.965 .727 .528 r
.39894 .27095 .39927 .31173 .38909 .30364 .38861 .27413 Metetra
.968 .726 .519 r
.38861 .27413 .38909 .30364 .37876 .29551 .37826 .26911 Metetra
.968 .725 .516 r
.37826 .26911 .37876 .29551 .36828 .28756 .36778 .26333 Metetra
.967 .722 .515 r
.36778 .26333 .36828 .28756 .35767 .27925 .35708 .25966 Metetra
.971 .723 .502 r
.35708 .25966 .35767 .27925 .34688 .27149 .34642 .24826 Metetra
.97 .725 .508 r
.34642 .24826 .34688 .27149 .33599 .26181 .33559 .23744 Metetra
.969 .724 .511 r
.33559 .23744 .33599 .26181 .32491 .25349 .32456 .22856 Metetra
.968 .723 .514 r
.32456 .22856 .32491 .25349 .31357 .24809 .31328 .22246 Metetra
.966 .722 .517 r
.31328 .22246 .31357 .24809 .30205 .24281 .3017 .22019 Metetra
.967 .721 .511 r
.3017 .22019 .30205 .24281 .29056 .2312 .29004 .21459 Metetra
.971 .718 .494 r
.29004 .21459 .29056 .2312 .279 .2168 .27842 .20267 Metetra
.966 .709 .495 r
.27842 .20267 .279 .2168 .26705 .20851 .26635 .19813 Metetra
.965 .698 .477 r
.26635 .19813 .26705 .20851 .25494 .19952 .25412 .19268 Metetra
.966 .678 .433 r
.25412 .19268 .25494 .19952 .24253 .19331 .2418 .18434 Metetra
.972 .697 .451 r
.2418 .18434 .24253 .19331 .23027 .17871 .22945 .17219 Metetra
.661 .79 .943 r
.47605 .36555 .47703 .36527 .4679 .35643 .46692 .35667 Metetra
.651 .747 .92 r
.46692 .35667 .4679 .35643 .45869 .34339 .45768 .34548 Metetra
.897 .799 .744 r
.45768 .34548 .45869 .34339 .44932 .33589 .44833 .33514 Metetra
0 .138 .605 r
.44833 .33514 .44932 .33589 .43978 .33196 .43883 .32723 Metetra
.956 .652 .417 r
.43883 .32723 .43978 .33196 .43013 .32548 .42915 .32394 Metetra
.858 .404 .062 r
.42915 .32394 .43013 .32548 .42036 .31855 .41935 .31856 Metetra
.156 0 0 r
.41935 .31856 .42036 .31855 .41039 .31617 .4093 .32088 Metetra
.945 .786 .653 r
.4093 .32088 .41039 .31617 .40034 .30905 .39927 .31173 Metetra
.926 .815 .717 r
.39927 .31173 .40034 .30905 .39013 .30254 .38909 .30364 Metetra
.845 .846 .845 r
.38909 .30364 .39013 .30254 .3798 .2952 .37876 .29551 Metetra
.649 .826 .968 r
.37876 .29551 .3798 .2952 .36932 .28749 .36828 .28756 Metetra
.509 .77 .99 r
.36828 .28756 .36932 .28749 .35872 .27881 .35767 .27925 Metetra
.698 .847 .954 r
.35767 .27925 .35872 .27881 .34798 .26947 .34688 .27149 Metetra
.9 .82 .759 r
.34688 .27149 .34798 .26947 .33714 .25819 .33599 .26181 Metetra
.94 .805 .683 r
.33599 .26181 .33714 .25819 .32608 .24942 .32491 .25349 Metetra
.953 .813 .667 r
.32491 .25349 .32608 .24942 .31486 .2405 .31357 .24809 Metetra
.963 .783 .612 r
.31357 .24809 .31486 .2405 .3034 .23375 .30205 .24281 Metetra
.955 .766 .608 r
.30205 .24281 .3034 .23375 .29184 .22484 .29056 .2312 Metetra
.943 .769 .636 r
.29056 .2312 .29184 .22484 .28021 .21304 .279 .2168 Metetra
.942 .808 .682 r
.279 .2168 .28021 .21304 .26832 .20338 .26705 .20851 Metetra
.95 .792 .65 r
.26705 .20851 .26832 .20338 .25621 .19485 .25494 .19952 Metetra
.955 .806 .657 r
.25494 .19952 .25621 .19485 .24395 .18533 .24253 .19331 Metetra
.95 .766 .62 r
.24253 .19331 .24395 .18533 .23168 .17153 .23027 .17871 Metetra
0 .043 .538 r
.47703 .36527 .47801 .36618 .46888 .35776 .4679 .35643 Metetra
0 0 .446 r
.4679 .35643 .46888 .35776 .45968 .3426 .45869 .34339 Metetra
.806 .846 .881 r
.45869 .34339 .45968 .3426 .45033 .33423 .44932 .33589 Metetra
.915 .875 .782 r
.44932 .33589 .45033 .33423 .44082 .32765 .43978 .33196 Metetra
.95 .798 .657 r
.43978 .33196 .44082 .32765 .43115 .3245 .43013 .32548 Metetra
.837 .86 .862 r
.43013 .32548 .43115 .3245 .4214 .31631 .42036 .31855 Metetra
.943 .869 .735 r
.42036 .31855 .4214 .31631 .41139 .31692 .41039 .31617 Metetra
.445 0 0 r
.41039 .31617 .41139 .31692 .40133 .31088 .40034 .30905 Metetra
.886 .457 .112 r
.40034 .30905 .40133 .31088 .39101 .31046 .39013 .30254 Metetra
.968 .691 .454 r
.39013 .30254 .39101 .31046 .38066 .30378 .3798 .2952 Metetra
.969 .695 .459 r
.3798 .2952 .38066 .30378 .37012 .29891 .36932 .28749 Metetra
.97 .708 .478 r
.36932 .28749 .37012 .29891 .35956 .28759 .35872 .27881 Metetra
.971 .697 .456 r
.35872 .27881 .35956 .28759 .3488 .27896 .34798 .26947 Metetra
.973 .702 .458 r
.34798 .26947 .3488 .27896 .33799 .26591 .33714 .25819 Metetra
.969 .689 .446 r
.33714 .25819 .33799 .26591 .32694 .25631 .32608 .24942 Metetra
.969 .682 .433 r
.32608 .24942 .32694 .25631 .3156 .25153 .31486 .2405 Metetra
.968 .703 .479 r
.31486 .2405 .3156 .25153 .3039 .25215 .3034 .23375 Metetra
.97 .719 .501 r
.3034 .23375 .3039 .25215 .29256 .2356 .29184 .22484 Metetra
.972 .706 .467 r
.29184 .22484 .29256 .2356 .2809 .22413 .28021 .21304 Metetra
.97 .705 .473 r
.28021 .21304 .2809 .22413 .26938 .2043 .26832 .20338 Metetra
.55 .006 0 r
.26832 .20338 .26938 .2043 .25738 .19279 .25621 .19485 Metetra
.903 .832 .766 r
.25621 .19485 .25738 .19279 .24506 .18497 .24395 .18533 Metetra
.662 .765 .926 r
.24395 .18533 .24506 .18497 .23263 .17509 .23168 .17153 Metetra
.936 .795 .68 r
.47801 .36618 .47901 .36269 .46989 .35409 .46888 .35776 Metetra
.913 .762 .681 r
.46888 .35776 .46989 .35409 .46064 .34668 .45968 .3426 Metetra
.963 .642 .354 r
.45968 .3426 .46064 .34668 .45127 .3392 .45033 .33423 Metetra
.964 .661 .403 r
.45033 .33423 .45127 .3392 .44178 .33173 .44082 .32765 Metetra
.952 .636 .396 r
.44082 .32765 .44178 .33173 .43216 .32425 .43115 .3245 Metetra
.633 .806 .966 r
.43115 .3245 .43216 .32425 .42235 .32077 .4214 .31631 Metetra
.944 .64 .429 r
.4214 .31631 .42235 .32077 .41238 .31898 .41139 .31692 Metetra
.908 .501 .178 r
.41139 .31692 .41238 .31898 .40233 .31202 .40133 .31088 Metetra
.808 .335 .096 r
.40133 .31088 .40233 .31202 .39201 .31221 .39101 .31046 Metetra
.875 .436 .083 r
.39101 .31046 .39201 .31221 .38163 .30712 .38066 .30378 Metetra
.946 .606 .341 r
.38066 .30378 .38163 .30712 .37114 .29975 .37012 .29891 Metetra
0 .181 .681 r
.37012 .29891 .37114 .29975 .36054 .29059 .35956 .28759 Metetra
.944 .584 .269 r
.35956 .28759 .36054 .29059 .34997 .27365 .3488 .27896 Metetra
.94 .774 .648 r
.3488 .27896 .34997 .27365 .33908 .26472 .33799 .26591 Metetra
.846 .835 .835 r
.33799 .26591 .33908 .26472 .32804 .25508 .32694 .25631 Metetra
.872 .9 .849 r
.32694 .25631 .32804 .25508 .31681 .24632 .3156 .25153 Metetra
.972 .819 .632 r
.3156 .25153 .31681 .24632 .30512 .24738 .3039 .25215 Metetra
.928 .768 .663 r
.3039 .25215 .30512 .24738 .29383 .22966 .29256 .2356 Metetra
.948 .778 .639 r
.29256 .2356 .29383 .22966 .28216 .21913 .2809 .22413 Metetra
.923 .759 .661 r
.2809 .22413 .28216 .21913 .27043 .20511 .26938 .2043 Metetra
0 .182 .667 r
.26938 .2043 .27043 .20511 .25841 .19456 .25738 .19279 Metetra
.864 .416 .06 r
.25738 .19279 .25841 .19456 .24616 .18498 .24506 .18497 Metetra
.437 .734 .99 r
.24506 .18497 .24616 .18498 .23374 .17494 .23263 .17509 Metetra
.934 .795 .682 r
.47901 .36269 .48001 .35928 .4709 .35059 .46989 .35409 Metetra
.94 .801 .679 r
.46989 .35409 .4709 .35059 .46168 .34025 .46064 .34668 Metetra
.956 .778 .622 r
.46064 .34668 .46168 .34025 .45233 .33242 .45127 .3392 Metetra
.957 .777 .619 r
.45127 .3392 .45233 .33242 .44286 .32475 .44178 .33173 Metetra
.957 .776 .617 r
.44178 .33173 .44286 .32475 .43325 .31705 .43216 .32425 Metetra
.965 .785 .609 r
.43216 .32425 .43325 .31705 .42361 .30267 .42235 .32077 Metetra
.969 .759 .566 r
.42235 .32077 .42361 .30267 .41369 .29917 .41238 .31898 Metetra
.966 .754 .567 r
.41238 .31898 .41369 .29917 .40353 .30137 .40233 .31202 Metetra
.972 .777 .583 r
.40233 .31202 .40353 .30137 .39338 .2934 .39201 .31221 Metetra
.967 .757 .568 r
.39201 .31221 .39338 .2934 .38308 .28581 .38163 .30712 Metetra
.966 .753 .566 r
.38163 .30712 .38308 .28581 .37262 .27853 .37114 .29975 Metetra
.965 .752 .567 r
.37114 .29975 .37262 .27853 .36208 .26836 .36054 .29059 Metetra
.96 .747 .57 r
.36054 .29059 .36208 .26836 .35136 .25976 .34997 .27365 Metetra
.963 .76 .582 r
.34997 .27365 .35136 .25976 .34048 .25105 .33908 .26472 Metetra
.962 .759 .583 r
.33908 .26472 .34048 .25105 .32945 .24224 .32804 .25508 Metetra
.963 .762 .586 r
.32804 .25508 .32945 .24224 .31818 .23618 .31681 .24632 Metetra
.973 .782 .587 r
.31681 .24632 .31818 .23618 .30651 .23717 .30512 .24738 Metetra
.95 .755 .605 r
.30512 .24738 .30651 .23717 .29496 .22805 .29383 .22966 Metetra
.875 .826 .796 r
.29383 .22966 .29496 .22805 .28359 .20887 .28216 .21913 Metetra
.955 .761 .602 r
.28216 .21913 .28359 .20887 .27184 .19624 .27043 .20511 Metetra
.957 .77 .608 r
.27043 .20511 .27184 .19624 .2598 .18657 .25841 .19456 Metetra
.958 .775 .614 r
.25841 .19456 .2598 .18657 .24756 .17748 .24616 .18498 Metetra
.956 .777 .62 r
.24616 .18498 .24756 .17748 .23518 .16698 .23374 .17494 Metetra
.945 .784 .651 r
.48001 .35928 .48101 .35463 .47192 .34395 .4709 .35059 Metetra
.95 .769 .623 r
.4709 .35059 .47192 .34395 .46272 .33417 .46168 .34025 Metetra
.954 .779 .627 r
.46168 .34025 .46272 .33417 .45339 .32541 .45233 .33242 Metetra
.957 .775 .616 r
.45233 .33242 .45339 .32541 .44393 .3176 .44286 .32475 Metetra
.957 .775 .615 r
.44286 .32475 .44393 .3176 .43436 .3081 .43325 .31705 Metetra
.949 .757 .609 r
.43325 .31705 .43436 .3081 .42469 .29719 .42361 .30267 Metetra
.963 .798 .63 r
.42361 .30267 .42469 .29719 .4148 .29259 .41369 .29917 Metetra
.976 .804 .605 r
.41369 .29917 .4148 .29259 .40472 .29072 .40353 .30137 Metetra
.962 .765 .592 r
.40353 .30137 .40472 .29072 .39448 .28886 .39338 .2934 Metetra
.949 .795 .655 r
.39338 .2934 .39448 .28886 .38403 .28969 .38308 .28581 Metetra
.957 .629 .351 r
.38308 .28581 .38403 .28969 .37356 .28341 .37262 .27853 Metetra
.967 .657 .374 r
.37262 .27853 .37356 .28341 .36302 .27291 .36208 .26836 Metetra
.963 .648 .372 r
.36208 .26836 .36302 .27291 .35248 .25656 .35136 .25976 Metetra
.934 .808 .698 r
.35136 .25976 .35248 .25656 .34167 .24593 .34048 .25105 Metetra
.95 .789 .647 r
.34048 .25105 .34167 .24593 .33065 .23698 .32945 .24224 Metetra
.957 .797 .642 r
.32945 .24224 .33065 .23698 .31945 .22888 .31818 .23618 Metetra
.974 .798 .605 r
.31818 .23618 .31945 .22888 .30782 .22913 .30651 .23717 Metetra
.958 .774 .612 r
.30651 .23717 .30782 .22913 .29618 .22357 .29496 .22805 Metetra
.918 .761 .67 r
.29496 .22805 .29618 .22357 .28452 .21325 .28359 .20887 Metetra
.965 .64 .334 r
.28359 .20887 .28452 .21325 .27289 .19728 .27184 .19624 Metetra
.591 .064 0 r
.27184 .19624 .27289 .19728 .26087 .18715 .2598 .18657 Metetra
0 .319 .747 r
.2598 .18657 .26087 .18715 .24839 .18399 .24756 .17748 Metetra
.969 .676 .418 r
.24756 .17748 .24839 .18399 .23629 .16677 .23518 .16698 Metetra
.968 .65 .343 r
.48101 .35463 .48197 .35894 .47287 .35025 .47192 .34395 Metetra
.972 .684 .418 r
.47192 .34395 .47287 .35025 .46366 .34122 .46272 .33417 Metetra
.971 .689 .437 r
.46272 .33417 .46366 .34122 .45431 .33384 .45339 .32541 Metetra
.97 .697 .458 r
.45339 .32541 .45431 .33384 .44487 .32333 .44393 .3176 Metetra
.971 .675 .406 r
.44393 .3176 .44487 .32333 .43525 .31836 .43436 .3081 Metetra
.974 .708 .465 r
.43436 .3081 .43525 .31836 .42536 .32322 .42469 .29719 Metetra
.968 .725 .515 r
.42469 .29719 .42536 .32322 .41541 .32006 .4148 .29259 Metetra
.967 .724 .518 r
.4148 .29259 .41541 .32006 .40521 .32368 .40472 .29072 Metetra
.967 .726 .521 r
.40472 .29072 .40521 .32368 .39501 .31744 .39448 .28886 Metetra
.966 .723 .52 r
.39448 .28886 .39501 .31744 .3845 .31947 .38403 .28969 Metetra
.969 .727 .517 r
.38403 .28969 .3845 .31947 .37398 .313 .37356 .28341 Metetra
.97 .728 .514 r
.37356 .28341 .37398 .313 .36338 .30357 .36302 .27291 Metetra
.973 .731 .511 r
.36302 .27291 .36338 .30357 .35259 .29605 .35248 .25656 Metetra
.97 .731 .52 r
.35248 .25656 .35259 .29605 .34206 .27163 .34167 .24593 Metetra
.97 .725 .511 r
.34167 .24593 .34206 .27163 .33099 .26334 .33065 .23698 Metetra
.969 .725 .512 r
.33065 .23698 .33099 .26334 .31941 .26692 .31945 .22888 Metetra
.966 .727 .524 r
.31945 .22888 .31941 .26692 .30781 .26446 .30782 .22913 Metetra
.968 .728 .52 r
.30782 .22913 .30781 .26446 .29631 .25273 .29618 .22357 Metetra
.97 .727 .513 r
.29618 .22357 .29631 .25273 .28494 .23247 .28452 .21325 Metetra
.974 .723 .495 r
.28452 .21325 .28494 .23247 .27368 .2054 .27289 .19728 Metetra
.97 .691 .445 r
.27289 .19728 .27368 .2054 .2617 .194 .26087 .18715 Metetra
.959 .672 .448 r
.26087 .18715 .2617 .194 .2494 .18621 .24839 .18399 Metetra
.84 .427 0 r
.24839 .18399 .2494 .18621 .23717 .17195 .23629 .16677 Metetra
.963 .64 .345 r
.48197 .35894 .48294 .36294 .47384 .3534 .47287 .35025 Metetra
.952 .601 .275 r
.47287 .35025 .47384 .3534 .46461 .34602 .46366 .34122 Metetra
.965 .659 .391 r
.46366 .34122 .46461 .34602 .45527 .33846 .45431 .33384 Metetra
.969 .656 .36 r
.45431 .33384 .45527 .33846 .44579 .33093 .44487 .32333 Metetra
.966 .689 .457 r
.44487 .32333 .44579 .33093 .43617 .32519 .43525 .31836 Metetra
.947 .669 .48 r
.43525 .31836 .43617 .32519 .42633 .32622 .42536 .32322 Metetra
.939 .592 .338 r
.42536 .32322 .42633 .32622 .41639 .32317 .41541 .32006 Metetra
.919 .59 .404 r
.41541 .32006 .41639 .32317 .40601 .33808 .40521 .32368 Metetra
.969 .713 .494 r
.40521 .32368 .40601 .33808 .39588 .32658 .39501 .31744 Metetra
.957 .688 .486 r
.39501 .31744 .39588 .32658 .38561 .31557 .3845 .31947 Metetra
.949 .808 .67 r
.3845 .31947 .38561 .31557 .37504 .31252 .37398 .313 Metetra
.717 .821 .929 r
.37398 .313 .37504 .31252 .3645 .30066 .36338 .30357 Metetra
.934 .819 .709 r
.36338 .30357 .3645 .30066 .35386 .28681 .35259 .29605 Metetra
.937 .744 .616 r
.35259 .29605 .35386 .28681 .34296 .27797 .34206 .27163 Metetra
.967 .676 .423 r
.34206 .27163 .34296 .27797 .33188 .26966 .33099 .26334 Metetra
.947 .661 .464 r
.33099 .26334 .33188 .26966 .32051 .26581 .31941 .26692 Metetra
.861 .94 .871 r
.31941 .26692 .32051 .26581 .30878 .26796 .30781 .26446 Metetra
.953 .605 .277 r
.30781 .26446 .30878 .26796 .29728 .25637 .29631 .25273 Metetra
.942 .595 .183 r
.29631 .25273 .29728 .25637 .28644 .22048 .28494 .23247 Metetra
.943 .743 .602 r
.28494 .23247 .28644 .22048 .27483 .20357 .27368 .2054 Metetra
.885 .819 .778 r
.27368 .2054 .27483 .20357 .26296 .18962 .2617 .194 Metetra
.95 .805 .665 r
.2617 .194 .26296 .18962 .25058 .18429 .2494 .18621 Metetra
.876 .798 .77 r
.2494 .18621 .25058 .18429 .23818 .1744 .23717 .17195 Metetra
.466 .696 .967 r
.48294 .36294 .48392 .36303 .47483 .35346 .47384 .3534 Metetra
.419 .725 .988 r
.47384 .3534 .47483 .35346 .46561 .34574 .46461 .34602 Metetra
.653 .819 .963 r
.46461 .34602 .46561 .34574 .45627 .33793 .45527 .33846 Metetra
.74 .842 .927 r
.45527 .33846 .45627 .33793 .4468 .33059 .44579 .33093 Metetra
.657 .863 .978 r
.44579 .33093 .4468 .33059 .43721 .32308 .43617 .32519 Metetra
.954 .907 .734 r
.43617 .32519 .43721 .32308 .42739 .32298 .42633 .32622 Metetra
.955 .834 .684 r
.42633 .32622 .42739 .32298 .41743 .32137 .41639 .32317 Metetra
.744 .888 .485 r
.41639 .32317 .41743 .32137 .40714 .33142 .40601 .33808 Metetra
.949 .77 .626 r
.40601 .33808 .40714 .33142 .39696 .32355 .39588 .32658 Metetra
.921 .794 .704 r
.39588 .32658 .39696 .32355 .38656 .32022 .38561 .31557 Metetra
.954 .645 .41 r
.38561 .31557 .38656 .32022 .37605 .3139 .37504 .31252 Metetra
.676 .201 0 r
.37504 .31252 .37605 .3139 .36547 .304 .3645 .30066 Metetra
.949 .595 .23 r
.3645 .30066 .36547 .304 .35472 .29484 .35386 .28681 Metetra
.97 .692 .448 r
.35386 .28681 .35472 .29484 .34378 .2871 .34296 .27797 Metetra
.97 .697 .46 r
.34296 .27797 .34378 .2871 .33275 .27705 .33188 .26966 Metetra
.962 .681 .454 r
.33188 .26966 .33275 .27705 .32138 .27285 .32051 .26581 Metetra
.952 .67 .467 r
.32051 .26581 .32138 .27285 .30987 .26737 .30878 .26796 Metetra
.736 .805 .907 r
.30878 .26796 .30987 .26737 .29828 .2587 .29728 .25637 Metetra
0 0 .493 r
.29728 .25637 .29828 .2587 .28715 .23145 .28644 .22048 Metetra
.977 .71 .456 r
.28644 .22048 .28715 .23145 .2759 .20417 .27483 .20357 Metetra
.036 .41 .86 r
.27483 .20357 .2759 .20417 .26393 .19296 .26296 .18962 Metetra
.942 .595 .329 r
.26296 .18962 .26393 .19296 .2517 .18373 .25058 .18429 Metetra
.725 .839 .935 r
.25058 .18429 .2517 .18373 .23926 .17487 .23818 .1744 Metetra
0 .061 .569 r
.48392 .36303 .4849 .36396 .47581 .35527 .47483 .35346 Metetra
.878 .445 .06 r
.47483 .35346 .47581 .35527 .4666 .34582 .46561 .34574 Metetra
.409 .712 .985 r
.46561 .34574 .4666 .34582 .45726 .33809 .45627 .33793 Metetra
.318 .676 .977 r
.45627 .33793 .45726 .33809 .4478 .33056 .4468 .33059 Metetra
.492 .763 .991 r
.4468 .33059 .4478 .33056 .43819 .32505 .43721 .32308 Metetra
.897 .51 .282 r
.43721 .32308 .43819 .32505 .42845 .31889 .42739 .32298 Metetra
.965 .824 .653 r
.42739 .32298 .42845 .31889 .41834 .32958 .41743 .32137 Metetra
.943 .674 .499 r
.41743 .32137 .41834 .32958 .40812 .33419 .40714 .33142 Metetra
.939 .569 .25 r
.40714 .33142 .40812 .33419 .39795 .32624 .39696 .32355 Metetra
.93 .567 .306 r
.39696 .32355 .39795 .32624 .38763 .31818 .38656 .32022 Metetra
.918 .846 .757 r
.38656 .32022 .38763 .31818 .37713 .31212 .37605 .3139 Metetra
.888 .82 .775 r
.37605 .3139 .37713 .31212 .36657 .30181 .36547 .304 Metetra
.909 .821 .748 r
.36547 .304 .36657 .30181 .35581 .29345 .35472 .29484 Metetra
.874 .854 .819 r
.35472 .29484 .35581 .29345 .34511 .2764 .34378 .2871 Metetra
.96 .764 .595 r
.34378 .2871 .34511 .2764 .33407 .26745 .33275 .27705 Metetra
.967 .777 .595 r
.33275 .27705 .33407 .26745 .32261 .26745 .32138 .27285 Metetra
.96 .799 .639 r
.32138 .27285 .32261 .26745 .3108 .27223 .30987 .26737 Metetra
.963 .65 .38 r
.30987 .26737 .3108 .27223 .29952 .2538 .29828 .2587 Metetra
.904 .737 .665 r
.29828 .2587 .29952 .2538 .288 .23844 .28715 .23145 Metetra
.982 .692 .351 r
.28715 .23145 .288 .23844 .27689 .20686 .2759 .20417 Metetra
.928 .543 .188 r
.2759 .20417 .27689 .20686 .26498 .19411 .26393 .19296 Metetra
.67 .149 0 r
.26393 .19296 .26498 .19411 .25285 .18231 .2517 .18373 Metetra
.87 .855 .825 r
.2517 .18373 .25285 .18231 .2405 .17153 .23926 .17487 Metetra
.693 .199 0 r
.4849 .36396 .48588 .3652 .47679 .35566 .47581 .35527 Metetra
.184 .541 .927 r
.47581 .35527 .47679 .35566 .46758 .34813 .4666 .34582 Metetra
.922 .529 .182 r
.4666 .34582 .46758 .34813 .45824 .34062 .45726 .33809 Metetra
.933 .554 .223 r
.45726 .33809 .45824 .34062 .44878 .33307 .4478 .33056 Metetra
.932 .558 .259 r
.4478 .33056 .44878 .33307 .43919 .3255 .43819 .32505 Metetra
0 .372 .766 r
.43819 .32505 .43919 .3255 .42942 .32243 .42845 .31889 Metetra
.903 .597 .457 r
.42845 .31889 .42942 .32243 .4193 .33341 .41834 .32958 Metetra
.927 .615 .432 r
.41834 .32958 .4193 .33341 .40915 .33408 .40812 .33419 Metetra
.539 .784 .988 r
.40812 .33419 .40915 .33408 .39898 .32615 .39795 .32624 Metetra
.523 .777 .99 r
.39795 .32624 .39898 .32615 .38863 .32031 .38763 .31818 Metetra
.91 .505 .187 r
.38763 .31818 .38863 .32031 .37808 .31671 .37713 .31212 Metetra
.966 .649 .359 r
.37713 .31212 .37808 .31671 .36749 .30781 .36657 .30181 Metetra
.967 .673 .415 r
.36657 .30181 .36749 .30781 .35684 .29443 .35581 .29345 Metetra
0 .233 .751 r
.35581 .29345 .35684 .29443 .34651 .26275 .34511 .2764 Metetra
.963 .761 .582 r
.34511 .2764 .34651 .26275 .3355 .25362 .33407 .26745 Metetra
.972 .77 .573 r
.33407 .26745 .3355 .25362 .32425 .2473 .32261 .26745 Metetra
.974 .764 .559 r
.32261 .26745 .32425 .2473 .31251 .25135 .3108 .27223 Metetra
.96 .748 .573 r
.3108 .27223 .31251 .25135 .30114 .23708 .29952 .2538 Metetra
.96 .752 .579 r
.29952 .2538 .30114 .23708 .2898 .21725 .288 .23844 Metetra
.952 .739 .578 r
.288 .23844 .2898 .21725 .27796 .20731 .27689 .20686 Metetra
.139 .502 .909 r
.27689 .20686 .27796 .20731 .26612 .19273 .26498 .19411 Metetra
.852 .822 .818 r
.26498 .19411 .26612 .19273 .25392 .18304 .25285 .18231 Metetra
0 .22 .687 r
.25285 .18231 .25392 .18304 .24154 .17316 .2405 .17153 Metetra
.969 .66 .371 r
.48588 .3652 .48684 .36994 .47775 .36167 .47679 .35566 Metetra
.969 .678 .422 r
.47679 .35566 .47775 .36167 .46857 .34895 .46758 .34813 Metetra
.473 0 0 r
.46758 .34813 .46857 .34895 .45923 .34142 .45824 .34062 Metetra
.455 0 0 r
.45824 .34062 .45923 .34142 .44978 .33346 .44878 .33307 Metetra
.045 .499 .887 r
.44878 .33307 .44978 .33346 .4402 .32561 .43919 .3255 Metetra
.095 .627 .867 r
.43919 .3255 .4402 .32561 .43049 .31772 .42942 .32243 Metetra
.993 .859 .596 r
.42942 .32243 .43049 .31772 .42063 .31168 .4193 .33341 Metetra
.971 .758 .558 r
.4193 .33341 .42063 .31168 .41054 .31091 .40915 .33408 Metetra
.966 .752 .563 r
.40915 .33408 .41054 .31091 .40036 .30572 .39898 .32615 Metetra
.967 .755 .565 r
.39898 .32615 .40036 .30572 .38995 .30545 .38863 .32031 Metetra
.968 .763 .573 r
.38863 .32031 .38995 .30545 .37951 .29747 .37808 .31671 Metetra
.965 .754 .569 r
.37808 .31671 .37951 .29747 .36896 .28829 .36749 .30781 Metetra
.962 .751 .571 r
.36749 .30781 .36896 .28829 .35835 .27495 .35684 .29443 Metetra
.95 .738 .582 r
.35684 .29443 .35835 .27495 .34766 .25924 .34651 .26275 Metetra
.937 .804 .688 r
.34651 .26275 .34766 .25924 .33665 .25047 .3355 .25362 Metetra
.943 .825 .699 r
.3355 .25362 .33665 .25047 .32512 .25436 .32425 .2473 Metetra
.949 .668 .471 r
.32425 .2473 .32512 .25436 .31373 .24649 .31251 .25135 Metetra
.935 .776 .659 r
.31251 .25135 .31373 .24649 .30221 .23736 .30114 .23708 Metetra
.444 .576 .891 r
.30114 .23708 .30221 .23736 .29059 .22593 .2898 .21725 Metetra
.971 .694 .45 r
.2898 .21725 .29059 .22593 .27887 .21259 .27796 .20731 Metetra
.971 .661 .36 r
.27796 .20731 .27887 .21259 .2673 .19057 .26612 .19273 Metetra
.907 .829 .758 r
.26612 .19273 .2673 .19057 .25488 .18667 .25392 .18304 Metetra
.953 .608 .306 r
.25392 .18304 .25488 .18667 .24264 .17343 .24154 .17316 Metetra
.901 .819 .757 r
.48684 .36994 .48784 .36806 .47874 .36092 .47775 .36167 Metetra
.772 .765 .846 r
.47775 .36167 .47874 .36092 .46955 .35115 .46857 .34895 Metetra
.915 .515 .163 r
.46857 .34895 .46955 .35115 .46023 .3422 .45923 .34142 Metetra
0 .12 .589 r
.45923 .34142 .46023 .3422 .4508 .33148 .44978 .33346 Metetra
.908 .826 .755 r
.44978 .33346 .4508 .33148 .44123 .32364 .4402 .32561 Metetra
.907 .827 .756 r
.4402 .32561 .44123 .32364 .4316 .30997 .43049 .31772 Metetra
.962 .777 .607 r
.43049 .31772 .4316 .30997 .42179 .30105 .42063 .31168 Metetra
.971 .776 .582 r
.42063 .31168 .42179 .30105 .41174 .29948 .41054 .31091 Metetra
.966 .768 .585 r
.41054 .31091 .41174 .29948 .40154 .29692 .40036 .30572 Metetra
.972 .785 .592 r
.40036 .30572 .40154 .29692 .39118 .29475 .38995 .30545 Metetra
.963 .766 .592 r
.38995 .30545 .39118 .29475 .38074 .28793 .37951 .29747 Metetra
.96 .768 .599 r
.37951 .29747 .38074 .28793 .37022 .2781 .36896 .28829 Metetra
.955 .76 .6 r
.36896 .28829 .37022 .2781 .35943 .27349 .35835 .27495 Metetra
.838 .771 .788 r
.35835 .27495 .35943 .27349 .34873 .25847 .34766 .25924 Metetra
.788 .848 .897 r
.34766 .25924 .34873 .25847 .33773 .24951 .33665 .25047 Metetra
.754 .995 .826 r
.33665 .25047 .33773 .24951 .3265 .24327 .32512 .25436 Metetra
.963 .767 .591 r
.32512 .25436 .3265 .24327 .31495 .24179 .31373 .24649 Metetra
.948 .794 .657 r
.31373 .24649 .31495 .24179 .30339 .23401 .30221 .23736 Metetra
.928 .798 .697 r
.30221 .23736 .30339 .23401 .29174 .22384 .29059 .22593 Metetra
.887 .8 .758 r
.29059 .22593 .29174 .22384 .2799 .21433 .27887 .21259 Metetra
0 0 .431 r
.27887 .21259 .2799 .21433 .26795 .2025 .2673 .19057 Metetra
.965 .702 .484 r
.2673 .19057 .26795 .2025 .25573 .19321 .25488 .18667 Metetra
.972 .678 .405 r
.25488 .18667 .25573 .19321 .24345 .18065 .24264 .17343 Metetra
.919 .522 .178 r
.48784 .36806 .48881 .37028 .47972 .36288 .47874 .36092 Metetra
.874 .45 .03 r
.47874 .36092 .47972 .36288 .47056 .34738 .46955 .35115 Metetra
.938 .792 .673 r
.46955 .35115 .47056 .34738 .46125 .33937 .46023 .3422 Metetra
.917 .792 .707 r
.46023 .3422 .46125 .33937 .45181 .33084 .4508 .33148 Metetra
.771 .843 .906 r
.4508 .33148 .45181 .33084 .44224 .32412 .44123 .32364 Metetra
.253 .51 .904 r
.44123 .32364 .44224 .32412 .43246 .32294 .4316 .30997 Metetra
.972 .713 .483 r
.4316 .30997 .43246 .32294 .42232 .33692 .42179 .30105 Metetra
.968 .727 .521 r
.42179 .30105 .42232 .33692 .41225 .33357 .41174 .29948 Metetra
.968 .727 .52 r
.41174 .29948 .41225 .33357 .40198 .33252 .40154 .29692 Metetra
.968 .727 .521 r
.40154 .29692 .40198 .33252 .39152 .33325 .39118 .29475 Metetra
.969 .73 .519 r
.39118 .29475 .39152 .33325 .38093 .33147 .38074 .28793 Metetra
.97 .731 .52 r
.38074 .28793 .38093 .33147 .37032 .32292 .37022 .2781 Metetra
.969 .73 .522 r
.37022 .2781 .37032 .32292 .35954 .31503 .35943 .27349 Metetra
.972 .732 .517 r
.35943 .27349 .35954 .31503 .34873 .30154 .34873 .25847 Metetra
.97 .731 .52 r
.34873 .25847 .34873 .30154 .33811 .27555 .33773 .24951 Metetra
.969 .724 .511 r
.33773 .24951 .33811 .27555 .32643 .28407 .3265 .24327 Metetra
.968 .728 .522 r
.3265 .24327 .32643 .28407 .31486 .28093 .31495 .24179 Metetra
.969 .729 .519 r
.31495 .24179 .31486 .28093 .30328 .27197 .30339 .23401 Metetra
.97 .73 .517 r
.30339 .23401 .30328 .27197 .29217 .24376 .29174 .22384 Metetra
.971 .721 .5 r
.29174 .22384 .29217 .24376 .28106 .21233 .2799 .21433 Metetra
.891 .814 .766 r
.2799 .21433 .28106 .21233 .2691 .20098 .26795 .2025 Metetra
.875 .847 .812 r
.26795 .2025 .2691 .20098 .25668 .19717 .25573 .19321 Metetra
.959 .621 .305 r
.25573 .19321 .25668 .19717 .24473 .17633 .24345 .18065 Metetra
.91 .504 .146 r
.48881 .37028 .48979 .37239 .48071 .36387 .47972 .36288 Metetra
0 .235 .753 r
.47972 .36288 .48071 .36387 .47152 .35343 .47056 .34738 Metetra
.97 .678 .419 r
.47056 .34738 .47152 .35343 .4622 .34583 .46125 .33937 Metetra
.971 .683 .424 r
.46125 .33937 .4622 .34583 .45272 .34183 .45181 .33084 Metetra
.97 .707 .477 r
.45181 .33084 .45272 .34183 .44313 .33511 .44224 .32412 Metetra
.964 .701 .488 r
.44224 .32412 .44313 .33511 .43344 .3258 .43246 .32294 Metetra
.875 .564 .456 r
.43246 .32294 .43344 .3258 .42294 .36768 .42232 .33692 Metetra
.968 .726 .517 r
.42232 .33692 .42294 .36768 .41312 .34424 .41225 .33357 Metetra
.963 .699 .486 r
.41225 .33357 .41312 .34424 .4029 .33954 .40198 .33252 Metetra
.955 .674 .465 r
.40198 .33252 .4029 .33954 .39253 .33494 .39152 .33325 Metetra
.876 .451 .191 r
.39152 .33325 .39253 .33494 .38203 .32913 .38093 .33147 Metetra
.917 .823 .738 r
.38093 .33147 .38203 .32913 .37145 .3194 .37032 .32292 Metetra
.941 .809 .685 r
.37032 .32292 .37145 .3194 .3608 .30618 .35954 .31503 Metetra
.953 .763 .609 r
.35954 .31503 .3608 .30618 .35016 .28672 .34873 .30154 Metetra
.949 .743 .59 r
.34873 .30154 .35016 .28672 .33959 .25967 .33811 .27555 Metetra
.978 .774 .56 r
.33811 .27555 .33959 .25967 .32833 .25422 .32643 .28407 Metetra
.969 .752 .555 r
.32643 .28407 .32833 .25422 .31626 .27017 .31486 .28093 Metetra
.962 .767 .594 r
.31486 .28093 .31626 .27017 .30454 .2665 .30328 .27197 Metetra
.909 .737 .656 r
.30328 .27197 .30454 .2665 .29313 .24759 .29217 .24376 Metetra
.867 .544 .028 r
.29217 .24376 .29313 .24759 .28196 .21765 .28106 .21233 Metetra
.968 .66 .379 r
.28106 .21233 .28196 .21765 .2701 .20364 .2691 .20098 Metetra
.924 .55 .284 r
.2691 .20098 .2701 .20364 .25758 .20244 .25668 .19717 Metetra
.973 .661 .318 r
.25668 .19717 .25758 .20244 .24573 .17907 .24473 .17633 Metetra
.879 .823 .789 r
.48979 .37239 .49079 .37089 .4817 .36354 .48071 .36387 Metetra
.681 .771 .919 r
.48071 .36387 .4817 .36354 .47252 .35303 .47152 .35343 Metetra
.701 .831 .945 r
.47152 .35343 .47252 .35303 .46321 .34421 .4622 .34583 Metetra
.913 .878 .787 r
.4622 .34583 .46321 .34421 .45378 .33588 .45272 .34183 Metetra
.958 .785 .627 r
.45272 .34183 .45378 .33588 .44419 .3299 .44313 .33511 Metetra
.948 .782 .642 r
.44313 .33511 .44419 .3299 .4345 .32189 .43344 .3258 Metetra
.43344 .3258 .4345 .32189 .42432 .34063 .42294 .36768 Metetra
.959 .742 .566 r
.42294 .36768 .42432 .34063 .41392 .35975 .41312 .34424 Metetra
.968 .714 .497 r
.41312 .34424 .41392 .35975 .40389 .34236 .4029 .33954 Metetra
.936 .575 .299 r
.4029 .33954 .40389 .34236 .39355 .33618 .39253 .33494 Metetra
.779 .278 0 r
.39253 .33494 .39355 .33618 .38294 .336 .38203 .32913 Metetra
.971 .684 .425 r
.38203 .32913 .38294 .336 .3724 .32429 .37145 .3194 Metetra
.97 .656 .348 r
.37145 .3194 .3724 .32429 .3616 .31736 .3608 .30618 Metetra
.981 .714 .449 r
.3608 .30618 .3616 .31736 .35085 .30218 .35016 .28672 Metetra
.983 .727 .463 r
.35016 .28672 .35085 .30218 .34027 .27485 .33959 .25967 Metetra
.968 .713 .494 r
.33959 .25967 .34027 .27485 .32907 .26631 .32833 .25422 Metetra
.946 .687 .512 r
.32833 .25422 .32907 .26631 .31718 .27557 .31626 .27017 Metetra
.957 .655 .419 r
.31626 .27017 .31718 .27557 .30543 .2729 .30454 .2665 Metetra
.978 .682 .372 r
.30454 .2665 .30543 .2729 .29465 .23449 .29313 .24759 Metetra
.944 .74 .599 r
.29313 .24759 .29465 .23449 .28315 .21497 .28196 .21765 Metetra
.905 .793 .727 r
.28196 .21765 .28315 .21497 .27131 .20054 .2701 .20364 Metetra
.96 .861 .698 r
.2701 .20364 .27131 .20054 .25872 .20146 .25758 .20244 Metetra
.76 .71 .806 r
.25758 .20244 .25872 .20146 .24689 .17779 .24573 .17907 Metetra
0 .197 .654 r
.49079 .37089 .49177 .37158 .48271 .36074 .4817 .36354 Metetra
.917 .792 .707 r
.4817 .36354 .48271 .36074 .47353 .35088 .47252 .35303 Metetra
.908 .813 .741 r
.47252 .35303 .47353 .35088 .46422 .34324 .46321 .34421 Metetra
.829 .836 .853 r
.46321 .34421 .46422 .34324 .45478 .33571 .45378 .33588 Metetra
.559 .826 .996 r
.45378 .33588 .45478 .33571 .44522 .32868 .44419 .3299 Metetra
.859 .842 .827 r
.44419 .3299 .44522 .32868 .43549 .32397 .4345 .32189 Metetra
.825 .511 .458 r
.4345 .32189 .43549 .32397 .42523 .34975 .42432 .34063 Metetra
.933 .67 .516 r
.42432 .34063 .42523 .34975 .41521 .34274 .41392 .35975 Metetra
.958 .749 .578 r
.41392 .35975 .41521 .34274 .40521 .32503 .40389 .34236 Metetra
.967 .758 .569 r
.40389 .34236 .40521 .32503 .39493 .31697 .39355 .33618 Metetra
.971 .761 .561 r
.39355 .33618 .39493 .31697 .38441 .31427 .38294 .336 Metetra
.964 .751 .566 r
.38294 .336 .38441 .31427 .37395 .30047 .3724 .32429 Metetra
.968 .753 .561 r
.3724 .32429 .37395 .30047 .36323 .29212 .3616 .31736 Metetra
.963 .748 .564 r
.3616 .31736 .36323 .29212 .35246 .27914 .35085 .30218 Metetra
.956 .741 .573 r
.35085 .30218 .35246 .27914 .3415 .26829 .34027 .27485 Metetra
.957 .782 .625 r
.34027 .27485 .3415 .26829 .33015 .26606 .32907 .26631 Metetra
.198 0 0 r
.32907 .26631 .33015 .26606 .31858 .26475 .31718 .27557 Metetra
.97 .776 .586 r
.31718 .27557 .31858 .26475 .30681 .2633 .30543 .2729 Metetra
.922 .727 .621 r
.30543 .2729 .30681 .2633 .2956 .23895 .29465 .23449 Metetra
.964 .638 .272 r
.29465 .23449 .2956 .23895 .284 .2221 .28315 .21497 Metetra
.975 .686 .411 r
.28315 .21497 .284 .2221 .27241 .20052 .27131 .20054 Metetra
.038 0 0 r
.27131 .20054 .27241 .20052 .26023 .1909 .25872 .20146 Metetra
.946 .749 .607 r
.25872 .20146 .26023 .1909 .24807 .17588 .24689 .17779 Metetra
.716 .773 .898 r
.49177 .37158 .49276 .37113 .48369 .36314 .48271 .36074 Metetra
.918 .526 .141 r
.48271 .36074 .48369 .36314 .47452 .35225 .47353 .35088 Metetra
.779 .295 0 r
.47353 .35088 .47452 .35225 .46522 .3437 .46422 .34324 Metetra
0 .434 .845 r
.46422 .34324 .46522 .3437 .45579 .33546 .45478 .33571 Metetra
.621 .825 .979 r
.45478 .33571 .45579 .33546 .44622 .32997 .44522 .32868 Metetra
.811 .325 0 r
.44522 .32868 .44622 .32997 .43649 .3254 .43549 .32397 Metetra
.759 .454 .469 r
.43549 .32397 .43649 .3254 .42623 .35182 .42523 .34975 Metetra
.904 .491 .146 r
.42523 .34975 .42623 .35182 .41609 .35279 .41521 .34274 Metetra
.981 .711 .441 r
.41521 .34274 .41609 .35279 .40604 .33831 .40521 .32503 Metetra
.971 .712 .484 r
.40521 .32503 .40604 .33831 .39574 .3306 .39493 .31697 Metetra
.966 .709 .493 r
.39493 .31697 .39574 .3306 .3852 .3275 .38441 .31427 Metetra
.976 .716 .474 r
.38441 .31427 .3852 .3275 .37467 .31639 .37395 .30047 Metetra
.971 .717 .492 r
.37395 .30047 .37467 .31639 .36393 .30823 .36323 .29212 Metetra
.974 .72 .486 r
.36323 .29212 .36393 .30823 .35349 .2806 .35246 .27914 Metetra
.74 .261 0 r
.35246 .27914 .35349 .2806 .34247 .27204 .3415 .26829 Metetra
.943 .614 .376 r
.3415 .26829 .34247 .27204 .3309 .27805 .33015 .26606 Metetra
.964 .701 .488 r
.33015 .26606 .3309 .27805 .31915 .28233 .31858 .26475 Metetra
.966 .713 .503 r
.31858 .26475 .31915 .28233 .30768 .27066 .30681 .2633 Metetra
.982 .695 .372 r
.30681 .2633 .30768 .27066 .29656 .24274 .2956 .23895 Metetra
.955 .611 .241 r
.2956 .23895 .29656 .24274 .28542 .21255 .284 .2221 Metetra
.945 .752 .611 r
.284 .2221 .28542 .21255 .27353 .20007 .27241 .20052 Metetra
.691 .834 .952 r
.27241 .20052 .27353 .20007 .261 .1997 .26023 .1909 Metetra
.976 .698 .436 r
.26023 .1909 .261 .1997 .24869 .18812 .24807 .17588 Metetra
.971 .692 .442 r
.49276 .37113 .49372 .37859 .48467 .36445 .48369 .36314 Metetra
.634 .164 0 r
.48369 .36314 .48467 .36445 .47552 .35073 .47452 .35225 Metetra
.88 .826 .79 r
.47452 .35225 .47552 .35073 .46622 .34317 .46522 .3437 Metetra
.739 .83 .92 r
.46522 .3437 .46622 .34317 .45681 .33446 .45579 .33546 Metetra
.847 .884 .866 r
.45579 .33546 .45681 .33446 .44726 .32675 .44622 .32997 Metetra
.95 .826 .686 r
.44622 .32997 .44726 .32675 .43761 .3166 .43649 .3254 Metetra
1 .826 .524 r
.43649 .3254 .43761 .3166 .42777 .31143 .42623 .35182 Metetra
.971 .75 .547 r
.42623 .35182 .42777 .31143 .41776 .30842 .41609 .35279 Metetra
.966 .744 .551 r
.41609 .35279 .41776 .30842 .40752 .30999 .40604 .33831 Metetra
.968 .75 .557 r
.40604 .33831 .40752 .30999 .39728 .30194 .39574 .3306 Metetra
.97 .752 .554 r
.39574 .3306 .39728 .30194 .38684 .29643 .3852 .3275 Metetra
.966 .748 .556 r
.3852 .3275 .38684 .29643 .37636 .28526 .37467 .31639 Metetra
.968 .749 .555 r
.37467 .31639 .37636 .28526 .36568 .27662 .36393 .30823 Metetra
.96 .741 .563 r
.36393 .30823 .36568 .27662 .35506 .25909 .35349 .2806 Metetra
.967 .754 .564 r
.35349 .2806 .35506 .25909 .3441 .25005 .34247 .27204 Metetra
.975 .763 .554 r
.34247 .27204 .3441 .25005 .33295 .24203 .3309 .27805 Metetra
.972 .753 .548 r
.3309 .27805 .33295 .24203 .32119 .24906 .31915 .28233 Metetra
.967 .748 .556 r
.31915 .28233 .32119 .24906 .30956 .24469 .30768 .27066 Metetra
.958 .742 .569 r
.30768 .27066 .30956 .24469 .29829 .22315 .29656 .24274 Metetra
.953 .741 .58 r
.29656 .24274 .29829 .22315 .28676 .20542 .28542 .21255 Metetra
.952 .773 .624 r
.28542 .21255 .28676 .20542 .27496 .19082 .27353 .20007 Metetra
.973 .787 .593 r
.27353 .20007 .27496 .19082 .26265 .18526 .261 .1997 Metetra
.963 .76 .581 r
.261 .1997 .26265 .18526 .25049 .17081 .24869 .18812 Metetra
.953 .756 .599 r
.49372 .37859 .49474 .36853 .4857 .35622 .48467 .36445 Metetra
.95 .759 .611 r
.48467 .36445 .4857 .35622 .47654 .34601 .47552 .35073 Metetra
.951 .79 .647 r
.47552 .35073 .47654 .34601 .46726 .3381 .46622 .34317 Metetra
.949 .784 .643 r
.46622 .34317 .46726 .3381 .45787 .32779 .45681 .33446 Metetra
.958 .779 .619 r
.45681 .33446 .45787 .32779 .44836 .31792 .44726 .32675 Metetra
.958 .766 .603 r
.44726 .32675 .44836 .31792 .43881 .30022 .43761 .3166 Metetra
.968 .759 .569 r
.43761 .3166 .43881 .30022 .42893 .3007 .42777 .31143 Metetra
.969 .773 .584 r
.42777 .31143 .42893 .3007 .41892 .29861 .41776 .30842 Metetra
.975 .783 .582 r
.41776 .30842 .41892 .29861 .40882 .2931 .40752 .30999 Metetra
.966 .757 .571 r
.40752 .30999 .40882 .2931 .39862 .28401 .39728 .30194 Metetra
.968 .758 .567 r
.39728 .30194 .39862 .28401 .38814 .28275 .38684 .29643 Metetra
.962 .758 .582 r
.38684 .29643 .38814 .28275 .37774 .269 .37636 .28526 Metetra
.965 .758 .573 r
.37636 .28526 .37774 .269 .36712 .2594 .36568 .27662 Metetra
.959 .75 .577 r
.36568 .27662 .36712 .2594 .35636 .2488 .35506 .25909 Metetra
.962 .767 .595 r
.35506 .25909 .35636 .2488 .34543 .23955 .3441 .25005 Metetra
.964 .769 .593 r
.3441 .25005 .34543 .23955 .33428 .23235 .33295 .24203 Metetra
.982 .794 .578 r
.33295 .24203 .33428 .23235 .32272 .23326 .32119 .24906 Metetra
.969 .763 .571 r
.32119 .24906 .32272 .23326 .31103 .23202 .30956 .24469 Metetra
.951 .75 .594 r
.30956 .24469 .31103 .23202 .29965 .21475 .29829 .22315 Metetra
.947 .759 .616 r
.29829 .22315 .29965 .21475 .28802 .20028 .28676 .20542 Metetra
.938 .776 .654 r
.28676 .20542 .28802 .20028 .27621 .18656 .27496 .19082 Metetra
.956 .816 .665 r
.27496 .19082 .27621 .18656 .26409 .17641 .26265 .18526 Metetra
.954 .766 .611 r
.26265 .18526 .26409 .17641 .2518 .16573 .25049 .17081 Metetra
.939 .77 .645 r
.49474 .36853 .49574 .3634 .4867 .35362 .4857 .35622 Metetra
.914 .796 .716 r
.4857 .35622 .4867 .35362 .47755 .34384 .47654 .34601 Metetra
.914 .821 .74 r
.47654 .34601 .47755 .34384 .46828 .33443 .46726 .3381 Metetra
.933 .788 .677 r
.46726 .3381 .46828 .33443 .45889 .32649 .45787 .32779 Metetra
.856 .816 .809 r
.45787 .32779 .45889 .32649 .44936 .31847 .44836 .31792 Metetra
.319 .489 .87 r
.44836 .31792 .44936 .31847 .43969 .31269 .43881 .30022 Metetra
.963 .704 .495 r
.43881 .30022 .43969 .31269 .42937 .34725 .42893 .3007 Metetra
.969 .73 .523 r
.42893 .3007 .42937 .34725 .41925 .34914 .41892 .29861 Metetra
.97 .732 .522 r
.41892 .29861 .41925 .34914 .40922 .33373 .40882 .2931 Metetra
.971 .731 .518 r
.40882 .2931 .40922 .33373 .39884 .33226 .39862 .28401 Metetra
.968 .73 .523 r
.39862 .28401 .39884 .33226 .38826 .33255 .38814 .28275 Metetra
.972 .734 .519 r
.38814 .28275 .38826 .33255 .3778 .31814 .37774 .269 Metetra
.971 .732 .52 r
.37774 .269 .3778 .31814 .36708 .30956 .36712 .2594 Metetra
.971 .733 .52 r
.36712 .2594 .36708 .30956 .35621 .30055 .35636 .2488 Metetra
.97 .733 .521 r
.35636 .2488 .35621 .30055 .34562 .27421 .34543 .23955 Metetra
.97 .728 .515 r
.34543 .23955 .34562 .27421 .33399 .28295 .33428 .23235 Metetra
.968 .73 .524 r
.33428 .23235 .33399 .28295 .32259 .27561 .32272 .23326 Metetra
.968 .729 .521 r
.32272 .23326 .32259 .27561 .31082 .2748 .31103 .23202 Metetra
.973 .733 .515 r
.31103 .23202 .31082 .2748 .29982 .24324 .29965 .21475 Metetra
.973 .728 .506 r
.29965 .21475 .29982 .24324 .28875 .21123 .28802 .20028 Metetra
.975 .707 .459 r
.28802 .20028 .28875 .21123 .27698 .19572 .27621 .18656 Metetra
.971 .696 .451 r
.27621 .18656 .27698 .19572 .26479 .18726 .26409 .17641 Metetra
.972 .704 .464 r
.26409 .17641 .26479 .18726 .25261 .17337 .2518 .16573 Metetra
0 .017 .529 r
.49574 .3634 .49673 .3644 .48769 .35646 .4867 .35362 Metetra
.941 .573 .216 r
.4867 .35362 .48769 .35646 .47853 .34801 .47755 .34384 Metetra
.965 .642 .34 r
.47755 .34384 .47853 .34801 .46926 .33817 .46828 .33443 Metetra
.959 .627 .331 r
.46828 .33443 .46926 .33817 .45986 .33058 .45889 .32649 Metetra
.962 .638 .35 r
.45889 .32649 .45986 .33058 .45032 .32362 .44936 .31847 Metetra
.963 .661 .406 r
.44936 .31847 .45032 .32362 .44064 .31813 .43969 .31269 Metetra
.874 .608 .532 r
.43969 .31269 .44064 .31813 .43049 .33989 .42937 .34725 Metetra
.977 .798 .596 r
.42937 .34725 .43049 .33989 .42051 .33255 .41925 .34914 Metetra
.96 .751 .577 r
.41925 .34914 .42051 .33255 .41041 .32404 .40922 .33373 Metetra
.971 .78 .587 r
.40922 .33373 .41041 .32404 .40012 .31812 .39884 .33226 Metetra
.973 .769 .569 r
.39884 .33226 .40012 .31812 .38967 .31296 .38826 .33255 Metetra
.962 .751 .57 r
.38826 .33255 .38967 .31296 .37923 .29954 .3778 .31814 Metetra
.966 .756 .568 r
.3778 .31814 .37923 .29954 .36854 .29115 .36708 .30956 Metetra
.966 .756 .569 r
.36708 .30956 .36854 .29115 .3577 .28261 .35621 .30055 Metetra
.953 .743 .581 r
.35621 .30055 .3577 .28261 .3467 .27386 .34562 .27421 Metetra
.084 0 0 r
.34562 .27421 .3467 .27386 .33556 .26449 .33399 .28295 Metetra
.967 .758 .568 r
.33399 .28295 .33556 .26449 .32422 .25624 .32259 .27561 Metetra
.972 .762 .562 r
.32259 .27561 .32422 .25624 .31264 .25051 .31082 .2748 Metetra
.955 .74 .572 r
.31082 .2748 .31264 .25051 .30168 .21914 .29982 .24324 Metetra
.955 .74 .572 r
.29982 .24324 .30168 .21914 .29013 .20262 .28875 .21123 Metetra
.952 .764 .613 r
.28875 .21123 .29013 .20262 .27819 .19262 .27698 .19572 Metetra
.936 .821 .707 r
.27698 .19572 .27819 .19262 .26609 .18182 .26479 .18726 Metetra
.943 .779 .649 r
.26479 .18726 .26609 .18182 .25381 .17106 .25261 .17337 Metetra
.947 .791 .654 r
.49673 .3644 .49773 .36003 .4887 .35001 .48769 .35646 Metetra
.955 .777 .621 r
.48769 .35646 .4887 .35001 .47956 .34063 .47853 .34801 Metetra
.955 .77 .614 r
.47853 .34801 .47956 .34063 .47029 .33383 .46926 .33817 Metetra
.949 .795 .655 r
.46926 .33817 .47029 .33383 .4609 .32645 .45986 .33058 Metetra
.95 .8 .66 r
.45986 .33058 .4609 .32645 .45138 .31873 .45032 .32362 Metetra
.958 .798 .641 r
.45032 .32362 .45138 .31873 .44167 .31735 .44064 .31813 Metetra
.249 0 .19 r
.44064 .31813 .44167 .31735 .43175 .32082 .43049 .33989 Metetra
.967 .756 .566 r
.43049 .33989 .43175 .32082 .42177 .3156 .42051 .33255 Metetra
.966 .757 .571 r
.42051 .33255 .42177 .3156 .41171 .30627 .41041 .32404 Metetra
.968 .758 .567 r
.41041 .32404 .41171 .30627 .40152 .29688 .40012 .31812 Metetra
.969 .756 .561 r
.40012 .31812 .40152 .29688 .39108 .29327 .38967 .31296 Metetra
.963 .751 .569 r
.38967 .31296 .39108 .29327 .38067 .28012 .37923 .29954 Metetra
.967 .755 .566 r
.37923 .29954 .38067 .28012 .37 .27249 .36854 .29115 Metetra
.966 .756 .568 r
.36854 .29115 .37 .27249 .35933 .25774 .3577 .28261 Metetra
.967 .752 .56 r
.3577 .28261 .35933 .25774 .34843 .24716 .3467 .27386 Metetra
.967 .751 .558 r
.3467 .27386 .34843 .24716 .3373 .23925 .33556 .26449 Metetra
.968 .752 .559 r
.33556 .26449 .3373 .23925 .32571 .24177 .32422 .25624 Metetra
.968 .764 .575 r
.32422 .25624 .32571 .24177 .31428 .23193 .31264 .25051 Metetra
.951 .74 .582 r
.31264 .25051 .31428 .23193 .30298 .21264 .30168 .21914 Metetra
.942 .766 .634 r
.30168 .21914 .30298 .21264 .29127 .20109 .29013 .20262 Metetra
.874 .839 .808 r
.29013 .20262 .29127 .20109 .27943 .18854 .27819 .19262 Metetra
.94 .798 .675 r
.27819 .19262 .27943 .18854 .26721 .18154 .26609 .18182 Metetra
.621 .798 .967 r
.26609 .18182 .26721 .18154 .25494 .17052 .25381 .17106 Metetra
.971 .667 .379 r
.49773 .36003 .4987 .36522 .48968 .35362 .4887 .35001 Metetra
.959 .622 .303 r
.4887 .35001 .48968 .35362 .48054 .34523 .47956 .34063 Metetra
.964 .653 .382 r
.47956 .34063 .48054 .34523 .47127 .3368 .47029 .33383 Metetra
.946 .588 .274 r
.47029 .33383 .47127 .3368 .46188 .33004 .4609 .32645 Metetra
.957 .62 .322 r
.4609 .32645 .46188 .33004 .45236 .32239 .45138 .31873 Metetra
.944 .619 .386 r
.45138 .31873 .45236 .32239 .44265 .32047 .44167 .31735 Metetra
.921 .591 .399 r
.44167 .31735 .44265 .32047 .43262 .33371 .43175 .32082 Metetra
.969 .71 .486 r
.43175 .32082 .43262 .33371 .42259 .33171 .42177 .3156 Metetra
.972 .718 .49 r
.42177 .3156 .42259 .33171 .41249 .32372 .41171 .30627 Metetra
.972 .72 .493 r
.41171 .30627 .41249 .32372 .40225 .31599 .40152 .29688 Metetra
.968 .718 .503 r
.40152 .29688 .40225 .31599 .39186 .3078 .39108 .29327 Metetra
.975 .718 .479 r
.39108 .29327 .39186 .3078 .38134 .29923 .38067 .28012 Metetra
.971 .72 .499 r
.38067 .28012 .38134 .29923 .37066 .29076 .37 .27249 Metetra
.975 .723 .489 r
.37 .27249 .37066 .29076 .35983 .28225 .35933 .25774 Metetra
.972 .726 .504 r
.35933 .25774 .35983 .28225 .34885 .27356 .34843 .24716 Metetra
.971 .725 .508 r
.34843 .24716 .34885 .27356 .33771 .26462 .3373 .23925 Metetra
.966 .72 .514 r
.3373 .23925 .33771 .26462 .3264 .2559 .32571 .24177 Metetra
.972 .713 .482 r
.32571 .24177 .3264 .2559 .31481 .2506 .31428 .23193 Metetra
.977 .725 .485 r
.31428 .23193 .31481 .2506 .30328 .23762 .30298 .21264 Metetra
.972 .726 .504 r
.30298 .21264 .30328 .23762 .29217 .20703 .29127 .20109 Metetra
.971 .671 .389 r
.29127 .20109 .29217 .20703 .28037 .19308 .27943 .18854 Metetra
.958 .638 .372 r
.27943 .18854 .28037 .19308 .26825 .18332 .26721 .18154 Metetra
.833 .378 0 r
.26721 .18154 .26825 .18332 .25607 .17008 .25494 .17052 Metetra
.829 .788 .813 r
.4987 .36522 .49969 .36409 .49067 .35415 .48968 .35362 Metetra
0 .405 .839 r
.48968 .35362 .49067 .35415 .48153 .34664 .48054 .34523 Metetra
.771 .291 0 r
.48054 .34523 .48153 .34664 .47227 .33868 .47127 .3368 Metetra
.889 .463 .103 r
.47127 .3368 .47227 .33868 .46287 .33156 .46188 .33004 Metetra
.82 .352 0 r
.46188 .33004 .46287 .33156 .45336 .32386 .45236 .32239 Metetra
.859 .416 .143 r
.45236 .32239 .45336 .32386 .44368 .31961 .44265 .32047 Metetra
.44265 .32047 .44368 .31961 .43365 .33296 .43262 .33371 Metetra
.791 .956 .922 r
.43262 .33371 .43365 .33296 .42362 .33136 .42259 .33171 Metetra
.67 .83 .96 r
.42259 .33171 .42362 .33136 .41353 .32341 .41249 .32372 Metetra
.645 .83 .971 r
.41249 .32372 .41353 .32341 .4033 .31536 .40225 .31599 Metetra
.759 .849 .918 r
.40225 .31599 .4033 .31536 .39291 .30779 .39186 .3078 Metetra
.475 .751 .99 r
.39186 .3078 .39291 .30779 .3824 .29896 .38134 .29923 Metetra
.625 .815 .974 r
.38134 .29923 .3824 .29896 .37179 .28783 .37066 .29076 Metetra
.932 .816 .709 r
.37066 .29076 .37179 .28783 .36134 .26287 .35983 .28225 Metetra
.967 .756 .566 r
.35983 .28225 .36134 .26287 .35053 .2484 .34885 .27356 Metetra
.968 .752 .559 r
.34885 .27356 .35053 .2484 .33944 .23951 .33771 .26462 Metetra
.968 .752 .559 r
.33771 .26462 .33944 .23951 .32749 .25547 .3264 .2559 Metetra
.664 .895 .98 r
.3264 .2559 .32749 .25547 .31602 .24657 .31481 .2506 Metetra
.933 .787 .677 r
.31481 .2506 .31602 .24657 .30507 .21534 .30328 .23762 Metetra
.955 .741 .574 r
.30328 .23762 .30507 .21534 .29352 .19941 .29217 .20703 Metetra
.952 .769 .62 r
.29217 .20703 .29352 .19941 .28163 .18856 .28037 .19308 Metetra
.947 .798 .663 r
.28037 .19308 .28163 .18856 .26948 .17994 .26825 .18332 Metetra
.924 .795 .699 r
.26825 .18332 .26948 .17994 .25719 .16985 .25607 .17008 Metetra
.934 .788 .675 r
.49969 .36409 .50069 .36043 .49167 .35126 .49067 .35415 Metetra
.934 .811 .701 r
.49067 .35415 .49167 .35126 .48255 .34208 .48153 .34664 Metetra
.949 .791 .651 r
.48153 .34664 .48255 .34208 .47331 .33209 .47227 .33868 Metetra
.959 .781 .618 r
.47227 .33868 .47331 .33209 .46394 .32437 .46287 .33156 Metetra
.959 .777 .612 r
.46287 .33156 .46394 .32437 .45444 .31654 .45336 .32386 Metetra
.966 .784 .606 r
.45336 .32386 .45444 .31654 .44481 .30866 .44368 .31961 Metetra
.988 .795 .556 r
.44368 .31961 .44481 .30866 .43503 .30283 .43365 .33296 Metetra
.971 .752 .551 r
.43365 .33296 .43503 .30283 .42509 .29822 .42362 .33136 Metetra
.968 .749 .552 r
.42362 .33136 .42509 .29822 .415 .29378 .41353 .32341 Metetra
.968 .75 .554 r
.41353 .32341 .415 .29378 .4048 .28709 .4033 .31536 Metetra
.968 .751 .555 r
.4033 .31536 .4048 .28709 .39446 .27947 .39291 .30779 Metetra
.968 .75 .556 r
.39291 .30779 .39446 .27947 .38403 .26933 .3824 .29896 Metetra
.967 .749 .556 r
.3824 .29896 .38403 .26933 .37343 .25989 .37179 .28783 Metetra
.96 .743 .564 r
.37179 .28783 .37343 .25989 .36274 .24804 .36134 .26287 Metetra
.961 .755 .58 r
.36134 .26287 .36274 .24804 .35183 .23882 .35053 .2484 Metetra
.962 .77 .598 r
.35053 .2484 .35183 .23882 .34074 .2307 .33944 .23951 Metetra
.992 .815 .563 r
.33944 .23951 .34074 .2307 .32923 .23158 .32749 .25547 Metetra
.968 .753 .561 r
.32749 .25547 .32923 .23158 .31796 .21757 .31602 .24657 Metetra
.958 .74 .566 r
.31602 .24657 .31796 .21757 .30649 .20493 .30507 .21534 Metetra
.955 .76 .6 r
.30507 .21534 .30649 .20493 .29476 .19484 .29352 .19941 Metetra
.944 .793 .662 r
.29352 .19941 .29476 .19484 .28286 .18476 .28163 .18856 Metetra
.944 .811 .681 r
.28163 .18856 .28286 .18476 .27073 .17591 .26948 .17994 Metetra
.942 .802 .676 r
.26948 .17994 .27073 .17591 .25857 .16291 .25719 .16985 Metetra
.96 .765 .596 r
.50069 .36043 .50169 .35095 .49268 .34654 .49167 .35126 Metetra
.946 .785 .649 r
.49167 .35126 .49268 .34654 .48358 .33427 .48255 .34208 Metetra
.956 .769 .609 r
.48255 .34208 .48358 .33427 .47435 .32515 .47331 .33209 Metetra
.959 .777 .614 r
.47331 .33209 .47435 .32515 .46498 .31907 .46394 .32437 Metetra
.954 .787 .637 r
.46394 .32437 .46498 .31907 .45555 .30489 .45444 .31654 Metetra
.964 .764 .584 r
.45444 .31654 .45555 .30489 .44599 .29222 .44481 .30866 Metetra
.968 .759 .568 r
.44481 .30866 .44599 .29222 .43621 .28885 .43503 .30283 Metetra
.969 .764 .573 r
.43503 .30283 .43621 .28885 .42618 .2935 .42509 .29822 Metetra
.961 .806 .644 r
.42509 .29822 .42618 .2935 .41615 .28626 .415 .29378 Metetra
.963 .78 .609 r
.415 .29378 .41615 .28626 .40596 .27974 .4048 .28709 Metetra
.961 .779 .612 r
.4048 .28709 .40596 .27974 .39558 .27522 .39446 .27947 Metetra
.942 .791 .665 r
.39446 .27947 .39558 .27522 .38516 .26488 .38403 .26933 Metetra
.946 .793 .659 r
.38403 .26933 .38516 .26488 .37466 .25152 .37343 .25989 Metetra
.956 .768 .609 r
.37343 .25989 .37466 .25152 .36392 .2427 .36274 .24804 Metetra
.952 .788 .642 r
.36274 .24804 .36392 .2427 .35302 .23387 .35183 .23882 Metetra
.953 .795 .648 r
.35183 .23882 .35302 .23387 .34196 .2248 .34074 .2307 Metetra
.975 .813 .618 r
.34074 .2307 .34196 .2248 .33047 .22587 .32923 .23158 Metetra
.943 .774 .642 r
.32923 .23158 .33047 .22587 .31907 .21674 .31796 .21757 Metetra
.781 .803 .871 r
.31796 .21757 .31907 .21674 .30748 .20796 .30649 .20493 Metetra
.941 .573 .241 r
.30649 .20493 .30748 .20796 .29595 .19205 .29476 .19484 Metetra
.924 .817 .721 r
.29476 .19484 .29595 .19205 .28397 .18448 .28286 .18476 Metetra
.608 .823 .983 r
.28286 .18476 .28397 .18448 .27158 .18299 .27073 .17591 Metetra
.973 .683 .412 r
.27073 .17591 .27158 .18299 .25969 .16268 .25857 .16291 Metetra
.967 .694 .462 r
.50169 .35095 .50267 .35931 .49367 .34985 .49268 .34654 Metetra
.95 .599 .229 r
.49268 .34654 .49367 .34985 .48455 .34023 .48358 .33427 Metetra
.972 .678 .406 r
.48358 .33427 .48455 .34023 .47532 .33179 .47435 .32515 Metetra
.968 .682 .434 r
.47435 .32515 .47532 .33179 .46595 .32411 .46498 .31907 Metetra
.973 .663 .34 r
.46498 .31907 .46595 .32411 .45646 .31635 .45555 .30489 Metetra
.977 .713 .463 r
.45555 .30489 .45646 .31635 .4468 .31386 .44599 .29222 Metetra
.969 .721 .507 r
.44599 .29222 .4468 .31386 .43675 .33198 .43621 .28885 Metetra
.967 .728 .523 r
.43621 .28885 .43675 .33198 .42677 .32812 .42618 .2935 Metetra
.971 .729 .514 r
.42618 .2935 .42677 .32812 .41674 .31702 .41615 .28626 Metetra
.971 .728 .512 r
.41615 .28626 .41674 .31702 .40656 .30704 .40596 .27974 Metetra
.97 .725 .511 r
.40596 .27974 .40656 .30704 .39599 .31164 .39558 .27522 Metetra
.972 .731 .513 r
.39558 .27522 .39599 .31164 .38578 .28784 .38516 .26488 Metetra
.974 .726 .499 r
.38516 .26488 .38578 .28784 .37513 .2798 .37466 .25152 Metetra
.972 .727 .508 r
.37466 .25152 .37513 .2798 .36439 .26891 .36392 .2427 Metetra
.972 .726 .506 r
.36392 .2427 .36439 .26891 .35345 .26044 .35302 .23387 Metetra
.972 .726 .507 r
.35302 .23387 .35345 .26044 .34231 .25301 .34196 .2248 Metetra
.967 .723 .514 r
.34196 .2248 .34231 .25301 .33059 .2608 .33047 .22587 Metetra
.971 .729 .513 r
.33047 .22587 .33059 .2608 .31912 .25214 .31907 .21674 Metetra
.971 .729 .513 r
.31907 .21674 .31912 .25214 .30811 .22284 .30748 .20796 Metetra
.976 .718 .475 r
.30748 .20796 .30811 .22284 .29667 .20345 .29595 .19205 Metetra
.97 .704 .471 r
.29595 .19205 .29667 .20345 .28478 .19302 .28397 .18448 Metetra
.961 .684 .464 r
.28397 .18448 .28478 .19302 .27265 .18388 .27158 .18299 Metetra
.017 .307 .799 r
.27158 .18299 .27265 .18388 .26043 .17247 .25969 .16268 Metetra
.952 .602 .265 r
.50267 .35931 .50365 .36255 .49465 .35232 .49367 .34985 Metetra
.922 .533 .153 r
.49367 .34985 .49465 .35232 .48553 .34556 .48455 .34023 Metetra
.969 .668 .393 r
.48455 .34023 .48553 .34556 .47629 .33656 .47532 .33179 Metetra
.966 .656 .379 r
.47532 .33179 .47629 .33656 .46693 .32914 .46595 .32411 Metetra
.967 .661 .388 r
.46595 .32411 .46693 .32914 .45743 .32157 .45646 .31635 Metetra
.958 .658 .424 r
.45646 .31635 .45743 .32157 .4478 .31546 .4468 .31386 Metetra
.797 .471 .436 r
.4468 .31386 .4478 .31546 .43771 .33789 .43675 .33198 Metetra
.962 .668 .429 r
.43675 .33198 .43771 .33789 .4277 .33575 .42677 .32812 Metetra
.975 .692 .428 r
.42677 .32812 .4277 .33575 .41768 .32412 .41674 .31702 Metetra
.973 .687 .424 r
.41674 .31702 .41768 .32412 .40747 .31579 .40656 .30704 Metetra
.954 .683 .484 r
.40656 .30704 .40747 .31579 .3969 .3203 .39599 .31164 Metetra
.985 .707 .396 r
.39599 .31164 .3969 .3203 .38654 .30304 .38578 .28784 Metetra
.972 .715 .487 r
.38578 .28784 .38654 .30304 .37592 .29288 .37513 .2798 Metetra
.974 .713 .475 r
.37513 .2798 .37592 .29288 .36516 .28226 .36439 .26891 Metetra
.972 .711 .48 r
.36439 .26891 .36516 .28226 .35423 .27256 .35345 .26044 Metetra
.971 .707 .476 r
.35345 .26044 .35423 .27256 .3432 .26035 .34231 .25301 Metetra
.945 .666 .478 r
.34231 .25301 .3432 .26035 .33182 .25531 .33059 .2608 Metetra
.955 .791 .64 r
.33059 .2608 .33182 .25531 .32006 .25731 .31912 .25214 Metetra
.955 .645 .222 r
.31912 .25214 .32006 .25731 .30874 .23803 .30811 .22284 Metetra
.979 .721 .471 r
.30811 .22284 .30874 .23803 .29758 .20907 .29667 .20345 Metetra
.968 .663 .388 r
.29667 .20345 .29758 .20907 .28595 .19088 .28478 .19302 Metetra
.91 .837 .76 r
.28478 .19302 .28595 .19088 .27386 .18115 .27265 .18388 Metetra
.918 .812 .726 r
.27265 .18388 .27386 .18115 .26159 .17103 .26043 .17247 Metetra
.538 .717 .955 r
.50365 .36255 .50464 .36254 .49565 .35268 .49465 .35232 Metetra
.041 .508 .886 r
.49465 .35232 .49565 .35268 .48653 .34462 .48553 .34556 Metetra
.821 .826 .852 r
.48553 .34556 .48653 .34462 .4773 .33657 .47629 .33656 Metetra
.454 .746 .991 r
.47629 .33656 .4773 .33657 .46794 .32899 .46693 .32914 Metetra
.574 .797 .984 r
.46693 .32914 .46794 .32899 .45845 .32203 .45743 .32157 Metetra
0 .375 .768 r
.45743 .32157 .45845 .32203 .44879 .3188 .4478 .31546 Metetra
.862 .57 .493 r
.4478 .31546 .44879 .3188 .43867 .34394 .43771 .33789 Metetra
.959 .668 .439 r
.43771 .33789 .43867 .34394 .4288 .33064 .4277 .33575 Metetra
.944 .779 .647 r
.4277 .33575 .4288 .33064 .41873 .32364 .41768 .32412 Metetra
.716 .837 .939 r
.41768 .32412 .41873 .32364 .40852 .31575 .40747 .31579 Metetra
.239 0 0 r
.40747 .31579 .40852 .31575 .39812 .31034 .3969 .3203 Metetra
.951 .756 .603 r
.3969 .3203 .39812 .31034 .38769 .29803 .38654 .30304 Metetra
.948 .787 .649 r
.38654 .30304 .38769 .29803 .37705 .28962 .37592 .29288 Metetra
.93 .801 .696 r
.37592 .29288 .37705 .28962 .36626 .28096 .36516 .28226 Metetra
.857 .836 .825 r
.36516 .28226 .36626 .28096 .35553 .26288 .35423 .27256 Metetra
.958 .765 .6 r
.35423 .27256 .35553 .26288 .3448 .23974 .3432 .26035 Metetra
.97 .758 .561 r
.3432 .26035 .3448 .23974 .33323 .24337 .33182 .25531 Metetra
.976 .779 .574 r
.33182 .25531 .33323 .24337 .32144 .2473 .32006 .25731 Metetra
.95 .755 .605 r
.32006 .25731 .32144 .2473 .30989 .23624 .30874 .23803 Metetra
.808 .7 .746 r
.30874 .23803 .30989 .23624 .29888 .20306 .29758 .20907 Metetra
.937 .765 .642 r
.29758 .20907 .29888 .20306 .28713 .18876 .28595 .19088 Metetra
.907 .833 .762 r
.28595 .19088 .28713 .18876 .27505 .17899 .27386 .18115 Metetra
.907 .83 .76 r
.27386 .18115 .27505 .17899 .26271 .17096 .26159 .17103 Metetra
.964 .637 .321 r
.50464 .36254 .50563 .36654 .49663 .35922 .49565 .35268 Metetra
.971 .683 .423 r
.49565 .35268 .49663 .35922 .48751 .35045 .48653 .34462 Metetra
.97 .674 .408 r
.48653 .34462 .48751 .35045 .47828 .34016 .4773 .33657 Metetra
.957 .62 .32 r
.4773 .33657 .47828 .34016 .46891 .33501 .46794 .32899 Metetra
.968 .675 .418 r
.46794 .32899 .46891 .33501 .45941 .32842 .45845 .32203 Metetra
.962 .675 .441 r
.45845 .32203 .45941 .32842 .44981 .31898 .44879 .3188 Metetra
.597 .276 .396 r
.44879 .3188 .44981 .31898 .43976 .33824 .43867 .34394 Metetra
.943 .771 .639 r
.43867 .34394 .43976 .33824 .42988 .32731 .4288 .33064 Metetra
.944 .815 .687 r
.4288 .33064 .42988 .32731 .41984 .31814 .41873 .32364 Metetra
.956 .789 .636 r
.41873 .32364 .41984 .31814 .40965 .30983 .40852 .31575 Metetra
.963 .794 .626 r
.40852 .31575 .40965 .30983 .39924 .30643 .39812 .31034 Metetra
.932 .785 .676 r
.39812 .31034 .39924 .30643 .38878 .29665 .38769 .29803 Metetra
.871 .847 .818 r
.38769 .29803 .38878 .29665 .37816 .2871 .37705 .28962 Metetra
.923 .823 .73 r
.37705 .28962 .37816 .2871 .36752 .27199 .36626 .28096 Metetra
.948 .757 .61 r
.36626 .28096 .36752 .27199 .35677 .25586 .35553 .26288 Metetra
.932 .749 .632 r
.35553 .26288 .35677 .25586 .34583 .24137 .3448 .23974 Metetra
.853 .447 .266 r
.3448 .23974 .34583 .24137 .33424 .24601 .33323 .24337 Metetra
.904 .549 .359 r
.33323 .24337 .33424 .24601 .32248 .24914 .32144 .2473 Metetra
.84 .392 0 r
.32144 .2473 .32248 .24914 .31149 .2194 .30989 .23624 Metetra
.949 .739 .586 r
.30989 .23624 .31149 .2194 .29998 .20279 .29888 .20306 Metetra
.636 .745 .927 r
.29888 .20306 .29998 .20279 .28816 .19075 .28713 .18876 Metetra
.874 .438 .053 r
.28713 .18876 .28816 .19075 .27606 .18153 .27505 .17899 Metetra
.921 .529 .204 r
.27505 .17899 .27606 .18153 .26383 .17071 .26271 .17096 Metetra
.878 .843 .807 r
.50563 .36654 .50662 .36518 .49763 .35609 .49663 .35922 Metetra
.933 .801 .692 r
.49663 .35922 .49763 .35609 .48853 .34484 .48751 .35045 Metetra
.949 .777 .635 r
.48751 .35045 .48853 .34484 .4793 .33709 .47828 .34016 Metetra
.948 .826 .691 r
.47828 .34016 .4793 .33709 .46996 .32892 .46891 .33501 Metetra
.96 .786 .623 r
.46891 .33501 .46996 .32892 .46048 .32151 .45941 .32842 Metetra
.956 .775 .617 r
.45941 .32842 .46048 .32151 .4508 .32184 .44981 .31898 Metetra
.858 .555 .475 r
.44981 .31898 .4508 .32184 .44082 .3354 .43976 .33824 Metetra
.919 .797 .71 r
.43976 .33824 .44082 .3354 .43047 .36398 .42988 .32731 Metetra
.972 .731 .513 r
.42988 .32731 .43047 .36398 .42046 .34905 .41984 .31814 Metetra
.972 .728 .51 r
.41984 .31814 .42046 .34905 .41036 .33215 .40965 .30983 Metetra
.969 .721 .506 r
.40965 .30983 .41036 .33215 .39972 .34018 .39924 .30643 Metetra
.972 .73 .511 r
.39924 .30643 .39972 .34018 .38963 .30798 .38878 .29665 Metetra
.973 .707 .467 r
.38878 .29665 .38963 .30798 .37906 .2952 .37816 .2871 Metetra
.978 .697 .419 r
.37816 .2871 .37906 .2952 .36863 .27019 .36752 .27199 Metetra
.859 .774 .766 r
.36752 .27199 .36863 .27019 .35776 .2594 .35677 .25586 Metetra
.951 .6 .233 r
.35677 .25586 .35776 .2594 .34667 .25087 .34583 .24137 Metetra
.956 .685 .484 r
.34583 .24137 .34667 .25087 .33481 .26515 .33424 .24601 Metetra
.965 .713 .506 r
.33424 .24601 .33481 .26515 .32302 .26832 .32248 .24914 Metetra
.983 .731 .472 r
.32248 .24914 .32302 .26832 .31173 .24784 .31149 .2194 Metetra
.975 .729 .502 r
.31149 .2194 .31173 .24784 .30109 .2026 .29998 .20279 Metetra
.596 .763 .959 r
.29998 .20279 .30109 .2026 .2892 .19263 .28816 .19075 Metetra
.864 .419 .037 r
.28816 .19075 .2892 .19263 .27715 .18227 .27606 .18153 Metetra
0 .229 .696 r
.27606 .18153 .27715 .18227 .26485 .17339 .26383 .17071 Metetra
.97 .666 .382 r
.50662 .36518 .50761 .37035 .49863 .35462 .49763 .35609 Metetra
.861 .796 .786 r
.49763 .35609 .49863 .35462 .48952 .34708 .48853 .34484 Metetra
.915 .515 .155 r
.48853 .34484 .48952 .34708 .4803 .33825 .4793 .33709 Metetra
.668 .161 0 r
.4793 .33709 .4803 .33825 .47096 .32947 .46996 .32892 Metetra
0 .336 .767 r
.46996 .32892 .47096 .32947 .4615 .32107 .46048 .32151 Metetra
.548 .927 .911 r
.46048 .32151 .4615 .32107 .45193 .31011 .4508 .32184 Metetra
.988 .792 .552 r
.4508 .32184 .45193 .31011 .44215 .30758 .44082 .3354 Metetra
.985 .768 .53 r
.44082 .3354 .44215 .30758 .43214 .31174 .43047 .36398 Metetra
.968 .744 .546 r
.43047 .36398 .43214 .31174 .42207 .30739 .42046 .34905 Metetra
.967 .744 .55 r
.42046 .34905 .42207 .30739 .41178 .30745 .41036 .33215 Metetra
.977 .761 .547 r
.41036 .33215 .41178 .30745 .40147 .29888 .39972 .34018 Metetra
.962 .74 .556 r
.39972 .34018 .40147 .29888 .39106 .28712 .38963 .30798 Metetra
.965 .752 .565 r
.38963 .30798 .39106 .28712 .38057 .273 .37906 .2952 Metetra
.958 .744 .57 r
.37906 .2952 .38057 .273 .36994 .25885 .36863 .27019 Metetra
.962 .764 .589 r
.36863 .27019 .36994 .25885 .3591 .24757 .35776 .2594 Metetra
.965 .766 .585 r
.35776 .2594 .3591 .24757 .34803 .23957 .34667 .25087 Metetra
.988 .796 .558 r
.34667 .25087 .34803 .23957 .33679 .23161 .33481 .26515 Metetra
.973 .754 .546 r
.33481 .26515 .33679 .23161 .32516 .23142 .32302 .26832 Metetra
.965 .745 .554 r
.32302 .26832 .32516 .23142 .31379 .21565 .31173 .24784 Metetra
.955 .735 .566 r
.31173 .24784 .31379 .21565 .30222 .20132 .30109 .2026 Metetra
.852 .844 .836 r
.30109 .2026 .30222 .20132 .29037 .19082 .2892 .19263 Metetra
.89 .833 .785 r
.2892 .19263 .29037 .19082 .27825 .18244 .27715 .18227 Metetra
.265 .66 .967 r
.27715 .18227 .27825 .18244 .26601 .17209 .26485 .17339 Metetra
.952 .754 .598 r
.50761 .37035 .50861 .36013 .49963 .35034 .49863 .35462 Metetra
.949 .795 .655 r
.49863 .35462 .49963 .35034 .49055 .33927 .48952 .34708 Metetra
.959 .772 .607 r
.48952 .34708 .49055 .33927 .48136 .32704 .4803 .33825 Metetra
.963 .764 .586 r
.4803 .33825 .48136 .32704 .47204 .31817 .47096 .32947 Metetra
.964 .764 .585 r
.47096 .32947 .47204 .31817 .46262 .30696 .4615 .32107 Metetra
.963 .757 .578 r
.4615 .32107 .46262 .30696 .45314 .28848 .45193 .31011 Metetra
.971 .757 .556 r
.45193 .31011 .45314 .28848 .44346 .28039 .44215 .30758 Metetra
.975 .757 .547 r
.44215 .30758 .44346 .28039 .4334 .29227 .43214 .31174 Metetra
.97 .758 .561 r
.43214 .31174 .4334 .29227 .42333 .29095 .42207 .30739 Metetra
.974 .766 .562 r
.42207 .30739 .42333 .29095 .41313 .28722 .41178 .30745 Metetra
.968 .755 .563 r
.41178 .30745 .41313 .28722 .40275 .28451 .40147 .29888 Metetra
.963 .758 .578 r
.40147 .29888 .40275 .28451 .39232 .27628 .39106 .28712 Metetra
.957 .76 .595 r
.39106 .28712 .39232 .27628 .38184 .26221 .38057 .273 Metetra
.958 .76 .595 r
.38057 .273 .38184 .26221 .37121 .24906 .36994 .25885 Metetra
.96 .766 .598 r
.36994 .25885 .37121 .24906 .36035 .23986 .3591 .24757 Metetra
.962 .779 .61 r
.3591 .24757 .36035 .23986 .34925 .23392 .34803 .23957 Metetra
.957 .792 .635 r
.34803 .23957 .34925 .23392 .33781 .23386 .33679 .23161 Metetra
.903 .517 .284 r
.33679 .23161 .33781 .23386 .32637 .22709 .32516 .23142 Metetra
.929 .776 .67 r
.32516 .23142 .32637 .22709 .31488 .21584 .31379 .21565 Metetra
.408 .634 .947 r
.31379 .21565 .31488 .21584 .30334 .20087 .30222 .20132 Metetra
.693 .82 .943 r
.30222 .20132 .30334 .20087 .2915 .18982 .29037 .19082 Metetra
.824 .87 .879 r
.29037 .19082 .2915 .18982 .27931 .1837 .27825 .18244 Metetra
.682 .174 0 r
.27825 .18244 .27931 .1837 .26712 .17233 .26601 .17209 Metetra
.758 .294 0 r
.50861 .36013 .5096 .36164 .50063 .34984 .49963 .35034 Metetra
.728 .776 .891 r
.49963 .35034 .50063 .34984 .49156 .338 .49055 .33927 Metetra
.839 .786 .801 r
.49055 .33927 .49156 .338 .48235 .33015 .48136 .32704 Metetra
.949 .592 .26 r
.48136 .32704 .48235 .33015 .47304 .32029 .47204 .31817 Metetra
.873 .458 .021 r
.47204 .31817 .47304 .32029 .46358 .31493 .46262 .30696 Metetra
.982 .701 .4 r
.46262 .30696 .46358 .31493 .45391 .31654 .45314 .28848 Metetra
.972 .728 .507 r
.45314 .28848 .45391 .31654 .44402 .32498 .44346 .28039 Metetra
.966 .727 .525 r
.44346 .28039 .44402 .32498 .43398 .33131 .4334 .29227 Metetra
.97 .729 .518 r
.4334 .29227 .43398 .33131 .42386 .32919 .42333 .29095 Metetra
.97 .729 .516 r
.42333 .29095 .42386 .32919 .41364 .32293 .41313 .28722 Metetra
.97 .728 .515 r
.41313 .28722 .41364 .32293 .4031 .32743 .40275 .28451 Metetra
.972 .732 .516 r
.40275 .28451 .4031 .32743 .39276 .31032 .39232 .27628 Metetra
.974 .731 .508 r
.39232 .27628 .39276 .31032 .38214 .30097 .38184 .26221 Metetra
.973 .732 .511 r
.38184 .26221 .38214 .30097 .37147 .28726 .37121 .24906 Metetra
.972 .731 .513 r
.37121 .24906 .37147 .28726 .3607 .27133 .36035 .23986 Metetra
.971 .727 .511 r
.36035 .23986 .3607 .27133 .34988 .2518 .34925 .23392 Metetra
.967 .714 .501 r
.34925 .23392 .34988 .2518 .33827 .25757 .33781 .23386 Metetra
.971 .723 .503 r
.33781 .23386 .33827 .25757 .3266 .25785 .32637 .22709 Metetra
.973 .729 .507 r
.32637 .22709 .3266 .25785 .31527 .23937 .31488 .21584 Metetra
.975 .726 .496 r
.31488 .21584 .31527 .23937 .30442 .20147 .30334 .20087 Metetra
0 .36 .808 r
.30334 .20087 .30442 .20147 .29259 .19045 .2915 .18982 Metetra
.408 0 0 r
.2915 .18982 .29259 .19045 .28056 .17995 .27931 .1837 Metetra
.937 .801 .685 r
.27931 .1837 .28056 .17995 .26839 .1681 .26712 .17233 Metetra
.948 .77 .628 r
.5096 .36164 .51059 .35547 .50164 .34241 .50063 .34984 Metetra
.953 .766 .614 r
.50063 .34984 .50164 .34241 .49257 .33491 .49156 .338 Metetra
.937 .808 .693 r
.49156 .338 .49257 .33491 .48337 .32704 .48235 .33015 Metetra
.929 .797 .695 r
.48235 .33015 .48337 .32704 .47406 .31946 .47304 .32029 Metetra
.82 .892 .894 r
.47304 .32029 .47406 .31946 .4646 .31364 .46358 .31493 Metetra
.895 .977 .814 r
.46358 .31493 .4646 .31364 .45496 .31406 .45391 .31654 Metetra
.967 .936 .652 r
.45391 .31654 .45496 .31406 .44515 .31577 .44402 .32498 Metetra
.983 .795 .573 r
.44402 .32498 .44515 .31577 .4352 .31527 .43398 .33131 Metetra
.972 .764 .564 r
.43398 .33131 .4352 .31527 .42519 .3071 .42386 .32919 Metetra
.97 .755 .558 r
.42386 .32919 .42519 .3071 .415 .30177 .41364 .32293 Metetra
.976 .763 .552 r
.41364 .32293 .415 .30177 .40458 .30119 .4031 .32743 Metetra
.965 .747 .56 r
.4031 .32743 .40458 .30119 .39428 .28449 .39276 .31032 Metetra
.968 .752 .557 r
.39276 .31032 .39428 .28449 .38374 .2737 .38214 .30097 Metetra
.967 .749 .558 r
.38214 .30097 .38374 .2737 .37297 .26689 .37147 .28726 Metetra
.964 .751 .568 r
.37147 .28726 .37297 .26689 .36224 .25078 .3607 .27133 Metetra
.961 .748 .57 r
.3607 .27133 .36224 .25078 .35129 .23845 .34988 .2518 Metetra
.979 .779 .564 r
.34988 .2518 .35129 .23845 .33992 .23611 .33827 .25757 Metetra
.974 .761 .556 r
.33827 .25757 .33992 .23611 .32843 .23143 .3266 .25785 Metetra
.964 .748 .561 r
.3266 .25785 .32843 .23143 .31708 .21539 .31527 .23937 Metetra
.953 .737 .573 r
.31527 .23937 .31708 .21539 .30576 .19382 .30442 .20147 Metetra
.958 .776 .615 r
.30442 .20147 .30576 .19382 .29389 .18449 .29259 .19045 Metetra
.954 .786 .635 r
.29259 .19045 .29389 .18449 .28184 .17513 .28056 .17995 Metetra
.945 .79 .658 r
.28056 .17995 .28184 .17513 .26966 .16391 .26839 .1681 Metetra
.934 .57 .166 r
.51059 .35547 .51158 .3585 .50262 .3489 .50164 .34241 Metetra
.971 .682 .423 r
.50164 .34241 .50262 .3489 .49355 .34135 .49257 .33491 Metetra
.971 .681 .42 r
.49257 .33491 .49355 .34135 .48435 .33339 .48337 .32704 Metetra
.97 .68 .419 r
.48337 .32704 .48435 .33339 .47503 .32627 .47406 .31946 Metetra
.968 .682 .435 r
.47406 .31946 .47503 .32627 .46558 .31853 .4646 .31364 Metetra
.95 .648 .429 r
.4646 .31364 .46558 .31853 .456 .31209 .45496 .31406 Metetra
.951 .927 .742 r
.45496 .31406 .456 .31209 .44615 .31811 .44515 .31577 Metetra
.913 .54 .302 r
.44515 .31577 .44615 .31811 .43615 .32261 .4352 .31527 Metetra
.971 .687 .432 r
.4352 .31527 .43615 .32261 .42613 .31533 .42519 .3071 Metetra
.968 .69 .452 r
.42519 .3071 .42613 .31533 .41593 .30998 .415 .30177 Metetra
.961 .685 .465 r
.415 .30177 .41593 .30998 .40558 .30492 .40458 .30119 Metetra
.95 .606 .214 r
.40458 .30119 .40558 .30492 .39521 .29165 .39428 .28449 Metetra
.974 .686 .419 r
.39428 .28449 .39521 .29165 .38461 .28349 .38374 .2737 Metetra
.97 .699 .461 r
.38374 .2737 .38461 .28349 .37389 .27355 .37297 .26689 Metetra
.978 .684 .384 r
.37297 .26689 .37389 .27355 .36315 .25814 .36224 .25078 Metetra
.975 .688 .416 r
.36224 .25078 .36315 .25814 .35215 .24709 .35129 .23845 Metetra
.964 .687 .462 r
.35129 .23845 .35215 .24709 .34084 .24224 .33992 .23611 Metetra
.962 .666 .423 r
.33992 .23611 .34084 .24224 .32925 .24102 .32843 .23143 Metetra
.978 .704 .435 r
.32843 .23143 .32925 .24102 .3181 .2178 .31708 .21539 Metetra
.774 .391 0 r
.31708 .21539 .3181 .2178 .30666 .20016 .30576 .19382 Metetra
.969 .672 .408 r
.30576 .19382 .30666 .20016 .29498 .18492 .29389 .18449 Metetra
.007 .476 .87 r
.29389 .18449 .29498 .18492 .28291 .17626 .28184 .17513 Metetra
.578 .068 0 r
.28184 .17513 .28291 .17626 .27076 .16439 .26966 .16391 Metetra
.946 .784 .65 r
.51158 .3585 .51258 .35385 .50363 .3446 .50262 .3489 Metetra
.95 .795 .654 r
.50262 .3489 .50363 .3446 .49457 .33252 .49355 .34135 Metetra
.963 .771 .597 r
.49355 .34135 .49457 .33252 .4854 .32275 .48435 .33339 Metetra
.966 .767 .586 r
.48435 .33339 .4854 .32275 .47609 .31744 .47503 .32627 Metetra
.963 .772 .597 r
.47503 .32627 .47609 .31744 .46662 .31474 .46558 .31853 Metetra
.951 .809 .668 r
.46558 .31853 .46662 .31474 .45702 .31136 .456 .31209 Metetra
.478 .86 .65 r
.456 .31209 .45702 .31136 .44718 .31804 .44615 .31811 Metetra
.226 0 0 r
.44615 .31811 .44718 .31804 .43728 .3142 .43615 .32261 Metetra
.964 .775 .601 r
.43615 .32261 .43728 .3142 .42719 .31349 .42613 .31533 Metetra
.917 .865 .773 r
.42613 .31533 .42719 .31349 .41702 .30692 .41593 .30998 Metetra
.949 .834 .697 r
.41593 .30998 .41702 .30692 .40668 .30175 .40558 .30492 Metetra
.918 .786 .699 r
.40558 .30492 .40668 .30175 .39629 .29041 .39521 .29165 Metetra
.859 .854 .836 r
.39521 .29165 .39629 .29041 .38575 .27945 .38461 .28349 Metetra
.942 .797 .671 r
.38461 .28349 .38575 .27945 .3751 .26679 .37389 .27355 Metetra
.946 .767 .628 r
.37389 .27355 .3751 .26679 .36434 .25273 .36315 .25814 Metetra
.949 .784 .643 r
.36315 .25814 .36434 .25273 .35334 .24258 .35215 .24709 Metetra
.961 .814 .653 r
.35215 .24709 .35334 .24258 .34205 .2377 .34084 .24224 Metetra
.97 .828 .646 r
.34084 .24224 .34205 .2377 .33027 .24387 .32925 .24102 Metetra
.829 .465 0 r
.32925 .24102 .33027 .24387 .31909 .22168 .3181 .2178 Metetra
.953 .61 .229 r
.3181 .2178 .31909 .22168 .30724 .21691 .30666 .20016 Metetra
.976 .72 .48 r
.30666 .20016 .30724 .21691 .29595 .18885 .29498 .18492 Metetra
.955 .618 .325 r
.29498 .18492 .29595 .18885 .28398 .17733 .28291 .17626 Metetra
.516 .012 0 r
.28291 .17626 .28398 .17733 .27187 .16455 .27076 .16439 Metetra
.634 .775 .949 r
.51258 .35385 .51357 .35364 .50463 .3439 .50363 .3446 Metetra
.768 .773 .857 r
.50363 .3446 .50463 .3439 .49557 .33437 .49457 .33252 Metetra
.847 .41 0 r
.49457 .33252 .49557 .33437 .4864 .32565 .4854 .32275 Metetra
.942 .584 .291 r
.4854 .32275 .4864 .32565 .47708 .32108 .47609 .31744 Metetra
.948 .619 .369 r
.47609 .31744 .47708 .32108 .46764 .31478 .46662 .31474 Metetra
.222 .708 .928 r
.46662 .31474 .46764 .31478 .45804 .31251 .45702 .31136 Metetra
.8 .391 .276 r
.45702 .31136 .45804 .31251 .44815 .32476 .44718 .31804 Metetra
.964 .677 .439 r
.44718 .31804 .44815 .32476 .43825 .32052 .43728 .3142 Metetra
.958 .669 .446 r
.43728 .3142 .43825 .32052 .42823 .31386 .42719 .31349 Metetra
0 .475 .847 r
.42719 .31349 .42823 .31386 .41799 .31235 .41702 .30692 Metetra
.963 .661 .408 r
.41702 .30692 .41799 .31235 .40766 .30632 .40668 .30175 Metetra
.967 .646 .337 r
.40668 .30175 .40766 .30632 .39729 .29411 .39629 .29041 Metetra
.957 .614 .285 r
.39629 .29041 .39729 .29411 .38689 .27542 .38575 .27945 Metetra
.934 .786 .673 r
.38575 .27945 .38689 .27542 .37631 .25989 .3751 .26679 Metetra
.949 .769 .625 r
.3751 .26679 .37631 .25989 .36563 .24304 .36434 .25273 Metetra
.962 .769 .597 r
.36434 .25273 .36563 .24304 .35462 .23399 .35334 .24258 Metetra
.968 .782 .598 r
.35334 .24258 .35462 .23399 .34315 .23686 .34205 .2377 Metetra
.587 .927 .726 r
.34205 .2377 .34315 .23686 .33148 .23942 .33027 .24387 Metetra
.913 .754 .671 r
.33027 .24387 .33148 .23942 .32028 .21829 .31909 .22168 Metetra
.954 .836 .689 r
.31909 .22168 .32028 .21829 .30883 .20111 .30724 .21691 Metetra
.952 .744 .585 r
.30724 .21691 .30883 .20111 .29711 .18717 .29595 .18885 Metetra
.877 .826 .794 r
.29595 .18885 .29711 .18717 .28509 .17734 .28398 .17733 Metetra
.489 .71 .968 r
.28398 .17733 .28509 .17734 .27288 .16737 .27187 .16455 Metetra
.975 .706 .455 r
.51357 .35364 .51456 .36347 .50562 .34902 .50463 .3439 Metetra
.971 .664 .374 r
.50463 .3439 .50562 .34902 .49656 .34044 .49557 .33437 Metetra
.972 .678 .406 r
.49557 .33437 .49656 .34044 .48737 .33278 .4864 .32565 Metetra
.967 .684 .444 r
.4864 .32565 .48737 .33278 .47807 .32511 .47708 .32108 Metetra
.959 .634 .354 r
.47708 .32108 .47807 .32511 .46871 .30651 .46764 .31478 Metetra
.972 .785 .593 r
.46764 .31478 .46871 .30651 .45919 .29625 .45804 .31251 Metetra
.983 .776 .547 r
.45804 .31251 .45919 .29625 .44942 .29971 .44815 .32476 Metetra
.971 .754 .553 r
.44815 .32476 .44942 .29971 .43955 .29662 .43825 .32052 Metetra
.97 .754 .556 r
.43825 .32052 .43955 .29662 .42944 .30038 .42823 .31386 Metetra
.973 .77 .569 r
.42823 .31386 .42944 .30038 .41917 .303 .41799 .31235 Metetra
.967 .775 .593 r
.41799 .31235 .41917 .303 .40886 .29693 .40766 .30632 Metetra
.958 .765 .6 r
.40766 .30632 .40886 .29693 .39867 .27496 .39729 .29411 Metetra
.961 .749 .571 r
.39729 .29411 .39867 .27496 .38821 .26184 .38689 .27542 Metetra
.96 .755 .583 r
.38689 .27542 .38821 .26184 .37765 .2469 .37631 .25989 Metetra
.958 .755 .587 r
.37631 .25989 .37765 .2469 .36682 .23782 .36563 .24304 Metetra
.953 .792 .643 r
.36563 .24304 .36682 .23782 .35581 .2293 .35462 .23399 Metetra
.98 .839 .632 r
.35462 .23399 .35581 .2293 .34442 .22966 .34315 .23686 Metetra
.979 .806 .598 r
.34315 .23686 .34442 .22966 .33282 .2304 .33148 .23942 Metetra
.946 .754 .612 r
.33148 .23942 .33282 .2304 .32137 .21854 .32028 .21829 Metetra
.422 .6 .919 r
.32028 .21829 .32137 .21854 .3101 .1956 .30883 .20111 Metetra
.945 .779 .645 r
.30883 .20111 .3101 .1956 .2984 .18173 .29711 .18717 Metetra
.954 .792 .643 r
.29711 .18717 .2984 .18173 .28637 .17252 .28509 .17734 Metetra
.95 .797 .656 r
.28509 .17734 .28637 .17252 .27425 .16049 .27288 .16737 Metetra
.95 .759 .611 r
.51456 .36347 .51556 .35544 .50662 .34192 .50562 .34902 Metetra
.959 .775 .612 r
.50562 .34902 .50662 .34192 .49757 .33404 .49656 .34044 Metetra
.959 .781 .619 r
.49656 .34044 .49757 .33404 .48844 .31833 .48737 .33278 Metetra
.967 .76 .572 r
.48737 .33278 .48844 .31833 .47915 .31138 .47807 .32511 Metetra
.956 .749 .585 r
.47807 .32511 .47915 .31138 .46976 .30256 .46871 .30651 Metetra
.939 .79 .669 r
.46871 .30651 .46976 .30256 .46028 .28723 .45919 .29625 Metetra
.98 .791 .578 r
.45919 .29625 .46028 .28723 .45063 .27962 .44942 .29971 Metetra
.972 .759 .557 r
.44942 .29971 .45063 .27962 .44076 .2801 .43955 .29662 Metetra
.977 .769 .556 r
.43955 .29662 .44076 .2801 .4307 .28269 .42944 .30038 Metetra
.976 .766 .556 r
.42944 .30038 .4307 .28269 .42055 .27924 .41917 .303 Metetra
.97 .755 .555 r
.41917 .303 .42055 .27924 .41022 .27745 .40886 .29693 Metetra
.959 .746 .572 r
.40886 .29693 .41022 .27745 .39986 .26744 .39867 .27496 Metetra
.953 .769 .616 r
.39867 .27496 .39986 .26744 .38945 .25235 .38821 .26184 Metetra
.955 .761 .602 r
.38821 .26184 .38945 .25235 .37885 .23991 .37765 .2469 Metetra
.959 .78 .617 r
.37765 .2469 .37885 .23991 .36804 .23089 .36682 .23782 Metetra
.96 .782 .618 r
.36682 .23782 .36804 .23089 .35707 .22187 .35581 .2293 Metetra
.976 .799 .599 r
.35581 .2293 .35707 .22187 .34575 .21988 .34442 .22966 Metetra
.976 .787 .583 r
.34442 .22966 .34575 .21988 .33418 .22023 .33282 .2304 Metetra
.961 .767 .596 r
.33282 .2304 .33418 .22023 .32257 .21487 .32137 .21854 Metetra
.898 .751 .69 r
.32137 .21854 .32257 .21487 .31108 .19951 .3101 .1956 Metetra
.958 .616 .274 r
.3101 .1956 .31108 .19951 .29934 .18662 .2984 .18173 Metetra
.964 .646 .365 r
.2984 .18173 .29934 .18662 .2872 .18058 .28637 .17252 Metetra
.974 .69 .426 r
.28637 .17252 .2872 .18058 .27527 .1633 .27425 .16049 Metetra
.716 .292 0 r
.51556 .35544 .51655 .3572 .50762 .34475 .50662 .34192 Metetra
.942 .575 .24 r
.50662 .34192 .50762 .34475 .49857 .33659 .49757 .33404 Metetra
.861 .477 0 r
.49757 .33404 .49857 .33659 .4894 .3289 .48844 .31833 Metetra
.972 .706 .467 r
.48844 .31833 .4894 .3289 .48011 .32212 .47915 .31138 Metetra
.974 .707 .463 r
.47915 .31138 .48011 .32212 .47068 .31712 .46976 .30256 Metetra
.979 .721 .47 r
.46976 .30256 .47068 .31712 .46111 .31175 .46028 .28723 Metetra
.973 .726 .503 r
.46028 .28723 .46111 .31175 .45131 .31789 .45063 .27962 Metetra
.97 .728 .517 r
.45063 .27962 .45131 .31789 .44147 .30994 .44076 .2801 Metetra
.968 .724 .514 r
.44076 .2801 .44147 .30994 .43153 .29949 .4307 .28269 Metetra
.97 .716 .495 r
.4307 .28269 .43153 .29949 .42118 .30916 .42055 .27924 Metetra
.97 .726 .511 r
.42055 .27924 .42118 .30916 .41086 .30419 .41022 .27745 Metetra
.973 .727 .503 r
.41022 .27745 .41086 .30419 .40055 .28924 .39986 .26744 Metetra
.976 .727 .491 r
.39986 .26744 .40055 .28924 .39012 .27331 .38945 .25235 Metetra
.975 .725 .492 r
.38945 .25235 .39012 .27331 .37955 .25831 .37885 .23991 Metetra
.973 .72 .491 r
.37885 .23991 .37955 .25831 .36874 .24769 .36804 .23089 Metetra
.973 .718 .487 r
.36804 .23089 .36874 .24769 .35774 .23895 .35707 .22187 Metetra
.968 .714 .496 r
.35707 .22187 .35774 .23895 .34639 .23773 .34575 .21988 Metetra
.967 .713 .499 r
.34575 .21988 .34639 .23773 .3346 .24524 .33418 .22023 Metetra
.971 .723 .504 r
.33418 .22023 .3346 .24524 .32348 .22149 .32257 .21487 Metetra
.976 .68 .386 r
.32257 .21487 .32348 .22149 .31212 .20138 .31108 .19951 Metetra
.817 .371 0 r
.31108 .19951 .31212 .20138 .30057 .18307 .29934 .18662 Metetra
.952 .829 .686 r
.29934 .18662 .30057 .18307 .28857 .17303 .2872 .18058 Metetra
.948 .765 .622 r
.2872 .18058 .28857 .17303 .27626 .16667 .27527 .1633 Metetra
.165 .461 .886 r
.51655 .3572 .51754 .35777 .50861 .34689 .50762 .34475 Metetra
.903 .493 .113 r
.50762 .34475 .50861 .34689 .49957 .33753 .49857 .33659 Metetra
.542 .017 0 r
.49857 .33659 .49957 .33753 .49041 .33027 .4894 .3289 Metetra
.791 .306 0 r
.4894 .3289 .49041 .33027 .48112 .32364 .48011 .32212 Metetra
.849 .388 .04 r
.48011 .32212 .48112 .32364 .4717 .31732 .47068 .31712 Metetra
.139 .615 .921 r
.47068 .31712 .4717 .31732 .46212 .31457 .46111 .31175 Metetra
.905 .571 .401 r
.46111 .31175 .46212 .31457 .45233 .31845 .45131 .31789 Metetra
0 .344 .778 r
.45131 .31789 .45233 .31845 .44246 .31417 .44147 .30994 Metetra
.964 .638 .325 r
.44147 .30994 .44246 .31417 .43254 .30236 .43153 .29949 Metetra
.893 .566 .422 r
.43153 .29949 .43254 .30236 .42236 .29959 .42118 .30916 Metetra
.969 .776 .59 r
.42118 .30916 .42236 .29959 .41197 .30072 .41086 .30419 Metetra
.918 .777 .69 r
.41086 .30419 .41197 .30072 .40175 .28058 .40055 .28924 Metetra
.952 .761 .609 r
.40055 .28924 .40175 .28058 .39125 .27 .39012 .27331 Metetra
.915 .779 .696 r
.39012 .27331 .39125 .27 .38071 .25384 .37955 .25831 Metetra
.945 .792 .66 r
.37955 .25831 .38071 .25384 .36988 .24478 .36874 .24769 Metetra
.933 .819 .71 r
.36874 .24769 .36988 .24478 .35899 .23165 .35774 .23895 Metetra
.974 .797 .603 r
.35774 .23895 .35899 .23165 .34762 .23203 .34639 .23773 Metetra
.988 .836 .603 r
.34639 .23773 .34762 .23203 .33611 .22974 .3346 .24524 Metetra
.956 .748 .583 r
.3346 .24524 .33611 .22974 .32463 .21975 .32348 .22149 Metetra
.84 .753 .768 r
.32348 .22149 .32463 .21975 .31333 .19778 .31212 .20138 Metetra
.912 .771 .691 r
.31212 .20138 .31333 .19778 .30158 .18581 .30057 .18307 Metetra
.928 .542 .194 r
.30057 .18307 .30158 .18581 .28953 .17766 .28857 .17303 Metetra
.958 .637 .371 r
.28857 .17303 .28953 .17766 .27738 .16668 .27626 .16667 Metetra
.905 .511 .096 r
.51754 .35777 .51854 .36018 .50961 .35072 .50861 .34689 Metetra
.961 .628 .309 r
.50861 .34689 .50961 .35072 .50056 .34238 .49957 .33753 Metetra
.966 .657 .379 r
.49957 .33753 .50056 .34238 .4914 .33446 .49041 .33027 Metetra
.961 .64 .358 r
.49041 .33027 .4914 .33446 .48212 .3268 .48112 .32364 Metetra
.948 .597 .297 r
.48112 .32364 .48212 .3268 .4727 .31971 .4717 .31732 Metetra
.922 .545 .274 r
.4717 .31732 .4727 .31971 .46315 .31403 .46212 .31457 Metetra
.422 .853 .727 r
.46212 .31457 .46315 .31403 .45339 .31529 .45233 .31845 Metetra
.953 .834 .688 r
.45233 .31845 .45339 .31529 .44354 .31027 .44246 .31417 Metetra
.934 .786 .673 r
.44246 .31417 .44354 .31027 .43357 .30315 .43254 .30236 Metetra
.649 .091 0 r
.43254 .30236 .43357 .30315 .42342 .29864 .42236 .29959 Metetra
.811 .993 .871 r
.42236 .29959 .42342 .29864 .41308 .29703 .41197 .30072 Metetra
.904 .754 .685 r
.41197 .30072 .41308 .29703 .40283 .27917 .40175 .28058 Metetra
.862 .823 .809 r
.40175 .28058 .40283 .27917 .39231 .2701 .39125 .27 Metetra
.51 .643 .915 r
.39125 .27 .39231 .2701 .38169 .25833 .38071 .25384 Metetra
.963 .641 .35 r
.38071 .25384 .38169 .25833 .37089 .24776 .36988 .24478 Metetra
.932 .559 .174 r
.36988 .24478 .37089 .24776 .36 .23462 .35899 .23165 Metetra
.925 .573 .346 r
.35899 .23165 .36 .23462 .34879 .22828 .34762 .23203 Metetra
.965 .84 .67 r
.34762 .23203 .34879 .22828 .3372 .22976 .33611 .22974 Metetra
.45 .729 .986 r
.33611 .22974 .3372 .22976 .3257 .22088 .32463 .21975 Metetra
0 .221 .741 r
.32463 .21975 .3257 .22088 .31435 .20066 .31333 .19778 Metetra
.931 .551 .183 r
.31333 .19778 .31435 .20066 .30259 .18917 .30158 .18581 Metetra
.946 .59 .287 r
.30158 .18581 .30259 .18917 .29061 .17859 .28953 .17766 Metetra
0 .083 .566 r
.28953 .17766 .29061 .17859 .27854 .1655 .27738 .16668 Metetra
.958 .617 .287 r
.51854 .36018 .51954 .36374 .51061 .35256 .50961 .35072 Metetra
.866 .43 .022 r
.50961 .35072 .51061 .35256 .50157 .34435 .50056 .34238 Metetra
.887 .463 .076 r
.50056 .34238 .50157 .34435 .4924 .33693 .4914 .33446 Metetra
.926 .539 .191 r
.4914 .33446 .4924 .33693 .48312 .3298 .48212 .3268 Metetra
.945 .585 .27 r
.48212 .3268 .48312 .3298 .47369 .32469 .4727 .31971 Metetra
.964 .656 .393 r
.4727 .31971 .47369 .32469 .46413 .31952 .46315 .31403 Metetra
.952 .656 .441 r
.46315 .31403 .46413 .31952 .45406 .3573 .45339 .31529 Metetra
.972 .731 .514 r
.45339 .31529 .45406 .3573 .44446 .32213 .44354 .31027 Metetra
.972 .708 .472 r
.44354 .31027 .44446 .32213 .43448 .31499 .43357 .30315 Metetra
.97 .706 .477 r
.43357 .30315 .43448 .31499 .42405 .33069 .42342 .29864 Metetra
.97 .727 .512 r
.42342 .29864 .42405 .33069 .41364 .33066 .41308 .29703 Metetra
.976 .733 .503 r
.41308 .29703 .41364 .33066 .40331 .31511 .40283 .27917 Metetra
.973 .73 .509 r
.40283 .27917 .40331 .31511 .39313 .28349 .39231 .2701 Metetra
.976 .714 .47 r
.39231 .2701 .39313 .28349 .3825 .27123 .38169 .25833 Metetra
.975 .712 .47 r
.38169 .25833 .3825 .27123 .37181 .25503 .37089 .24776 Metetra
.976 .687 .408 r
.37089 .24776 .37181 .25503 .36107 .23527 .36 .23462 Metetra
.397 0 0 r
.36 .23462 .36107 .23527 .34981 .2313 .34879 .22828 Metetra
.922 .573 .356 r
.34879 .22828 .34981 .2313 .33787 .24608 .3372 .22976 Metetra
.973 .716 .485 r
.3372 .22976 .33787 .24608 .32636 .23649 .3257 .22088 Metetra
.98 .722 .467 r
.3257 .22088 .32636 .23649 .31544 .20119 .31435 .20066 Metetra
.009 .435 .864 r
.31435 .20066 .31544 .20119 .30382 .18525 .30259 .18917 Metetra
.942 .803 .679 r
.30259 .18917 .30382 .18525 .29184 .17522 .29061 .17859 Metetra
.926 .798 .699 r
.29061 .17859 .29184 .17522 .27949 .17027 .27854 .1655 Metetra
.901 .794 .733 r
.51954 .36374 .52053 .3615 .51161 .35061 .51061 .35256 Metetra
.907 .824 .754 r
.51061 .35256 .51161 .35061 .50258 .34068 .50157 .34435 Metetra
.946 .805 .672 r
.50157 .34435 .50258 .34068 .49343 .33241 .4924 .33693 Metetra
.954 .797 .649 r
.4924 .33693 .49343 .33241 .48415 .32658 .48312 .3298 Metetra
.951 .826 .685 r
.48312 .3298 .48415 .32658 .47473 .3207 .47369 .32469 Metetra
.957 .813 .66 r
.47369 .32469 .47473 .3207 .46519 .31536 .46413 .31952 Metetra
.729 .734 .214 r
.46413 .31952 .46519 .31536 .45537 .32493 .45406 .3573 Metetra
.959 .738 .561 r
.45406 .3573 .45537 .32493 .44553 .31853 .44446 .32213 Metetra
.947 .812 .677 r
.44446 .32213 .44553 .31853 .43553 .31409 .43448 .31499 Metetra
.43448 .31499 .43553 .31409 .42543 .30591 .42405 .33069 Metetra
.974 .758 .55 r
.42405 .33069 .42543 .30591 .41499 .31073 .41364 .33066 Metetra
.964 .751 .566 r
.41364 .33066 .41499 .31073 .40474 .29249 .40331 .31511 Metetra
.956 .74 .571 r
.40331 .31511 .40474 .29249 .3944 .272 .39313 .28349 Metetra
.962 .762 .588 r
.39313 .28349 .3944 .272 .38389 .25496 .3825 .27123 Metetra
.962 .753 .575 r
.3825 .27123 .38389 .25496 .37313 .24359 .37181 .25503 Metetra
.953 .753 .595 r
.37181 .25503 .37313 .24359 .36221 .23251 .36107 .23527 Metetra
.949 .855 .714 r
.36107 .23527 .36221 .23251 .35104 .22547 .34981 .2313 Metetra
.996 .851 .576 r
.34981 .2313 .35104 .22547 .33922 .23632 .33787 .24608 Metetra
.964 .772 .595 r
.33787 .24608 .33922 .23632 .32813 .21243 .32636 .23649 Metetra
.956 .74 .57 r
.32636 .23649 .32813 .21243 .31664 .19776 .31544 .20119 Metetra
.917 .782 .696 r
.31544 .20119 .31664 .19776 .30492 .18539 .30382 .18525 Metetra
.337 .677 .978 r
.30382 .18525 .30492 .18539 .29287 .17782 .29184 .17522 Metetra
.921 .536 .248 r
.29184 .17522 .29287 .17782 .28062 .17002 .27949 .17027 Metetra
.977 .692 .416 r
.52053 .3615 .52154 .36874 .51261 .34727 .51161 .35061 Metetra
.932 .794 .685 r
.51161 .35061 .51261 .34727 .50358 .34065 .50258 .34068 Metetra
.514 .753 .982 r
.50258 .34068 .50358 .34065 .49443 .33611 .49343 .33241 Metetra
.956 .623 .34 r
.49343 .33241 .49443 .33611 .48515 .3294 .48415 .32658 Metetra
.94 .574 .269 r
.48415 .32658 .48515 .3294 .47575 .3218 .47473 .3207 Metetra
.731 .211 0 r
.47473 .3207 .47575 .3218 .46625 .30985 .46519 .31536 Metetra
.993 .841 .586 r
.46519 .31536 .46625 .30985 .45659 .30307 .45537 .32493 Metetra
.97 .756 .556 r
.45537 .32493 .45659 .30307 .44673 .30276 .44553 .31853 Metetra
.971 .763 .565 r
.44553 .31853 .44673 .30276 .43675 .2986 .43553 .31409 Metetra
.968 .76 .569 r
.43553 .31409 .43675 .2986 .42668 .2903 .42543 .30591 Metetra
.979 .772 .556 r
.42543 .30591 .42668 .2903 .41645 .28311 .41499 .31073 Metetra
.965 .747 .558 r
.41499 .31073 .41645 .28311 .4061 .27344 .40474 .29249 Metetra
.961 .748 .571 r
.40474 .29249 .4061 .27344 .3957 .25871 .3944 .272 Metetra
.959 .755 .584 r
.3944 .272 .3957 .25871 .38511 .24707 .38389 .25496 Metetra
.958 .773 .61 r
.38389 .25496 .38511 .24707 .37435 .23661 .37313 .24359 Metetra
.956 .777 .62 r
.37313 .24359 .37435 .23661 .36344 .22577 .36221 .23251 Metetra
.963 .788 .617 r
.36221 .23251 .36344 .22577 .3522 .22221 .35104 .22547 Metetra
.981 .914 .63 r
.35104 .22547 .3522 .22221 .34061 .22484 .33922 .23632 Metetra
.95 .749 .598 r
.33922 .23632 .34061 .22484 .32929 .21025 .32813 .21243 Metetra
.887 .794 .752 r
.32813 .21243 .32929 .21025 .31782 .19532 .31664 .19776 Metetra
.908 .809 .739 r
.31664 .19776 .31782 .19532 .30601 .18595 .30492 .18539 Metetra
0 .305 .708 r
.30492 .18539 .30601 .18595 .294 .17728 .29287 .17782 Metetra
.712 .873 .957 r
.29287 .17782 .294 .17728 .28197 .16357 .28062 .17002 Metetra
.95 .746 .592 r
.52154 .36874 .52252 .35642 .51361 .34079 .51261 .34727 Metetra
.962 .784 .615 r
.51261 .34727 .51361 .34079 .5046 .33209 .50358 .34065 Metetra
.969 .779 .592 r
.50358 .34065 .5046 .33209 .49549 .3147 .49443 .33611 Metetra
.97 .755 .557 r
.49443 .33611 .49549 .3147 .48626 .30598 .48515 .3294 Metetra
.97 .753 .555 r
.48515 .3294 .48626 .30598 .4769 .29833 .47575 .3218 Metetra
.967 .751 .558 r
.47575 .3218 .4769 .29833 .46746 .28372 .46625 .30985 Metetra
.971 .753 .552 r
.46625 .30985 .46746 .28372 .45785 .27558 .45659 .30307 Metetra
.974 .756 .547 r
.45659 .30307 .45785 .27558 .44793 .28604 .44673 .30276 Metetra
.972 .762 .563 r
.44673 .30276 .44793 .28604 .43796 .28373 .43675 .2986 Metetra
.968 .761 .571 r
.43675 .2986 .43796 .28373 .42784 .28123 .42668 .2903 Metetra
.966 .775 .595 r
.42668 .2903 .42784 .28123 .41761 .2756 .41645 .28311 Metetra
.96 .776 .611 r
.41645 .28311 .41761 .2756 .40733 .26267 .4061 .27344 Metetra
.958 .76 .593 r
.4061 .27344 .40733 .26267 .39694 .24877 .3957 .25871 Metetra
.961 .766 .595 r
.3957 .25871 .39694 .24877 .38632 .23987 .38511 .24707 Metetra
.958 .777 .616 r
.38511 .24707 .38632 .23987 .37556 .22994 .37435 .23661 Metetra
.956 .779 .623 r
.37435 .23661 .37556 .22994 .36461 .22176 .36344 .22577 Metetra
.963 .828 .663 r
.36344 .22577 .36461 .22176 .3534 .21731 .3522 .22221 Metetra
.98 .836 .628 r
.3522 .22221 .3534 .21731 .3419 .21749 .34061 .22484 Metetra
.952 .77 .62 r
.34061 .22484 .3419 .21749 .3303 .21349 .32929 .21025 Metetra
.937 .571 .183 r
.32929 .21025 .3303 .21349 .31886 .19729 .31782 .19532 Metetra
.872 .434 .048 r
.31782 .19532 .31886 .19729 .30721 .18302 .30601 .18595 Metetra
.935 .827 .714 r
.30601 .18595 .30721 .18302 .29513 .17681 .294 .17728 Metetra
.693 .78 .917 r
.294 .17728 .29513 .17681 .28328 .15829 .28197 .16357 Metetra
.054 .328 .81 r
.52252 .35642 .52351 .35729 .51461 .34388 .51361 .34079 Metetra
.948 .59 .251 r
.51361 .34079 .51461 .34388 .5056 .33314 .5046 .33209 Metetra
0 .245 .757 r
.5046 .33209 .5056 .33314 .49648 .32496 .49549 .3147 Metetra
.975 .706 .458 r
.49549 .3147 .49648 .32496 .48723 .31729 .48626 .30598 Metetra
.973 .708 .467 r
.48626 .30598 .48723 .31729 .47784 .31201 .4769 .29833 Metetra
.979 .719 .465 r
.4769 .29833 .47784 .31201 .46828 .3131 .46746 .28372 Metetra
.973 .729 .505 r
.46746 .28372 .46828 .3131 .45859 .31131 .45785 .27558 Metetra
.966 .724 .519 r
.45785 .27558 .45859 .31131 .44875 .30818 .44793 .28604 Metetra
.97 .721 .503 r
.44793 .28604 .44875 .30818 .43883 .29946 .43796 .28373 Metetra
.969 .713 .492 r
.43796 .28373 .43883 .29946 .42869 .29691 .42784 .28123 Metetra
.972 .715 .487 r
.42784 .28123 .42869 .29691 .41836 .29676 .41761 .2756 Metetra
.976 .725 .49 r
.41761 .2756 .41836 .29676 .40811 .28045 .40733 .26267 Metetra
.977 .723 .482 r
.40733 .26267 .40811 .28045 .3976 .27228 .39694 .24877 Metetra
.974 .725 .498 r
.39694 .24877 .3976 .27228 .38701 .2601 .38632 .23987 Metetra
.974 .723 .492 r
.38632 .23987 .38701 .2601 .37626 .24802 .37556 .22994 Metetra
.973 .719 .489 r
.37556 .22994 .37626 .24802 .36535 .23699 .36461 .22176 Metetra
.97 .712 .486 r
.36461 .22176 .36535 .23699 .35422 .2287 .3534 .21731 Metetra
.964 .698 .48 r
.3534 .21731 .35422 .2287 .3425 .23656 .3419 .21749 Metetra
.97 .717 .495 r
.3419 .21749 .3425 .23656 .33128 .21786 .3303 .21349 Metetra
.963 .632 .28 r
.3303 .21349 .33128 .21786 .32 .19617 .31886 .19729 Metetra
.815 .797 .835 r
.31886 .19729 .32 .19617 .30827 .18477 .30721 .18302 Metetra
.861 .409 .067 r
.30721 .18302 .30827 .18477 .29646 .17023 .29513 .17681 Metetra
.943 .766 .633 r
.29513 .17681 .29646 .17023 .28418 .1644 .28328 .15829 Metetra
.93 .772 .665 r
.52351 .35729 .5245 .35314 .51561 .34565 .51461 .34388 Metetra
.805 .364 0 r
.51461 .34388 .51561 .34565 .5066 .33706 .5056 .33314 Metetra
.961 .631 .326 r
.5056 .33314 .5066 .33706 .49748 .32624 .49648 .32496 Metetra
.732 .234 0 r
.49648 .32496 .49748 .32624 .48824 .31892 .48723 .31729 Metetra
.863 .413 .063 r
.48723 .31729 .48824 .31892 .47884 .31641 .47784 .31201 Metetra
.946 .636 .418 r
.47784 .31201 .47884 .31641 .4693 .31499 .46828 .3131 Metetra
.894 .485 .219 r
.46828 .3131 .4693 .31499 .45961 .31213 .45859 .31131 Metetra
.661 .108 0 r
.45859 .31131 .45961 .31213 .44974 .31337 .44875 .30818 Metetra
.968 .66 .377 r
.44875 .30818 .44974 .31337 .43985 .30222 .43883 .29946 Metetra
.93 .567 .305 r
.43883 .29946 .43985 .30222 .42967 .3028 .42869 .29691 Metetra
.956 .661 .437 r
.42869 .29691 .42967 .3028 .41939 .29879 .41836 .29676 Metetra
.755 .343 0 r
.41836 .29676 .41939 .29879 .40923 .27701 .40811 .28045 Metetra
.943 .813 .686 r
.40811 .28045 .40923 .27701 .39873 .26837 .3976 .27228 Metetra
.935 .79 .676 r
.3976 .27228 .39873 .26837 .38814 .25673 .38701 .2601 Metetra
.928 .795 .693 r
.38701 .2601 .38814 .25673 .3774 .24518 .37626 .24802 Metetra
.923 .807 .714 r
.37626 .24802 .3774 .24518 .36643 .23709 .36535 .23699 Metetra
.347 .704 .984 r
.36535 .23699 .36643 .23709 .35526 .23045 .35422 .2287 Metetra
.846 .463 .324 r
.35422 .2287 .35526 .23045 .34364 .23488 .3425 .23656 Metetra
.842 .761 .774 r
.3425 .23656 .34364 .23488 .33218 .22524 .33128 .21786 Metetra
.981 .691 .372 r
.33128 .21786 .33218 .22524 .32109 .19659 .32 .19617 Metetra
.117 .512 .91 r
.32 .19617 .32109 .19659 .30943 .18322 .30827 .18477 Metetra
.854 .8 .797 r
.30827 .18477 .30943 .18322 .29759 .16987 .29646 .17023 Metetra
.611 .879 .991 r
.29646 .17023 .29759 .16987 .28541 .1613 .28418 .1644 Metetra
.973 .691 .435 r
.5245 .35314 .52551 .36073 .51661 .34742 .51561 .34565 Metetra
.848 .405 0 r
.51561 .34565 .51661 .34742 .50761 .33814 .5066 .33706 Metetra
0 .012 .538 r
.5066 .33706 .50761 .33814 .49849 .32914 .49748 .32624 Metetra
.943 .579 .254 r
.49748 .32624 .49849 .32914 .48924 .32175 .48824 .31892 Metetra
.935 .578 .317 r
.48824 .31892 .48924 .32175 .47987 .31552 .47884 .31641 Metetra
.828 .964 .895 r
.47884 .31641 .47987 .31552 .47032 .31615 .4693 .31499 Metetra
.791 .293 0 r
.4693 .31499 .47032 .31615 .46063 .31358 .45961 .31213 Metetra
.85 .421 .205 r
.45961 .31213 .46063 .31358 .45079 .31311 .44974 .31337 Metetra
.645 .765 .936 r
.44974 .31337 .45079 .31311 .4409 .30179 .43985 .30222 Metetra
.512 .912 .896 r
.43985 .30222 .4409 .30179 .43082 .29467 .42967 .3028 Metetra
.97 .785 .597 r
.42967 .3028 .43082 .29467 .42059 .28868 .41939 .29879 Metetra
.948 .75 .603 r
.41939 .29879 .42059 .28868 .41015 .28593 .40923 .27701 Metetra
.973 .696 .445 r
.40923 .27701 .41015 .28593 .39971 .27377 .39873 .26837 Metetra
.971 .663 .365 r
.39873 .26837 .39971 .27377 .38917 .25905 .38814 .25673 Metetra
.893 .484 .074 r
.38814 .25673 .38917 .25905 .37856 .24113 .3774 .24518 Metetra
.95 .808 .668 r
.3774 .24518 .37856 .24113 .36764 .23127 .36643 .23709 Metetra
.963 .796 .629 r
.36643 .23709 .36764 .23127 .35644 .22673 .35526 .23045 Metetra
.982 .872 .651 r
.35526 .23045 .35644 .22673 .34478 .23328 .34364 .23488 Metetra
.881 .842 .802 r
.34364 .23488 .34478 .23328 .33349 .21743 .33218 .22524 Metetra
.931 .743 .627 r
.33218 .22524 .33349 .21743 .32216 .1978 .32109 .19659 Metetra
0 0 .481 r
.32109 .19659 .32216 .1978 .31053 .18357 .30943 .18322 Metetra
.258 .57 .939 r
.30943 .18322 .31053 .18357 .29856 .17438 .29759 .16987 Metetra
.96 .634 .349 r
.29759 .16987 .29856 .17438 .2864 .16536 .28541 .1613 Metetra
.879 .778 .747 r
.52551 .36073 .52651 .35877 .51761 .3485 .51661 .34742 Metetra
.544 .049 0 r
.51661 .34742 .51761 .3485 .50861 .34 .50761 .33814 Metetra
.856 .419 0 r
.50761 .33814 .50861 .34 .49949 .33243 .49849 .32914 Metetra
.951 .602 .289 r
.49849 .32914 .49949 .33243 .49025 .32479 .48924 .32175 Metetra
.945 .588 .284 r
.48924 .32175 .49025 .32479 .48088 .31705 .47987 .31552 Metetra
.862 .437 .21 r
.47987 .31552 .48088 .31705 .47135 .31437 .47032 .31615 Metetra
.93 .897 .773 r
.47032 .31615 .47135 .31437 .46166 .31443 .46063 .31358 Metetra
.724 .2 0 r
.46063 .31358 .46166 .31443 .45187 .30842 .45079 .31311 Metetra
.944 .784 .653 r
.45079 .31311 .45187 .30842 .44193 .3024 .4409 .30179 Metetra
0 .255 .683 r
.4409 .30179 .44193 .3024 .43185 .29666 .43082 .29467 Metetra
.894 .472 .134 r
.43082 .29467 .43185 .29666 .42158 .29327 .42059 .28868 Metetra
.954 .64 .394 r
.42059 .28868 .42158 .29327 .41136 .27667 .41015 .28593 Metetra
.96 .767 .599 r
.41015 .28593 .41136 .27667 .40085 .26919 .39971 .27377 Metetra
.935 .776 .661 r
.39971 .27377 .40085 .26919 .39025 .25883 .38917 .25905 Metetra
.636 .686 .88 r
.38917 .25905 .39025 .25883 .37954 .24585 .37856 .24113 Metetra
.965 .646 .35 r
.37856 .24113 .37954 .24585 .3686 .2368 .36764 .23127 Metetra
.961 .657 .407 r
.36764 .23127 .3686 .2368 .3575 .22782 .35644 .22673 Metetra
.777 .342 .216 r
.35644 .22673 .3575 .22782 .34603 .22719 .34478 .23328 Metetra
.944 .771 .637 r
.34478 .23328 .34603 .22719 .3346 .21719 .33349 .21743 Metetra
.634 .681 .877 r
.33349 .21743 .3346 .21719 .32327 .19781 .32216 .1978 Metetra
.512 .692 .95 r
.32216 .1978 .32327 .19781 .31151 .18761 .31053 .18357 Metetra
.957 .62 .32 r
.31053 .18357 .31151 .18761 .29961 .17645 .29856 .17438 Metetra
.883 .453 .082 r
.29856 .17438 .29961 .17645 .28749 .16618 .2864 .16536 Metetra
.562 .086 0 r
.52651 .35877 .52751 .35996 .51862 .34944 .51761 .3485 Metetra
0 .028 .519 r
.51761 .3485 .51862 .34944 .50962 .34085 .50861 .34 Metetra
.467 0 0 r
.50861 .34 .50962 .34085 .5005 .33286 .49949 .33243 Metetra
.01 .468 .87 r
.49949 .33243 .5005 .33286 .49126 .32638 .49025 .32479 Metetra
.825 .362 0 r
.49025 .32479 .49126 .32638 .48189 .31895 .48088 .31705 Metetra
.897 .485 .201 r
.48088 .31705 .48189 .31895 .47236 .31771 .47135 .31437 Metetra
.937 .602 .372 r
.47135 .31437 .47236 .31771 .46259 .32831 .46166 .31443 Metetra
.972 .713 .48 r
.46166 .31443 .46259 .32831 .45273 .32791 .45187 .30842 Metetra
.973 .721 .494 r
.45187 .30842 .45273 .32791 .4428 .31976 .44193 .3024 Metetra
.972 .718 .49 r
.44193 .3024 .4428 .31976 .43269 .31395 .43185 .29666 Metetra
.971 .716 .493 r
.43185 .29666 .43269 .31395 .42235 .31474 .42158 .29327 Metetra
.978 .727 .486 r
.42158 .29327 .42235 .31474 .4122 .29123 .41136 .27667 Metetra
.973 .714 .479 r
.41136 .27667 .4122 .29123 .40179 .27695 .40085 .26919 Metetra
.974 .69 .424 r
.40085 .26919 .40179 .27695 .39118 .26652 .39025 .25883 Metetra
.977 .691 .413 r
.39025 .25883 .39118 .26652 .38054 .24982 .37954 .24585 Metetra
.958 .622 .318 r
.37954 .24585 .38054 .24982 .36969 .23682 .3686 .2368 Metetra
.434 .736 .99 r
.3686 .2368 .36969 .23682 .35848 .2328 .3575 .22782 Metetra
.951 .642 .411 r
.3575 .22782 .35848 .2328 .34662 .24737 .34603 .22719 Metetra
.974 .722 .49 r
.34603 .22719 .34662 .24737 .33552 .22406 .3346 .21719 Metetra
.979 .684 .368 r
.3346 .21719 .33552 .22406 .32429 .20096 .32327 .19781 Metetra
.941 .574 .237 r
.32327 .19781 .32429 .20096 .31261 .18815 .31151 .18761 Metetra
0 .427 .855 r
.31151 .18761 .31261 .18815 .30056 .1815 .29961 .17645 Metetra
.965 .648 .359 r
.29961 .17645 .30056 .1815 .28849 .16977 .28749 .16618 Metetra
.976 .725 .489 r
.52751 .35996 .52855 .37971 .51963 .35707 .51862 .34944 Metetra
.974 .692 .43 r
.51862 .34944 .51963 .35707 .51062 .34401 .50962 .34085 Metetra
.949 .594 .268 r
.50962 .34085 .51062 .34401 .50151 .33562 .5005 .33286 Metetra
.938 .568 .248 r
.5005 .33286 .50151 .33562 .49227 .32832 .49126 .32638 Metetra
.885 .458 .08 r
.49126 .32638 .49227 .32832 .48291 .31953 .48189 .31895 Metetra
.573 0 0 r
.48189 .31895 .48291 .31953 .47345 .30781 .47236 .31771 Metetra
.989 .798 .557 r
.47236 .31771 .47345 .30781 .46381 .30375 .46259 .32831 Metetra
.975 .758 .548 r
.46259 .32831 .46381 .30375 .454 .30286 .45273 .32791 Metetra
.971 .753 .553 r
.45273 .32791 .454 .30286 .44402 .30332 .4428 .31976 Metetra
.971 .762 .564 r
.4428 .31976 .44402 .30332 .43388 .3027 .43269 .31395 Metetra
.977 .78 .572 r
.43269 .31395 .43388 .3027 .42358 .30193 .42235 .31474 Metetra
.952 .747 .591 r
.42235 .31474 .42358 .30193 .41333 .28652 .4122 .29123 Metetra
.937 .777 .657 r
.4122 .29123 .41333 .28652 .40293 .27261 .40179 .27695 Metetra
.945 .794 .662 r
.40179 .27695 .40293 .27261 .39238 .25942 .39118 .26652 Metetra
.947 .764 .624 r
.39118 .26652 .39238 .25942 .38182 .23953 .38054 .24982 Metetra
.961 .765 .594 r
.38054 .24982 .38182 .23953 .37091 .23051 .36969 .23682 Metetra
.969 .799 .618 r
.36969 .23682 .37091 .23051 .35957 .23257 .35848 .2328 Metetra
.351 0 .056 r
.35848 .2328 .35957 .23257 .34795 .23797 .34662 .24737 Metetra
.946 .752 .61 r
.34662 .24737 .34795 .23797 .33664 .2233 .33552 .22406 Metetra
.731 .697 .818 r
.33552 .22406 .33664 .2233 .32554 .19589 .32429 .20096 Metetra
.946 .786 .652 r
.32429 .20096 .32554 .19589 .3138 .18568 .31261 .18815 Metetra
.933 .851 .739 r
.31261 .18815 .3138 .18568 .30187 .17579 .30056 .1815 Metetra
.952 .787 .64 r
.30056 .1815 .30187 .17579 .28975 .1658 .28849 .16977 Metetra
.96 .744 .567 r
.52855 .37971 .5295 .35838 .52062 .34924 .51963 .35707 Metetra
.953 .764 .61 r
.51963 .35707 .52062 .34924 .51163 .34038 .51062 .34401 Metetra
.943 .801 .674 r
.51062 .34401 .51163 .34038 .50253 .32961 .50151 .33562 Metetra
.96 .786 .622 r
.50151 .33562 .50253 .32961 .49333 .31624 .49227 .32832 Metetra
.966 .764 .579 r
.49227 .32832 .49333 .31624 .484 .30599 .48291 .31953 Metetra
.964 .758 .577 r
.48291 .31953 .484 .30599 .4746 .28757 .47345 .30781 Metetra
.973 .759 .555 r
.47345 .30781 .4746 .28757 .465 .28223 .46381 .30375 Metetra
.975 .76 .551 r
.46381 .30375 .465 .28223 .45525 .27909 .454 .30286 Metetra
.975 .759 .548 r
.454 .30286 .45525 .27909 .44522 .28814 .44402 .30332 Metetra
.975 .768 .561 r
.44402 .30332 .44522 .28814 .43518 .28181 .43388 .3027 Metetra
.975 .761 .552 r
.43388 .3027 .43518 .28181 .42498 .27645 .42358 .30193 Metetra
.967 .75 .557 r
.42358 .30193 .42498 .27645 .41467 .2678 .41333 .28652 Metetra
.966 .754 .566 r
.41333 .28652 .41467 .2678 .40433 .25247 .40293 .27261 Metetra
.967 .754 .563 r
.40293 .27261 .40433 .25247 .39378 .24143 .39238 .25942 Metetra
.961 .75 .572 r
.39238 .25942 .39378 .24143 .38313 .22789 .38182 .23953 Metetra
.967 .767 .583 r
.38182 .23953 .38313 .22789 .37222 .21989 .37091 .23051 Metetra
.979 .785 .574 r
.37091 .23051 .37222 .21989 .36103 .21646 .35957 .23257 Metetra
.98 .773 .555 r
.35957 .23257 .36103 .21646 .3495 .21965 .34795 .23797 Metetra
.966 .755 .568 r
.34795 .23797 .3495 .21965 .338 .21349 .33664 .2233 Metetra
.942 .746 .61 r
.33664 .2233 .338 .21349 .32657 .19842 .32554 .19589 Metetra
.915 .515 .148 r
.32554 .19589 .32657 .19842 .31486 .18741 .3138 .18568 Metetra
.825 .362 0 r
.3138 .18568 .31486 .18741 .30289 .17876 .30187 .17579 Metetra
.935 .559 .219 r
.30187 .17579 .30289 .17876 .29096 .1633 .28975 .1658 Metetra
.157 .526 .92 r
.5295 .35838 .5305 .35879 .52163 .35025 .52062 .34924 Metetra
.514 .012 0 r
.52062 .34924 .52163 .35025 .51264 .34145 .51163 .34038 Metetra
0 .029 .554 r
.51163 .34038 .51264 .34145 .50354 .33377 .50253 .32961 Metetra
.964 .633 .279 r
.50253 .32961 .50354 .33377 .49431 .32613 .49333 .31624 Metetra
.976 .705 .448 r
.49333 .31624 .49431 .32613 .48496 .31971 .484 .30599 Metetra
.982 .721 .455 r
.484 .30599 .48496 .31971 .47549 .3109 .4746 .28757 Metetra
.973 .724 .5 r
.4746 .28757 .47549 .3109 .46569 .33071 .465 .28223 Metetra
.972 .732 .515 r
.465 .28223 .46569 .33071 .4559 .32415 .45525 .27909 Metetra
.969 .728 .519 r
.45525 .27909 .4559 .32415 .44594 .31998 .44522 .28814 Metetra
.973 .729 .506 r
.44522 .28814 .44594 .31998 .43581 .31827 .43518 .28181 Metetra
.973 .73 .509 r
.43518 .28181 .43581 .31827 .42547 .31991 .42498 .27645 Metetra
.974 .732 .51 r
.42498 .27645 .42547 .31991 .41526 .30021 .41467 .2678 Metetra
.976 .732 .5 r
.41467 .2678 .41526 .30021 .40486 .28588 .40433 .25247 Metetra
.975 .73 .504 r
.40433 .25247 .40486 .28588 .39437 .26815 .39378 .24143 Metetra
.976 .729 .496 r
.39378 .24143 .39437 .26815 .38359 .25945 .38313 .22789 Metetra
.973 .728 .504 r
.38313 .22789 .38359 .25945 .37287 .24037 .37222 .21989 Metetra
.971 .719 .496 r
.37222 .21989 .37287 .24037 .36162 .23832 .36103 .21646 Metetra
.968 .717 .504 r
.36103 .21646 .36162 .23832 .34963 .25906 .3495 .21965 Metetra
.973 .73 .51 r
.3495 .21965 .34963 .25906 .33817 .24937 .338 .21349 Metetra
.975 .732 .503 r
.338 .21349 .33817 .24937 .32712 .2185 .32657 .19842 Metetra
.975 .722 .488 r
.32657 .19842 .32712 .2185 .31579 .19347 .31486 .18741 Metetra
.968 .666 .397 r
.31486 .18741 .31579 .19347 .3039 .1821 .30289 .17876 Metetra
.939 .574 .188 r
.30289 .17876 .3039 .1821 .29194 .16763 .29096 .1633 Metetra
.975 .727 .498 r
.5305 .35879 .53156 .38354 .52264 .35995 .52163 .35025 Metetra
.975 .704 .451 r
.52163 .35025 .52264 .35995 .51365 .34855 .51264 .34145 Metetra
.973 .687 .425 r
.51264 .34145 .51365 .34855 .50454 .33995 .50354 .33377 Metetra
.971 .677 .408 r
.50354 .33377 .50454 .33995 .49532 .33095 .49431 .32613 Metetra
.965 .653 .379 r
.49431 .32613 .49532 .33095 .48596 .32547 .48496 .31971 Metetra
.971 .671 .391 r
.48496 .31971 .48596 .32547 .47646 .32093 .47549 .3109 Metetra
.939 .676 .512 r
.47549 .3109 .47646 .32093 .46676 .32599 .46569 .33071 Metetra
.958 .802 .645 r
.46569 .33071 .46676 .32599 .45671 .35194 .4559 .32415 Metetra
.972 .726 .504 r
.4559 .32415 .45671 .35194 .44668 .35153 .44594 .31998 Metetra
.971 .727 .508 r
.44594 .31998 .44668 .35153 .43644 .35566 .43581 .31827 Metetra
.97 .728 .513 r
.43581 .31827 .43644 .35566 .42614 .35075 .42547 .31991 Metetra
.978 .733 .496 r
.42547 .31991 .42614 .35075 .41603 .32127 .41526 .30021 Metetra
.977 .726 .486 r
.41526 .30021 .41603 .32127 .4057 .30035 .40486 .28588 Metetra
.981 .72 .461 r
.40486 .28588 .4057 .30035 .39538 .27208 .39437 .26815 Metetra
.957 .62 .316 r
.39437 .26815 .39538 .27208 .38484 .25057 .38359 .25945 Metetra
.95 .758 .609 r
.38359 .25945 .38484 .25057 .37401 .23748 .37287 .24037 Metetra
.959 .865 .703 r
.37287 .24037 .37401 .23748 .36281 .2341 .36162 .23832 Metetra
.975 .895 .538 r
.36162 .23832 .36281 .2341 .34995 .29141 .34963 .25906 Metetra
.974 .729 .503 r
.34963 .25906 .34995 .29141 .33874 .26989 .33817 .24937 Metetra
.984 .732 .467 r
.33817 .24937 .33874 .26989 .32847 .20982 .32712 .2185 Metetra
.941 .75 .616 r
.32712 .2185 .32847 .20982 .31703 .18915 .31579 .19347 Metetra
.944 .798 .667 r
.31579 .19347 .31703 .18915 .30509 .17988 .3039 .1821 Metetra
.892 .801 .752 r
.3039 .1821 .30509 .17988 .29288 .17305 .29194 .16763 Metetra
.956 .744 .577 r
.53156 .38354 .53252 .36651 .52364 .35479 .52264 .35995 Metetra
.946 .777 .641 r
.52264 .35995 .52364 .35479 .51466 .34472 .51365 .34855 Metetra
.945 .798 .667 r
.51365 .34855 .51466 .34472 .50557 .33419 .50454 .33995 Metetra
.956 .783 .628 r
.50454 .33995 .50557 .33419 .49635 .32707 .49532 .33095 Metetra
.957 .814 .662 r
.49532 .33095 .49635 .32707 .48699 .32358 .48596 .32547 Metetra
.926 .87 .764 r
.48596 .32547 .48699 .32358 .47748 .323 .47646 .32093 Metetra
.883 .516 .345 r
.47646 .32093 .47748 .323 .46765 .3478 .46676 .32599 Metetra
.954 .706 .524 r
.46676 .32599 .46765 .3478 .4579 .33494 .45671 .35194 Metetra
.976 .766 .557 r
.45671 .35194 .4579 .33494 .44787 .33766 .44668 .35153 Metetra
.98 .776 .558 r
.44668 .35153 .44787 .33766 .43792 .31893 .43644 .35566 Metetra
.973 .751 .543 r
.43644 .35566 .43792 .31893 .42741 .33485 .42614 .35075 Metetra
.951 .742 .584 r
.42614 .35075 .42741 .33485 .41733 .30495 .41603 .32127 Metetra
.959 .75 .576 r
.41603 .32127 .41733 .30495 .40679 .29942 .4057 .30035 Metetra
.736 .662 .777 r
.4057 .30035 .40679 .29942 .3964 .2757 .39538 .27208 Metetra
.917 .57 .113 r
.39538 .27208 .3964 .2757 .38561 .26679 .38484 .25057 Metetra
.977 .72 .475 r
.38484 .25057 .38561 .26679 .375 .24234 .37401 .23748 Metetra
.956 .643 .393 r
.37401 .23748 .375 .24234 .36387 .23563 .36281 .2341 Metetra
.701 .431 .514 r
.36281 .2341 .36387 .23563 .35181 .26017 .34995 .29141 Metetra
.967 .747 .554 r
.34995 .29141 .35181 .26017 .34061 .24087 .33874 .26989 Metetra
.949 .729 .571 r
.33874 .26989 .34061 .24087 .32928 .22055 .32847 .20982 Metetra
.982 .71 .428 r
.32847 .20982 .32928 .22055 .31802 .1935 .31703 .18915 Metetra
.96 .629 .333 r
.31703 .18915 .31802 .1935 .30608 .1842 .30509 .17988 Metetra
.956 .626 .349 r
.30509 .17988 .30608 .1842 .29393 .17544 .29288 .17305 Metetra
.967 .643 .307 r
.53252 .36651 .53353 .37086 .52465 .35999 .52364 .35479 Metetra
.972 .664 .364 r
.52364 .35479 .52465 .35999 .51567 .35174 .51466 .34472 Metetra
.976 .688 .409 r
.51466 .34472 .51567 .35174 .50657 .34404 .50557 .33419 Metetra
.973 .703 .456 r
.50557 .33419 .50657 .34404 .49735 .33648 .49635 .32707 Metetra
.969 .697 .462 r
.49635 .32707 .49735 .33648 .488 .3297 .48699 .32358 Metetra
.959 .667 .439 r
.48699 .32358 .488 .3297 .47851 .32425 .47748 .323 Metetra
.746 .433 .454 r
.47748 .323 .47851 .32425 .46866 .35251 .46765 .3478 Metetra
.969 .649 .319 r
.46765 .3478 .46866 .35251 .45845 .39636 .4579 .33494 Metetra
.971 .733 .518 r
.4579 .33494 .45845 .39636 .44844 .38862 .44787 .33766 Metetra
.976 .736 .508 r
.44787 .33766 .44844 .38862 .43805 .40271 .43792 .31893 Metetra
.97 .733 .523 r
.43792 .31893 .43805 .40271 .42799 .37314 .42741 .33485 Metetra
.98 .737 .495 r
.42741 .33485 .42799 .37314 .41805 .32996 .41733 .30495 Metetra
.973 .724 .5 r
.41733 .30495 .41805 .32996 .40758 .31701 .40679 .29942 Metetra
.983 .727 .464 r
.40679 .29942 .40758 .31701 .39724 .28944 .3964 .2757 Metetra
.974 .712 .472 r
.3964 .2757 .39724 .28944 .38684 .25912 .38561 .26679 Metetra
.936 .749 .624 r
.38561 .26679 .38684 .25912 .37601 .24597 .375 .24234 Metetra
.951 .606 .315 r
.375 .24234 .37601 .24597 .36474 .24555 .36387 .23563 Metetra
.934 .667 .509 r
.36387 .23563 .36474 .24555 .3513 .32759 .35181 .26017 Metetra
.975 .737 .512 r
.35181 .26017 .3513 .32759 .33867 .35908 .34061 .24087 Metetra
.974 .739 .518 r
.34061 .24087 .33867 .35908 .32946 .25442 .32928 .22055 Metetra
.98 .735 .494 r
.32928 .22055 .32946 .25442 .3183 .22183 .31802 .1935 Metetra
.974 .727 .5 r
.31802 .1935 .3183 .22183 .30654 .20529 .30608 .1842 Metetra
.974 .721 .491 r
.30608 .1842 .30654 .20529 .29416 .20261 .29393 .17544 Metetra
.83 .399 0 r
.53353 .37086 .53454 .37278 .52566 .35979 .52465 .35999 Metetra
.611 .792 .968 r
.52465 .35999 .52566 .35979 .51668 .35117 .51567 .35174 Metetra
.753 .844 .92 r
.51567 .35174 .51668 .35117 .50759 .34189 .50657 .34404 Metetra
.919 .831 .742 r
.50657 .34404 .50759 .34189 .49837 .33623 .49735 .33648 Metetra
.615 .831 .983 r
.49735 .33648 .49837 .33623 .48902 .32926 .488 .3297 Metetra
.696 .884 .967 r
.488 .3297 .48902 .32926 .47956 .31998 .47851 .32425 Metetra
.902 .849 .395 r
.47851 .32425 .47956 .31998 .46989 .32332 .46866 .35251 Metetra
.991 .774 .511 r
.46866 .35251 .46989 .32332 .46003 .32962 .45845 .39636 Metetra
.973 .746 .535 r
.45845 .39636 .46003 .32962 .45004 .33126 .44844 .38862 Metetra
.977 .752 .53 r
.44844 .38862 .45004 .33126 .43998 .3232 .43805 .40271 Metetra
.969 .741 .539 r
.43805 .40271 .43998 .3232 .42972 .32038 .42799 .37314 Metetra
.964 .738 .549 r
.42799 .37314 .42972 .32038 .41958 .29677 .41805 .32996 Metetra
.97 .749 .548 r
.41805 .32996 .41958 .29677 .40922 .28092 .40758 .31701 Metetra
.965 .743 .552 r
.40758 .31701 .40922 .28092 .39863 .271 .39724 .28944 Metetra
.955 .742 .577 r
.39724 .28944 .39863 .271 .38808 .25084 .38684 .25912 Metetra
.958 .77 .608 r
.38684 .25912 .38808 .25084 .37718 .2419 .37601 .24597 Metetra
.973 .842 .653 r
.37601 .24597 .37718 .2419 .36612 .23268 .36474 .24555 Metetra
.958 .805 .366 r
.36474 .24555 .36612 .23268 .35453 .23874 .3513 .32759 Metetra
.978 .75 .526 r
.3513 .32759 .35453 .23874 .34317 .22713 .33867 .35908 Metetra
.964 .734 .542 r
.33867 .35908 .34317 .22713 .33193 .20513 .32946 .25442 Metetra
.967 .742 .547 r
.32946 .25442 .33193 .20513 .3205 .18506 .3183 .22183 Metetra
.97 .748 .547 r
.3183 .22183 .3205 .18506 .30842 .18109 .30654 .20529 Metetra
.974 .759 .551 r
.30654 .20529 .30842 .18109 .2958 .18728 .29416 .20261 Metetra
.976 .674 .359 r
.53454 .37278 .53556 .37851 .52666 .35769 .52566 .35979 Metetra
.911 .82 .744 r
.52566 .35979 .52666 .35769 .51769 .34941 .51668 .35117 Metetra
.893 .82 .769 r
.51668 .35117 .51769 .34941 .50861 .33674 .50759 .34189 Metetra
.963 .798 .632 r
.50759 .34189 .50861 .33674 .4994 .32956 .49837 .33623 Metetra
.964 .784 .612 r
.49837 .33623 .4994 .32956 .49008 .31995 .48902 .32926 Metetra
.964 .77 .593 r
.48902 .32926 .49008 .31995 .48063 .31187 .47956 .31998 Metetra
.982 .799 .58 r
.47956 .31998 .48063 .31187 .47105 .30399 .46989 .32332 Metetra
.98 .767 .546 r
.46989 .32332 .47105 .30399 .46126 .30687 .46003 .32962 Metetra
.976 .761 .547 r
.46003 .32962 .46126 .30687 .45131 .30773 .45004 .33126 Metetra
.971 .755 .553 r
.45004 .33126 .45131 .30773 .44128 .30123 .43998 .3232 Metetra
.974 .759 .551 r
.43998 .3232 .44128 .30123 .43112 .29293 .42972 .32038 Metetra
.964 .745 .558 r
.42972 .32038 .43112 .29293 .42082 .28446 .41958 .29677 Metetra
.96 .758 .585 r
.41958 .29677 .42082 .28446 .41045 .2711 .40922 .28092 Metetra
.965 .77 .592 r
.40922 .28092 .41045 .2711 .39991 .25914 .39863 .271 Metetra
.955 .753 .591 r
.39863 .271 .39991 .25914 .38933 .24171 .38808 .25084 Metetra
.965 .775 .596 r
.38808 .25084 .38933 .24171 .3785 .23067 .37718 .2419 Metetra
.967 .769 .584 r
.37718 .2419 .3785 .23067 .36731 .22859 .36612 .23268 Metetra
.986 .869 .633 r
.36612 .23268 .36731 .22859 .35515 .25939 .35453 .23874 Metetra
.976 .723 .487 r
.35453 .23874 .35515 .25939 .34371 .24977 .34317 .22713 Metetra
.98 .729 .481 r
.34317 .22713 .34371 .24977 .33297 .20761 .33193 .20513 Metetra
.81 .42 0 r
.33193 .20513 .33297 .20761 .32147 .19003 .3205 .18506 Metetra
.957 .642 .389 r
.3205 .18506 .32147 .19003 .30928 .18941 .30842 .18109 Metetra
.953 .673 .469 r
.30842 .18109 .30928 .18941 .2972 .17909 .2958 .18728 Metetra
.962 .746 .564 r
.53556 .37851 .53649 .35681 .52765 .34802 .52666 .35769 Metetra
.966 .769 .589 r
.52666 .35769 .52765 .34802 .5187 .3392 .51769 .34941 Metetra
.96 .761 .591 r
.51769 .34941 .5187 .3392 .50963 .32915 .50861 .33674 Metetra
.965 .779 .603 r
.50861 .33674 .50963 .32915 .50045 .3184 .4994 .32956 Metetra
.965 .765 .583 r
.4994 .32956 .50045 .3184 .49116 .30606 .49008 .31995 Metetra
.969 .762 .571 r
.49008 .31995 .49116 .30606 .4818 .28417 .48063 .31187 Metetra
.972 .752 .548 r
.48063 .31187 .4818 .28417 .47225 .27868 .47105 .30399 Metetra
.977 .759 .543 r
.47105 .30399 .47225 .27868 .46242 .29072 .46126 .30687 Metetra
.977 .768 .556 r
.46126 .30687 .46242 .29072 .45258 .28383 .45131 .30773 Metetra
.972 .755 .551 r
.45131 .30773 .45258 .28383 .44255 .28061 .44128 .30123 Metetra
.971 .756 .557 r
.44128 .30123 .44255 .28061 .43234 .28033 .43112 .29293 Metetra
.968 .766 .576 r
.43112 .29293 .43234 .28033 .42215 .26513 .42082 .28446 Metetra
.967 .754 .563 r
.42082 .28446 .42215 .26513 .41185 .24965 .41045 .2711 Metetra
.969 .754 .559 r
.41045 .2711 .41185 .24965 .40136 .23731 .39991 .25914 Metetra
.966 .75 .562 r
.39991 .25914 .40136 .23731 .39067 .22817 .38933 .24171 Metetra
.967 .762 .576 r
.38933 .24171 .39067 .22817 .37981 .21917 .3785 .23067 Metetra
.975 .777 .574 r
.3785 .23067 .37981 .21917 .36866 .21679 .36731 .22859 Metetra
.999 .812 .519 r
.36731 .22859 .36866 .21679 .35711 .2231 .35515 .25939 Metetra
.972 .75 .544 r
.35515 .25939 .35711 .2231 .34565 .21663 .34371 .24977 Metetra
.96 .738 .559 r
.34371 .24977 .34565 .21663 .33437 .197 .33297 .20761 Metetra
.957 .76 .596 r
.33297 .20761 .33437 .197 .3226 .18934 .32147 .19003 Metetra
.706 .971 .929 r
.32147 .19003 .3226 .18934 .31071 .17955 .30928 .18941 Metetra
.965 .773 .594 r
.30928 .18941 .31071 .17955 .29899 .15859 .2972 .17909 Metetra
.887 .825 .781 r
.53649 .35681 .53748 .35521 .52865 .34646 .52765 .34802 Metetra
.884 .826 .785 r
.52765 .34802 .52865 .34646 .51971 .3387 .5187 .3392 Metetra
.73 .797 .905 r
.5187 .3392 .51971 .3387 .51064 .3275 .50963 .32915 Metetra
.878 .807 .776 r
.50963 .32915 .51064 .3275 .50147 .31878 .50045 .3184 Metetra
.299 .559 .926 r
.50045 .3184 .50147 .31878 .49216 .31187 .49116 .30606 Metetra
.973 .669 .291 r
.49116 .30606 .49216 .31187 .4827 .31079 .4818 .28417 Metetra
.973 .726 .501 r
.4818 .28417 .4827 .31079 .47306 .3153 .47225 .27868 Metetra
.967 .725 .517 r
.47225 .27868 .47306 .3153 .46333 .30863 .46242 .29072 Metetra
.974 .72 .487 r
.46242 .29072 .46333 .30863 .45326 .32508 .45258 .28383 Metetra
.973 .731 .511 r
.45258 .28383 .45326 .32508 .44309 .33059 .44255 .28061 Metetra
.972 .732 .514 r
.44255 .28061 .44309 .33059 .43271 .33752 .43234 .28033 Metetra
.975 .736 .51 r
.43234 .28033 .43271 .33752 .42259 .3116 .42215 .26513 Metetra
.976 .735 .507 r
.42215 .26513 .42259 .3116 .41224 .29473 .41185 .24965 Metetra
.975 .734 .508 r
.41185 .24965 .41224 .29473 .40189 .26977 .40136 .23731 Metetra
.975 .729 .503 r
.40136 .23731 .40189 .26977 .39129 .25302 .39067 .22817 Metetra
.975 .726 .496 r
.39067 .22817 .39129 .25302 .38047 .24062 .37981 .21917 Metetra
.971 .72 .497 r
.37981 .21917 .38047 .24062 .36949 .22896 .36866 .21679 Metetra
.96 .696 .489 r
.36866 .21679 .36949 .22896 .35736 .25918 .35711 .2231 Metetra
.973 .729 .506 r
.35711 .2231 .35736 .25918 .34606 .24468 .34565 .21663 Metetra
.978 .731 .491 r
.34565 .21663 .34606 .24468 .33531 .20343 .33437 .197 Metetra
.968 .67 .407 r
.33437 .197 .33531 .20343 .32384 .18507 .3226 .18934 Metetra
.949 .805 .667 r
.3226 .18934 .32384 .18507 .31207 .17177 .31071 .17955 Metetra
.945 .76 .621 r
.31071 .17955 .31207 .17177 .30003 .16136 .29899 .15859 Metetra
.976 .707 .454 r
.53748 .35521 .53852 .36567 .52967 .35235 .52865 .34646 Metetra
.971 .673 .398 r
.52865 .34646 .52967 .35235 .52072 .34459 .51971 .3387 Metetra
.975 .675 .377 r
.51971 .3387 .52072 .34459 .51166 .33645 .51064 .3275 Metetra
.975 .7 .441 r
.51064 .3275 .51166 .33645 .50247 .32936 .50147 .31878 Metetra
.974 .705 .46 r
.50147 .31878 .50247 .32936 .49316 .32222 .49216 .31187 Metetra
.967 .699 .472 r
.49216 .31187 .49316 .32222 .48372 .31409 .4827 .31079 Metetra
.923 .594 .402 r
.4827 .31079 .48372 .31409 .47406 .3211 .47306 .3153 Metetra
.968 .668 .401 r
.47306 .3153 .47406 .3211 .46409 .3483 .46333 .30863 Metetra
.967 .724 .519 r
.46333 .30863 .46409 .3483 .45406 .35342 .45326 .32508 Metetra
.969 .722 .51 r
.45326 .32508 .45406 .35342 .44399 .34561 .44309 .33059 Metetra
.963 .705 .498 r
.44309 .33059 .44399 .34561 .43354 .35781 .43271 .33752 Metetra
.984 .731 .468 r
.43271 .33752 .43354 .35781 .42343 .32915 .42259 .3116 Metetra
.98 .724 .472 r
.42259 .3116 .42343 .32915 .41292 .32084 .41224 .29473 Metetra
.981 .733 .483 r
.41224 .29473 .41292 .32084 .40265 .28914 .40189 .26977 Metetra
.979 .725 .478 r
.40189 .26977 .40265 .28914 .39236 .25396 .39129 .25302 Metetra
0 .155 .666 r
.39129 .25302 .39236 .25396 .3816 .23848 .38047 .24062 Metetra
.9 .815 .754 r
.38047 .24062 .3816 .23848 .37054 .23084 .36949 .22896 Metetra
.777 .467 .463 r
.36949 .22896 .37054 .23084 .35805 .27752 .35736 .25918 Metetra
.978 .722 .478 r
.35736 .25918 .35805 .27752 .34657 .26856 .34606 .24468 Metetra
.987 .738 .463 r
.34606 .24468 .34657 .26856 .33621 .21154 .33531 .20343 Metetra
.98 .694 .396 r
.33531 .20343 .33621 .21154 .32485 .18904 .32384 .18507 Metetra
.957 .614 .272 r
.32384 .18507 .32485 .18904 .31297 .17907 .31207 .17177 Metetra
.972 .681 .412 r
.31207 .17177 .31297 .17907 .30091 .16919 .30003 .16136 Metetra
.957 .762 .598 r
.53852 .36567 .53949 .35651 .53066 .3473 .52967 .35235 Metetra
.956 .791 .637 r
.52967 .35235 .53066 .3473 .52173 .33756 .52072 .34459 Metetra
.962 .779 .609 r
.52072 .34459 .52173 .33756 .51267 .33205 .51166 .33645 Metetra
.955 .801 .65 r
.51166 .33645 .51267 .33205 .5035 .32441 .50247 .32936 Metetra
.958 .796 .639 r
.50247 .32936 .5035 .32441 .4942 .31677 .49316 .32222 Metetra
.958 .789 .631 r
.49316 .32222 .4942 .31677 .48476 .31248 .48372 .31409 Metetra
.886 .981 .695 r
.48372 .31409 .48476 .31248 .47515 .31356 .47406 .3211 Metetra
.997 .839 .498 r
.47406 .3211 .47515 .31356 .46533 .32106 .46409 .3483 Metetra
.978 .759 .54 r
.46409 .3483 .46533 .32106 .45541 .31954 .45406 .35342 Metetra
.972 .751 .544 r
.45406 .35342 .45541 .31954 .44528 .32311 .44399 .34561 Metetra
.982 .768 .538 r
.44399 .34561 .44528 .32311 .43502 .3232 .43354 .35781 Metetra
.965 .743 .553 r
.43354 .35781 .43502 .3232 .4248 .30643 .42343 .32915 Metetra
.971 .756 .554 r
.42343 .32915 .4248 .30643 .41446 .28974 .41292 .32084 Metetra
.963 .742 .557 r
.41292 .32084 .41446 .28974 .40394 .27655 .40265 .28914 Metetra
.941 .736 .598 r
.40265 .28914 .40394 .27655 .39342 .25514 .39236 .25396 Metetra
0 .063 .609 r
.39236 .25396 .39342 .25514 .38267 .23939 .3816 .23848 Metetra
.54 0 0 r
.3816 .23848 .38267 .23939 .37167 .22912 .37054 .23084 Metetra
.188 0 .297 r
.37054 .23084 .37167 .22912 .3598 .24966 .35805 .27752 Metetra
.972 .754 .549 r
.35805 .27752 .3598 .24966 .3484 .23995 .34657 .26856 Metetra
.951 .731 .569 r
.34657 .26856 .3484 .23995 .33755 .20278 .33621 .21154 Metetra
.946 .755 .613 r
.33621 .21154 .33755 .20278 .32602 .18699 .32485 .18904 Metetra
.905 .837 .767 r
.32485 .18904 .32602 .18699 .31416 .17698 .31297 .17907 Metetra
.908 .838 .765 r
.31297 .17907 .31416 .17698 .30226 .16237 .30091 .16919 Metetra
.868 .441 .016 r
.53949 .35651 .5405 .35849 .53167 .34801 .53066 .3473 Metetra
0 .294 .774 r
.53066 .3473 .53167 .34801 .52274 .3396 .52173 .33756 Metetra
.903 .49 .152 r
.52173 .33756 .52274 .3396 .51369 .33197 .51267 .33205 Metetra
.53 .777 .988 r
.51267 .33205 .51369 .33197 .50452 .32409 .5035 .32441 Metetra
.66 .827 .964 r
.5035 .32441 .50452 .32409 .49523 .31649 .4942 .31677 Metetra
.582 .875 .994 r
.4942 .31677 .49523 .31649 .48579 .31327 .48476 .31248 Metetra
.721 .208 0 r
.48476 .31248 .48579 .31327 .47614 .32155 .47515 .31356 Metetra
.951 .675 .479 r
.47515 .31356 .47614 .32155 .46638 .32066 .46533 .32106 Metetra
.581 .924 .959 r
.46533 .32106 .46638 .32066 .45651 .31457 .45541 .31954 Metetra
.985 .837 .615 r
.45541 .31954 .45651 .31457 .44644 .31341 .44528 .32311 Metetra
.978 .786 .577 r
.44528 .32311 .44644 .31341 .43626 .30763 .43502 .3232 Metetra
.963 .754 .574 r
.43502 .3232 .43626 .30763 .42611 .28796 .4248 .30643 Metetra
.965 .752 .567 r
.4248 .30643 .42611 .28796 .41561 .285 .41446 .28974 Metetra
.942 .783 .655 r
.41446 .28974 .41561 .285 .40509 .27209 .40394 .27655 Metetra
.916 .756 .668 r
.40394 .27655 .40509 .27209 .39446 .25754 .39342 .25514 Metetra
.851 .448 0 r
.39342 .25514 .39446 .25754 .3838 .23761 .38267 .23939 Metetra
.89 .831 .782 r
.38267 .23939 .3838 .23761 .37291 .22238 .37167 .22912 Metetra
.998 .847 .544 r
.37167 .22912 .37291 .22238 .36114 .23946 .3598 .24966 Metetra
.966 .772 .59 r
.3598 .24966 .36114 .23946 .34946 .24187 .3484 .23995 Metetra
0 .101 .636 r
.3484 .23995 .34946 .24187 .33865 .20342 .33755 .20278 Metetra
.1 .423 .868 r
.33755 .20278 .33865 .20342 .32715 .18671 .32602 .18699 Metetra
.616 .808 .974 r
.32602 .18699 .32715 .18671 .31537 .1741 .31416 .17698 Metetra
.913 .797 .719 r
.31416 .17698 .31537 .1741 .30333 .16415 .30226 .16237 Metetra
.912 .8 .723 r
.5405 .35849 .54149 .35606 .53268 .34801 .53167 .34801 Metetra
.503 .743 .981 r
.53167 .34801 .53268 .34801 .52375 .33604 .52274 .3396 Metetra
.947 .807 .674 r
.52274 .3396 .52375 .33604 .51471 .32689 .51369 .33197 Metetra
.957 .792 .637 r
.51369 .33197 .51471 .32689 .50554 .32458 .50452 .32409 Metetra
0 .422 .837 r
.50452 .32409 .50554 .32458 .49625 .31733 .49523 .31649 Metetra
.663 .111 0 r
.49523 .31649 .49625 .31733 .48681 .3152 .48579 .31327 Metetra
.861 .501 .367 r
.48579 .31327 .48681 .3152 .4772 .31876 .47614 .32155 Metetra
.964 .87 .696 r
.47614 .32155 .4772 .31876 .46755 .30222 .46638 .32066 Metetra
.972 .76 .557 r
.46638 .32066 .46755 .30222 .45773 .29383 .45651 .31457 Metetra
.976 .761 .55 r
.45651 .31457 .45773 .29383 .44773 .28998 .44644 .31341 Metetra
.973 .756 .551 r
.44644 .31341 .44773 .28998 .43748 .29425 .43626 .30763 Metetra
.958 .752 .583 r
.43626 .30763 .43748 .29425 .42743 .26857 .42611 .28796 Metetra
.975 .762 .554 r
.42611 .28796 .42743 .26857 .41705 .25973 .41561 .285 Metetra
.97 .752 .553 r
.41561 .285 .41705 .25973 .40655 .2487 .40509 .27209 Metetra
.968 .752 .557 r
.40509 .27209 .40655 .2487 .39596 .23431 .39446 .25754 Metetra
.966 .749 .56 r
.39446 .25754 .39596 .23431 .38502 .23073 .3838 .23761 Metetra
.95 .77 .624 r
.3838 .23761 .38502 .23073 .37409 .21835 .37291 .22238 Metetra
.982 .899 .565 r
.37291 .22238 .37409 .21835 .36281 .21451 .36114 .23946 Metetra
.977 .761 .545 r
.36114 .23946 .36281 .21451 .35147 .2051 .34946 .24187 Metetra
.963 .74 .554 r
.34946 .24187 .35147 .2051 .33968 .20676 .33865 .20342 Metetra
.932 .568 .159 r
.33865 .20342 .33968 .20676 .32827 .18675 .32715 .18671 Metetra
.473 .703 .969 r
.32715 .18671 .32827 .18675 .31642 .1766 .31537 .1741 Metetra
.911 .508 .142 r
.31537 .1741 .31642 .1766 .30438 .16661 .30333 .16415 Metetra
.385 .689 .98 r
.54149 .35606 .5425 .35619 .53368 .34588 .53268 .34801 Metetra
.894 .792 .74 r
.53268 .34801 .53368 .34588 .52476 .33837 .52375 .33604 Metetra
.906 .504 .11 r
.52375 .33604 .52476 .33837 .51572 .33068 .51471 .32689 Metetra
.95 .622 .368 r
.51471 .32689 .51572 .33068 .50657 .32296 .50554 .32458 Metetra
.898 .848 .787 r
.50554 .32458 .50657 .32296 .49728 .31516 .49625 .31733 Metetra
.948 .883 .736 r
.49625 .31733 .49728 .31516 .48788 .3073 .48681 .3152 Metetra
.984 .801 .579 r
.48681 .3152 .48788 .3073 .47834 .29933 .4772 .31876 Metetra
.965 .751 .564 r
.4772 .31876 .47834 .29933 .46865 .29413 .46755 .30222 Metetra
.965 .777 .601 r
.46755 .30222 .46865 .29413 .4588 .29194 .45773 .29383 Metetra
.929 .883 .767 r
.45773 .29383 .4588 .29194 .44885 .28374 .44773 .28998 Metetra
.986 .82 .595 r
.44773 .28998 .44885 .28374 .43864 .2856 .43748 .29425 Metetra
.939 .745 .615 r
.43748 .29425 .43864 .2856 .42853 .26629 .42743 .26857 Metetra
.918 .83 .742 r
.42743 .26857 .42853 .26629 .41815 .25758 .41705 .25973 Metetra
.903 .816 .751 r
.41705 .25973 .41815 .25758 .40767 .24557 .40655 .2487 Metetra
.917 .787 .702 r
.40655 .2487 .40767 .24557 .39704 .23453 .39596 .23431 Metetra
0 .514 .787 r
.39596 .23431 .39704 .23453 .38622 .22475 .38502 .23073 Metetra
.953 .781 .632 r
.38502 .23073 .38622 .22475 .37524 .21547 .37409 .21835 Metetra
.953 .856 .707 r
.37409 .21835 .37524 .21547 .36393 .21345 .36281 .21451 Metetra
.831 .854 .863 r
.36281 .21451 .36393 .21345 .35258 .20493 .35147 .2051 Metetra
.112 .663 .708 r
.35147 .2051 .35258 .20493 .34113 .19375 .33968 .20676 Metetra
.959 .755 .585 r
.33968 .20676 .34113 .19375 .32956 .18057 .32827 .18675 Metetra
.959 .789 .629 r
.32827 .18675 .32956 .18057 .31774 .17004 .31642 .1766 Metetra
.961 .788 .623 r
.31642 .1766 .31774 .17004 .30576 .15854 .30438 .16661 Metetra
.96 .77 .601 r
.5425 .35619 .54346 .34808 .53467 .33873 .53368 .34588 Metetra
.964 .78 .606 r
.53368 .34588 .53467 .33873 .52576 .32955 .52476 .33837 Metetra
.966 .774 .592 r
.52476 .33837 .52576 .32955 .51674 .32134 .51572 .33068 Metetra
.967 .772 .589 r
.51572 .33068 .51674 .32134 .5076 .31112 .50657 .32296 Metetra
.969 .766 .576 r
.50657 .32296 .5076 .31112 .49835 .30046 .49728 .31516 Metetra
.97 .762 .567 r
.49728 .31516 .49835 .30046 .48903 .27492 .48788 .3073 Metetra
.973 .751 .544 r
.48788 .3073 .48903 .27492 .47954 .26667 .47834 .29933 Metetra
.974 .752 .542 r
.47834 .29933 .47954 .26667 .46983 .27367 .46865 .29413 Metetra
.975 .761 .551 r
.46865 .29413 .46983 .27367 .45997 .27726 .4588 .29194 Metetra
.97 .763 .568 r
.4588 .29194 .45997 .27726 .44996 .27741 .44885 .28374 Metetra
.982 .813 .6 r
.44885 .28374 .44996 .27741 .43989 .26903 .43864 .2856 Metetra
.962 .751 .572 r
.43864 .2856 .43989 .26903 .42967 .26041 .42853 .26629 Metetra
.96 .789 .627 r
.42853 .26629 .42967 .26041 .41934 .24935 .41815 .25758 Metetra
.96 .772 .605 r
.41815 .25758 .41934 .24935 .40893 .23401 .40767 .24557 Metetra
.966 .766 .583 r
.40767 .24557 .40893 .23401 .39835 .22115 .39704 .23453 Metetra
.969 .764 .574 r
.39704 .23453 .39835 .22115 .38749 .21537 .38622 .22475 Metetra
.966 .774 .594 r
.38622 .22475 .38749 .21537 .37638 .21312 .37524 .21547 Metetra
.949 .888 .736 r
.37524 .21547 .37638 .21312 .36511 .20995 .36393 .21345 Metetra
.945 .818 .687 r
.36393 .21345 .36511 .20995 .35367 .20583 .35258 .20493 Metetra
0 .138 .629 r
.35258 .20493 .35367 .20583 .34235 .18935 .34113 .19375 Metetra
.941 .791 .666 r
.34113 .19375 .34235 .18935 .33071 .17938 .32956 .18057 Metetra
.841 .845 .848 r
.32956 .18057 .33071 .17938 .31894 .16735 .31774 .17004 Metetra
.921 .817 .728 r
.31774 .17004 .31894 .16735 .30694 .15698 .30576 .15854 Metetra
.973 .669 .376 r
.54346 .34808 .54449 .35364 .53569 .3451 .53467 .33873 Metetra
.974 .68 .399 r
.53467 .33873 .53569 .3451 .52678 .33352 .52576 .32955 Metetra
.961 .63 .319 r
.52576 .32955 .52678 .33352 .51776 .32603 .51674 .32134 Metetra
.969 .651 .337 r
.51674 .32134 .51776 .32603 .50862 .31692 .5076 .31112 Metetra
.974 .672 .375 r
.5076 .31112 .50862 .31692 .49934 .31482 .49835 .30046 Metetra
.987 .726 .438 r
.49835 .30046 .49934 .31482 .48992 .31348 .48903 .27492 Metetra
.975 .732 .505 r
.48903 .27492 .48992 .31348 .48037 .30951 .47954 .26667 Metetra
.97 .729 .514 r
.47954 .26667 .48037 .30951 .47067 .30527 .46983 .27367 Metetra
.97 .725 .509 r
.46983 .27367 .47067 .30527 .46078 .30685 .45997 .27726 Metetra
.972 .726 .505 r
.45997 .27726 .46078 .30685 .45078 .30346 .44996 .27741 Metetra
.975 .727 .496 r
.44996 .27741 .45078 .30346 .44063 .29795 .43989 .26903 Metetra
.975 .728 .498 r
.43989 .26903 .44063 .29795 .43041 .28661 .42967 .26041 Metetra
.976 .728 .494 r
.42967 .26041 .43041 .28661 .42001 .27816 .41934 .24935 Metetra
.978 .731 .493 r
.41934 .24935 .42001 .27816 .40962 .2589 .40893 .23401 Metetra
.977 .728 .491 r
.40893 .23401 .40962 .2589 .39902 .245 .39835 .22115 Metetra
.974 .724 .495 r
.39835 .22115 .39902 .245 .38826 .23238 .38749 .21537 Metetra
.971 .714 .488 r
.38749 .21537 .38826 .23238 .37727 .22322 .37638 .21312 Metetra
.968 .695 .461 r
.37638 .21312 .37727 .22322 .36593 .22267 .36511 .20995 Metetra
.971 .705 .472 r
.36511 .20995 .36593 .22267 .35444 .2201 .35367 .20583 Metetra
.98 .717 .458 r
.35367 .20583 .35444 .2201 .34316 .20115 .34235 .18935 Metetra
.975 .706 .457 r
.34235 .18935 .34316 .20115 .33171 .18362 .33071 .17938 Metetra
.96 .624 .299 r
.33071 .17938 .33171 .18362 .31989 .17337 .31894 .16735 Metetra
.97 .665 .382 r
.31894 .16735 .31989 .17337 .30788 .16314 .30694 .15698 Metetra
.492 .732 .979 r
.54449 .35364 .54549 .35365 .53669 .34189 .53569 .3451 Metetra
.926 .789 .69 r
.53569 .3451 .53669 .34189 .52778 .32868 .52678 .33352 Metetra
.957 .795 .64 r
.52678 .33352 .52778 .32868 .51877 .31699 .51776 .32603 Metetra
.965 .771 .593 r
.51776 .32603 .51877 .31699 .50964 .31344 .50862 .31692 Metetra
.967 .841 .666 r
.50862 .31692 .50964 .31344 .50037 .31397 .49934 .31482 Metetra
.813 .969 .902 r
.49934 .31482 .50037 .31397 .49097 .30935 .48992 .31348 Metetra
.964 .82 .652 r
.48992 .31348 .49097 .30935 .48143 .30461 .48037 .30951 Metetra
.967 .809 .634 r
.48037 .30951 .48143 .30461 .4718 .29151 .47067 .30527 Metetra
.979 .774 .558 r
.47067 .30527 .4718 .29151 .462 .28563 .46078 .30685 Metetra
.975 .76 .55 r
.46078 .30685 .462 .28563 .45207 .27834 .45078 .30346 Metetra
.974 .756 .548 r
.45078 .30346 .45207 .27834 .44198 .27151 .44063 .29795 Metetra
.971 .752 .55 r
.44063 .29795 .44198 .27151 .43181 .25952 .43041 .28661 Metetra
.972 .754 .548 r
.43041 .28661 .43181 .25952 .42145 .25158 .42001 .27816 Metetra
.967 .748 .555 r
.42001 .27816 .42145 .25158 .41096 .24186 .40962 .2589 Metetra
.967 .756 .567 r
.40962 .2589 .41096 .24186 .40037 .22979 .39902 .245 Metetra
.967 .759 .571 r
.39902 .245 .40037 .22979 .38958 .22018 .38826 .23238 Metetra
.969 .768 .578 r
.38826 .23238 .38958 .22018 .37862 .21096 .37727 .22322 Metetra
.977 .778 .568 r
.37727 .22322 .37862 .21096 .36742 .20519 .36593 .22267 Metetra
.976 .766 .557 r
.36593 .22267 .36742 .20519 .35609 .19737 .35444 .2201 Metetra
.967 .751 .56 r
.35444 .2201 .35609 .19737 .34449 .19277 .34316 .20115 Metetra
.953 .765 .611 r
.34316 .20115 .34449 .19277 .33303 .17617 .33171 .18362 Metetra
.963 .782 .612 r
.33171 .18362 .33303 .17617 .32133 .16267 .31989 .17337 Metetra
.967 .772 .587 r
.31989 .17337 .32133 .16267 .30923 .15625 .30788 .16314 Metetra
.859 .794 .786 r
.54549 .35365 .54649 .35219 .53771 .34466 .53669 .34189 Metetra
.908 .529 .093 r
.53669 .34189 .53771 .34466 .52881 .33713 .52778 .32868 Metetra
.979 .699 .422 r
.52778 .32868 .52881 .33713 .5198 .32958 .51877 .31699 Metetra
.972 .709 .475 r
.51877 .31699 .5198 .32958 .51066 .32194 .50964 .31344 Metetra
.963 .688 .463 r
.50964 .31344 .51066 .32194 .5014 .31489 .50037 .31397 Metetra
.653 .106 0 r
.50037 .31397 .5014 .31489 .492 .30991 .49097 .30935 Metetra
.364 0 0 r
.49097 .30935 .492 .30991 .48243 .31336 .48143 .30461 Metetra
.979 .7 .421 r
.48143 .30461 .48243 .31336 .47277 .30466 .4718 .29151 Metetra
.973 .711 .472 r
.4718 .29151 .47277 .30466 .46299 .29435 .462 .28563 Metetra
.973 .694 .44 r
.462 .28563 .46299 .29435 .45301 .29084 .45207 .27834 Metetra
.974 .709 .467 r
.45207 .27834 .45301 .29084 .44285 .28955 .44198 .27151 Metetra
.978 .722 .478 r
.44198 .27151 .44285 .28955 .43271 .27386 .43181 .25952 Metetra
.975 .714 .472 r
.43181 .25952 .43271 .27386 .4224 .26082 .42145 .25158 Metetra
.975 .698 .437 r
.42145 .25158 .4224 .26082 .41189 .25187 .41096 .24186 Metetra
.978 .703 .438 r
.41096 .24186 .41189 .25187 .40119 .24529 .40037 .22979 Metetra
.976 .716 .474 r
.40037 .22979 .40119 .24529 .39054 .2271 .38958 .22018 Metetra
.972 .679 .407 r
.38958 .22018 .39054 .2271 .37949 .22182 .37862 .21096 Metetra
.972 .701 .459 r
.37862 .21096 .37949 .22182 .3681 .22412 .36742 .20519 Metetra
.975 .719 .485 r
.36742 .20519 .3681 .22412 .35665 .22034 .35609 .19737 Metetra
.973 .722 .494 r
.35609 .19737 .35665 .22034 .34528 .20569 .34449 .19277 Metetra
.98 .714 .45 r
.34449 .19277 .34528 .20569 .33393 .18434 .33303 .17617 Metetra
.977 .691 .412 r
.33303 .17617 .33393 .18434 .32216 .17272 .32133 .16267 Metetra
.971 .696 .451 r
.32133 .16267 .32216 .17272 .31028 .15861 .30923 .15625 Metetra
.966 .648 .353 r
.54649 .35219 .54752 .35673 .53872 .34702 .53771 .34466 Metetra
.917 .52 .157 r
.53771 .34466 .53872 .34702 .52982 .33698 .52881 .33713 Metetra
.576 .796 .983 r
.52881 .33713 .52982 .33698 .52081 .32783 .5198 .32958 Metetra
.903 .84 .773 r
.5198 .32958 .52081 .32783 .51168 .32169 .51066 .32194 Metetra
.62 .827 .98 r
.51066 .32194 .51168 .32169 .50242 .31679 .5014 .31489 Metetra
.891 .466 .132 r
.5014 .31489 .50242 .31679 .49302 .31542 .492 .30991 Metetra
.949 .653 .442 r
.492 .30991 .49302 .31542 .48348 .31135 .48243 .31336 Metetra
.909 .83 .756 r
.48243 .31336 .48348 .31135 .4738 .30704 .47277 .30466 Metetra
.902 .498 .095 r
.47277 .30466 .4738 .30704 .46399 .3006 .46299 .29435 Metetra
.964 .669 .422 r
.46299 .29435 .46399 .3006 .45405 .29254 .45301 .29084 Metetra
.873 .443 .177 r
.45301 .29084 .45405 .29254 .44387 .29435 .44285 .28955 Metetra
.968 .646 .293 r
.44285 .28955 .44387 .29435 .43378 .27388 .43271 .27386 Metetra
.518 .691 .947 r
.43271 .27386 .43378 .27388 .4234 .26658 .4224 .26082 Metetra
.97 .665 .383 r
.4224 .26082 .4234 .26658 .41291 .25561 .41189 .25187 Metetra
.953 .611 .317 r
.41189 .25187 .41291 .25561 .40228 .24519 .40119 .24529 Metetra
.597 .668 .889 r
.40119 .24529 .40228 .24519 .3916 .22869 .39054 .2271 Metetra
.842 .376 .031 r
.39054 .2271 .3916 .22869 .38065 .2188 .37949 .22182 Metetra
.973 .889 .683 r
.37949 .22182 .38065 .2188 .36939 .21586 .3681 .22412 Metetra
.973 .79 .595 r
.3681 .22412 .36939 .21586 .35785 .21642 .35665 .22034 Metetra
.931 .788 .679 r
.35665 .22034 .35785 .21642 .34662 .19674 .34528 .20569 Metetra
.949 .758 .609 r
.34528 .20569 .34662 .19674 .3351 .18258 .33393 .18434 Metetra
.884 .828 .788 r
.33393 .18434 .3351 .18258 .32336 .1701 .32216 .17272 Metetra
.908 .803 .731 r
.32216 .17272 .32336 .1701 .31143 .15832 .31028 .15861 Metetra
.859 .818 .807 r
.54752 .35673 .54851 .35543 .53973 .34572 .53872 .34702 Metetra
.858 .815 .806 r
.53872 .34702 .53973 .34572 .53083 .33487 .52982 .33698 Metetra
.91 .818 .744 r
.52982 .33698 .53083 .33487 .52183 .32671 .52081 .32783 Metetra
.861 .876 .848 r
.52081 .32783 .52183 .32671 .51271 .32012 .51168 .32169 Metetra
.909 .879 .794 r
.51168 .32169 .51271 .32012 .50346 .31517 .50242 .31679 Metetra
.928 .922 .785 r
.50242 .31679 .50346 .31517 .49406 .31502 .49302 .31542 Metetra
.652 .904 .982 r
.49302 .31542 .49406 .31502 .48453 .30979 .48348 .31135 Metetra
.91 .891 .8 r
.48348 .31135 .48453 .30979 .47485 .3069 .4738 .30704 Metetra
.524 .812 .998 r
.4738 .30704 .47485 .3069 .46504 .30102 .46399 .3006 Metetra
.023 .482 .877 r
.46399 .3006 .46504 .30102 .45511 .29266 .45405 .29254 Metetra
.282 0 0 r
.45405 .29254 .45511 .29266 .445 .28782 .44387 .29435 Metetra
.937 .756 .632 r
.44387 .29435 .445 .28782 .43489 .27034 .43378 .27388 Metetra
.95 .819 .68 r
.43378 .27388 .43489 .27034 .42454 .26147 .4234 .26658 Metetra
.951 .789 .644 r
.4234 .26658 .42454 .26147 .41406 .25116 .41291 .25561 Metetra
.948 .796 .658 r
.41291 .25561 .41406 .25116 .40351 .23656 .40228 .24519 Metetra
.955 .764 .607 r
.40228 .24519 .40351 .23656 .39273 .22653 .3916 .22869 Metetra
.91 .83 .754 r
.3916 .22869 .39273 .22653 .38178 .21734 .38065 .2188 Metetra
.902 .925 .824 r
.38065 .2188 .38178 .21734 .37051 .21523 .36939 .21586 Metetra
.642 .963 .909 r
.36939 .21586 .37051 .21523 .35921 .206 .35785 .21642 Metetra
.955 .758 .597 r
.35785 .21642 .35921 .206 .34768 .19904 .34662 .19674 Metetra
.861 .444 0 r
.34662 .19674 .34768 .19904 .33623 .18227 .3351 .18258 Metetra
.64 .778 .947 r
.3351 .18258 .33623 .18227 .32438 .17382 .32336 .1701 Metetra
.952 .6 .261 r
.32336 .1701 .32438 .17382 .31254 .15891 .31143 .15832 Metetra
.891 .482 .065 r
.54851 .35543 .54953 .35767 .54074 .34513 .53973 .34572 Metetra
.75 .789 .884 r
.53973 .34572 .54074 .34513 .53185 .33554 .53083 .33487 Metetra
0 .274 .737 r
.53083 .33487 .53185 .33554 .52285 .3279 .52183 .32671 Metetra
.718 .207 0 r
.52183 .32671 .52285 .3279 .51373 .3197 .51271 .32012 Metetra
.68 .89 .974 r
.51271 .32012 .51373 .3197 .5045 .30464 .50346 .31517 Metetra
.978 .781 .57 r
.50346 .31517 .5045 .30464 .49515 .2956 .49406 .31502 Metetra
.974 .76 .553 r
.49406 .31502 .49515 .2956 .48563 .29578 .48453 .30979 Metetra
.975 .769 .562 r
.48453 .30979 .48563 .29578 .47599 .29146 .47485 .3069 Metetra
.973 .764 .562 r
.47485 .3069 .47599 .29146 .46617 .29071 .46504 .30102 Metetra
.968 .771 .584 r
.46504 .30102 .46617 .29071 .45626 .28244 .45511 .29266 Metetra
.973 .777 .58 r
.45511 .29266 .45626 .28244 .44621 .27396 .445 .28782 Metetra
.962 .755 .578 r
.445 .28782 .44621 .27396 .43602 .26481 .43489 .27034 Metetra
.958 .792 .633 r
.43489 .27034 .43602 .26481 .42575 .25093 .42454 .26147 Metetra
.966 .769 .586 r
.42454 .26147 .42575 .25093 .41533 .23847 .41406 .25116 Metetra
.964 .76 .58 r
.41406 .25116 .41533 .23847 .40472 .229 .40351 .23656 Metetra
.963 .779 .609 r
.40351 .23656 .40472 .229 .39396 .21875 .39273 .22653 Metetra
.965 .781 .606 r
.39273 .22653 .39396 .21875 .38294 .21392 .38178 .21734 Metetra
.966 .852 .678 r
.38178 .21734 .38294 .21392 .37165 .21317 .37051 .21523 Metetra
.91 .84 .763 r
.37051 .21523 .37165 .21317 .36027 .20803 .35921 .206 Metetra
.885 .453 .103 r
.35921 .206 .36027 .20803 .34911 .18628 .34768 .19904 Metetra
.963 .76 .583 r
.34768 .19904 .34911 .18628 .33753 .17557 .33623 .18227 Metetra
.964 .791 .618 r
.33623 .18227 .33753 .17557 .32575 .16544 .32438 .17382 Metetra
.958 .771 .608 r
.32438 .17382 .32575 .16544 .3138 .15468 .31254 .15891 Metetra
.964 .759 .579 r
.54953 .35767 .55047 .34551 .54167 .32723 .54074 .34513 Metetra
.97 .757 .559 r
.54074 .34513 .54167 .32723 .53282 .3195 .53185 .33554 Metetra
.971 .76 .561 r
.53185 .33554 .53282 .3195 .52384 .31137 .52285 .3279 Metetra
.971 .76 .561 r
.52285 .3279 .52384 .31137 .51475 .29598 .51373 .3197 Metetra
.968 .75 .554 r
.51373 .3197 .51475 .29598 .50555 .28658 .5045 .30464 Metetra
.971 .758 .559 r
.5045 .30464 .50555 .28658 .49624 .27351 .49515 .2956 Metetra
.977 .761 .545 r
.49515 .2956 .49624 .27351 .48679 .26525 .48563 .29578 Metetra
.975 .754 .541 r
.48563 .29578 .48679 .26525 .47714 .27145 .47599 .29146 Metetra
.977 .763 .548 r
.47599 .29146 .47714 .27145 .46733 .27577 .46617 .29071 Metetra
.971 .763 .566 r
.46617 .29071 .46733 .27577 .45744 .26819 .45626 .28244 Metetra
.971 .764 .568 r
.45626 .28244 .45744 .26819 .44734 .26726 .44621 .27396 Metetra
.962 .784 .616 r
.44621 .27396 .44734 .26726 .43719 .25657 .43602 .26481 Metetra
.957 .768 .606 r
.43602 .26481 .43719 .25657 .42693 .24339 .42575 .25093 Metetra
.958 .774 .611 r
.42575 .25093 .42693 .24339 .4166 .22554 .41533 .23847 Metetra
.969 .766 .574 r
.41533 .23847 .4166 .22554 .40608 .21192 .40472 .229 Metetra
.97 .76 .563 r
.40472 .229 .40608 .21192 .39535 .20194 .39396 .21875 Metetra
.974 .765 .559 r
.39396 .21875 .39535 .20194 .38416 .2076 .38294 .21392 Metetra
.977 .81 .609 r
.38294 .21392 .38416 .2076 .37272 .21508 .37165 .21317 Metetra
.88 .445 .119 r
.37165 .21317 .37272 .21508 .36137 .20848 .36027 .20803 Metetra
.378 .519 .872 r
.36027 .20803 .36137 .20848 .35011 .19109 .34911 .18628 Metetra
.965 .642 .337 r
.34911 .18628 .35011 .19109 .33865 .17537 .33753 .17557 Metetra
.578 .793 .981 r
.33753 .17557 .33865 .17537 .32688 .16519 .32575 .16544 Metetra
.608 .796 .971 r
.32575 .16544 .32688 .16519 .31499 .15271 .3138 .15468 Metetra
.881 .75 .713 r
.55047 .34551 .55146 .34292 .54268 .32661 .54167 .32723 Metetra
.766 .845 .911 r
.54167 .32723 .54268 .32661 .53383 .31933 .53282 .3195 Metetra
.599 .792 .973 r
.53282 .3195 .53383 .31933 .52486 .31162 .52384 .31137 Metetra
.466 .602 .903 r
.52384 .31137 .52486 .31162 .51578 .30387 .51475 .29598 Metetra
.976 .693 .422 r
.51475 .29598 .51578 .30387 .50656 .30442 .50555 .28658 Metetra
.979 .724 .475 r
.50555 .28658 .50656 .30442 .4972 .30391 .49624 .27351 Metetra
.976 .73 .498 r
.49624 .27351 .4972 .30391 .48769 .30302 .48679 .26525 Metetra
.971 .727 .511 r
.48679 .26525 .48769 .30302 .47806 .29495 .47714 .27145 Metetra
.969 .72 .503 r
.47714 .27145 .47806 .29495 .46829 .28843 .46733 .27577 Metetra
.975 .71 .465 r
.46733 .27577 .46829 .28843 .45838 .28137 .45744 .26819 Metetra
.969 .707 .479 r
.45744 .26819 .45838 .28137 .44831 .27694 .44734 .26726 Metetra
.977 .702 .437 r
.44734 .26726 .44831 .27694 .43815 .2656 .43719 .25657 Metetra
.979 .7 .423 r
.43719 .25657 .43815 .2656 .42784 .25543 .42693 .24339 Metetra
.982 .714 .439 r
.42693 .24339 .42784 .25543 .41741 .24364 .4166 .22554 Metetra
.979 .723 .475 r
.4166 .22554 .41741 .24364 .40683 .23266 .40608 .21192 Metetra
.976 .723 .485 r
.40608 .21192 .40683 .23266 .39613 .21954 .39535 .20194 Metetra
.966 .71 .496 r
.39535 .20194 .39613 .21954 .38519 .21105 .38416 .2076 Metetra
.914 .584 .405 r
.38416 .2076 .38519 .21105 .37399 .20701 .37272 .21508 Metetra
.97 .786 .6 r
.37272 .21508 .37399 .20701 .36259 .20379 .36137 .20848 Metetra
.933 .774 .661 r
.36137 .20848 .36259 .20379 .35126 .18964 .35011 .19109 Metetra
.841 .79 .802 r
.35011 .19109 .35126 .18964 .33979 .1748 .33865 .17537 Metetra
.724 .838 .935 r
.33865 .17537 .33979 .1748 .32807 .1628 .32688 .16519 Metetra
.908 .816 .745 r
.32688 .16519 .32807 .1628 .31617 .15113 .31499 .15271 Metetra
.983 .713 .428 r
.55146 .34292 .55252 .35353 .54374 .33959 .54268 .32661 Metetra
.976 .713 .468 r
.54268 .32661 .54374 .33959 .53488 .33219 .53383 .31933 Metetra
.976 .713 .466 r
.53383 .31933 .53488 .33219 .5259 .32392 .52486 .31162 Metetra
.976 .711 .463 r
.52486 .31162 .5259 .32392 .51681 .31754 .51578 .30387 Metetra
.969 .708 .484 r
.51578 .30387 .51681 .31754 .50758 .30969 .50656 .30442 Metetra
.956 .654 .419 r
.50656 .30442 .50758 .30969 .49822 .30884 .4972 .30391 Metetra
.955 .647 .409 r
.4972 .30391 .49822 .30884 .48871 .3089 .48769 .30302 Metetra
.971 .669 .39 r
.48769 .30302 .48871 .3089 .47904 .30798 .47806 .29495 Metetra
.974 .711 .469 r
.47806 .29495 .47904 .30798 .46929 .29755 .46829 .28843 Metetra
.973 .696 .443 r
.46829 .28843 .46929 .29755 .45929 .29989 .45838 .28137 Metetra
.973 .719 .487 r
.45838 .28137 .45929 .29989 .44915 .30049 .44831 .27694 Metetra
.977 .727 .488 r
.44831 .27694 .44915 .30049 .43903 .28293 .43815 .2656 Metetra
.977 .72 .477 r
.43815 .2656 .43903 .28293 .42873 .27056 .42784 .25543 Metetra
.978 .717 .467 r
.42784 .25543 .42873 .27056 .41836 .25286 .41741 .24364 Metetra
.977 .698 .431 r
.41741 .24364 .41836 .25286 .40778 .2408 .40683 .23266 Metetra
.978 .693 .41 r
.40683 .23266 .40778 .2408 .39712 .225 .39613 .21954 Metetra
.968 .658 .374 r
.39613 .21954 .39712 .225 .3862 .21544 .38519 .21105 Metetra
.955 .629 .366 r
.38519 .21105 .3862 .21544 .375 .21188 .37399 .20701 Metetra
.956 .64 .385 r
.37399 .20701 .375 .21188 .36342 .21603 .36259 .20379 Metetra
.979 .711 .448 r
.36259 .20379 .36342 .21603 .35215 .19915 .35126 .18964 Metetra
.979 .7 .423 r
.35126 .18964 .35215 .19915 .34072 .18192 .33979 .1748 Metetra
.974 .68 .397 r
.33979 .1748 .34072 .18192 .32908 .1673 .32807 .1628 Metetra
.962 .631 .313 r
.32807 .1628 .32908 .1673 .31709 .15834 .31617 .15113 Metetra
.91 .539 .097 r
.55252 .35353 .55355 .35646 .54478 .34681 .54374 .33959 Metetra
.974 .687 .42 r
.54374 .33959 .54478 .34681 .53591 .33711 .53488 .33219 Metetra
.969 .655 .359 r
.53488 .33219 .53591 .33711 .52693 .32912 .5259 .32392 Metetra
.967 .659 .382 r
.5259 .32392 .52693 .32912 .51783 .32251 .51681 .31754 Metetra
.968 .655 .364 r
.51681 .31754 .51783 .32251 .50861 .31604 .50758 .30969 Metetra
.961 .67 .435 r
.50758 .30969 .50861 .31604 .49925 .31054 .49822 .30884 Metetra
.876 .458 .214 r
.49822 .30884 .49925 .31054 .48976 .30624 .48871 .3089 Metetra
.963 .876 .701 r
.48871 .3089 .48976 .30624 .48013 .30088 .47904 .30798 Metetra
.96 .778 .612 r
.47904 .30798 .48013 .30088 .47041 .2862 .46929 .29755 Metetra
.981 .783 .563 r
.46929 .29755 .47041 .2862 .46053 .278 .45929 .29989 Metetra
.978 .762 .545 r
.45929 .29989 .46053 .278 .45039 .28226 .44915 .30049 Metetra
.965 .752 .565 r
.44915 .30049 .45039 .28226 .44031 .26436 .43903 .28293 Metetra
.969 .756 .561 r
.43903 .28293 .44031 .26436 .42995 .25894 .42873 .27056 Metetra
.959 .758 .588 r
.42873 .27056 .42995 .25894 .4196 .24212 .41836 .25286 Metetra
.965 .767 .587 r
.41836 .25286 .4196 .24212 .409 .2329 .40778 .2408 Metetra
.954 .767 .612 r
.40778 .2408 .409 .2329 .39825 .22274 .39712 .225 Metetra
.916 .831 .747 r
.39712 .225 .39825 .22274 .38738 .21143 .3862 .21544 Metetra
.966 .833 .66 r
.3862 .21544 .38738 .21143 .37624 .20537 .375 .21188 Metetra
.986 .821 .596 r
.375 .21188 .37624 .20537 .36474 .20708 .36342 .21603 Metetra
.956 .765 .604 r
.36342 .21603 .36474 .20708 .35339 .19375 .35215 .19915 Metetra
.94 .774 .647 r
.35215 .19915 .35339 .19375 .34199 .17633 .34072 .18192 Metetra
.948 .781 .642 r
.34072 .18192 .34199 .17633 .33023 .16623 .32908 .1673 Metetra
.832 .869 .872 r
.32908 .1673 .33023 .16623 .31832 .15512 .31709 .15834 Metetra
.961 .775 .606 r
.55355 .35646 .55451 .34908 .54576 .3383 .54478 .34681 Metetra
.964 .771 .596 r
.54478 .34681 .54576 .3383 .5369 .32804 .53591 .33711 Metetra
.967 .773 .589 r
.53591 .33711 .5369 .32804 .52794 .32087 .52693 .32912 Metetra
.969 .779 .593 r
.52693 .32912 .52794 .32087 .51885 .3135 .51783 .32251 Metetra
.97 .777 .588 r
.51783 .32251 .51885 .3135 .50965 .30776 .50861 .31604 Metetra
.971 .782 .592 r
.50861 .31604 .50965 .30776 .5003 .3078 .49925 .31054 Metetra
.951 .848 .705 r
.49925 .31054 .5003 .3078 .49082 .30145 .48976 .30624 Metetra
.964 .808 .638 r
.48976 .30624 .49082 .30145 .48118 .30042 .48013 .30088 Metetra
.704 .738 .878 r
.48013 .30088 .48118 .30042 .47143 .29222 .47041 .2862 Metetra
.971 .67 .391 r
.47041 .2862 .47143 .29222 .4615 .28984 .46053 .278 Metetra
.964 .698 .483 r
.46053 .278 .4615 .28984 .45135 .29375 .45039 .28226 Metetra
.983 .713 .432 r
.45039 .28226 .45135 .29375 .4413 .27156 .44031 .26436 Metetra
.969 .68 .425 r
.44031 .26436 .4413 .27156 .43098 .26299 .42995 .25894 Metetra
.952 .612 .22 r
.42995 .25894 .43098 .26299 .42055 .25135 .4196 .24212 Metetra
.975 .697 .436 r
.4196 .24212 .42055 .25135 .40989 .24519 .409 .2329 Metetra
.977 .709 .456 r
.409 .2329 .40989 .24519 .39933 .22402 .39825 .22274 Metetra
.615 .125 0 r
.39825 .22274 .39933 .22402 .38835 .21818 .38738 .21143 Metetra
.968 .673 .414 r
.38738 .21143 .38835 .21818 .37719 .21281 .37624 .20537 Metetra
.959 .672 .448 r
.37624 .20537 .37719 .21281 .36562 .21762 .36474 .20708 Metetra
.978 .704 .437 r
.36474 .20708 .36562 .21762 .35455 .19225 .35339 .19375 Metetra
.837 .776 .793 r
.35339 .19375 .35455 .19225 .34309 .17723 .34199 .17633 Metetra
0 .1 .573 r
.34199 .17633 .34309 .17723 .33136 .16613 .33023 .16623 Metetra
.529 .758 .981 r
.33023 .16623 .33136 .16613 .31949 .15388 .31832 .15512 Metetra
.959 .619 .269 r
.55451 .34908 .55554 .35288 .54677 .33868 .54576 .3383 Metetra
.239 .555 .933 r
.54576 .3383 .54677 .33868 .53792 .3301 .5369 .32804 Metetra
.894 .475 .099 r
.5369 .32804 .53792 .3301 .52896 .32249 .52794 .32087 Metetra
.83 .37 0 r
.52794 .32087 .52896 .32249 .51988 .31608 .51885 .3135 Metetra
.93 .548 .226 r
.51885 .3135 .51988 .31608 .51068 .31029 .50965 .30776 Metetra
.92 .552 .311 r
.50965 .30776 .51068 .31029 .50133 .30783 .5003 .3078 Metetra
.383 .743 .991 r
.5003 .3078 .50133 .30783 .49184 .30731 .49082 .30145 Metetra
.96 .662 .425 r
.49082 .30145 .49184 .30731 .48223 .30036 .48118 .30042 Metetra
.512 .769 .989 r
.48118 .30042 .48223 .30036 .47248 .29235 .47143 .29222 Metetra
.005 .569 .797 r
.47143 .29222 .47248 .29235 .46259 .28553 .4615 .28984 Metetra
.986 .853 .624 r
.4615 .28984 .46259 .28553 .45256 .27804 .45135 .29375 Metetra
.96 .75 .575 r
.45135 .29375 .45256 .27804 .44243 .2662 .4413 .27156 Metetra
.959 .795 .635 r
.4413 .27156 .44243 .2662 .43216 .25432 .43098 .26299 Metetra
.963 .772 .599 r
.43098 .26299 .43216 .25432 .4218 .23916 .42055 .25135 Metetra
.973 .771 .573 r
.42055 .25135 .4218 .23916 .41116 .23377 .40989 .24519 Metetra
.956 .754 .592 r
.40989 .24519 .41116 .23377 .40044 .22262 .39933 .22402 Metetra
.887 .892 .829 r
.39933 .22402 .40044 .22262 .38955 .21289 .38835 .21818 Metetra
.967 .809 .633 r
.38835 .21818 .38955 .21289 .37833 .21126 .37719 .21281 Metetra
.892 .989 .765 r
.37719 .21281 .37833 .21126 .36705 .20302 .36562 .21762 Metetra
.957 .749 .581 r
.36562 .21762 .36705 .20302 .35572 .18979 .35455 .19225 Metetra
.9 .796 .737 r
.35455 .19225 .35572 .18979 .34418 .1787 .34309 .17723 Metetra
.72 .233 0 r
.34309 .17723 .34418 .1787 .33252 .16521 .33136 .16613 Metetra
.795 .825 .875 r
.33136 .16613 .33252 .16521 .32049 .15838 .31949 .15388 Metetra
.921 .774 .681 r
.55554 .35288 .55652 .34936 .54776 .3345 .54677 .33868 Metetra
.95 .797 .655 r
.54677 .33868 .54776 .3345 .53892 .32492 .53792 .3301 Metetra
.959 .793 .632 r
.53792 .3301 .53892 .32492 .52996 .31287 .52896 .32249 Metetra
.97 .775 .583 r
.52896 .32249 .52996 .31287 .5209 .30812 .51988 .31608 Metetra
.97 .782 .594 r
.51988 .31608 .5209 .30812 .51171 .30714 .51068 .31029 Metetra
.964 .849 .68 r
.51068 .31029 .51171 .30714 .50241 .28431 .50133 .30783 Metetra
.977 .76 .543 r
.50133 .30783 .50241 .28431 .49294 .28878 .49184 .30731 Metetra
.973 .76 .555 r
.49184 .30731 .49294 .28878 .48332 .2914 .48223 .30036 Metetra
.968 .776 .591 r
.48223 .30036 .48332 .2914 .47359 .28361 .47248 .29235 Metetra
.97 .779 .591 r
.47248 .29235 .47359 .28361 .46369 .28114 .46259 .28553 Metetra
.957 .806 .653 r
.46259 .28553 .46369 .28114 .45363 .27752 .45256 .27804 Metetra
.722 .789 .905 r
.45256 .27804 .45363 .27752 .44357 .25985 .44243 .2662 Metetra
.956 .78 .624 r
.44243 .2662 .44357 .25985 .43331 .24889 .43216 .25432 Metetra
.944 .775 .642 r
.43216 .25432 .43331 .24889 .42287 .24033 .4218 .23916 Metetra
.739 .22 0 r
.4218 .23916 .42287 .24033 .41236 .22621 .41116 .23377 Metetra
.961 .778 .609 r
.41116 .23377 .41236 .22621 .40168 .21439 .40044 .22262 Metetra
.965 .778 .601 r
.40044 .22262 .40168 .21439 .39079 .20522 .38955 .21289 Metetra
.977 .798 .594 r
.38955 .21289 .39079 .20522 .37959 .20352 .37833 .21126 Metetra
.967 .784 .604 r
.37833 .21126 .37959 .20352 .36824 .1998 .36705 .20302 Metetra
.926 .8 .702 r
.36705 .20302 .36824 .1998 .357 .18328 .35572 .18979 Metetra
.96 .785 .623 r
.35572 .18979 .357 .18328 .34555 .16897 .34418 .1787 Metetra
.963 .77 .595 r
.34418 .1787 .34555 .16897 .33367 .16435 .33252 .16521 Metetra
.8 .901 .913 r
.33252 .16521 .33367 .16435 .32191 .14869 .32049 .15838 Metetra
.965 .754 .567 r
.55652 .34936 .55742 .33337 .5487 .32092 .54776 .3345 Metetra
.975 .763 .556 r
.52996 .31287 .53094 .29631 .5219 .28847 .5209 .30812 Metetra
.977 .763 .547 r
.5209 .30812 .5219 .28847 .51274 .28039 .51171 .30714 Metetra
.966 .746 .554 r
.51171 .30714 .51274 .28039 .50347 .26843 .50241 .28431 Metetra
.982 .773 .547 r
.50241 .28431 .50347 .26843 .49407 .26016 .49294 .28878 Metetra
.978 .758 .536 r
.49294 .28878 .49407 .26016 .48452 .2555 .48332 .2914 Metetra
.974 .751 .539 r
.48332 .2914 .48452 .2555 .47483 .25161 .47359 .28361 Metetra
.976 .754 .538 r
.47359 .28361 .47483 .25161 .46494 .25467 .46369 .28114 Metetra
.976 .757 .543 r
.46369 .28114 .46494 .25467 .45486 .25896 .45363 .27752 Metetra
.966 .752 .564 r
.45363 .27752 .45486 .25896 .4448 .24453 .44357 .25985 Metetra
.97 .761 .566 r
.44357 .25985 .4448 .24453 .43464 .22695 .43331 .24889 Metetra
.973 .757 .551 r
.43331 .24889 .43464 .22695 .42433 .21249 .42287 .24033 Metetra
.971 .751 .548 r
.42287 .24033 .42433 .21249 .41388 .19733 .41236 .22621 Metetra
.972 .752 .546 r
.41236 .22621 .41388 .19733 .40323 .18658 .40168 .21439 Metetra
.974 .754 .545 r
.40168 .21439 .40323 .18658 .39244 .17533 .39079 .20522 Metetra
.977 .757 .54 r
.39079 .20522 .39244 .17533 .38115 .18091 .37959 .20352 Metetra
.976 .76 .548 r
.37959 .20352 .38115 .18091 .36982 .17833 .36824 .1998 Metetra
.969 .753 .558 r
.36824 .1998 .36982 .17833 .3583 .17528 .357 .18328 Metetra
.958 .773 .609 r
.357 .18328 .3583 .17528 .34673 .16653 .34555 .16897 Metetra
.943 .871 .738 r
.34555 .16897 .34673 .16653 .33501 .15654 .33367 .16435 Metetra
.956 .772 .613 r
.33367 .16435 .33501 .15654 .3233 .1401 .32191 .14869 Metetra
.543 .679 .928 r
.55742 .33337 .55843 .33341 .54972 .32274 .5487 .32092 Metetra
.975 .698 .436 r
.53094 .29631 .53198 .30513 .52294 .29732 .5219 .28847 Metetra
.976 .698 .436 r
.5219 .28847 .52294 .29732 .51377 .2995 .51274 .28039 Metetra
.979 .724 .477 r
.51274 .28039 .51377 .2995 .50446 .30381 .50347 .26843 Metetra
.976 .731 .5 r
.50347 .26843 .50446 .30381 .49498 .3077 .49407 .26016 Metetra
.975 .733 .507 r
.49407 .26016 .49498 .3077 .48538 .29974 .48452 .2555 Metetra
.975 .732 .506 r
.48452 .2555 .48538 .29974 .47565 .29309 .47483 .25161 Metetra
.973 .73 .508 r
.47483 .25161 .47565 .29309 .46577 .28618 .46494 .25467 Metetra
.971 .725 .506 r
.46494 .25467 .46577 .28618 .45569 .28722 .45486 .25896 Metetra
.979 .73 .489 r
.45486 .25896 .45569 .28722 .44563 .26804 .4448 .24453 Metetra
.98 .729 .48 r
.4448 .24453 .44563 .26804 .43535 .25859 .43464 .22695 Metetra
.978 .732 .493 r
.43464 .22695 .43535 .25859 .42492 .24903 .42433 .21249 Metetra
.978 .733 .496 r
.42433 .21249 .42492 .24903 .41437 .23774 .41388 .19733 Metetra
.977 .733 .501 r
.41388 .19733 .41437 .23774 .40368 .22536 .40323 .18658 Metetra
.977 .732 .5 r
.40323 .18658 .40368 .22536 .39286 .21232 .39244 .17533 Metetra
.972 .727 .507 r
.39244 .17533 .39286 .21232 .38184 .20147 .38115 .18091 Metetra
.973 .719 .49 r
.38115 .18091 .38184 .20147 .37063 .19198 .36982 .17833 Metetra
.971 .707 .473 r
.36982 .17833 .37063 .19198 .35908 .1898 .3583 .17528 Metetra
.976 .713 .467 r
.3583 .17528 .35908 .1898 .34771 .17251 .34673 .16653 Metetra
.97 .664 .378 r
.34673 .16653 .34771 .17251 .33605 .16014 .33501 .15654 Metetra
.941 .583 .188 r
.33501 .15654 .33605 .16014 .32415 .14972 .3233 .1401 Metetra
.978 .727 .484 r
.55843 .33341 .55958 .35508 .55085 .34534 .54972 .32274 Metetra
.978 .727 .486 r
.54972 .32274 .55085 .34534 .54201 .33548 .5409 .31261 Metetra
.976 .726 .489 r
.5409 .31261 .54201 .33548 .53306 .32721 .53198 .30513 Metetra
.977 .725 .488 r
.53198 .30513 .53306 .32721 .52399 .31685 .52294 .29732 Metetra
.97 .717 .496 r
.52294 .29732 .52399 .31685 .51481 .315 .51377 .2995 Metetra
.967 .709 .492 r
.51377 .2995 .51481 .315 .50549 .30822 .50446 .30381 Metetra
.94 .63 .422 r
.50446 .30381 .50549 .30822 .49601 .31121 .49498 .3077 Metetra
.953 .604 .282 r
.49498 .3077 .49601 .31121 .4864 .30923 .48538 .29974 Metetra
.974 .698 .445 r
.48538 .29974 .4864 .30923 .47666 .30102 .47565 .29309 Metetra
.973 .688 .428 r
.47565 .29309 .47666 .30102 .46674 .30066 .46577 .28618 Metetra
.969 .708 .484 r
.46577 .28618 .46674 .30066 .45669 .29509 .45569 .28722 Metetra
.982 .694 .375 r
.45569 .28722 .45669 .29509 .44659 .27968 .44563 .26804 Metetra
.977 .708 .453 r
.44563 .26804 .44659 .27968 .43633 .26729 .43535 .25859 Metetra
.976 .694 .427 r
.43535 .25859 .43633 .26729 .42591 .25639 .42492 .24903 Metetra
.976 .685 .402 r
.42492 .24903 .42591 .25639 .41543 .23943 .41437 .23774 Metetra
.746 .288 0 r
.41437 .23774 .41543 .23943 .40476 .22639 .40368 .22536 Metetra
0 .104 .627 r
.40368 .22536 .40476 .22639 .3939 .21535 .39286 .21232 Metetra
.934 .558 .193 r
.39286 .21232 .3939 .21535 .38288 .20474 .38184 .20147 Metetra
.943 .578 .241 r
.38184 .20147 .38288 .20474 .37168 .1948 .37063 .19198 Metetra
.925 .554 .288 r
.37063 .19198 .37168 .1948 .3602 .18991 .35908 .1898 Metetra
.49 .639 .921 r
.35908 .1898 .3602 .18991 .3487 .1779 .34771 .17251 Metetra
.97 .654 .345 r
.34771 .17251 .3487 .1779 .33701 .16639 .33605 .16014 Metetra
.971 .667 .382 r
.33605 .16014 .33701 .16639 .32508 .15689 .32415 .14972 Metetra
.96 .778 .614 r
.55958 .35508 .56054 .3485 .55182 .33826 .55085 .34534 Metetra
.961 .776 .609 r
.55085 .34534 .55182 .33826 .543 .33012 .54201 .33548 Metetra
.959 .79 .63 r
.54201 .33548 .543 .33012 .53407 .32121 .53306 .32721 Metetra
.957 .78 .623 r
.53306 .32721 .53407 .32121 .52502 .31471 .52399 .31685 Metetra
.95 .89 .736 r
.52399 .31685 .52502 .31471 .51584 .30833 .51481 .315 Metetra
.967 .788 .609 r
.51481 .315 .51584 .30833 .50653 .30562 .50549 .30822 Metetra
.973 .907 .685 r
.50549 .30822 .50653 .30562 .49709 .29738 .49601 .31121 Metetra
.977 .771 .559 r
.49601 .31121 .49709 .29738 .4875 .29692 .4864 .30923 Metetra
.971 .767 .573 r
.4864 .30923 .4875 .29692 .47779 .2871 .47666 .30102 Metetra
.979 .773 .558 r
.47666 .30102 .47779 .2871 .46794 .2799 .46674 .30066 Metetra
.975 .76 .55 r
.46674 .30066 .46794 .2799 .45794 .27321 .45669 .29509 Metetra
.969 .753 .556 r
.45669 .29509 .45794 .27321 .44784 .26156 .44659 .27968 Metetra
.97 .757 .56 r
.44659 .27968 .44784 .26156 .43757 .25264 .43633 .26729 Metetra
.97 .762 .568 r
.43633 .26729 .43757 .25264 .4272 .24056 .42591 .25639 Metetra
.965 .756 .57 r
.42591 .25639 .4272 .24056 .41668 .22822 .41543 .23943 Metetra
.965 .765 .584 r
.41543 .23943 .41668 .22822 .40597 .21918 .40476 .22639 Metetra
.961 .78 .612 r
.40476 .22639 .40597 .21918 .39513 .20815 .3939 .21535 Metetra
.962 .782 .612 r
.3939 .21535 .39513 .20815 .38411 .19849 .38288 .20474 Metetra
.961 .789 .624 r
.38288 .20474 .38411 .19849 .37298 .18638 .37168 .1948 Metetra
.973 .788 .593 r
.37168 .1948 .37298 .18638 .36148 .18298 .3602 .18991 Metetra
.96 .782 .618 r
.3602 .18991 .36148 .18298 .34999 .17096 .3487 .1779 Metetra
.961 .783 .618 r
.3487 .1779 .34999 .17096 .33831 .16004 .33701 .16639 Metetra
.963 .792 .623 r
.33701 .16639 .33831 .16004 .32653 .14595 .32508 .15689 Metetra
.953 .605 .249 r
.56054 .3485 .56158 .35203 .55286 .34218 .55182 .33826 Metetra
.961 .626 .308 r
.55182 .33826 .55286 .34218 .54403 .33134 .543 .33012 Metetra
.638 .144 0 r
.543 .33012 .54403 .33134 .53509 .323 .53407 .32121 Metetra
.867 .425 .044 r
.53407 .32121 .53509 .323 .52605 .31611 .52502 .31471 Metetra
.793 .307 0 r
.52502 .31471 .52605 .31611 .51687 .31138 .51584 .30833 Metetra
.939 .585 .314 r
.51584 .30833 .51687 .31138 .50757 .30673 .50653 .30562 Metetra
.61 .097 0 r
.50653 .30562 .50757 .30673 .49812 .3064 .49709 .29738 Metetra
.966 .69 .459 r
.49709 .29738 .49812 .3064 .48852 .30399 .4875 .29692 Metetra
.975 .684 .402 r
.4875 .29692 .48852 .30399 .47881 .29448 .47779 .2871 Metetra
.972 .684 .419 r
.47779 .2871 .47881 .29448 .46897 .28486 .46794 .2799 Metetra
.965 .649 .367 r
.46794 .2799 .46897 .28486 .45885 .29314 .45794 .27321 Metetra
.978 .724 .478 r
.45794 .27321 .45885 .29314 .44882 .27147 .44784 .26156 Metetra
.976 .701 .441 r
.44784 .26156 .44882 .27147 .43857 .25973 .43757 .25264 Metetra
.976 .683 .392 r
.43757 .25264 .43857 .25973 .4282 .24693 .4272 .24056 Metetra
.975 .674 .374 r
.4272 .24056 .4282 .24693 .41765 .23699 .41668 .22822 Metetra
.975 .693 .429 r
.41668 .22822 .41765 .23699 .40698 .2248 .40597 .21918 Metetra
.971 .661 .36 r
.40597 .21918 .40698 .2248 .39615 .21288 .39513 .20815 Metetra
.965 .64 .336 r
.39513 .20815 .39615 .21288 .38511 .20433 .38411 .19849 Metetra
.972 .664 .361 r
.38411 .19849 .38511 .20433 .37382 .19911 .37298 .18638 Metetra
.971 .705 .468 r
.37298 .18638 .37382 .19911 .36238 .19251 .36148 .18298 Metetra
.977 .698 .428 r
.36148 .18298 .36238 .19251 .35091 .1793 .34999 .17096 Metetra
.975 .689 .417 r
.34999 .17096 .35091 .1793 .33921 .16856 .33831 .16004 Metetra
.978 .693 .409 r
.33831 .16004 .33921 .16856 .32742 .15478 .32653 .14595 Metetra
.645 .771 .94 r
.56158 .35203 .56258 .35179 .55386 .34077 .55286 .34218 Metetra
.862 .807 .795 r
.55286 .34218 .55386 .34077 .54505 .33178 .54403 .33134 Metetra
.076 .495 .897 r
.54403 .33134 .54505 .33178 .53612 .32391 .53509 .323 Metetra
.533 0 0 r
.53509 .323 .53612 .32391 .52708 .31704 .52605 .31611 Metetra
.654 .108 0 r
.52605 .31611 .52708 .31704 .51791 .3122 .51687 .31138 Metetra
.587 .027 0 r
.51687 .31138 .51791 .3122 .50861 .30633 .50757 .30673 Metetra
.527 .915 .924 r
.50757 .30673 .50861 .30633 .49916 .30756 .49812 .3064 Metetra
.788 .289 0 r
.49812 .3064 .49916 .30756 .48956 .30872 .48852 .30399 Metetra
.967 .646 .336 r
.48852 .30399 .48956 .30872 .47984 .3005 .47881 .29448 Metetra
.973 .67 .38 r
.47881 .29448 .47984 .3005 .46995 .29816 .46897 .28486 Metetra
.962 .7 .491 r
.46897 .28486 .46995 .29816 .45978 .31085 .45885 .29314 Metetra
.984 .727 .458 r
.45885 .29314 .45978 .31085 .44979 .28229 .44882 .27147 Metetra
.979 .706 .44 r
.44882 .27147 .44979 .28229 .43955 .2692 .43857 .25973 Metetra
.979 .701 .425 r
.43857 .25973 .43955 .2692 .42927 .24829 .4282 .24693 Metetra
.687 .194 0 r
.4282 .24693 .42927 .24829 .41874 .23676 .41765 .23699 Metetra
.623 .76 .944 r
.41765 .23699 .41874 .23676 .40806 .22584 .40698 .2248 Metetra
0 .07 .583 r
.40698 .2248 .40806 .22584 .39719 .21644 .39615 .21288 Metetra
.95 .597 .277 r
.39615 .21288 .39719 .21644 .38622 .20393 .38511 .20433 Metetra
.632 .893 .986 r
.38511 .20433 .38622 .20393 .37495 .19827 .37382 .19911 Metetra
.799 .9 .913 r
.37382 .19911 .37495 .19827 .36354 .19088 .36238 .19251 Metetra
.868 .815 .795 r
.36238 .19251 .36354 .19088 .35202 .18002 .35091 .1793 Metetra
0 .274 .738 r
.35091 .1793 .35202 .18002 .34033 .16902 .33921 .16856 Metetra
.179 .516 .916 r
.33921 .16856 .34033 .16902 .32846 .15809 .32742 .15478 Metetra
.968 .646 .313 r
.56258 .35179 .56363 .35637 .5549 .34446 .55386 .34077 Metetra
.957 .615 .28 r
.55386 .34077 .5549 .34446 .54607 .33312 .54505 .33178 Metetra
.733 .242 0 r
.54505 .33178 .54607 .33312 .53715 .3253 .53612 .32391 Metetra
.78 .293 0 r
.53612 .32391 .53715 .3253 .52811 .31762 .52708 .31704 Metetra
.366 0 0 r
.52708 .31704 .52811 .31762 .51894 .3094 .51791 .3122 Metetra
.946 .836 .703 r
.51791 .3122 .51894 .3094 .50966 .29859 .50861 .30633 Metetra
.982 .799 .582 r
.50861 .30633 .50966 .29859 .50024 .29256 .49916 .30756 Metetra
.98 .772 .552 r
.49916 .30756 .50024 .29256 .49067 .29148 .48956 .30872 Metetra
.973 .761 .557 r
.48956 .30872 .49067 .29148 .48098 .28456 .47984 .3005 Metetra
.977 .768 .554 r
.47984 .3005 .48098 .28456 .47113 .27969 .46995 .29816 Metetra
.986 .775 .534 r
.46995 .29816 .47113 .27969 .46114 .27472 .45978 .31085 Metetra
.968 .744 .547 r
.45978 .31085 .46114 .27472 .45105 .26265 .44979 .28229 Metetra
.97 .756 .557 r
.44979 .28229 .45105 .26265 .44086 .24797 .43955 .2692 Metetra
.966 .75 .56 r
.43955 .2692 .44086 .24797 .43052 .23534 .42927 .24829 Metetra
.969 .764 .574 r
.42927 .24829 .43052 .23534 .42 .22498 .41874 .23676 Metetra
.968 .767 .578 r
.41874 .23676 .42 .22498 .40932 .2154 .40806 .22584 Metetra
.969 .773 .584 r
.40806 .22584 .40932 .2154 .39848 .206 .39719 .21644 Metetra
.966 .769 .588 r
.39719 .21644 .39848 .206 .38749 .19546 .38622 .20393 Metetra
.973 .786 .593 r
.38622 .20393 .38749 .19546 .3763 .18697 .37495 .19827 Metetra
.972 .774 .578 r
.37495 .19827 .3763 .18697 .36484 .18265 .36354 .19088 Metetra
.965 .779 .603 r
.36354 .19088 .36484 .18265 .35333 .17241 .35202 .18002 Metetra
.964 .782 .609 r
.35202 .18002 .35333 .17241 .34165 .16221 .34033 .16902 Metetra
.962 .786 .619 r
.34033 .16902 .34165 .16221 .32991 .14696 .32846 .15809 Metetra
.968 .759 .568 r
.56363 .35637 .56453 .34211 .55584 .3323 .5549 .34446 Metetra
.967 .762 .575 r
.5549 .34446 .55584 .3323 .54704 .32225 .54607 .33312 Metetra
.97 .769 .577 r
.54607 .33312 .54704 .32225 .53813 .31465 .53715 .3253 Metetra
.97 .77 .578 r
.53715 .3253 .53813 .31465 .52911 .30679 .52811 .31762 Metetra
.97 .77 .578 r
.52811 .31762 .52911 .30679 .51997 .29868 .51894 .3094 Metetra
.967 .766 .582 r
.51894 .3094 .51997 .29868 .5107 .28408 .50966 .29859 Metetra
.974 .766 .561 r
.50966 .29859 .5107 .28408 .50131 .27717 .50024 .29256 Metetra
.978 .769 .553 r
.50024 .29256 .50131 .27717 .49178 .2752 .49067 .29148 Metetra
.974 .763 .558 r
.49067 .29148 .49178 .2752 .48209 .27203 .48098 .28456 Metetra
.975 .771 .567 r
.48098 .28456 .48209 .27203 .47225 .27131 .47113 .27969 Metetra
.973 .785 .59 r
.47113 .27969 .47225 .27131 .46223 .27196 .46114 .27472 Metetra
.919 .802 .715 r
.46114 .27472 .46223 .27196 .45214 .26148 .45105 .26265 Metetra
.819 .782 .818 r
.45105 .26265 .45214 .26148 .44198 .24485 .44086 .24797 Metetra
.925 .798 .701 r
.44086 .24797 .44198 .24485 .43165 .23168 .43052 .23534 Metetra
.942 .806 .68 r
.43052 .23534 .43165 .23168 .42116 .22016 .42 .22498 Metetra
.955 .799 .647 r
.42 .22498 .42116 .22016 .41055 .20659 .40932 .2154 Metetra
.968 .778 .595 r
.40932 .2154 .41055 .20659 .39969 .19967 .39848 .206 Metetra
.96 .787 .623 r
.39848 .206 .39969 .19967 .38855 .19803 .38749 .19546 Metetra
.918 .52 .166 r
.38749 .19546 .38855 .19803 .37732 .19173 .3763 .18697 Metetra
.957 .636 .371 r
.3763 .18697 .37732 .19173 .36589 .1859 .36484 .18265 Metetra
.941 .573 .227 r
.36484 .18265 .36589 .1859 .35437 .17598 .35333 .17241 Metetra
.948 .591 .257 r
.35333 .17241 .35437 .17598 .34249 .17328 .34165 .16221 Metetra
.98 .706 .433 r
.34165 .16221 .34249 .17328 .3309 .15262 .32991 .14696 Metetra
.976 .684 .396 r
.56453 .34211 .56559 .34889 .55688 .33705 .55584 .3323 Metetra
.969 .65 .331 r
.55584 .3323 .55688 .33705 .54808 .32655 .54704 .32225 Metetra
.964 .638 .333 r
.54704 .32225 .54808 .32655 .53918 .32027 .53813 .31465 Metetra
.971 .667 .38 r
.53813 .31465 .53918 .32027 .53015 .31123 .52911 .30679 Metetra
.965 .641 .335 r
.52911 .30679 .53015 .31123 .52101 .31116 .51997 .29868 Metetra
.982 .715 .444 r
.51997 .29868 .52101 .31116 .51173 .30873 .5107 .28408 Metetra
.976 .726 .49 r
.5107 .28408 .51173 .30873 .5023 .31358 .50131 .27717 Metetra
.975 .73 .502 r
.50131 .27717 .5023 .31358 .49261 .34383 .49178 .2752 Metetra
.976 .736 .509 r
.49178 .2752 .49261 .34383 .48281 .34694 .48209 .27203 Metetra
.975 .736 .511 r
.48209 .27203 .48281 .34694 .47312 .30317 .47225 .27131 Metetra
.973 .727 .501 r
.47225 .27131 .47312 .30317 .46277 .3422 .46223 .27196 Metetra
.977 .737 .507 r
.46223 .27196 .46277 .3422 .45274 .31397 .45214 .26148 Metetra
.978 .736 .501 r
.45214 .26148 .45274 .31397 .4428 .2692 .44198 .24485 Metetra
.979 .728 .483 r
.44198 .24485 .4428 .2692 .43241 .2579 .43165 .23168 Metetra
.978 .728 .487 r
.43165 .23168 .43241 .2579 .4219 .2456 .42116 .22016 Metetra
.979 .728 .485 r
.42116 .22016 .4219 .2456 .41131 .22825 .41055 .20659 Metetra
.976 .722 .485 r
.41055 .20659 .41131 .22825 .40049 .21695 .39969 .19967 Metetra
.972 .714 .483 r
.39969 .19967 .40049 .21695 .38945 .20927 .38855 .19803 Metetra
.973 .702 .454 r
.38855 .19803 .38945 .20927 .37827 .19973 .37732 .19173 Metetra
.97 .683 .428 r
.37732 .19173 .37827 .19973 .36687 .19258 .36589 .1859 Metetra
.972 .673 .391 r
.36589 .1859 .36687 .19258 .3554 .18036 .35437 .17598 Metetra
.951 .623 .365 r
.35437 .17598 .3554 .18036 .34375 .16843 .34249 .17328 Metetra
.929 .767 .661 r
.34249 .17328 .34375 .16843 .33193 .15636 .3309 .15262 Metetra
.974 .666 .344 r
.56559 .34889 .56664 .35435 .55793 .34278 .55688 .33705 Metetra
.974 .67 .364 r
.55688 .33705 .55793 .34278 .54914 .33531 .54808 .32655 Metetra
.974 .696 .438 r
.54808 .32655 .54914 .33531 .54023 .32778 .53918 .32027 Metetra
.976 .689 .412 r
.53918 .32027 .54023 .32778 .5312 .3207 .53015 .31123 Metetra
.967 .693 .462 r
.53015 .31123 .5312 .3207 .52205 .31447 .52101 .31116 Metetra
.944 .598 .332 r
.52101 .31116 .52205 .31447 .51277 .31867 .51173 .30873 Metetra
.961 .69 .476 r
.51173 .30873 .51277 .31867 .50334 .32057 .5023 .31358 Metetra
.907 .636 .516 r
.5023 .31358 .50334 .32057 .49371 .33266 .49261 .34383 Metetra
.983 .786 .56 r
.49261 .34383 .49371 .33266 .48403 .31315 .48281 .34694 Metetra
.961 .738 .555 r
.48281 .34694 .48403 .31315 .47418 .30466 .47312 .30317 Metetra
.73 .444 .495 r
.47312 .30317 .47418 .30466 .46401 .32054 .46277 .3422 Metetra
.962 .745 .564 r
.46277 .3422 .46401 .32054 .45405 .28805 .45274 .31397 Metetra
.956 .736 .565 r
.45274 .31397 .45405 .28805 .44373 .28361 .4428 .2692 Metetra
.979 .716 .461 r
.4428 .2692 .44373 .28361 .43361 .24913 .43241 .2579 Metetra
.963 .772 .598 r
.43241 .2579 .43361 .24913 .42311 .23694 .4219 .2456 Metetra
.955 .764 .605 r
.4219 .2456 .42311 .23694 .41242 .22779 .41131 .22825 Metetra
.701 .804 .929 r
.41131 .22825 .41242 .22779 .40157 .2184 .40049 .21695 Metetra
.777 .285 0 r
.40049 .21695 .40157 .2184 .39056 .20908 .38945 .20927 Metetra
.575 .795 .983 r
.38945 .20927 .39056 .20908 .37939 .19962 .37827 .19973 Metetra
.479 .801 1 r
.37827 .19973 .37939 .19962 .36757 .2116 .36687 .19258 Metetra
.978 .721 .474 r
.36687 .19258 .36757 .2116 .35615 .19631 .3554 .18036 Metetra
.978 .717 .465 r
.3554 .18036 .35615 .19631 .34465 .1776 .34375 .16843 Metetra
.977 .695 .422 r
.34375 .16843 .34465 .1776 .33297 .15994 .33193 .15636 Metetra
.941 .784 .658 r
.56664 .35435 .56762 .35013 .55893 .34031 .55793 .34278 Metetra
.932 .827 .72 r
.55793 .34278 .55893 .34031 .55015 .33251 .54914 .33531 Metetra
.939 .822 .703 r
.54914 .33531 .55015 .33251 .54125 .32492 .54023 .32778 Metetra
.942 .825 .7 r
.54023 .32778 .54125 .32492 .53223 .31711 .5312 .3207 Metetra
.955 .819 .67 r
.5312 .3207 .53223 .31711 .52309 .31129 .52205 .31447 Metetra
.983 .888 .648 r
.52205 .31447 .52309 .31129 .51382 .30783 .51277 .31867 Metetra
.982 .785 .562 r
.51277 .31867 .51382 .30783 .50441 .30248 .50334 .32057 Metetra
.987 .775 .533 r
.50334 .32057 .50441 .30248 .49487 .29582 .49371 .33266 Metetra
.971 .747 .542 r
.49371 .33266 .49487 .29582 .48519 .28889 .48403 .31315 Metetra
.974 .756 .546 r
.48403 .31315 .48519 .28889 .47537 .28294 .47418 .30466 Metetra
.987 .772 .528 r
.47418 .30466 .47537 .28294 .4654 .27738 .46401 .32054 Metetra
.968 .743 .543 r
.46401 .32054 .4654 .27738 .45534 .26476 .45405 .28805 Metetra
.976 .759 .544 r
.45405 .28805 .45534 .26476 .44513 .25327 .44373 .28361 Metetra
.964 .742 .554 r
.44373 .28361 .44513 .25327 .43471 .24772 .43361 .24913 Metetra
.856 .815 .809 r
.43361 .24913 .43471 .24772 .42421 .23658 .42311 .23694 Metetra
.66 .825 .963 r
.42311 .23694 .42421 .23658 .41354 .22613 .41242 .22779 Metetra
.889 .846 .795 r
.41242 .22779 .41354 .22613 .40275 .21412 .40157 .2184 Metetra
.953 .807 .661 r
.40157 .2184 .40275 .21412 .39179 .20302 .39056 .20908 Metetra
.962 .792 .625 r
.39056 .20908 .39179 .20302 .38066 .19189 .37939 .19962 Metetra
.994 .824 .564 r
.37939 .19962 .38066 .19189 .36918 .18958 .36757 .2116 Metetra
.971 .755 .554 r
.36757 .2116 .36918 .18958 .35776 .17574 .35615 .19631 Metetra
.968 .754 .559 r
.35615 .19631 .35776 .17574 .3461 .16541 .34465 .1776 Metetra
.963 .761 .583 r
.34465 .1776 .3461 .16541 .3342 .15689 .33297 .15994 Metetra
.839 .818 .83 r
.56762 .35013 .56862 .34903 .55992 .33671 .55893 .34031 Metetra
.949 .808 .671 r
.55893 .34031 .55992 .33671 .55114 .32783 .55015 .33251 Metetra
.958 .799 .641 r
.55015 .33251 .55114 .32783 .54225 .31941 .54125 .32492 Metetra
.962 .792 .626 r
.54125 .32492 .54225 .31941 .53325 .31395 .53223 .31711 Metetra
.952 .829 .685 r
.53223 .31711 .53325 .31395 .52412 .30994 .52309 .31129 Metetra
.899 .914 .824 r
.52309 .31129 .52412 .30994 .51486 .30882 .51382 .30783 Metetra
.66 .121 0 r
.51382 .30783 .51486 .30882 .50546 .30505 .50441 .30248 Metetra
.925 .536 .197 r
.50441 .30248 .50546 .30505 .49588 .31111 .49487 .29582 Metetra
.976 .716 .471 r
.49487 .29582 .49588 .31111 .48618 .30795 .48519 .28889 Metetra
.976 .72 .482 r
.48519 .28889 .48618 .30795 .4763 .30851 .47537 .28294 Metetra
.976 .726 .491 r
.47537 .28294 .4763 .30851 .46625 .30831 .4654 .27738 Metetra
.979 .731 .491 r
.4654 .27738 .46625 .30831 .45629 .27891 .45534 .26476 Metetra
.979 .715 .459 r
.45534 .26476 .45629 .27891 .4461 .26494 .44513 .25327 Metetra
.974 .704 .458 r
.44513 .25327 .4461 .26494 .43581 .24683 .43471 .24772 Metetra
.799 .824 .871 r
.43471 .24772 .43581 .24683 .4253 .23642 .42421 .23658 Metetra
.576 .771 .971 r
.42421 .23658 .4253 .23642 .41466 .2249 .41354 .22613 Metetra
.839 .821 .83 r
.41354 .22613 .41466 .2249 .40383 .21554 .40275 .21412 Metetra
.683 .198 0 r
.40275 .21412 .40383 .21554 .39286 .20486 .39179 .20302 Metetra
.813 .359 0 r
.39179 .20302 .39286 .20486 .38169 .19628 .38066 .19189 Metetra
.951 .624 .368 r
.38066 .19189 .38169 .19628 .37017 .19582 .36918 .18958 Metetra
.974 .669 .36 r
.36918 .18958 .37017 .19582 .3588 .17962 .35776 .17574 Metetra
.954 .606 .278 r
.35776 .17574 .3588 .17962 .3472 .16687 .3461 .16541 Metetra
.764 .268 0 r
.3461 .16541 .3472 .16687 .33534 .15676 .3342 .15689 Metetra
.958 .62 .251 r
.56862 .34903 .56967 .35299 .56098 .34241 .55992 .33671 Metetra
.973 .669 .373 r
.55992 .33671 .56098 .34241 .55218 .33184 .55114 .32783 Metetra
.961 .627 .306 r
.55114 .32783 .55218 .33184 .54328 .31994 .54225 .31941 Metetra
0 .295 .693 r
.54225 .31941 .54328 .31994 .53428 .31477 .53325 .31395 Metetra
.609 .048 0 r
.53325 .31395 .53428 .31477 .52516 .31388 .52412 .30994 Metetra
.949 .622 .372 r
.52412 .30994 .52516 .31388 .51591 .31498 .51486 .30882 Metetra
.966 .669 .412 r
.51486 .30882 .51591 .31498 .5065 .31253 .50546 .30505 Metetra
.954 .672 .464 r
.50546 .30505 .5065 .31253 .49693 .31715 .49588 .31111 Metetra
.964 .666 .412 r
.49588 .31111 .49693 .31715 .48721 .31652 .48618 .30795 Metetra
.965 .685 .455 r
.48618 .30795 .48721 .31652 .47735 .31139 .4763 .30851 Metetra
.927 .567 .321 r
.4763 .30851 .47735 .31139 .46734 .30726 .46625 .30831 Metetra
.745 .66 .767 r
.46625 .30831 .46734 .30726 .45723 .29561 .45629 .27891 Metetra
.98 .721 .464 r
.45629 .27891 .45723 .29561 .44717 .26624 .4461 .26494 Metetra
0 .087 .642 r
.4461 .26494 .44717 .26624 .4369 .2465 .43581 .24683 Metetra
.656 .8 .951 r
.43581 .24683 .4369 .2465 .4264 .23637 .4253 .23642 Metetra
.534 .734 .967 r
.4253 .23642 .4264 .23637 .41573 .22703 .41466 .2249 Metetra
.878 .449 .051 r
.41466 .2249 .41573 .22703 .40498 .213 .40383 .21554 Metetra
.921 .822 .731 r
.40383 .21554 .40498 .213 .39391 .20832 .39286 .20486 Metetra
.947 .589 .264 r
.39286 .20486 .39391 .20832 .38281 .19598 .38169 .19628 Metetra
.392 .847 .897 r
.38169 .19628 .38281 .19598 .37143 .18924 .37017 .19582 Metetra
.951 .774 .626 r
.37017 .19582 .37143 .18924 .35994 .17927 .3588 .17962 Metetra
.659 .782 .939 r
.3588 .17962 .35994 .17927 .34827 .16933 .3472 .16687 Metetra
.902 .492 .112 r
.3472 .16687 .34827 .16933 .33642 .15913 .33534 .15676 Metetra
.935 .567 .179 r
.56967 .35299 .5707 .35602 .562 .34279 .56098 .34241 Metetra
.253 .557 .933 r
.56098 .34241 .562 .34279 .55323 .33653 .55218 .33184 Metetra
.968 .647 .307 r
.55218 .33184 .55323 .33653 .54434 .3288 .54328 .31994 Metetra
.973 .695 .442 r
.54328 .31994 .54434 .3288 .53533 .32003 .53428 .31477 Metetra
.958 .654 .411 r
.53428 .31477 .53533 .32003 .52619 .30884 .52516 .31388 Metetra
.983 .828 .613 r
.52516 .31388 .52619 .30884 .51694 .30052 .51591 .31498 Metetra
.978 .77 .556 r
.51591 .31498 .51694 .30052 .50756 .29715 .5065 .31253 Metetra
.983 .775 .545 r
.5065 .31253 .50756 .29715 .49803 .29688 .49693 .31715 Metetra
.979 .764 .544 r
.49693 .31715 .49803 .29688 .48835 .29553 .48721 .31652 Metetra
.976 .76 .547 r
.48721 .31652 .48835 .29553 .47854 .28829 .47735 .31139 Metetra
.977 .759 .544 r
.47735 .31139 .47854 .28829 .46856 .28574 .46734 .30726 Metetra
.972 .756 .551 r
.46734 .30726 .46856 .28574 .4585 .2734 .45723 .29561 Metetra
.962 .745 .562 r
.45723 .29561 .4585 .2734 .44836 .25499 .44717 .26624 Metetra
.958 .757 .589 r
.44717 .26624 .44836 .25499 .43807 .23991 .4369 .2465 Metetra
.962 .785 .617 r
.4369 .2465 .43807 .23991 .42758 .22939 .4264 .23637 Metetra
.965 .786 .611 r
.4264 .23637 .42758 .22939 .41696 .21808 .41573 .22703 Metetra
.962 .77 .598 r
.41573 .22703 .41696 .21808 .40614 .20985 .40498 .213 Metetra
.957 .848 .694 r
.40498 .213 .40614 .20985 .39513 .2026 .39391 .20832 Metetra
.955 .787 .634 r
.39391 .20832 .39513 .2026 .38383 .2013 .38281 .19598 Metetra
.964 .65 .372 r
.38281 .19598 .38383 .2013 .37241 .19614 .37143 .18924 Metetra
.973 .675 .394 r
.37143 .18924 .37241 .19614 .36105 .18027 .35994 .17927 Metetra
.504 0 0 r
.35994 .17927 .36105 .18027 .34947 .16664 .34827 .16933 Metetra
.928 .83 .728 r
.34827 .16933 .34947 .16664 .33772 .15338 .33642 .15913 Metetra
.953 .77 .618 r
.5707 .35602 .57166 .3494 .56297 .33699 .562 .34279 Metetra
.967 .794 .617 r
.562 .34279 .56297 .33699 .55421 .32924 .55323 .33653 Metetra
.967 .782 .601 r
.55323 .33653 .55421 .32924 .54534 .32153 .54434 .3288 Metetra
.965 .78 .604 r
.54434 .3288 .54534 .32153 .53634 .31379 .53533 .32003 Metetra
.957 .779 .62 r
.53533 .32003 .53634 .31379 .52721 .29875 .52619 .30884 Metetra
.97 .772 .581 r
.52619 .30884 .52721 .29875 .51797 .28401 .51694 .30052 Metetra
.977 .766 .552 r
.51694 .30052 .51797 .28401 .50863 .2758 .50756 .29715 Metetra
.979 .763 .541 r
.50756 .29715 .50863 .2758 .49913 .27782 .49803 .29688 Metetra
.979 .764 .546 r
.49803 .29688 .49913 .27782 .48947 .27817 .48835 .29553 Metetra
.974 .762 .555 r
.48835 .29553 .48947 .27817 .47968 .27404 .47854 .28829 Metetra
.978 .771 .557 r
.47854 .28829 .47968 .27404 .46972 .27318 .46856 .28574 Metetra
.968 .764 .575 r
.46856 .28574 .46972 .27318 .45968 .26023 .4585 .2734 Metetra
.962 .756 .578 r
.4585 .2734 .45968 .26023 .44955 .24365 .44836 .25499 Metetra
.964 .763 .584 r
.44836 .25499 .44955 .24365 .43927 .22958 .43807 .23991 Metetra
.968 .771 .584 r
.43807 .23991 .43927 .22958 .42881 .21932 .42758 .22939 Metetra
.967 .771 .587 r
.42758 .22939 .42881 .21932 .41827 .20373 .41696 .21808 Metetra
.973 .767 .564 r
.41696 .21808 .41827 .20373 .40745 .19661 .40614 .20985 Metetra
.974 .77 .567 r
.40614 .20985 .40745 .19661 .39642 .19237 .39513 .2026 Metetra
.979 .786 .573 r
.39513 .2026 .39642 .19237 .38497 .19986 .38383 .2013 Metetra
.891 .906 .83 r
.38383 .2013 .38497 .19986 .37364 .19145 .37241 .19614 Metetra
.939 .783 .659 r
.37241 .19614 .37364 .19145 .36203 .18663 .36105 .18027 Metetra
.974 .67 .364 r
.36105 .18027 .36203 .18663 .35024 .18169 .34947 .16664 Metetra
.979 .716 .458 r
.34947 .16664 .35024 .18169 .33885 .15367 .33772 .15338 Metetra
.724 .758 .879 r
.57166 .3494 .57267 .34891 .56399 .33795 .56297 .33699 Metetra
.519 .001 0 r
.56297 .33699 .56399 .33795 .55523 .32925 .55421 .32924 Metetra
.466 .744 .989 r
.55421 .32924 .55523 .32925 .54636 .32154 .54534 .32153 Metetra
.464 .745 .99 r
.54534 .32153 .54636 .32154 .53738 .31484 .53634 .31379 Metetra
0 .204 .731 r
.53634 .31379 .53738 .31484 .52827 .31155 .52721 .29875 Metetra
.982 .716 .443 r
.52721 .29875 .52827 .31155 .51904 .30945 .51797 .28401 Metetra
.978 .727 .488 r
.51797 .28401 .51904 .30945 .50965 .31384 .50863 .2758 Metetra
.974 .729 .504 r
.50863 .2758 .50965 .31384 .50012 .30946 .49913 .27782 Metetra
.974 .727 .5 r
.49913 .27782 .50012 .30946 .49045 .30113 .48947 .27817 Metetra
.975 .723 .489 r
.48947 .27817 .49045 .30113 .48065 .29321 .47968 .27404 Metetra
.973 .718 .487 r
.47968 .27404 .48065 .29321 .47064 .29694 .46972 .27318 Metetra
.979 .728 .481 r
.46972 .27318 .47064 .29694 .46063 .27665 .45968 .26023 Metetra
.982 .722 .458 r
.45968 .26023 .46063 .27665 .45041 .26727 .44955 .24365 Metetra
.98 .728 .479 r
.44955 .24365 .45041 .26727 .44006 .2569 .43927 .22958 Metetra
.978 .728 .488 r
.43927 .22958 .44006 .2569 .42966 .23865 .42881 .21932 Metetra
.981 .725 .469 r
.42881 .21932 .42966 .23865 .41909 .22332 .41827 .20373 Metetra
.976 .72 .479 r
.41827 .20373 .41909 .22332 .40828 .21399 .40745 .19661 Metetra
.974 .716 .478 r
.40745 .19661 .40828 .21399 .39731 .20489 .39642 .19237 Metetra
.962 .696 .482 r
.39642 .19237 .39731 .20489 .38618 .19516 .38497 .19986 Metetra
.959 .808 .65 r
.38497 .19986 .38618 .19516 .37482 .18864 .37364 .19145 Metetra
.951 .86 .714 r
.37364 .19145 .37482 .18864 .36335 .17879 .36203 .18663 Metetra
.974 .793 .597 r
.36203 .18663 .36335 .17879 .35176 .16618 .35024 .18169 Metetra
.959 .749 .577 r
.35024 .18169 .35176 .16618 .33994 .15583 .33885 .15367 Metetra
.976 .675 .368 r
.57267 .34891 .57373 .355 .56506 .34468 .56399 .33795 Metetra
.975 .682 .397 r
.56399 .33795 .56506 .34468 .5563 .33702 .55523 .32925 Metetra
.975 .69 .419 r
.55523 .32925 .5563 .33702 .54743 .32914 .54636 .32154 Metetra
.974 .688 .421 r
.54636 .32154 .54743 .32914 .53843 .3217 .53738 .31484 Metetra
.968 .677 .425 r
.53738 .31484 .53843 .3217 .52932 .31385 .52827 .31155 Metetra
.915 .525 .247 r
.52827 .31155 .52932 .31385 .5201 .32817 .51904 .30945 Metetra
.97 .715 .493 r
.51904 .30945 .5201 .32817 .5107 .3263 .50965 .31384 Metetra
.974 .708 .464 r
.50965 .31384 .5107 .3263 .50116 .31858 .50012 .30946 Metetra
.976 .697 .431 r
.50012 .30946 .50116 .31858 .49147 .31631 .49045 .30113 Metetra
.977 .716 .467 r
.49045 .30113 .49147 .31631 .48164 .31041 .48065 .29321 Metetra
.969 .712 .489 r
.48065 .29321 .48164 .31041 .47166 .3065 .47064 .29694 Metetra
.984 .705 .395 r
.47064 .29694 .47166 .3065 .46158 .29337 .46063 .27665 Metetra
.978 .719 .47 r
.46063 .27665 .46158 .29337 .45137 .28179 .45041 .26727 Metetra
.978 .715 .46 r
.45041 .26727 .45137 .28179 .44108 .2636 .44006 .2569 Metetra
.978 .679 .344 r
.44006 .2569 .44108 .2636 .43059 .25141 .42966 .23865 Metetra
.981 .714 .442 r
.42966 .23865 .43059 .25141 .41997 .23871 .41909 .22332 Metetra
.977 .715 .465 r
.41909 .22332 .41997 .23871 .40928 .22061 .40828 .21399 Metetra
.972 .673 .391 r
.40828 .21399 .40928 .22061 .39836 .20872 .39731 .20489 Metetra
.954 .606 .277 r
.39731 .20489 .39836 .20872 .38716 .20279 .38618 .19516 Metetra
.971 .68 .418 r
.38618 .19516 .38716 .20279 .37526 .22186 .37482 .18864 Metetra
.977 .73 .493 r
.37482 .18864 .37526 .22186 .36402 .19893 .36335 .17879 Metetra
.979 .723 .474 r
.36335 .17879 .36402 .19893 .35274 .17266 .35176 .16618 Metetra
.972 .669 .381 r
.35176 .16618 .35274 .17266 .34102 .15838 .33994 .15583 Metetra
.808 .809 .851 r
.57373 .355 .57474 .35411 .56606 .34145 .56506 .34468 Metetra
.946 .815 .684 r
.56506 .34468 .56606 .34145 .55728 .32995 .5563 .33702 Metetra
.966 .783 .604 r
.5563 .33702 .55728 .32995 .54842 .32286 .54743 .32914 Metetra
.966 .788 .613 r
.54743 .32914 .54842 .32286 .53945 .31654 .53843 .3217 Metetra
.961 .796 .632 r
.53843 .3217 .53945 .31654 .53035 .31254 .52932 .31385 Metetra
.52932 .31385 .53035 .31254 .52113 .31041 .5201 .32817 Metetra
.978 .766 .547 r
.5201 .32817 .52113 .31041 .51176 .30403 .5107 .3263 Metetra
.975 .757 .546 r
.5107 .3263 .51176 .30403 .50223 .30991 .50116 .31858 Metetra
.978 .789 .581 r
.50116 .31858 .50223 .30991 .49254 .31475 .49147 .31631 Metetra
.903 .879 .802 r
.49147 .31631 .49254 .31475 .48272 .3096 .48164 .31041 Metetra
.803 .935 .918 r
.48164 .31041 .48272 .3096 .47265 .32 .47166 .3065 Metetra
.98 .715 .45 r
.47166 .3065 .47265 .32 .46268 .29235 .46158 .29337 Metetra
.818 .817 .849 r
.46158 .29337 .46268 .29235 .45248 .2794 .45137 .28179 Metetra
.882 .768 .732 r
.45137 .28179 .45248 .2794 .44207 .27353 .44108 .2636 Metetra
.979 .702 .427 r
.44108 .2636 .44207 .27353 .43167 .25355 .43059 .25141 Metetra
.838 .41 0 r
.43059 .25141 .43167 .25355 .42117 .2316 .41997 .23871 Metetra
.95 .767 .621 r
.41997 .23871 .42117 .2316 .41043 .21799 .40928 .22061 Metetra
.919 .814 .727 r
.40928 .22061 .41043 .21799 .39949 .20736 .39836 .20872 Metetra
.881 .899 .839 r
.39836 .20872 .39949 .20736 .38833 .19985 .38716 .20279 Metetra
.896 .913 .513 r
.38716 .20279 .38833 .19985 .37708 .18822 .37526 .22186 Metetra
.971 .748 .544 r
.37526 .22186 .37708 .18822 .36562 .17831 .36402 .19893 Metetra
.965 .749 .562 r
.36402 .19893 .36562 .17831 .35399 .16823 .35274 .17266 Metetra
.942 .792 .665 r
.35274 .17266 .35399 .16823 .34218 .15766 .34102 .15838 Metetra
.856 .788 .784 r
.57474 .35411 .57574 .35264 .56707 .341 .56606 .34145 Metetra
.715 .771 .896 r
.56606 .34145 .56707 .341 .55831 .33128 .55728 .32995 Metetra
.743 .248 0 r
.55728 .32995 .55831 .33128 .54946 .32435 .54842 .32286 Metetra
.812 .336 0 r
.54842 .32286 .54946 .32435 .54048 .31518 .53945 .31654 Metetra
.899 .905 .82 r
.53945 .31654 .54048 .31518 .53139 .31084 .53035 .31254 Metetra
.931 .912 .778 r
.53035 .31254 .53139 .31084 .52217 .30753 .52113 .31041 Metetra
.946 .834 .701 r
.52113 .31041 .52217 .30753 .51281 .30131 .51176 .30403 Metetra
.977 .92 .656 r
.51176 .30403 .51281 .30131 .50331 .29565 .50223 .30991 Metetra
.984 .778 .546 r
.50223 .30991 .50331 .29565 .49368 .29005 .49254 .31475 Metetra
.977 .758 .541 r
.49254 .31475 .49368 .29005 .48391 .28324 .48272 .3096 Metetra
.984 .765 .528 r
.48272 .3096 .48391 .28324 .47394 .28501 .47265 .32 Metetra
.969 .745 .545 r
.47265 .32 .47394 .28501 .464 .26055 .46268 .29235 Metetra
.974 .751 .54 r
.46268 .29235 .464 .26055 .4538 .25276 .45248 .2794 Metetra
.977 .757 .54 r
.45248 .2794 .4538 .25276 .4435 .24155 .44207 .27353 Metetra
.971 .749 .544 r
.44207 .27353 .4435 .24155 .43302 .23236 .43167 .25355 Metetra
.967 .75 .558 r
.43167 .25355 .43302 .23236 .4224 .2225 .42117 .2316 Metetra
.963 .771 .596 r
.42117 .2316 .4224 .2225 .41161 .21371 .41043 .21799 Metetra
.95 .802 .662 r
.41043 .21799 .41161 .21371 .40066 .20434 .39949 .20736 Metetra
.945 .836 .705 r
.39949 .20736 .40066 .20434 .38955 .19499 .38833 .19985 Metetra
.952 .796 .65 r
.38833 .19985 .38955 .19499 .37821 .1881 .37708 .18822 Metetra
.531 .776 .987 r
.37708 .18822 .37821 .1881 .36676 .17808 .36562 .17831 Metetra
.589 .8 .98 r
.36562 .17831 .36676 .17808 .35519 .16543 .35399 .16823 Metetra
.93 .826 .722 r
.35399 .16823 .35519 .16543 .34347 .15215 .34218 .15766 Metetra
.465 .655 .943 r
.57574 .35264 .57675 .35279 .56805 .33679 .56707 .341 Metetra
.949 .794 .655 r
.56707 .341 .56805 .33679 .55932 .32876 .55831 .33128 Metetra
.936 .833 .717 r
.55831 .33128 .55932 .32876 .55047 .32092 .54946 .32435 Metetra
.943 .806 .679 r
.54946 .32435 .55047 .32092 .5415 .3131 .54048 .31518 Metetra
.937 .871 .746 r
.54048 .31518 .5415 .3131 .53241 .30522 .53139 .31084 Metetra
.974 .807 .614 r
.53139 .31084 .53241 .30522 .52318 .28603 .52217 .30753 Metetra
.976 .759 .545 r
.52217 .30753 .52318 .28603 .51386 .27696 .51281 .30131 Metetra
.976 .757 .542 r
.51281 .30131 .51386 .27696 .5044 .2782 .50331 .29565 Metetra
.976 .763 .552 r
.50331 .29565 .5044 .2782 .49477 .27884 .49368 .29005 Metetra
.973 .773 .573 r
.49368 .29005 .49477 .27884 .48503 .27064 .48391 .28324 Metetra
.982 .78 .555 r
.48391 .28324 .48503 .27064 .47509 .27168 .47394 .28501 Metetra
.957 .75 .582 r
.47394 .28501 .47509 .27168 .46509 .25871 .464 .26055 Metetra
.909 .853 .776 r
.464 .26055 .46509 .25871 .455 .23997 .4538 .25276 Metetra
.97 .766 .572 r
.4538 .25276 .455 .23997 .44472 .22882 .4435 .24155 Metetra
.972 .768 .57 r
.4435 .24155 .44472 .22882 .43437 .21175 .43302 .23236 Metetra
.974 .759 .55 r
.43302 .23236 .43437 .21175 .42381 .20023 .4224 .2225 Metetra
.975 .758 .547 r
.4224 .2225 .42381 .20023 .41305 .19147 .41161 .21371 Metetra
.975 .758 .548 r
.41161 .21371 .41305 .19147 .40209 .18571 .40066 .20434 Metetra
.974 .761 .554 r
.40066 .20434 .40209 .18571 .39089 .18305 .38955 .19499 Metetra
.974 .774 .572 r
.38955 .19499 .39089 .18305 .37944 .18308 .37821 .1881 Metetra
.958 .801 .645 r
.37821 .1881 .37944 .18308 .36799 .17358 .36676 .17808 Metetra
.947 .797 .661 r
.36676 .17808 .36799 .17358 .35638 .16322 .35519 .16543 Metetra
.9 .816 .755 r
.35519 .16543 .35638 .16322 .34471 .14823 .34347 .15215 Metetra
0 .067 .628 r
.57675 .35279 .57778 .35413 .56911 .34172 .56805 .33679 Metetra
.969 .653 .351 r
.56805 .33679 .56911 .34172 .56034 .32856 .55932 .32876 Metetra
.605 .802 .975 r
.55932 .32876 .56034 .32856 .5515 .3207 .55047 .32092 Metetra
.617 .809 .974 r
.55047 .32092 .5515 .3207 .54253 .31233 .5415 .3131 Metetra
.798 .854 .892 r
.5415 .3131 .54253 .31233 .53344 .30157 .53241 .30522 Metetra
.909 .758 .681 r
.53241 .30522 .53344 .30157 .52423 .29148 .52318 .28603 Metetra
.971 .661 .361 r
.52318 .28603 .52423 .29148 .51491 .28621 .51386 .27696 Metetra
.966 .69 .46 r
.51386 .27696 .51491 .28621 .50544 .28828 .5044 .2782 Metetra
.967 .694 .463 r
.5044 .2782 .50544 .28828 .49581 .28969 .49477 .27884 Metetra
.977 .705 .445 r
.49477 .27884 .49581 .28969 .48603 .28643 .48503 .27064 Metetra
.971 .711 .482 r
.48503 .27064 .48603 .28643 .47605 .29278 .47509 .27168 Metetra
.98 .726 .474 r
.47509 .27168 .47605 .29278 .46606 .27456 .46509 .25871 Metetra
.984 .722 .45 r
.46509 .25871 .46606 .27456 .45598 .25205 .455 .23997 Metetra
.979 .71 .445 r
.455 .23997 .45598 .25205 .44575 .23478 .44472 .22882 Metetra
.975 .667 .324 r
.44472 .22882 .44575 .23478 .43532 .22398 .43437 .21175 Metetra
.979 .71 .446 r
.43437 .21175 .43532 .22398 .42473 .21326 .42381 .20023 Metetra
.977 .71 .455 r
.42381 .20023 .42473 .21326 .41398 .20364 .41305 .19147 Metetra
.974 .705 .457 r
.41305 .19147 .41398 .20364 .40303 .19613 .40209 .18571 Metetra
.97 .695 .453 r
.40209 .18571 .40303 .19613 .39173 .19815 .39089 .18305 Metetra
.971 .708 .476 r
.39089 .18305 .39173 .19815 .38046 .18854 .37944 .18308 Metetra
.968 .653 .357 r
.37944 .18308 .38046 .18854 .36886 .1857 .36799 .17358 Metetra
.977 .707 .447 r
.36799 .17358 .36886 .1857 .3574 .16851 .35638 .16322 Metetra
.969 .649 .314 r
.35638 .16322 .3574 .16851 .34601 .14206 .34471 .14823 Metetra
.97 .757 .56 r
.57778 .35413 .57864 .33776 .57 .32538 .56911 .34172 Metetra
.969 .757 .561 r
.56911 .34172 .57 .32538 .56126 .31415 .56034 .32856 Metetra
.973 .764 .561 r
.56034 .32856 .56126 .31415 .55243 .30361 .5515 .3207 Metetra
.974 .761 .554 r
.5515 .3207 .55243 .30361 .54348 .29407 .54253 .31233 Metetra
.972 .758 .554 r
.54253 .31233 .54348 .29407 .53443 .28579 .53344 .30157 Metetra
.972 .761 .559 r
.53344 .30157 .53443 .28579 .52524 .26831 .52423 .29148 Metetra
.977 .758 .542 r
.52423 .29148 .52524 .26831 .51595 .26 .51491 .28621 Metetra
.98 .76 .533 r
.51491 .28621 .51595 .26 .50651 .27068 .50544 .28828 Metetra
.981 .769 .544 r
.50544 .28828 .50651 .27068 .4969 .27668 .49581 .28969 Metetra
.978 .773 .56 r
.49581 .28969 .4969 .27668 .48717 .26828 .48603 .28643 Metetra
.984 .772 .538 r
.48603 .28643 .48717 .26828 .47719 .28093 .47605 .29278 Metetra
.961 .758 .583 r
.47605 .29278 .47719 .28093 .46721 .26364 .46606 .27456 Metetra
.955 .753 .592 r
.46606 .27456 .46721 .26364 .45715 .24198 .45598 .25205 Metetra
.96 .762 .592 r
.45598 .25205 .45715 .24198 .44691 .22803 .44575 .23478 Metetra
.962 .784 .615 r
.44575 .23478 .44691 .22803 .43663 .20482 .43532 .22398 Metetra
.973 .759 .553 r
.43532 .22398 .43663 .20482 .42607 .19515 .42473 .21326 Metetra
.974 .761 .555 r
.42473 .21326 .42607 .19515 .41528 .1904 .41398 .20364 Metetra
.974 .77 .566 r
.41398 .20364 .41528 .1904 .40431 .1856 .40303 .19613 Metetra
.984 .79 .565 r
.40303 .19613 .40431 .1856 .39307 .18632 .39173 .19815 Metetra
.972 .771 .575 r
.39173 .19815 .39307 .18632 .38168 .1837 .38046 .18854 Metetra
.974 .827 .636 r
.38046 .18854 .38168 .1837 .36992 .18923 .36886 .1857 Metetra
.931 .569 .153 r
.36886 .1857 .36992 .18923 .3585 .16997 .3574 .16851 Metetra
0 .133 .678 r
.3574 .16851 .3585 .16997 .34705 .14635 .34601 .14206 Metetra
.938 .783 .662 r
.57864 .33776 .57961 .33369 .57096 .31929 .57 .32538 Metetra
.956 .778 .621 r
.57 .32538 .57096 .31929 .56224 .30827 .56126 .31415 Metetra
.957 .782 .623 r
.56126 .31415 .56224 .30827 .55344 .30088 .55243 .30361 Metetra
.929 .812 .708 r
.55243 .30361 .55344 .30088 .54449 .28836 .54348 .29407 Metetra
.963 .79 .622 r
.54348 .29407 .54449 .28836 .53544 .2766 .53443 .28579 Metetra
.956 .759 .598 r
.53443 .28579 .53544 .2766 .52627 .26425 .52524 .26831 Metetra
.954 .805 .659 r
.52524 .26831 .52627 .26425 .517 .25964 .51595 .26 Metetra
.224 0 0 r
.51595 .26 .517 .25964 .50758 .26133 .50651 .27068 Metetra
.989 .799 .558 r
.50651 .27068 .50758 .26133 .498 .26218 .4969 .27668 Metetra
.974 .765 .562 r
.4969 .27668 .498 .26218 .48828 .25783 .48717 .26828 Metetra
.994 .802 .541 r
.48717 .26828 .48828 .25783 .47832 .27121 .47719 .28093 Metetra
.959 .762 .595 r
.47719 .28093 .47832 .27121 .46833 .25849 .46721 .26364 Metetra
.927 .757 .651 r
.46721 .26364 .46833 .25849 .45835 .22905 .45715 .24198 Metetra
.968 .762 .574 r
.45715 .24198 .45835 .22905 .44814 .21329 .44691 .22803 Metetra
.961 .751 .575 r
.44691 .22803 .44814 .21329 .4378 .19846 .43663 .20482 Metetra
.963 .789 .618 r
.43663 .20482 .4378 .19846 .42725 .18876 .42607 .19515 Metetra
.973 .802 .61 r
.42607 .19515 .42725 .18876 .41647 .18444 .41528 .1904 Metetra
.972 .806 .617 r
.41528 .1904 .41647 .18444 .40558 .17612 .40431 .1856 Metetra
.983 .793 .573 r
.40431 .1856 .40558 .17612 .39445 .17163 .39307 .18632 Metetra
.979 .773 .556 r
.39307 .18632 .39445 .17163 .38295 .17665 .38168 .1837 Metetra
.989 .821 .583 r
.38168 .1837 .38295 .17665 .37115 .1849 .36992 .18923 Metetra
.927 .774 .67 r
.36992 .18923 .37115 .1849 .35953 .17498 .3585 .16997 Metetra
.956 .632 .224 r
.3585 .16997 .35953 .17498 .3482 .14604 .34705 .14635 Metetra
.983 .721 .452 r
.57961 .33369 .58077 .34856 .57212 .33622 .57096 .31929 Metetra
.98 .722 .466 r
.57096 .31929 .57212 .33622 .56342 .32972 .56224 .30827 Metetra
.978 .725 .481 r
.56224 .30827 .56342 .32972 .55459 .32132 .55344 .30088 Metetra
.981 .726 .473 r
.55344 .30088 .55459 .32132 .54566 .31781 .54449 .28836 Metetra
.98 .731 .487 r
.54449 .28836 .54566 .31781 .53659 .3103 .53544 .2766 Metetra
.98 .733 .49 r
.53544 .2766 .53659 .3103 .5274 .30851 .52627 .26425 Metetra
.977 .733 .5 r
.52627 .26425 .5274 .30851 .51808 .31464 .517 .25964 Metetra
.976 .733 .505 r
.517 .25964 .51808 .31464 .50858 .32721 .50758 .26133 Metetra
.976 .735 .506 r
.50758 .26133 .50858 .32721 .49893 .32278 .498 .26218 Metetra
.977 .735 .504 r
.498 .26218 .49893 .32278 .48912 .32038 .48828 .25783 Metetra
.974 .732 .51 r
.48828 .25783 .48912 .32038 .47899 .35204 .47832 .27121 Metetra
.978 .738 .504 r
.47832 .27121 .47899 .35204 .46896 .32721 .46833 .25849 Metetra
.981 .74 .497 r
.46833 .25849 .46896 .32721 .4589 .29422 .45835 .22905 Metetra
.979 .738 .501 r
.45835 .22905 .4589 .29422 .44869 .26867 .44814 .21329 Metetra
.979 .736 .499 r
.44814 .21329 .44869 .26867 .43833 .24816 .4378 .19846 Metetra
.978 .734 .499 r
.4378 .19846 .43833 .24816 .42788 .22567 .42725 .18876 Metetra
.977 .73 .496 r
.42725 .18876 .42788 .22567 .41714 .21447 .41647 .18444 Metetra
.978 .729 .489 r
.41647 .18444 .41714 .21447 .40623 .20502 .40558 .17612 Metetra
.976 .726 .491 r
.40558 .17612 .40623 .20502 .39514 .19549 .39445 .17163 Metetra
.971 .719 .494 r
.39445 .17163 .39514 .19549 .38369 .19628 .38295 .17665 Metetra
.968 .712 .492 r
.38295 .17665 .38369 .19628 .3723 .1843 .37115 .1849 Metetra
.731 .847 .935 r
.37115 .1849 .3723 .1843 .36086 .16686 .35953 .17498 Metetra
.939 .749 .619 r
.35953 .17498 .36086 .16686 .34908 .1566 .3482 .14604 Metetra
0 .03 .578 r
.58077 .34856 .5818 .34976 .57316 .33868 .57212 .33622 Metetra
.922 .529 .177 r
.57212 .33622 .57316 .33868 .56445 .33083 .56342 .32972 Metetra
.582 .077 0 r
.56342 .32972 .56445 .33083 .55561 .3197 .55459 .32132 Metetra
.921 .899 .788 r
.55459 .32132 .55561 .3197 .54668 .31547 .54566 .31781 Metetra
.93 .835 .73 r
.54566 .31781 .54668 .31547 .53762 .30779 .53659 .3103 Metetra
.96 .878 .709 r
.53659 .3103 .53762 .30779 .52845 .30854 .5274 .30851 Metetra
.386 0 0 r
.5274 .30851 .52845 .30854 .51912 .30263 .51808 .31464 Metetra
.992 .794 .536 r
.51808 .31464 .51912 .30263 .50965 .31381 .50858 .32721 Metetra
.977 .771 .56 r
.50858 .32721 .50965 .31381 .5 .32101 .49893 .32278 Metetra
.931 .912 .778 r
.49893 .32278 .5 .32101 .4902 .32116 .48912 .32038 Metetra
.678 .373 .449 r
.48912 .32038 .4902 .32116 .48014 .33902 .47899 .35204 Metetra
.956 .75 .584 r
.47899 .35204 .48014 .33902 .47016 .31068 .46896 .32721 Metetra
.955 .742 .577 r
.46896 .32721 .47016 .31068 .46005 .28736 .4589 .29422 Metetra
.934 .749 .63 r
.4589 .29422 .46005 .28736 .44985 .26233 .44869 .26867 Metetra
.941 .762 .632 r
.44869 .26867 .44985 .26233 .43948 .24407 .43833 .24816 Metetra
.912 .756 .675 r
.43833 .24816 .43948 .24407 .429 .22464 .42788 .22567 Metetra
.819 .831 .858 r
.42788 .22567 .429 .22464 .41825 .21518 .41714 .21447 Metetra
0 .26 .718 r
.41714 .21447 .41825 .21518 .40733 .20568 .40623 .20502 Metetra
0 .304 .752 r
.40623 .20502 .40733 .20568 .39625 .19622 .39514 .19549 Metetra
.656 .111 0 r
.39514 .19549 .39625 .19622 .38501 .18633 .38369 .19628 Metetra
.968 .773 .588 r
.38369 .19628 .38501 .18633 .3736 .1764 .3723 .1843 Metetra
.956 .77 .611 r
.3723 .1843 .3736 .1764 .36201 .16634 .36086 .16686 Metetra
.707 .838 .945 r
.36086 .16686 .36201 .16634 .35028 .15445 .34908 .1566 Metetra
.974 .666 .346 r
.5818 .34976 .58287 .3553 .57425 .34567 .57316 .33868 Metetra
.975 .683 .403 r
.57316 .33868 .57425 .34567 .56553 .33751 .56445 .33083 Metetra
.977 .681 .378 r
.56445 .33083 .56553 .33751 .5567 .32893 .55561 .3197 Metetra
.973 .696 .444 r
.55561 .3197 .5567 .32893 .54776 .32241 .54668 .31547 Metetra
.974 .681 .403 r
.54668 .31547 .54776 .32241 .5387 .31703 .53762 .30779 Metetra
.967 .691 .458 r
.53762 .30779 .5387 .31703 .52954 .32714 .52845 .30854 Metetra
.977 .72 .477 r
.52845 .30854 .52954 .32714 .52023 .35901 .51912 .30263 Metetra
.974 .732 .509 r
.51912 .30263 .52023 .35901 .51069 .37536 .50965 .31381 Metetra
.975 .733 .508 r
.50965 .31381 .51069 .37536 .50088 .4271 .5 .32101 Metetra
.977 .738 .509 r
.5 .32101 .50088 .4271 .49115 .35981 .4902 .32116 Metetra
.97 .724 .509 r
.4902 .32116 .49115 .35981 .48096 .39448 .48014 .33902 Metetra
.982 .739 .492 r
.48014 .33902 .48096 .39448 .47104 .34352 .47016 .31068 Metetra
.983 .735 .48 r
.47016 .31068 .47104 .34352 .46077 .33526 .46005 .28736 Metetra
.982 .738 .49 r
.46005 .28736 .46077 .33526 .45035 .32677 .44985 .26233 Metetra
.98 .738 .499 r
.44985 .26233 .45035 .32677 .43977 .3182 .43948 .24407 Metetra
.979 .739 .501 r
.43948 .24407 .43977 .3182 .42943 .27836 .429 .22464 Metetra
.978 .735 .5 r
.429 .22464 .42943 .27836 .41886 .25023 .41825 .21518 Metetra
.978 .731 .492 r
.41825 .21518 .41886 .25023 .40804 .2319 .40733 .20568 Metetra
.978 .727 .484 r
.40733 .20568 .40804 .2319 .39682 .22831 .39625 .19622 Metetra
.978 .73 .489 r
.39625 .19622 .39682 .22831 .38498 .24667 .38501 .18633 Metetra
.978 .736 .501 r
.38501 .18633 .38498 .24667 .37289 .26421 .3736 .1764 Metetra
.978 .738 .505 r
.3736 .1764 .37289 .26421 .36181 .22535 .36201 .16634 Metetra
.978 .736 .5 r
.36201 .16634 .36181 .22535 .35094 .17453 .35028 .15445 Metetra
.954 .79 .64 r
.58287 .3553 .58384 .35049 .57521 .33915 .57425 .34567 Metetra
.965 .785 .609 r
.57425 .34567 .57521 .33915 .5665 .3301 .56553 .33751 Metetra
.967 .78 .6 r
.56553 .33751 .5665 .3301 .55767 .32031 .5567 .32893 Metetra
.972 .78 .586 r
.5567 .32893 .55767 .32031 .54876 .31589 .54776 .32241 Metetra
.972 .794 .604 r
.54776 .32241 .54876 .31589 .53972 .31202 .5387 .31703 Metetra
.996 .856 .571 r
.5387 .31703 .53972 .31202 .53054 .3063 .52954 .32714 Metetra
.995 .782 .502 r
.52954 .32714 .53054 .3063 .52123 .30235 .52023 .35901 Metetra
.982 .754 .517 r
.52023 .35901 .52123 .30235 .51178 .32 .51069 .37536 Metetra
.989 .762 .502 r
.51069 .37536 .51178 .32 .50214 .32291 .50088 .4271 Metetra
.97 .739 .531 r
.50088 .4271 .50214 .32291 .49231 .33422 .49115 .35981 Metetra
.993 .777 .504 r
.49115 .35981 .49231 .33422 .48232 .33885 .48096 .39448 Metetra
.967 .739 .54 r
.48096 .39448 .48232 .33885 .4724 .30083 .47104 .34352 Metetra
.977 .751 .53 r
.47104 .34352 .4724 .30083 .4622 .29157 .46077 .33526 Metetra
.977 .751 .53 r
.46077 .33526 .4622 .29157 .45202 .26502 .45035 .32677 Metetra
.977 .748 .525 r
.45035 .32677 .45202 .26502 .44158 .25358 .43977 .3182 Metetra
.971 .742 .533 r
.43977 .3182 .44158 .25358 .43119 .22646 .42943 .27836 Metetra
.973 .745 .534 r
.42943 .27836 .43119 .22646 .42047 .21493 .41886 .25023 Metetra
.973 .749 .539 r
.41886 .25023 .42047 .21493 .40957 .20532 .40804 .2319 Metetra
.978 .759 .538 r
.40804 .2319 .40957 .20532 .39856 .1928 .39682 .22831 Metetra
.985 .763 .52 r
.39682 .22831 .39856 .1928 .38728 .18607 .38498 .24667 Metetra
.982 .754 .518 r
.38498 .24667 .38728 .18607 .37586 .17694 .37289 .26421 Metetra
.974 .743 .528 r
.37289 .26421 .37586 .17694 .36434 .16434 .36181 .22535 Metetra
.969 .74 .537 r
.36181 .22535 .36434 .16434 .35259 .15406 .35094 .17453 Metetra
.952 .605 .232 r
.58384 .35049 .58489 .35417 .57627 .34285 .57521 .33915 Metetra
.956 .611 .268 r
.57521 .33915 .57627 .34285 .56757 .33528 .5665 .3301 Metetra
.971 .657 .342 r
.5665 .3301 .56757 .33528 .55875 .32759 .55767 .32031 Metetra
.971 .682 .422 r
.55767 .32031 .55875 .32759 .54982 .31951 .54876 .31589 Metetra
.951 .61 .326 r
.54876 .31589 .54982 .31951 .54075 .30955 .53972 .31202 Metetra
.942 .848 .721 r
.53972 .31202 .54075 .30955 .53158 .30227 .53054 .3063 Metetra
.968 .827 .65 r
.53054 .3063 .53158 .30227 .52228 .29583 .52123 .30235 Metetra
.999 .844 .526 r
.52123 .30235 .52228 .29583 .51284 .2949 .51178 .32 Metetra
.981 .762 .532 r
.51178 .32 .51284 .2949 .50326 .29017 .50214 .32291 Metetra
.984 .761 .523 r
.50214 .32291 .50326 .29017 .49349 .30048 .49231 .33422 Metetra
.981 .758 .527 r
.49231 .33422 .49349 .30048 .4836 .29416 .48232 .33885 Metetra
.969 .742 .541 r
.48232 .33885 .4836 .29416 .47361 .27973 .4724 .30083 Metetra
.975 .759 .547 r
.4724 .30083 .47361 .27973 .46359 .25218 .4622 .29157 Metetra
.971 .746 .54 r
.4622 .29157 .46359 .25218 .45335 .23992 .45202 .26502 Metetra
.975 .755 .544 r
.45202 .26502 .45335 .23992 .44297 .22699 .44158 .25358 Metetra
.968 .747 .551 r
.44158 .25358 .44297 .22699 .4324 .21736 .43119 .22646 Metetra
.967 .775 .592 r
.43119 .22646 .4324 .21736 .42168 .208 .42047 .21493 Metetra
.966 .788 .611 r
.42047 .21493 .42168 .208 .4108 .19856 .40957 .20532 Metetra
.96 .782 .617 r
.40957 .20532 .4108 .19856 .39974 .18975 .39856 .1928 Metetra
.949 .843 .703 r
.39856 .1928 .39974 .18975 .3884 .18678 .38728 .18607 Metetra
0 .237 .686 r
.38728 .18607 .3884 .18678 .377 .17692 .37586 .17694 Metetra
.504 .72 .969 r
.37586 .17694 .377 .17692 .36539 .16871 .36434 .16434 Metetra
.959 .622 .301 r
.36434 .16434 .36539 .16871 .35384 .14984 .35259 .15406 Metetra
.959 .776 .614 r
.58489 .35417 .58584 .34759 .57724 .33808 .57627 .34285 Metetra
.961 .799 .637 r
.57627 .34285 .57724 .33808 .56855 .33043 .56757 .33528 Metetra
.961 .799 .636 r
.56757 .33528 .56855 .33043 .55975 .32259 .55875 .32759 Metetra
.961 .797 .634 r
.55875 .32759 .55975 .32259 .55083 .31477 .54982 .31951 Metetra
.954 .792 .643 r
.54982 .31951 .55083 .31477 .54178 .30531 .54075 .30955 Metetra
.959 .808 .651 r
.54075 .30955 .54178 .30531 .53259 .28843 .53158 .30227 Metetra
.976 .768 .56 r
.53158 .30227 .53259 .28843 .52331 .28234 .52228 .29583 Metetra
.981 .775 .554 r
.52228 .29583 .52331 .28234 .5139 .28372 .51284 .2949 Metetra
.977 .776 .568 r
.51284 .2949 .5139 .28372 .50435 .27928 .50326 .29017 Metetra
.992 .797 .543 r
.50326 .29017 .50435 .27928 .49462 .28165 .49349 .30048 Metetra
.977 .762 .548 r
.49349 .30048 .49462 .28165 .48473 .28351 .4836 .29416 Metetra
.965 .765 .584 r
.4836 .29416 .48473 .28351 .47479 .26453 .47361 .27973 Metetra
.958 .747 .576 r
.47361 .27973 .47479 .26453 .46471 .24837 .46359 .25218 Metetra
.94 .797 .675 r
.46359 .25218 .46471 .24837 .45448 .23516 .45335 .23992 Metetra
.948 .789 .651 r
.45335 .23992 .45448 .23516 .4441 .22384 .44297 .22699 Metetra
.94 .82 .698 r
.44297 .22699 .4441 .22384 .43356 .21328 .4324 .21736 Metetra
.953 .81 .665 r
.4324 .21736 .43356 .21328 .42285 .20403 .42168 .208 Metetra
.952 .812 .669 r
.42168 .208 .42285 .20403 .4119 .19968 .4108 .19856 Metetra
.605 .082 0 r
.4108 .19856 .4119 .19968 .40078 .19474 .39974 .18975 Metetra
.957 .638 .377 r
.39974 .18975 .40078 .19474 .38939 .19412 .3884 .18678 Metetra
.974 .679 .396 r
.3884 .18678 .38939 .19412 .37795 .18585 .377 .17692 Metetra
.974 .69 .423 r
.377 .17692 .37795 .18585 .36643 .17335 .36539 .16871 Metetra
.958 .624 .239 r
.36539 .16871 .36643 .17335 .35485 .15587 .35384 .14984 Metetra
.908 .818 .746 r
.58584 .34759 .58683 .34554 .57819 .33 .57724 .33808 Metetra
.97 .779 .591 r
.57724 .33808 .57819 .33 .56951 .32227 .56855 .33043 Metetra
.97 .779 .591 r
.56855 .33043 .56951 .32227 .56072 .31452 .55975 .32259 Metetra
.97 .78 .592 r
.55975 .32259 .56072 .31452 .55182 .3067 .55083 .31477 Metetra
.967 .777 .595 r
.55083 .31477 .55182 .3067 .54283 .30813 .54178 .30531 Metetra
.853 .478 0 r
.54178 .30531 .54283 .30813 .5337 .30971 .53259 .28843 Metetra
.978 .723 .481 r
.53259 .28843 .5337 .30971 .52443 .32211 .52331 .28234 Metetra
.976 .73 .5 r
.52331 .28234 .52443 .32211 .51498 .36232 .5139 .28372 Metetra
.978 .737 .505 r
.5139 .28372 .51498 .36232 .50532 .35453 .50435 .27928 Metetra
.977 .736 .506 r
.50435 .27928 .50532 .35453 .49551 .35267 .49462 .28165 Metetra
.977 .735 .506 r
.49462 .28165 .49551 .35267 .48505 .46667 .48473 .28351 Metetra
.979 .741 .507 r
.48473 .28351 .48505 .46667 .47542 .34489 .47479 .26453 Metetra
.979 .739 .501 r
.47479 .26453 .47542 .34489 .46528 .32167 .46471 .24837 Metetra
.979 .738 .501 r
.46471 .24837 .46528 .32167 .45495 .30689 .45448 .23516 Metetra
.979 .737 .502 r
.45448 .23516 .45495 .30689 .44467 .27533 .4441 .22384 Metetra
.979 .735 .497 r
.4441 .22384 .44467 .27533 .43415 .25667 .43356 .21328 Metetra
.978 .733 .495 r
.43356 .21328 .43415 .25667 .4237 .22312 .42285 .20403 Metetra
.976 .718 .477 r
.42285 .20403 .4237 .22312 .41285 .21056 .4119 .19968 Metetra
.973 .699 .448 r
.4119 .19968 .41285 .21056 .40185 .19808 .40078 .19474 Metetra
.934 .58 .327 r
.40078 .19474 .40185 .19808 .39066 .18667 .38939 .19412 Metetra
.97 .79 .604 r
.38939 .19412 .39066 .18667 .37899 .1909 .37795 .18585 Metetra
.967 .642 .316 r
.37795 .18585 .37899 .1909 .36772 .16658 .36643 .17335 Metetra
.952 .774 .624 r
.36643 .17335 .36772 .16658 .35601 .15516 .35485 .15587 Metetra
.984 .709 .414 r
.58683 .34554 .58796 .3559 .57934 .34373 .57819 .33 Metetra
.978 .715 .459 r
.57819 .33 .57934 .34373 .57066 .33612 .56951 .32227 Metetra
.978 .715 .459 r
.56951 .32227 .57066 .33612 .56186 .32843 .56072 .31452 Metetra
.978 .715 .459 r
.56072 .31452 .56186 .32843 .55294 .32068 .55182 .3067 Metetra
.971 .708 .477 r
.55182 .3067 .55294 .32068 .5439 .31318 .54283 .30813 Metetra
.953 .645 .414 r
.54283 .30813 .5439 .31318 .53476 .31203 .5337 .30971 Metetra
.865 .527 .41 r
.5337 .30971 .53476 .31203 .52549 .32544 .52443 .32211 Metetra
.818 .541 .521 r
.52443 .32211 .52549 .32544 .51604 .33448 .51498 .36232 Metetra
.977 .755 .538 r
.51498 .36232 .51604 .33448 .50642 .33499 .50532 .35453 Metetra
.98 .765 .542 r
.50532 .35453 .50642 .33499 .49661 .34612 .49551 .35267 Metetra
0 0 .335 r
.49551 .35267 .49661 .34612 .48667 .33815 .48505 .46667 Metetra
.967 .734 .534 r
.48505 .46667 .48667 .33815 .4766 .32976 .47542 .34489 Metetra
.962 .752 .573 r
.47542 .34489 .4766 .32976 .46651 .30328 .46528 .32167 Metetra
.971 .757 .557 r
.46528 .32167 .46651 .30328 .45627 .28176 .45495 .30689 Metetra
.965 .745 .556 r
.45495 .30689 .45627 .28176 .44596 .25763 .44467 .27533 Metetra
.968 .755 .561 r
.44467 .27533 .44596 .25763 .43553 .23397 .43415 .25667 Metetra
.962 .744 .56 r
.43415 .25667 .43553 .23397 .4249 .21666 .4237 .22312 Metetra
.959 .783 .621 r
.4237 .22312 .4249 .21666 .41403 .20683 .41285 .21056 Metetra
.94 .802 .681 r
.41285 .21056 .41403 .20683 .40303 .19484 .40185 .19808 Metetra
.936 .814 .699 r
.40185 .19808 .40303 .19484 .39177 .18802 .39066 .18667 Metetra
.811 .366 .184 r
.39066 .18667 .39177 .18802 .38014 .19062 .37899 .1909 Metetra
.638 .651 .846 r
.37899 .1909 .38014 .19062 .36868 .17499 .36772 .16658 Metetra
.976 .688 .406 r
.36772 .16658 .36868 .17499 .35706 .15966 .35601 .15516 Metetra
.952 .779 .632 r
.58796 .3559 .58892 .35045 .58032 .33914 .57934 .34373 Metetra
.96 .801 .641 r
.57934 .34373 .58032 .33914 .57164 .33124 .57066 .33612 Metetra
.961 .799 .635 r
.57066 .33612 .57164 .33124 .56285 .32338 .56186 .32843 Metetra
.962 .798 .632 r
.56186 .32843 .56285 .32338 .55395 .31698 .55294 .32068 Metetra
.954 .814 .667 r
.55294 .32068 .55395 .31698 .54494 .31257 .5439 .31318 Metetra
.709 .967 .936 r
.5439 .31318 .54494 .31257 .5358 .30901 .53476 .31203 Metetra
.951 .916 .55 r
.53476 .31203 .5358 .30901 .52654 .31975 .52549 .32544 Metetra
.996 .843 .571 r
.52549 .32544 .52654 .31975 .5171 .30881 .51604 .33448 Metetra
.981 .761 .533 r
.51604 .33448 .5171 .30881 .50752 .309 .50642 .33499 Metetra
.985 .766 .524 r
.50642 .33499 .50752 .309 .4978 .30083 .49661 .34612 Metetra
.977 .751 .528 r
.49661 .34612 .4978 .30083 .48779 .33081 .48667 .33815 Metetra
.969 .786 .603 r
.48667 .33815 .48779 .33081 .47784 .30172 .4766 .32976 Metetra
.969 .747 .549 r
.4766 .32976 .47784 .30172 .4678 .27522 .46651 .30328 Metetra
.971 .749 .546 r
.46651 .30328 .4678 .27522 .45751 .26636 .45627 .28176 Metetra
.962 .751 .572 r
.45627 .28176 .45751 .26636 .44721 .24294 .44596 .25763 Metetra
.962 .752 .574 r
.44596 .25763 .44721 .24294 .43674 .22477 .43553 .23397 Metetra
.96 .765 .598 r
.43553 .23397 .43674 .22477 .42605 .21373 .4249 .21666 Metetra
.936 .824 .71 r
.4249 .21666 .42605 .21373 .4152 .20302 .41403 .20683 Metetra
.942 .804 .678 r
.41403 .20683 .4152 .20302 .40416 .19459 .40303 .19484 Metetra
.562 .844 .997 r
.40303 .19484 .40416 .19459 .39293 .18656 .39177 .18802 Metetra
.887 .988 .8 r
.39177 .18802 .39293 .18656 .38155 .17693 .38014 .19062 Metetra
.969 .763 .571 r
.38014 .19062 .38155 .17693 .37004 .16503 .36868 .17499 Metetra
.965 .77 .591 r
.36868 .17499 .37004 .16503 .35833 .15429 .35706 .15966 Metetra
.949 .785 .645 r
.58892 .35045 .58988 .34574 .58131 .33607 .58032 .33914 Metetra
.944 .818 .69 r
.58032 .33914 .58131 .33607 .57266 .32959 .57164 .33124 Metetra
.899 .844 .781 r
.57164 .33124 .57266 .32959 .56386 .3199 .56285 .32338 Metetra
.956 .822 .672 r
.56285 .32338 .56386 .3199 .55497 .3136 .55395 .31698 Metetra
.962 .836 .671 r
.55395 .31698 .55497 .3136 .54597 .30892 .54494 .31257 Metetra
.967 .836 .66 r
.54494 .31257 .54597 .30892 .53685 .30875 .5358 .30901 Metetra
.309 0 0 r
.5358 .30901 .53685 .30875 .52758 .30887 .52654 .31975 Metetra
.969 .769 .578 r
.52654 .31975 .52758 .30887 .51817 .31715 .5171 .30881 Metetra
.966 .684 .446 r
.5171 .30881 .51817 .31715 .50859 .30899 .50752 .309 Metetra
.469 .754 .992 r
.50752 .309 .50859 .30899 .49885 .31309 .4978 .30083 Metetra
.94 .678 .512 r
.4978 .30083 .49885 .31309 .48888 .33103 .48779 .33081 Metetra
.542 .546 .808 r
.48779 .33081 .48888 .33103 .47903 .28371 .47784 .30172 Metetra
.963 .748 .566 r
.47784 .30172 .47903 .28371 .46889 .27502 .4678 .27522 Metetra
.585 .801 .982 r
.4678 .27522 .46889 .27502 .45866 .25997 .45751 .26636 Metetra
.936 .755 .633 r
.45751 .26636 .45866 .25997 .44834 .24017 .44721 .24294 Metetra
.897 .774 .717 r
.44721 .24294 .44834 .24017 .43788 .22226 .43674 .22477 Metetra
.92 .821 .732 r
.43674 .22477 .43788 .22226 .42723 .2093 .42605 .21373 Metetra
.952 .803 .658 r
.42605 .21373 .42723 .2093 .41631 .20401 .4152 .20302 Metetra
.541 .006 0 r
.4152 .20302 .41631 .20401 .40532 .19198 .40416 .19459 Metetra
.936 .845 .728 r
.40416 .19459 .40532 .19198 .39406 .18634 .39293 .18656 Metetra
.585 .804 .983 r
.39293 .18656 .39406 .18634 .38265 .1787 .38155 .17693 Metetra
.776 .314 0 r
.38155 .17693 .38265 .1787 .37119 .16485 .37004 .16503 Metetra
.566 .783 .98 r
.37004 .16503 .37119 .16485 .35948 .15448 .35833 .15429 Metetra
.97 .653 .331 r
.58988 .34574 .59096 .35071 .5824 .34265 .58131 .33607 Metetra
.973 .678 .4 r
.58131 .33607 .5824 .34265 .5737 .33167 .57266 .32959 Metetra
.858 .433 0 r
.57266 .32959 .5737 .33167 .56493 .32529 .56386 .3199 Metetra
.969 .66 .373 r
.56386 .3199 .56493 .32529 .55604 .31852 .55497 .3136 Metetra
.964 .649 .371 r
.55497 .3136 .55604 .31852 .54702 .31144 .54597 .30892 Metetra
.92 .546 .293 r
.54597 .30892 .54702 .31144 .5379 .30915 .53685 .30875 Metetra
.461 0 0 r
.53685 .30875 .5379 .30915 .52869 .33216 .52758 .30887 Metetra
.971 .718 .496 r
.52758 .30887 .52869 .33216 .51927 .3616 .51817 .31715 Metetra
.979 .734 .495 r
.51817 .31715 .51927 .3616 .50963 .3537 .50859 .30899 Metetra
.975 .731 .501 r
.50859 .30899 .50963 .3537 .49986 .34571 .49885 .31309 Metetra
.969 .721 .506 r
.49885 .31309 .49986 .34571 .48988 .35809 .48888 .33103 Metetra
.991 .74 .443 r
.48888 .33103 .48988 .35809 .4799 .32835 .47903 .28371 Metetra
.979 .734 .495 r
.47903 .28371 .4799 .32835 .46975 .31072 .46889 .27502 Metetra
.981 .733 .486 r
.46889 .27502 .46975 .31072 .45955 .28632 .45866 .25997 Metetra
.983 .731 .472 r
.45866 .25997 .45955 .28632 .44936 .24877 .44834 .24017 Metetra
.982 .696 .383 r
.44834 .24017 .44936 .24877 .43892 .22817 .43788 .22226 Metetra
.973 .663 .344 r
.43788 .22226 .43892 .22817 .42822 .21828 .42723 .2093 Metetra
.972 .69 .432 r
.42723 .2093 .42822 .21828 .41738 .20744 .41631 .20401 Metetra
.941 .576 .203 r
.41631 .20401 .41738 .20744 .4063 .20114 .40532 .19198 Metetra
.973 .69 .432 r
.40532 .19198 .4063 .20114 .39471 .21376 .39406 .18634 Metetra
.978 .726 .484 r
.39406 .18634 .39471 .21376 .38322 .20796 .38265 .1787 Metetra
.98 .73 .481 r
.38265 .1787 .38322 .20796 .37197 .18197 .37119 .16485 Metetra
.979 .717 .463 r
.37119 .16485 .37197 .18197 .36055 .15786 .35948 .15448 Metetra
.781 .843 .899 r
.59096 .35071 .59197 .35003 .58339 .33939 .5824 .34265 Metetra
.934 .797 .686 r
.5824 .34265 .58339 .33939 .57473 .33163 .5737 .33167 Metetra
.461 .774 .997 r
.5737 .33167 .57473 .33163 .56594 .32119 .56493 .32529 Metetra
.96 .812 .652 r
.56493 .32529 .56594 .32119 .55706 .31604 .55604 .31852 Metetra
.936 .837 .721 r
.55604 .31852 .55706 .31604 .54805 .30813 .54702 .31144 Metetra
.969 .851 .669 r
.54702 .31144 .54805 .30813 .53892 .30018 .5379 .30915 Metetra
1 .823 .502 r
.5379 .30915 .53892 .30018 .52966 .29442 .52869 .33216 Metetra
.988 .764 .508 r
.52869 .33216 .52966 .29442 .52028 .2945 .51927 .3616 Metetra
.978 .748 .522 r
.51927 .3616 .52028 .2945 .51074 .29509 .50963 .3537 Metetra
.978 .749 .524 r
.50963 .3537 .51074 .29509 .50106 .28671 .49986 .34571 Metetra
.982 .753 .517 r
.49986 .34571 .50106 .28671 .49122 .28428 .48988 .35809 Metetra
.974 .744 .527 r
.48988 .35809 .49122 .28428 .48128 .26878 .4799 .32835 Metetra
.976 .747 .527 r
.4799 .32835 .48128 .26878 .47122 .2533 .46975 .31072 Metetra
.974 .746 .529 r
.46975 .31072 .47122 .2533 .461 .24173 .45955 .28632 Metetra
.97 .743 .539 r
.45955 .28632 .461 .24173 .45068 .22605 .44936 .24877 Metetra
.97 .752 .552 r
.44936 .24877 .45068 .22605 .44017 .21582 .43892 .22817 Metetra
.973 .77 .57 r
.43892 .22817 .44017 .21582 .42949 .20646 .42822 .21828 Metetra
.972 .77 .574 r
.42822 .21828 .42949 .20646 .41865 .19692 .41738 .20744 Metetra
.976 .78 .575 r
.41738 .20744 .41865 .19692 .40765 .18731 .4063 .20114 Metetra
.991 .79 .537 r
.4063 .20114 .40765 .18731 .39635 .18544 .39471 .21376 Metetra
.978 .758 .536 r
.39471 .21376 .39635 .18544 .38485 .18293 .38322 .20796 Metetra
.969 .749 .551 r
.38322 .20796 .38485 .18293 .37321 .17791 .37197 .18197 Metetra
.911 .758 .679 r
.37197 .18197 .37321 .17791 .3619 .14946 .36055 .15786 Metetra
.95 .789 .646 r
.59197 .35003 .59294 .34544 .58437 .33541 .58339 .33939 Metetra
.955 .807 .657 r
.58339 .33939 .58437 .33541 .57565 .31945 .57473 .33163 Metetra
.971 .765 .569 r
.57473 .33163 .57565 .31945 .56689 .31107 .56594 .32119 Metetra
.976 .778 .572 r
.56594 .32119 .56689 .31107 .55802 .30317 .55706 .31604 Metetra
.974 .768 .563 r
.55706 .31604 .55802 .30317 .54903 .29512 .54805 .30813 Metetra
.974 .768 .563 r
.54805 .30813 .54903 .29512 .53989 .28009 .53892 .30018 Metetra
.978 .761 .543 r
.53892 .30018 .53989 .28009 .53066 .2725 .52966 .29442 Metetra
.981 .763 .536 r
.52966 .29442 .53066 .2725 .52132 .27411 .52028 .2945 Metetra
.982 .765 .537 r
.52028 .2945 .52132 .27411 .51181 .2727 .51074 .29509 Metetra
.976 .758 .543 r
.51074 .29509 .51181 .2727 .50215 .27642 .50106 .28671 Metetra
.98 .784 .568 r
.50106 .28671 .50215 .27642 .49232 .27634 .49122 .28428 Metetra
.958 .769 .606 r
.49122 .28428 .49232 .27634 .48238 .26668 .48128 .26878 Metetra
.883 .786 .75 r
.48128 .26878 .48238 .26668 .4724 .23914 .47122 .2533 Metetra
.972 .764 .564 r
.47122 .2533 .4724 .23914 .4622 .22901 .461 .24173 Metetra
.967 .762 .574 r
.461 .24173 .4622 .22901 .45186 .21832 .45068 .22605 Metetra
.967 .782 .601 r
.45068 .22605 .45186 .21832 .44135 .20894 .44017 .21582 Metetra
.967 .789 .61 r
.44017 .21582 .44135 .20894 .43067 .2011 .42949 .20646 Metetra
.962 .799 .634 r
.42949 .20646 .43067 .2011 .41983 .19276 .41865 .19692 Metetra
.954 .811 .664 r
.41865 .19692 .41983 .19276 .40882 .18452 .40765 .18731 Metetra
.962 .881 .706 r
.40765 .18731 .40882 .18452 .39751 .18359 .39635 .18544 Metetra
.929 .92 .783 r
.39635 .18544 .39751 .18359 .38611 .17702 .38485 .18293 Metetra
.974 .81 .619 r
.38485 .18293 .38611 .17702 .37451 .1707 .37321 .17791 Metetra
.935 .75 .627 r
.37321 .17791 .37451 .1707 .36298 .15257 .3619 .14946 Metetra
.925 .808 .712 r
.59294 .34544 .59392 .34281 .58538 .33363 .58437 .33541 Metetra
.859 .764 .756 r
.58437 .33541 .58538 .33363 .57673 .32565 .57565 .31945 Metetra
.974 .673 .379 r
.57565 .31945 .57673 .32565 .56795 .31468 .56689 .31107 Metetra
.954 .606 .273 r
.56689 .31107 .56795 .31468 .5591 .31 .55802 .30317 Metetra
.975 .68 .394 r
.55802 .30317 .5591 .31 .55011 .30225 .54903 .29512 Metetra
.98 .685 .362 r
.54903 .29512 .55011 .30225 .54105 .30756 .53989 .28009 Metetra
.979 .728 .485 r
.53989 .28009 .54105 .30756 .53182 .31012 .53066 .2725 Metetra
.976 .73 .498 r
.53066 .2725 .53182 .31012 .52242 .30379 .52132 .27411 Metetra
.976 .727 .491 r
.52132 .27411 .52242 .30379 .51288 .2995 .51181 .2727 Metetra
.974 .723 .493 r
.51181 .2727 .51288 .2995 .50319 .29568 .50215 .27642 Metetra
.974 .717 .482 r
.50215 .27642 .50319 .29568 .49336 .29082 .49232 .27634 Metetra
.979 .715 .455 r
.49232 .27634 .49336 .29082 .48341 .2786 .48238 .26668 Metetra
.988 .716 .393 r
.48238 .26668 .48341 .2786 .47335 .26302 .4724 .23914 Metetra
.98 .726 .477 r
.4724 .23914 .47335 .26302 .46314 .2493 .4622 .22901 Metetra
.98 .723 .47 r
.4622 .22901 .46314 .2493 .45284 .23133 .45186 .21832 Metetra
.979 .71 .449 r
.45186 .21832 .45284 .23133 .44232 .22199 .44135 .20894 Metetra
.977 .709 .452 r
.44135 .20894 .44232 .22199 .43164 .21267 .43067 .2011 Metetra
.977 .704 .443 r
.43067 .2011 .43164 .21267 .42081 .20314 .41983 .19276 Metetra
.976 .699 .434 r
.41983 .19276 .42081 .20314 .40981 .19356 .40882 .18452 Metetra
.968 .685 .442 r
.40882 .18452 .40981 .19356 .39847 .19405 .39751 .18359 Metetra
.975 .697 .439 r
.39751 .18359 .39847 .19405 .38712 .18356 .38611 .17702 Metetra
.969 .666 .393 r
.38611 .17702 .38712 .18356 .3758 .16384 .37451 .1707 Metetra
.952 .773 .623 r
.37451 .1707 .3758 .16384 .36412 .15345 .36298 .15257 Metetra
.953 .604 .251 r
.59392 .34281 .59498 .3464 .58638 .3317 .58538 .33363 Metetra
.913 .837 .757 r
.58538 .33363 .58638 .3317 .5777 .31949 .57673 .32565 Metetra
.959 .781 .618 r
.57673 .32565 .5777 .31949 .56896 .31156 .56795 .31468 Metetra
.959 .839 .682 r
.56795 .31468 .56896 .31156 .5601 .30366 .5591 .31 Metetra
.967 .79 .61 r
.5591 .31 .5601 .30366 .55108 .28792 .55011 .30225 Metetra
.986 .779 .54 r
.55011 .30225 .55108 .28792 .54198 .27919 .54105 .30756 Metetra
.982 .76 .528 r
.54105 .30756 .54198 .27919 .53279 .27931 .53182 .31012 Metetra
.978 .755 .532 r
.53182 .31012 .53279 .27931 .52344 .27712 .52242 .30379 Metetra
.979 .758 .534 r
.52242 .30379 .52344 .27712 .51395 .26656 .51288 .2995 Metetra
.979 .755 .53 r
.51288 .2995 .51395 .26656 .50432 .26372 .50319 .29568 Metetra
.979 .755 .531 r
.50319 .29568 .50432 .26372 .4945 .27145 .49336 .29082 Metetra
.974 .758 .551 r
.49336 .29082 .4945 .27145 .48465 .2447 .48341 .2786 Metetra
.975 .751 .536 r
.48341 .2786 .48465 .2447 .47466 .22598 .47335 .26302 Metetra
.976 .751 .533 r
.47335 .26302 .47466 .22598 .46449 .21497 .46314 .2493 Metetra
.974 .75 .537 r
.46314 .2493 .46449 .21497 .45418 .20478 .45284 .23133 Metetra
.977 .756 .539 r
.45284 .23133 .45418 .20478 .44372 .1943 .44232 .22199 Metetra
.977 .756 .537 r
.44232 .22199 .44372 .1943 .43309 .18507 .43164 .21267 Metetra
.977 .756 .538 r
.43164 .21267 .43309 .18507 .42228 .17749 .42081 .20314 Metetra
.977 .757 .54 r
.42081 .20314 .42228 .17749 .41129 .17103 .40981 .19356 Metetra
.982 .765 .536 r
.40981 .19356 .41129 .17103 .39988 .17774 .39847 .19405 Metetra
.975 .764 .557 r
.39847 .19405 .39988 .17774 .3883 .18156 .38712 .18356 Metetra
.862 .77 .759 r
.38712 .18356 .3883 .18156 .37679 .17151 .3758 .16384 Metetra
.975 .681 .396 r
.3758 .16384 .37679 .17151 .3654 .14747 .36412 .15345 Metetra
.93 .775 .667 r
.59498 .3464 .59596 .34244 .58729 .32147 .58638 .3317 Metetra
.967 .766 .581 r
.58638 .3317 .58729 .32147 .57867 .31356 .5777 .31949 Metetra
.966 .791 .615 r
.5777 .31949 .57867 .31356 .56995 .30589 .56896 .31156 Metetra
.965 .793 .62 r
.56896 .31156 .56995 .30589 .56108 .29581 .5601 .30366 Metetra
.956 .765 .605 r
.5601 .30366 .56108 .29581 .55222 .30498 .55108 .28792 Metetra
.98 .72 .465 r
.55108 .28792 .55222 .30498 .54316 .30784 .54198 .27919 Metetra
.976 .726 .492 r
.54198 .27919 .54316 .30784 .53394 .3122 .53279 .27931 Metetra
.977 .729 .492 r
.53279 .27931 .53394 .3122 .52464 .36063 .52344 .27712 Metetra
.979 .738 .501 r
.52344 .27712 .52464 .36063 .51504 .35286 .51395 .26656 Metetra
.978 .737 .503 r
.51395 .26656 .51504 .35286 .50529 .34524 .50432 .26372 Metetra
.977 .736 .506 r
.50432 .26372 .50529 .34524 .49531 .37417 .4945 .27145 Metetra
.981 .741 .499 r
.4945 .27145 .49531 .37417 .48536 .33509 .48465 .2447 Metetra
.98 .74 .5 r
.48465 .2447 .48536 .33509 .47521 .31998 .47466 .22598 Metetra
.979 .739 .502 r
.47466 .22598 .47521 .31998 .4649 .31027 .46449 .21497 Metetra
.979 .739 .502 r
.46449 .21497 .4649 .31027 .45479 .26105 .45418 .20478 Metetra
.979 .736 .496 r
.45418 .20478 .45479 .26105 .44447 .22837 .44372 .1943 Metetra
.979 .731 .488 r
.44372 .1943 .44447 .22837 .43385 .21525 .43309 .18507 Metetra
.979 .728 .486 r
.43309 .18507 .43385 .21525 .42304 .20415 .42228 .17749 Metetra
.978 .726 .483 r
.42228 .17749 .42304 .20415 .41205 .19447 .41129 .17103 Metetra
.972 .718 .491 r
.41129 .17103 .41205 .19447 .40077 .19195 .39988 .17774 Metetra
.969 .703 .474 r
.39988 .17774 .40077 .19195 .38938 .18519 .3883 .18156 Metetra
.947 .588 .245 r
.3883 .18156 .38938 .18519 .37795 .17061 .37679 .17151 Metetra
.747 .707 .814 r
.37679 .17151 .37795 .17061 .36643 .15314 .3654 .14747 Metetra
.824 .722 .752 r
.59596 .34244 .59696 .3408 .58844 .3332 .58729 .32147 Metetra
.979 .709 .446 r
.58729 .32147 .58844 .3332 .57978 .32148 .57867 .31356 Metetra
.976 .69 .413 r
.57867 .31356 .57978 .32148 .57104 .31299 .56995 .30589 Metetra
.977 .684 .387 r
.56995 .30589 .57104 .31299 .56221 .30806 .56108 .29581 Metetra
.962 .697 .484 r
.56108 .29581 .56221 .30806 .55325 .30198 .55222 .30498 Metetra
.981 .892 .659 r
.55222 .30498 .55325 .30198 .54418 .3024 .54316 .30784 Metetra
.991 .835 .591 r
.54316 .30784 .54418 .3024 .53498 .30436 .53394 .3122 Metetra
.913 .795 .318 r
.53394 .3122 .53498 .30436 .52561 .30175 .52464 .36063 Metetra
.978 .749 .522 r
.52464 .36063 .52561 .30175 .5161 .29748 .51504 .35286 Metetra
.978 .749 .523 r
.51504 .35286 .5161 .29748 .50643 .29446 .50529 .34524 Metetra
.986 .759 .509 r
.50529 .34524 .50643 .29446 .49662 .29076 .49531 .37417 Metetra
.974 .743 .526 r
.49531 .37417 .49662 .29076 .48669 .2772 .48536 .33509 Metetra
.977 .748 .525 r
.48536 .33509 .48669 .2772 .47663 .26332 .47521 .31998 Metetra
.978 .749 .524 r
.47521 .31998 .47663 .26332 .46645 .24848 .4649 .31027 Metetra
.97 .741 .534 r
.4649 .31027 .46645 .24848 .45615 .23189 .45479 .26105 Metetra
.967 .745 .549 r
.45479 .26105 .45615 .23189 .4457 .21697 .44447 .22837 Metetra
.969 .768 .577 r
.44447 .22837 .4457 .21697 .43505 .20825 .43385 .21525 Metetra
.965 .785 .611 r
.43385 .21525 .43505 .20825 .42427 .19615 .42304 .20415 Metetra
.97 .784 .598 r
.42304 .20415 .42427 .19615 .41337 .18202 .41205 .19447 Metetra
.981 .779 .56 r
.41205 .19447 .41337 .18202 .40221 .17425 .40077 .19195 Metetra
.978 .766 .55 r
.40077 .19195 .40221 .17425 .39075 .1731 .38938 .18519 Metetra
.969 .767 .576 r
.38938 .18519 .39075 .1731 .37926 .16301 .37795 .17061 Metetra
.957 .772 .613 r
.37795 .17061 .37926 .16301 .36783 .14224 .36643 .15314 Metetra
0 .321 .77 r
.59696 .3408 .59798 .34142 .58936 .32354 .58844 .3332 Metetra
.967 .768 .584 r
.58844 .3332 .58936 .32354 .58073 .31334 .57978 .32148 Metetra
.97 .779 .59 r
.57978 .32148 .58073 .31334 .57201 .30556 .57104 .31299 Metetra
.975 .79 .59 r
.57104 .31299 .57201 .30556 .56321 .30235 .56221 .30806 Metetra
.97 .799 .616 r
.56221 .30806 .56321 .30235 .5543 .3032 .55325 .30198 Metetra
.815 .345 .099 r
.55325 .30198 .5543 .3032 .54525 .30518 .54418 .3024 Metetra
.921 .563 .334 r
.54418 .3024 .54525 .30518 .53602 .29945 .53498 .30436 Metetra
.976 .821 .623 r
.53498 .30436 .53602 .29945 .5267 .31067 .52561 .30175 Metetra
.973 .692 .434 r
.52561 .30175 .5267 .31067 .51717 .30323 .5161 .29748 Metetra
.964 .659 .396 r
.5161 .29748 .51717 .30323 .50751 .29526 .50643 .29446 Metetra
.595 .028 0 r
.50643 .29446 .50751 .29526 .4977 .29041 .49662 .29076 Metetra
.671 .751 .911 r
.49662 .29076 .4977 .29041 .48778 .27575 .48669 .2772 Metetra
.851 .798 .799 r
.48669 .2772 .48778 .27575 .47778 .25333 .47663 .26332 Metetra
.965 .767 .587 r
.47663 .26332 .47778 .25333 .46761 .23925 .46645 .24848 Metetra
.961 .766 .595 r
.46645 .24848 .46761 .23925 .45727 .22998 .45615 .23189 Metetra
.877 .795 .765 r
.45615 .23189 .45727 .22998 .44686 .21206 .4457 .21697 Metetra
.962 .805 .642 r
.4457 .21697 .44686 .21206 .43619 .20606 .43505 .20825 Metetra
.905 .82 .752 r
.43505 .20825 .43619 .20606 .42539 .19632 .42427 .19615 Metetra
.43 .647 .949 r
.42427 .19615 .42539 .19632 .41443 .18675 .41337 .18202 Metetra
.962 .634 .332 r
.41337 .18202 .41443 .18675 .40322 .18192 .40221 .17425 Metetra
.966 .674 .427 r
.40221 .17425 .40322 .18192 .3919 .17271 .39075 .1731 Metetra
.66 .826 .963 r
.39075 .1731 .3919 .17271 .38039 .16402 .37926 .16301 Metetra
0 .28 .781 r
.37926 .16301 .38039 .16402 .36889 .14652 .36783 .14224 Metetra
.967 .654 .266 r
.59798 .34142 .59907 .34685 .59055 .33815 .58936 .32354 Metetra
.981 .718 .454 r
.58936 .32354 .59055 .33815 .58193 .33035 .58073 .31334 Metetra
.979 .72 .466 r
.58073 .31334 .58193 .33035 .57316 .31902 .57201 .30556 Metetra
.975 .71 .464 r
.57201 .30556 .57316 .31902 .56432 .31166 .56321 .30235 Metetra
.968 .691 .454 r
.56321 .30235 .56432 .31166 .55537 .30651 .5543 .3032 Metetra
.933 .592 .362 r
.5543 .3032 .55537 .30651 .54626 .29513 .54525 .30518 Metetra
.976 .779 .573 r
.54525 .30518 .54626 .29513 .53706 .29352 .53602 .29945 Metetra
.998 .844 .556 r
.53602 .29945 .53706 .29352 .52771 .28571 .5267 .31067 Metetra
.978 .757 .537 r
.5267 .31067 .52771 .28571 .51823 .28336 .51717 .30323 Metetra
.977 .761 .545 r
.51717 .30323 .51823 .28336 .50861 .27542 .50751 .29526 Metetra
.979 .763 .542 r
.50751 .29526 .50861 .27542 .49884 .26763 .4977 .29041 Metetra
.974 .755 .546 r
.4977 .29041 .49884 .26763 .48894 .25801 .48778 .27575 Metetra
.966 .752 .562 r
.48778 .27575 .48894 .25801 .47894 .24021 .47778 .25333 Metetra
.97 .763 .57 r
.47778 .25333 .47894 .24021 .46876 .23279 .46761 .23925 Metetra
.966 .791 .614 r
.46761 .23925 .46876 .23279 .45843 .22366 .45727 .22998 Metetra
.948 .77 .628 r
.45727 .22998 .45843 .22366 .44793 .2169 .44686 .21206 Metetra
.962 .638 .349 r
.44686 .21206 .44793 .2169 .43731 .20559 .43619 .20606 Metetra
.699 .834 .947 r
.43619 .20606 .43731 .20559 .42653 .19543 .42539 .19632 Metetra
.803 .858 .89 r
.42539 .19632 .42653 .19543 .41559 .18452 .41443 .18675 Metetra
.939 .882 .751 r
.41443 .18675 .41559 .18452 .40447 .17461 .40322 .18192 Metetra
.97 .79 .605 r
.40322 .18192 .40447 .17461 .39315 .16656 .3919 .17271 Metetra
.968 .799 .62 r
.3919 .17271 .39315 .16656 .38157 .16252 .38039 .16402 Metetra
.839 .784 .798 r
.38039 .16402 .38157 .16252 .37004 .14633 .36889 .14652 Metetra
.95 .805 .665 r
.59907 .34685 .60004 .34312 .59147 .32861 .59055 .33815 Metetra
.973 .775 .578 r
.59055 .33815 .59147 .32861 .58282 .31678 .58193 .33035 Metetra
.972 .763 .564 r
.58193 .33035 .58282 .31678 .5741 .30759 .57316 .31902 Metetra
.975 .772 .567 r
.57316 .31902 .5741 .30759 .56527 .29995 .56432 .31166 Metetra
.978 .774 .563 r
.56432 .31166 .56527 .29995 .5563 .28897 .55537 .30651 Metetra
.974 .759 .552 r
.55537 .30651 .5563 .28897 .54723 .2787 .54626 .29513 Metetra
.981 .769 .544 r
.54626 .29513 .54723 .2787 .53804 .27054 .53706 .29352 Metetra
.977 .758 .54 r
.53706 .29352 .53804 .27054 .52876 .27808 .52771 .28571 Metetra
.98 .797 .585 r
.52771 .28571 .52876 .27808 .51929 .27152 .51823 .28336 Metetra
.975 .772 .567 r
.51823 .28336 .51929 .27152 .50969 .26886 .50861 .27542 Metetra
.969 .792 .608 r
.50861 .27542 .50969 .26886 .49991 .27556 .49884 .26763 Metetra
.977 .687 .402 r
.49884 .26763 .49991 .27556 .49005 .25148 .48894 .25801 Metetra
.949 .768 .624 r
.48894 .25801 .49005 .25148 .48004 .23908 .47894 .24021 Metetra
.853 .88 .858 r
.47894 .24021 .48004 .23908 .46989 .22747 .46876 .23279 Metetra
.963 .799 .632 r
.46876 .23279 .46989 .22747 .45958 .21831 .45843 .22366 Metetra
.969 .807 .628 r
.45843 .22366 .45958 .21831 .44912 .20886 .44793 .2169 Metetra
.967 .78 .599 r
.44793 .2169 .44912 .20886 .43849 .1997 .43731 .20559 Metetra
.963 .794 .625 r
.43731 .20559 .43849 .1997 .42769 .19247 .42653 .19543 Metetra
.933 .82 .71 r
.42653 .19543 .42769 .19247 .41674 .18295 .41559 .18452 Metetra
.882 .852 .808 r
.41559 .18452 .41674 .18295 .40566 .17182 .40447 .17461 Metetra
.941 .843 .718 r
.40447 .17461 .40566 .17182 .39429 .16667 .39315 .16656 Metetra
.104 .631 .874 r
.39315 .16656 .39429 .16667 .38251 .17308 .38157 .16252 Metetra
.982 .703 .413 r
.38157 .16252 .38251 .17308 .37133 .14009 .37004 .14633 Metetra
.856 .773 .769 r
.60004 .34312 .60104 .34151 .59251 .33049 .59147 .32861 Metetra
.761 .329 0 r
.59147 .32861 .59251 .33049 .58386 .31779 .58282 .31678 Metetra
0 .038 .545 r
.58282 .31678 .58386 .31779 .57515 .31019 .5741 .30759 Metetra
.922 .531 .161 r
.5741 .30759 .57515 .31019 .56632 .30062 .56527 .29995 Metetra
0 .376 .838 r
.56527 .29995 .56632 .30062 .55743 .30115 .5563 .28897 Metetra
.981 .711 .441 r
.5563 .28897 .55743 .30115 .54841 .30443 .54723 .2787 Metetra
.98 .728 .48 r
.54723 .2787 .54841 .30443 .53924 .30879 .53804 .27054 Metetra
.975 .728 .499 r
.53804 .27054 .53924 .30879 .5299 .3118 .52876 .27808 Metetra
.979 .731 .488 r
.52876 .27808 .5299 .3118 .52041 .3203 .51929 .27152 Metetra
.978 .733 .497 r
.51929 .27152 .52041 .3203 .51074 .31771 .50969 .26886 Metetra
.976 .731 .501 r
.50969 .26886 .51074 .31771 .50088 .3357 .49991 .27556 Metetra
.982 .739 .49 r
.49991 .27556 .50088 .3357 .49097 .30097 .49005 .25148 Metetra
.98 .736 .492 r
.49005 .25148 .49097 .30097 .48093 .28196 .48004 .23908 Metetra
.98 .734 .49 r
.48004 .23908 .48093 .28196 .47072 .27019 .46989 .22747 Metetra
.98 .733 .491 r
.46989 .22747 .47072 .27019 .46053 .23711 .45958 .21831 Metetra
.98 .721 .466 r
.45958 .21831 .46053 .23711 .45009 .22293 .44912 .20886 Metetra
.979 .712 .452 r
.44912 .20886 .45009 .22293 .43949 .21088 .43849 .1997 Metetra
.977 .702 .44 r
.43849 .1997 .43949 .21088 .42871 .20015 .42769 .19247 Metetra
.975 .682 .398 r
.42769 .19247 .42871 .20015 .41777 .18995 .41674 .18295 Metetra
.975 .675 .378 r
.41674 .18295 .41777 .18995 .40663 .18186 .40566 .17182 Metetra
.974 .694 .437 r
.40566 .17182 .40663 .18186 .39535 .17168 .39429 .16667 Metetra
.94 .626 .415 r
.39429 .16667 .39535 .17168 .38409 .15123 .38251 .17308 Metetra
.965 .746 .559 r
.38251 .17308 .38409 .15123 .37247 .14094 .37133 .14009 Metetra
.856 .443 0 r
.60104 .34151 .6021 .34375 .59357 .33296 .59251 .33049 Metetra
.86 .462 0 r
.59251 .33049 .59357 .33296 .58495 .3236 .58386 .31779 Metetra
.972 .667 .371 r
.58386 .31779 .58495 .3236 .57624 .31522 .57515 .31019 Metetra
.97 .652 .33 r
.57515 .31019 .57624 .31522 .56741 .30731 .56632 .30062 Metetra
.963 .671 .43 r
.56632 .30062 .56741 .30731 .5585 .30431 .55743 .30115 Metetra
.927 .584 .367 r
.55743 .30115 .5585 .30431 .54945 .30222 .54841 .30443 Metetra
.961 .943 .691 r
.54841 .30443 .54945 .30222 .54032 .31291 .53924 .30879 Metetra
.942 .619 .394 r
.53924 .30879 .54032 .31291 .53098 .3123 .5299 .3118 Metetra
.65 .192 .152 r
.5299 .3118 .53098 .3123 .52147 .30659 .52041 .3203 Metetra
.981 .774 .553 r
.52041 .3203 .52147 .30659 .51183 .29838 .51074 .31771 Metetra
.992 .779 .517 r
.51074 .31771 .51183 .29838 .50205 .29158 .50088 .3357 Metetra
.971 .744 .537 r
.50088 .3357 .50205 .29158 .49213 .28134 .49097 .30097 Metetra
.97 .754 .554 r
.49097 .30097 .49213 .28134 .48207 .27254 .48093 .28196 Metetra
.969 .774 .587 r
.48093 .28196 .48207 .27254 .47186 .26367 .47072 .27019 Metetra
.918 .734 .638 r
.47072 .27019 .47186 .26367 .46164 .23741 .46053 .23711 Metetra
.36 .598 .937 r
.46053 .23711 .46164 .23741 .45124 .21924 .45009 .22293 Metetra
.941 .804 .68 r
.45009 .22293 .45124 .21924 .44065 .2065 .43949 .21088 Metetra
.953 .804 .658 r
.43949 .21088 .44065 .2065 .42988 .19645 .42871 .20015 Metetra
.948 .815 .678 r
.42871 .20015 .42988 .19645 .41895 .18668 .41777 .18995 Metetra
.95 .833 .694 r
.41777 .18995 .41895 .18668 .4077 .18578 .40663 .18186 Metetra
.953 .602 .263 r
.40663 .18186 .4077 .18578 .39637 .17854 .39535 .17168 Metetra
.977 .675 .327 r
.39535 .17168 .39637 .17854 .38487 .16996 .38409 .15123 Metetra
.98 .72 .464 r
.38409 .15123 .38487 .16996 .37351 .14636 .37247 .14094 Metetra
.853 .81 .807 r
.6021 .34375 .6031 .34247 .59458 .33175 .59357 .33296 Metetra
.854 .831 .823 r
.59357 .33296 .59458 .33175 .58595 .3207 .58495 .3236 Metetra
.94 .82 .698 r
.58495 .3236 .58595 .3207 .57725 .31306 .57624 .31522 Metetra
.923 .837 .741 r
.57624 .31522 .57725 .31306 .56845 .3073 .56741 .30731 Metetra
.26 .739 .934 r
.56741 .30731 .56845 .3073 .55954 .30345 .5585 .30431 Metetra
.815 .963 .904 r
.5585 .30431 .55954 .30345 .55052 .30473 .54945 .30222 Metetra
.881 .54 .401 r
.54945 .30222 .55052 .30473 .54133 .29948 .54032 .31291 Metetra
.983 .776 .55 r
.54032 .31291 .54133 .29948 .53201 .29744 .53098 .3123 Metetra
.978 .768 .553 r
.53098 .3123 .53201 .29744 .52253 .28996 .52147 .30659 Metetra
.977 .764 .551 r
.52147 .30659 .52253 .28996 .51292 .29451 .51183 .29838 Metetra
.96 .822 .663 r
.51183 .29838 .51292 .29451 .50314 .28959 .50205 .29158 Metetra
.905 .83 .762 r
.50205 .29158 .50314 .28959 .49328 .26566 .49213 .28134 Metetra
.976 .765 .554 r
.49213 .28134 .49328 .26566 .48322 .26095 .48207 .27254 Metetra
.974 .773 .57 r
.48207 .27254 .48322 .26095 .47313 .23789 .47186 .26367 Metetra
.969 .748 .548 r
.47186 .26367 .47313 .23789 .46282 .22794 .46164 .23741 Metetra
.96 .764 .594 r
.46164 .23741 .46282 .22794 .45238 .21678 .45124 .21924 Metetra
.912 .812 .735 r
.45124 .21924 .45238 .21678 .44176 .20736 .44065 .2065 Metetra
0 .161 .642 r
.44065 .2065 .44176 .20736 .43099 .19783 .42988 .19645 Metetra
.689 .191 0 r
.42988 .19645 .43099 .19783 .42006 .1882 .41895 .18668 Metetra
.835 .372 .098 r
.41895 .18668 .42006 .1882 .40902 .17435 .4077 .18578 Metetra
.977 .777 .57 r
.4077 .18578 .40902 .17435 .39769 .16853 .39637 .17854 Metetra
.974 .78 .58 r
.39637 .17854 .39769 .16853 .3862 .16111 .38487 .16996 Metetra
.952 .76 .606 r
.38487 .16996 .3862 .16111 .3748 .13996 .37351 .14636 Metetra
.947 .792 .656 r
.6031 .34247 .60407 .33832 .59556 .32768 .59458 .33175 Metetra
.946 .792 .659 r
.59458 .33175 .59556 .32768 .58699 .32078 .58595 .3207 Metetra
.407 .717 .987 r
.58595 .3207 .58699 .32078 .57824 .30734 .57725 .31306 Metetra
.971 .8 .613 r
.57725 .31306 .57824 .30734 .56943 .29995 .56845 .3073 Metetra
.978 .794 .588 r
.56845 .3073 .56943 .29995 .56058 .3022 .55954 .30345 Metetra
.884 .986 .814 r
.55954 .30345 .56058 .3022 .55153 .2967 .55052 .30473 Metetra
.976 .788 .585 r
.55052 .30473 .55153 .2967 .54246 .31676 .54133 .29948 Metetra
.976 .716 .473 r
.54133 .29948 .54246 .31676 .53313 .31728 .53201 .29744 Metetra
.979 .722 .471 r
.53201 .29744 .53313 .31728 .52363 .30636 .52253 .28996 Metetra
.971 .71 .481 r
.52253 .28996 .52363 .30636 .514 .29792 .51292 .29451 Metetra
.946 .59 .287 r
.51292 .29451 .514 .29792 .50423 .2929 .50314 .28959 Metetra
.808 .465 0 r
.50314 .28959 .50423 .2929 .49432 .28089 .49328 .26566 Metetra
.977 .713 .463 r
.49328 .26566 .49432 .28089 .48427 .27216 .48322 .26095 Metetra
.986 .711 .395 r
.48322 .26095 .48427 .27216 .47408 .26329 .47313 .23789 Metetra
.98 .727 .476 r
.47313 .23789 .47408 .26329 .46373 .25389 .46282 .22794 Metetra
.981 .728 .476 r
.46282 .22794 .46373 .25389 .45341 .22618 .45238 .21678 Metetra
.977 .695 .419 r
.45238 .21678 .45341 .22618 .44285 .21023 .44176 .20736 Metetra
.924 .535 .164 r
.44176 .20736 .44285 .21023 .43208 .20066 .43099 .19783 Metetra
.921 .531 .158 r
.43099 .19783 .43208 .20066 .42116 .19053 .42006 .1882 Metetra
.845 .425 0 r
.42006 .1882 .42116 .19053 .41008 .17951 .40902 .17435 Metetra
.963 .642 .357 r
.40902 .17435 .41008 .17951 .39877 .17244 .39769 .16853 Metetra
.952 .602 .289 r
.39769 .16853 .39877 .17244 .38742 .15733 .3862 .16111 Metetra
.916 .771 .686 r
.3862 .16111 .38742 .15733 .37585 .14482 .3748 .13996 Metetra
.935 .8 .687 r
.60407 .33832 .60504 .33513 .59649 .31986 .59556 .32768 Metetra
.973 .784 .589 r
.59556 .32768 .59649 .31986 .58787 .30767 .58699 .32078 Metetra
.97 .761 .567 r
.58699 .32078 .58787 .30767 .57918 .29841 .57824 .30734 Metetra
.973 .779 .581 r
.57824 .30734 .57918 .29841 .57043 .29404 .56943 .29995 Metetra
.988 .822 .588 r
.56943 .29995 .57043 .29404 .56156 .2923 .56058 .3022 Metetra
.977 .78 .572 r
.56058 .3022 .56156 .2923 .55253 .28628 .55153 .2967 Metetra
.999 .81 .51 r
.55153 .2967 .55253 .28628 .54343 .29505 .54246 .31676 Metetra
.982 .765 .533 r
.54246 .31676 .54343 .29505 .53413 .29196 .53313 .31728 Metetra
.977 .756 .538 r
.53313 .31728 .53413 .29196 .52467 .28446 .52363 .30636 Metetra
.978 .759 .541 r
.52363 .30636 .52467 .28446 .51508 .28099 .514 .29792 Metetra
.979 .767 .547 r
.514 .29792 .51508 .28099 .50532 .2852 .50423 .2929 Metetra
.965 .778 .602 r
.50423 .2929 .50532 .2852 .49548 .2587 .49432 .28089 Metetra
.978 .759 .541 r
.49432 .28089 .49548 .2587 .48548 .24686 .48427 .27216 Metetra
.978 .757 .537 r
.48427 .27216 .48548 .24686 .47536 .23285 .47408 .26329 Metetra
.978 .755 .533 r
.47408 .26329 .47536 .23285 .46508 .22163 .46373 .25389 Metetra
.971 .747 .541 r
.46373 .25389 .46508 .22163 .45466 .21092 .45341 .22618 Metetra
.971 .76 .563 r
.45341 .22618 .45466 .21092 .44407 .20113 .44285 .21023 Metetra
.972 .78 .586 r
.44285 .21023 .44407 .20113 .43335 .18876 .43208 .20066 Metetra
.974 .772 .57 r
.43208 .20066 .43335 .18876 .42244 .17978 .42116 .19053 Metetra
.972 .774 .578 r
.42116 .19053 .42244 .17978 .41133 .1723 .41008 .17951 Metetra
.973 .795 .602 r
.41008 .17951 .41133 .1723 .40008 .16245 .39877 .17244 Metetra
.967 .771 .588 r
.39877 .17244 .40008 .16245 .38873 .14892 .38742 .15733 Metetra
.968 .78 .598 r
.38742 .15733 .38873 .14892 .37716 .13762 .37585 .14482 Metetra
.946 .608 .195 r
.60504 .33513 .60612 .33923 .5975 .31875 .59649 .31986 Metetra
.827 .793 .82 r
.59649 .31986 .5975 .31875 .58893 .31002 .58787 .30767 Metetra
.892 .483 .066 r
.58787 .30767 .58893 .31002 .58026 .30197 .57918 .29841 Metetra
.951 .606 .308 r
.57918 .29841 .58026 .30197 .57147 .29393 .57043 .29404 Metetra
.294 .778 .912 r
.57043 .29404 .57147 .29393 .56256 .28597 .56156 .2923 Metetra
.972 .796 .605 r
.56156 .2923 .56256 .28597 .5536 .28917 .55253 .28628 Metetra
.901 .564 .399 r
.55253 .28628 .5536 .28917 .54444 .28412 .54343 .29505 Metetra
.98 .78 .562 r
.54343 .29505 .54444 .28412 .53517 .2846 .53413 .29196 Metetra
.972 .788 .597 r
.53413 .29196 .53517 .2846 .52575 .28754 .52467 .28446 Metetra
.938 .574 .281 r
.52467 .28446 .52575 .28754 .51616 .28285 .51508 .28099 Metetra
.871 .473 .279 r
.51508 .28099 .51616 .28285 .50641 .28435 .50532 .2852 Metetra
.732 .668 .786 r
.50532 .2852 .50641 .28435 .49655 .26619 .49548 .2587 Metetra
.978 .684 .382 r
.49548 .2587 .49655 .26619 .48656 .25198 .48548 .24686 Metetra
.968 .645 .295 r
.48548 .24686 .48656 .25198 .47646 .23237 .47536 .23285 Metetra
.709 .806 .925 r
.47536 .23285 .47646 .23237 .46621 .21823 .46508 .22163 Metetra
.942 .813 .688 r
.46508 .22163 .46621 .21823 .45582 .20469 .45466 .21092 Metetra
.966 .793 .618 r
.45466 .21092 .45582 .20469 .44523 .19658 .44407 .20113 Metetra
.951 .797 .655 r
.44407 .20113 .44523 .19658 .43446 .19074 .43335 .18876 Metetra
.85 .403 0 r
.43335 .18876 .43446 .19074 .42354 .18215 .42244 .17978 Metetra
.9 .485 .124 r
.42244 .17978 .42354 .18215 .41242 .17532 .41133 .1723 Metetra
.928 .544 .178 r
.41133 .1723 .41242 .17532 .40116 .16634 .40008 .16245 Metetra
.948 .595 .223 r
.40008 .16245 .40116 .16634 .38976 .15506 .38873 .14892 Metetra
.972 .661 .354 r
.38873 .14892 .38976 .15506 .37817 .14469 .37716 .13762 Metetra
.954 .754 .596 r
.60612 .33923 .60701 .32979 .59851 .31722 .5975 .31875 Metetra
.887 .837 .791 r
.5975 .31875 .59851 .31722 .58994 .30787 .58893 .31002 Metetra
.922 .835 .741 r
.58893 .31002 .58994 .30787 .58125 .29816 .58026 .30197 Metetra
.955 .811 .662 r
.58026 .30197 .58125 .29816 .57247 .29012 .57147 .29393 Metetra
.955 .812 .663 r
.57147 .29393 .57247 .29012 .56358 .2821 .56256 .28597 Metetra
.988 .864 .624 r
.56256 .28597 .56358 .2821 .55455 .27341 .5536 .28917 Metetra
.979 .767 .548 r
.5536 .28917 .55455 .27341 .54542 .26614 .54444 .28412 Metetra
.983 .769 .537 r
.54444 .28412 .54542 .26614 .53618 .26744 .53517 .2846 Metetra
.985 .772 .536 r
.53517 .2846 .53618 .26744 .52678 .26671 .52575 .28754 Metetra
.98 .762 .539 r
.52575 .28754 .52678 .26671 .51723 .26384 .51616 .28285 Metetra
.984 .769 .535 r
.51616 .28285 .51723 .26384 .50752 .26386 .50641 .28435 Metetra
.972 .754 .551 r
.50641 .28435 .50752 .26386 .49769 .24697 .49655 .26619 Metetra
.974 .758 .55 r
.49655 .26619 .49769 .24697 .48773 .23158 .48656 .25198 Metetra
.971 .754 .552 r
.48656 .25198 .48773 .23158 .47765 .21645 .47646 .23237 Metetra
.973 .761 .558 r
.47646 .23237 .47765 .21645 .4674 .20711 .46621 .21823 Metetra
.969 .768 .577 r
.46621 .21823 .4674 .20711 .45701 .19603 .45582 .20469 Metetra
.974 .784 .587 r
.45582 .20469 .45701 .19603 .44645 .18661 .44523 .19658 Metetra
.978 .783 .575 r
.44523 .19658 .44645 .18661 .4357 .18039 .43446 .19074 Metetra
.975 .778 .576 r
.43446 .19074 .4357 .18039 .4248 .17238 .42354 .18215 Metetra
.977 .783 .578 r
.42354 .18215 .4248 .17238 .4137 .16605 .41242 .17532 Metetra
.974 .782 .585 r
.41242 .17532 .4137 .16605 .40245 .15788 .40116 .16634 Metetra
.969 .782 .595 r
.40116 .16634 .40245 .15788 .39106 .14705 .38976 .15506 Metetra
.97 .786 .598 r
.38976 .15506 .39106 .14705 .3796 .13159 .37817 .14469 Metetra
.921 .791 .7 r
.60701 .32979 .608 .32689 .59953 .31712 .59851 .31722 Metetra
.576 .757 .964 r
.59851 .31722 .59953 .31712 .59097 .30818 .58994 .30787 Metetra
.284 .597 .95 r
.58994 .30787 .59097 .30818 .58232 .30132 .58125 .29816 Metetra
.942 .577 .221 r
.58125 .29816 .58232 .30132 .57352 .29011 .57247 .29012 Metetra
.489 .754 .988 r
.57247 .29012 .57352 .29011 .56466 .28671 .56358 .2821 Metetra
.966 .639 .317 r
.56358 .2821 .56466 .28671 .55575 .29653 .55455 .27341 Metetra
.98 .726 .476 r
.55455 .27341 .55575 .29653 .54673 .31775 .54542 .26614 Metetra
.978 .733 .497 r
.54542 .26614 .54673 .31775 .53741 .31391 .53618 .26744 Metetra
.978 .733 .495 r
.53618 .26744 .53741 .31391 .52795 .31161 .52678 .26671 Metetra
.979 .733 .493 r
.52678 .26671 .52795 .31161 .51834 .31283 .51723 .26384 Metetra
.978 .733 .496 r
.51723 .26384 .51834 .31283 .50856 .3342 .50752 .26386 Metetra
.981 .739 .494 r
.50752 .26386 .50856 .3342 .49868 .29407 .49769 .24697 Metetra
.982 .736 .488 r
.49769 .24697 .49868 .29407 .48868 .27209 .48773 .23158 Metetra
.982 .735 .484 r
.48773 .23158 .48868 .27209 .47854 .25677 .47765 .21645 Metetra
.98 .733 .488 r
.47765 .21645 .47854 .25677 .46824 .24631 .4674 .20711 Metetra
.981 .733 .486 r
.4674 .20711 .46824 .24631 .45791 .22149 .45701 .19603 Metetra
.98 .727 .476 r
.45701 .19603 .45791 .22149 .4473 .21389 .44645 .18661 Metetra
.979 .726 .481 r
.44645 .18661 .4473 .21389 .4366 .20022 .4357 .18039 Metetra
.979 .721 .468 r
.4357 .18039 .4366 .20022 .42569 .19046 .4248 .17238 Metetra
.978 .717 .466 r
.4248 .17238 .42569 .19046 .41462 .18057 .4137 .16605 Metetra
.978 .711 .452 r
.4137 .16605 .41462 .18057 .40329 .176 .40245 .15788 Metetra
.98 .719 .46 r
.40245 .15788 .40329 .176 .39192 .16323 .39106 .14705 Metetra
.982 .718 .447 r
.39106 .14705 .39192 .16323 .38058 .13996 .3796 .13159 Metetra
.981 .715 .446 r
.608 .32689 .60921 .34029 .60075 .33199 .59953 .31712 Metetra
.981 .717 .454 r
.59953 .31712 .60075 .33199 .59218 .32372 .59097 .30818 Metetra
.979 .717 .46 r
.59097 .30818 .59218 .32372 .58351 .3159 .58232 .30132 Metetra
.982 .718 .448 r
.58232 .30132 .58351 .3159 .57472 .30817 .57352 .29011 Metetra
.977 .719 .472 r
.57352 .29011 .57472 .30817 .56583 .30316 .56466 .28671 Metetra
.967 .708 .488 r
.56466 .28671 .56583 .30316 .55687 .30579 .55575 .29653 Metetra
.94 .669 .497 r
.55575 .29653 .55687 .30579 .54775 .30869 .54673 .31775 Metetra
.979 .787 .574 r
.54673 .31775 .54775 .30869 .5385 .31827 .53741 .31391 Metetra
.955 .628 .36 r
.53741 .31391 .5385 .31827 .52902 .30652 .52795 .31161 Metetra
.986 .834 .608 r
.52795 .31161 .52902 .30652 .51942 .30176 .51834 .31283 Metetra
.999 .809 .51 r
.51834 .31283 .51942 .30176 .50965 .33416 .50856 .3342 Metetra
.602 .54 .757 r
.50856 .3342 .50965 .33416 .4998 .28126 .49868 .29407 Metetra
.962 .755 .578 r
.49868 .29407 .4998 .28126 .48978 .27248 .48868 .27209 Metetra
.343 .563 .919 r
.48868 .27209 .48978 .27248 .47961 .26364 .47854 .25677 Metetra
.975 .675 .375 r
.47854 .25677 .47961 .26364 .46937 .24413 .46824 .24631 Metetra
.847 .732 .736 r
.46824 .24631 .46937 .24413 .459 .22481 .45791 .22149 Metetra
.942 .576 .242 r
.45791 .22149 .459 .22481 .44842 .21396 .4473 .21389 Metetra
.485 .681 .953 r
.4473 .21389 .44842 .21396 .43771 .20126 .4366 .20022 Metetra
.507 0 0 r
.4366 .20022 .43771 .20126 .42688 .1861 .42569 .19046 Metetra
.957 .81 .658 r
.42569 .19046 .42688 .1861 .41577 .18023 .41462 .18057 Metetra
.563 .885 .99 r
.41462 .18057 .41577 .18023 .40448 .17327 .40329 .176 Metetra
.922 .817 .724 r
.40329 .176 .40448 .17327 .39313 .16005 .39192 .16323 Metetra
.895 .761 .705 r
.39192 .16323 .39313 .16005 .38167 .14371 .38058 .13996 Metetra
.886 .842 .797 r
.60921 .34029 .61021 .33882 .60173 .32866 .60075 .33199 Metetra
.948 .814 .678 r
.60075 .33199 .60173 .32866 .59314 .31724 .59218 .32372 Metetra
.969 .789 .606 r
.59218 .32372 .59314 .31724 .58448 .30942 .58351 .3159 Metetra
.969 .79 .605 r
.58351 .3159 .58448 .30942 .57571 .30156 .57472 .30817 Metetra
.975 .796 .598 r
.57472 .30817 .57571 .30156 .56682 .29449 .56583 .30316 Metetra
.988 .799 .562 r
.56583 .30316 .56682 .29449 .55792 .30539 .55687 .30579 Metetra
.298 .783 .712 r
.55687 .30579 .55792 .30539 .54877 .30015 .54775 .30869 Metetra
.995 .812 .545 r
.54775 .30869 .54877 .30015 .53956 .31552 .5385 .31827 Metetra
.923 .807 .713 r
.5385 .31827 .53956 .31552 .53014 .32424 .52902 .30652 Metetra
.978 .718 .468 r
.52902 .30652 .53014 .32424 .52055 .342 .51942 .30176 Metetra
.968 .722 .51 r
.51942 .30176 .52055 .342 .51075 .33389 .50965 .33416 Metetra
.627 .529 .723 r
.50965 .33416 .51075 .33389 .50089 .28764 .4998 .28126 Metetra
.973 .669 .373 r
.4998 .28126 .50089 .28764 .49086 .27874 .48978 .27248 Metetra
.972 .667 .369 r
.48978 .27248 .49086 .27874 .48072 .26336 .47961 .26364 Metetra
.649 .681 .867 r
.47961 .26364 .48072 .26336 .47049 .24257 .46937 .24413 Metetra
.834 .757 .779 r
.46937 .24413 .47049 .24257 .46016 .21919 .459 .22481 Metetra
.961 .794 .629 r
.459 .22481 .46016 .21919 .44959 .20918 .44842 .21396 Metetra
.952 .795 .65 r
.44842 .21396 .44959 .20918 .43886 .19972 .43771 .20126 Metetra
.853 .799 .797 r
.43771 .20126 .43886 .19972 .42797 .18994 .42688 .1861 Metetra
.95 .601 .297 r
.42688 .1861 .42797 .18994 .41696 .17689 .41577 .18023 Metetra
.955 .84 .689 r
.41577 .18023 .41696 .17689 .40574 .16681 .40448 .17327 Metetra
.961 .787 .621 r
.40448 .17327 .40574 .16681 .39428 .15995 .39313 .16005 Metetra
.571 .701 .929 r
.39313 .16005 .39428 .15995 .3829 .14007 .38167 .14371 Metetra
0 .149 .664 r
.61021 .33882 .61125 .33976 .60273 .32647 .60173 .32866 Metetra
.905 .805 .738 r
.60173 .32866 .60273 .32647 .59417 .31704 .59314 .31724 Metetra
.605 .804 .976 r
.59314 .31724 .59417 .31704 .58553 .31018 .58448 .30942 Metetra
0 .195 .666 r
.58448 .30942 .58553 .31018 .57676 .3023 .57571 .30156 Metetra
0 .176 .63 r
.57571 .30156 .57676 .3023 .5679 .29887 .56682 .29449 Metetra
.924 .617 .443 r
.56682 .29449 .5679 .29887 .55892 .29556 .55792 .30539 Metetra
.978 .781 .571 r
.55792 .30539 .55892 .29556 .54986 .30447 .54877 .30015 Metetra
.91 .607 .458 r
.54877 .30015 .54986 .30447 .54058 .30058 .53956 .31552 Metetra
.99 .782 .53 r
.53956 .31552 .54058 .30058 .53117 .30214 .53014 .32424 Metetra
.991 .774 .513 r
.53014 .32424 .53117 .30214 .52159 .29712 .52055 .342 Metetra
.979 .752 .523 r
.52055 .342 .52159 .29712 .51186 .28905 .51075 .33389 Metetra
.969 .741 .539 r
.51075 .33389 .51186 .28905 .502 .27872 .50089 .28764 Metetra
.973 .781 .585 r
.50089 .28764 .502 .27872 .49201 .26458 .49086 .27874 Metetra
.971 .762 .565 r
.49086 .27874 .49201 .26458 .48189 .25069 .48072 .26336 Metetra
.964 .758 .577 r
.48072 .26336 .48189 .25069 .47167 .23224 .47049 .24257 Metetra
.956 .756 .593 r
.47049 .24257 .47167 .23224 .46128 .21849 .46016 .21919 Metetra
.764 .843 .911 r
.46016 .21919 .46128 .21849 .45075 .20516 .44959 .20918 Metetra
.955 .814 .666 r
.44959 .20918 .45075 .20516 .44005 .19423 .43886 .19972 Metetra
.964 .8 .63 r
.43886 .19972 .44005 .19423 .42925 .17885 .42797 .18994 Metetra
.971 .771 .577 r
.42797 .18994 .42925 .17885 .4181 .17669 .41696 .17689 Metetra
.576 .794 .982 r
.41696 .17689 .4181 .17669 .40689 .16658 .40574 .16681 Metetra
.541 .84 .999 r
.40574 .16681 .40689 .16658 .3955 .15632 .39428 .15995 Metetra
.917 .777 .69 r
.39428 .15995 .3955 .15632 .38403 .1414 .3829 .14007 Metetra
.796 .772 .831 r
.61125 .33976 .61226 .33884 .60382 .33036 .60273 .32647 Metetra
.957 .614 .262 r
.60273 .32647 .60382 .33036 .59521 .31722 .59417 .31704 Metetra
.285 .666 .971 r
.59417 .31704 .59521 .31722 .58655 .30887 .58553 .31018 Metetra
.875 .855 .819 r
.58553 .31018 .58655 .30887 .57781 .30304 .57676 .3023 Metetra
.569 0 0 r
.57676 .3023 .57781 .30304 .56896 .29959 .5679 .29887 Metetra
.56 0 0 r
.5679 .29887 .56896 .29959 .56002 .30171 .55892 .29556 Metetra
.946 .653 .452 r
.55892 .29556 .56002 .30171 .55089 .29852 .54986 .30447 Metetra
.977 .807 .606 r
.54986 .30447 .55089 .29852 .54168 .30826 .54058 .30058 Metetra
.964 .677 .438 r
.54058 .30058 .54168 .30826 .53225 .3058 .53117 .30214 Metetra
.951 .603 .3 r
.53117 .30214 .53225 .3058 .52268 .30692 .52159 .29712 Metetra
.978 .698 .424 r
.52159 .29712 .52268 .30692 .51295 .30774 .51186 .28905 Metetra
.981 .722 .461 r
.51186 .28905 .51295 .30774 .50308 .28984 .502 .27872 Metetra
.982 .707 .418 r
.502 .27872 .50308 .28984 .49311 .26484 .49201 .26458 Metetra
.395 .617 .94 r
.49201 .26458 .49311 .26484 .48303 .2446 .48189 .25069 Metetra
.947 .77 .631 r
.48189 .25069 .48303 .2446 .4728 .22905 .47167 .23224 Metetra
.928 .8 .699 r
.47167 .23224 .4728 .22905 .46241 .21795 .46128 .21849 Metetra
.72 .784 .903 r
.46128 .21849 .46241 .21795 .45184 .20883 .45075 .20516 Metetra
.947 .589 .228 r
.45075 .20516 .45184 .20883 .44116 .196 .44005 .19423 Metetra
.663 .226 0 r
.44005 .19423 .44116 .196 .43029 .18626 .42925 .17885 Metetra
.967 .672 .416 r
.42925 .17885 .43029 .18626 .41927 .17484 .4181 .17669 Metetra
.9 .849 .784 r
.4181 .17669 .41927 .17484 .40805 .16553 .40689 .16658 Metetra
.824 .857 .872 r
.40689 .16658 .40805 .16553 .39668 .15489 .3955 .15632 Metetra
.846 .808 .813 r
.3955 .15632 .39668 .15489 .3852 .1411 .38403 .1414 Metetra
0 .317 .781 r
.61226 .33884 .61329 .33951 .60487 .3319 .60382 .33036 Metetra
0 0 .428 r
.60382 .33036 .60487 .3319 .59626 .31866 .59521 .31722 Metetra
.727 .245 0 r
.59521 .31722 .59626 .31866 .58758 .30781 .58655 .30887 Metetra
.856 .892 .861 r
.58655 .30887 .58758 .30781 .57881 .29866 .57781 .30304 Metetra
.974 .825 .634 r
.57781 .30304 .57881 .29866 .56993 .29043 .56896 .29959 Metetra
.987 .795 .559 r
.56896 .29959 .56993 .29043 .56093 .28197 .56002 .30171 Metetra
.981 .764 .537 r
.56002 .30171 .56093 .28197 .55182 .2754 .55089 .29852 Metetra
.987 .769 .52 r
.55089 .29852 .55182 .2754 .54263 .28048 .54168 .30826 Metetra
.981 .759 .528 r
.54168 .30826 .54263 .28048 .53326 .27862 .53225 .3058 Metetra
.983 .761 .526 r
.53225 .3058 .53326 .27862 .52372 .27394 .52268 .30692 Metetra
.982 .758 .522 r
.52268 .30692 .52372 .27394 .51404 .27187 .51295 .30774 Metetra
.976 .75 .532 r
.51295 .30774 .51404 .27187 .50423 .2502 .50308 .28984 Metetra
.974 .747 .533 r
.50308 .28984 .50423 .2502 .4943 .23433 .49311 .26484 Metetra
.974 .751 .537 r
.49311 .26484 .4943 .23433 .48423 .22337 .48303 .2446 Metetra
.974 .756 .546 r
.48303 .2446 .48423 .22337 .474 .21451 .4728 .22905 Metetra
.975 .766 .559 r
.4728 .22905 .474 .21451 .46361 .20665 .46241 .21795 Metetra
.975 .775 .57 r
.46241 .21795 .46361 .20665 .45307 .19725 .45184 .20883 Metetra
.972 .77 .573 r
.45184 .20883 .45307 .19725 .44239 .18658 .44116 .196 Metetra
.973 .78 .583 r
.44116 .196 .44239 .18658 .43153 .17793 .43029 .18626 Metetra
.969 .781 .595 r
.43029 .18626 .43153 .17793 .42054 .16601 .41927 .17484 Metetra
.973 .784 .588 r
.41927 .17484 .42054 .16601 .4092 .1657 .40805 .16553 Metetra
.338 .667 .975 r
.40805 .16553 .4092 .1657 .39782 .15569 .39668 .15489 Metetra
0 .3 .785 r
.39668 .15489 .39782 .15569 .38644 .13703 .3852 .1411 Metetra
.955 .813 .663 r
.61329 .33951 .61426 .3358 .60572 .31901 .60487 .3319 Metetra
.97 .762 .566 r
.60487 .3319 .60572 .31901 .59717 .30839 .59626 .31866 Metetra
.971 .77 .576 r
.59626 .31866 .59717 .30839 .58854 .30039 .58758 .30781 Metetra
.969 .782 .596 r
.58758 .30781 .58854 .30039 .5798 .29248 .57881 .29866 Metetra
.968 .791 .61 r
.57881 .29866 .5798 .29248 .57091 .28214 .56993 .29043 Metetra
.972 .781 .587 r
.56993 .29043 .57091 .28214 .56195 .27622 .56093 .28197 Metetra
.971 .8 .614 r
.56093 .28197 .56195 .27622 .55288 .27385 .55182 .2754 Metetra
.886 .987 .722 r
.55182 .2754 .55288 .27385 .54367 .27218 .54263 .28048 Metetra
.982 .795 .575 r
.54263 .28048 .54367 .27218 .5343 .26997 .53326 .27862 Metetra
.979 .788 .578 r
.53326 .27862 .5343 .26997 .5248 .26984 .52372 .27394 Metetra
.977 .84 .642 r
.52372 .27394 .5248 .26984 .51513 .26284 .51404 .27187 Metetra
.954 .758 .6 r
.51404 .27187 .51513 .26284 .50533 .24957 .50423 .2502 Metetra
.734 .749 .864 r
.50423 .2502 .50533 .24957 .49541 .23226 .4943 .23433 Metetra
.906 .827 .758 r
.4943 .23433 .49541 .23226 .48534 .22195 .48423 .22337 Metetra
.877 .859 .82 r
.48423 .22337 .48534 .22195 .47512 .21202 .474 .21451 Metetra
.936 .847 .73 r
.474 .21451 .47512 .21202 .46479 .19828 .46361 .20665 Metetra
.972 .784 .591 r
.46361 .20665 .46479 .19828 .45426 .19008 .45307 .19725 Metetra
.968 .787 .606 r
.45307 .19725 .45426 .19008 .44355 .18365 .44239 .18658 Metetra
.943 .836 .709 r
.44239 .18658 .44355 .18365 .43266 .17778 .43153 .17793 Metetra
.571 .757 .966 r
.43153 .17793 .43266 .17778 .42155 .17548 .42054 .16601 Metetra
.969 .686 .44 r
.42054 .16601 .42155 .17548 .41035 .16563 .4092 .1657 Metetra
.497 .763 .99 r
.4092 .1657 .41035 .16563 .39876 .16805 .39782 .15569 Metetra
.984 .711 .417 r
.39782 .15569 .39876 .16805 .3875 .14204 .38644 .13703 Metetra
.948 .765 .622 r
.61426 .3358 .61519 .32949 .60672 .31702 .60572 .31901 Metetra
.902 .813 .75 r
.60572 .31901 .60672 .31702 .59821 .30922 .59717 .30839 Metetra
0 .148 .629 r
.59717 .30839 .59821 .30922 .58956 .29904 .58854 .30039 Metetra
.879 .854 .814 r
.58854 .30039 .58956 .29904 .58081 .28924 .5798 .29248 Metetra
.939 .807 .686 r
.5798 .29248 .58081 .28924 .57195 .28086 .57091 .28214 Metetra
.882 .887 .831 r
.57091 .28214 .57195 .28086 .56316 .29746 .56195 .27622 Metetra
.978 .722 .477 r
.56195 .27622 .56316 .29746 .55408 .29788 .55288 .27385 Metetra
.978 .724 .481 r
.55288 .27385 .55408 .29788 .54494 .31661 .54367 .27218 Metetra
.979 .733 .492 r
.54367 .27218 .54494 .31661 .53564 .34929 .5343 .26997 Metetra
.979 .737 .498 r
.5343 .26997 .53564 .34929 .52604 .3537 .5248 .26984 Metetra
.98 .738 .497 r
.5248 .26984 .52604 .3537 .51627 .38412 .51513 .26284 Metetra
.981 .74 .498 r
.51513 .26284 .51627 .38412 .50633 .33743 .50533 .24957 Metetra
.982 .74 .494 r
.50533 .24957 .50633 .33743 .49637 .28396 .49541 .23226 Metetra
.981 .736 .49 r
.49541 .23226 .49637 .28396 .48627 .26527 .48534 .22195 Metetra
.981 .734 .487 r
.48534 .22195 .48627 .26527 .47601 .25087 .47512 .21202 Metetra
.982 .734 .482 r
.47512 .21202 .47601 .25087 .46574 .22007 .46479 .19828 Metetra
.98 .723 .469 r
.46479 .19828 .46574 .22007 .45521 .2098 .45426 .19008 Metetra
.979 .72 .468 r
.45426 .19008 .45521 .2098 .4445 .20093 .44355 .18365 Metetra
.978 .716 .463 r
.44355 .18365 .4445 .20093 .43365 .19036 .43266 .17778 Metetra
.974 .702 .453 r
.43266 .17778 .43365 .19036 .42262 .18052 .42155 .17548 Metetra
.965 .639 .321 r
.42155 .17548 .42262 .18052 .41144 .16916 .41035 .16563 Metetra
.93 .582 .347 r
.41035 .16563 .41144 .16916 .40008 .15888 .39876 .16805 Metetra
.951 .756 .604 r
.39876 .16805 .40008 .15888 .38872 .13887 .3875 .14204 Metetra
.981 .694 .386 r
.61519 .32949 .61634 .33769 .60791 .32824 .60672 .31702 Metetra
.98 .707 .436 r
.60672 .31702 .60791 .32824 .59938 .32007 .59821 .30922 Metetra
.981 .707 .426 r
.59821 .30922 .59938 .32007 .59071 .30859 .58956 .29904 Metetra
.98 .7 .416 r
.58956 .29904 .59071 .30859 .58201 .30454 .58081 .28924 Metetra
.981 .717 .454 r
.58081 .28924 .58201 .30454 .57314 .29668 .57195 .28086 Metetra
.962 .702 .495 r
.57195 .28086 .57314 .29668 .56427 .30427 .56316 .29746 Metetra
.964 .67 .425 r
.56316 .29746 .56427 .30427 .55518 .3035 .55408 .29788 Metetra
.92 .631 .478 r
.55408 .29788 .55518 .3035 .54609 .33116 .54494 .31661 Metetra
.946 .686 .512 r
.54494 .31661 .54609 .33116 .53669 .33684 .53564 .34929 Metetra
.988 .786 .543 r
.53564 .34929 .53669 .33684 .52705 .31193 .52604 .3537 Metetra
.989 .763 .502 r
.52604 .3537 .52705 .31193 .51739 .40903 .51627 .38412 Metetra
.992 .738 .426 r
.51627 .38412 .51739 .40903 .50747 .29485 .50633 .33743 Metetra
.967 .738 .542 r
.50633 .33743 .50747 .29485 .49747 .28636 .49637 .28396 Metetra
.739 .351 0 r
.49637 .28396 .49747 .28636 .48739 .26152 .48627 .26527 Metetra
.935 .793 .679 r
.48627 .26527 .48739 .26152 .47716 .24554 .47601 .25087 Metetra
.911 .737 .653 r
.47601 .25087 .47716 .24554 .46681 .22706 .46574 .22007 Metetra
.975 .675 .376 r
.46574 .22007 .46681 .22706 .45627 .21716 .45521 .2098 Metetra
.975 .678 .389 r
.45521 .2098 .45627 .21716 .44566 .1985 .4445 .20093 Metetra
.922 .833 .739 r
.4445 .20093 .44566 .1985 .43471 .19653 .43365 .19036 Metetra
.972 .662 .358 r
.43365 .19036 .43471 .19653 .42374 .18211 .42262 .18052 Metetra
.716 .238 0 r
.42262 .18052 .42374 .18211 .41245 .17876 .41144 .16916 Metetra
.978 .694 .413 r
.41144 .16916 .41245 .17876 .40124 .15854 .40008 .15888 Metetra
.654 .698 .879 r
.40008 .15888 .40124 .15854 .38986 .14012 .38872 .13887 Metetra
.978 .683 .382 r
.61634 .33769 .61747 .34476 .60896 .32949 .60791 .32824 Metetra
.647 .15 0 r
.60791 .32824 .60896 .32949 .60036 .31562 .59938 .32007 Metetra
.95 .79 .649 r
.59938 .32007 .60036 .31562 .59174 .30758 .59071 .30859 Metetra
.855 .925 .875 r
.59071 .30859 .59174 .30758 .58301 .30025 .58201 .30454 Metetra
.96 .808 .647 r
.58201 .30454 .58301 .30025 .57422 .29991 .57314 .29668 Metetra
.915 .583 .4 r
.57314 .29668 .57422 .29991 .56533 .30397 .56427 .30427 Metetra
.444 .873 .919 r
.56427 .30427 .56533 .30397 .55627 .30592 .55518 .3035 Metetra
.815 .514 .479 r
.55518 .3035 .55627 .30592 .54705 .30784 .54609 .33116 Metetra
.986 .767 .523 r
.54609 .33116 .54705 .30784 .53766 .30423 .53669 .33684 Metetra
.973 .748 .537 r
.53669 .33684 .53766 .30423 .52812 .30117 .52705 .31193 Metetra
.706 .633 .072 r
.52705 .31193 .52812 .30117 .51844 .31648 .51739 .40903 Metetra
.966 .733 .535 r
.51739 .40903 .51844 .31648 .50858 .28598 .50747 .29485 Metetra
.974 .782 .584 r
.50747 .29485 .50858 .28598 .49862 .27003 .49747 .28636 Metetra
.965 .752 .565 r
.49747 .28636 .49862 .27003 .48854 .25235 .48739 .26152 Metetra
.964 .769 .592 r
.48739 .26152 .48854 .25235 .47834 .23414 .47716 .24554 Metetra
.965 .762 .58 r
.47716 .24554 .47834 .23414 .468 .21718 .46681 .22706 Metetra
.974 .778 .579 r
.46681 .22706 .468 .21718 .45748 .20766 .45627 .21716 Metetra
.962 .765 .593 r
.45627 .21716 .45748 .20766 .44679 .19787 .44566 .1985 Metetra
.695 .96 .945 r
.44566 .1985 .44679 .19787 .43607 .17754 .43471 .19653 Metetra
.975 .76 .549 r
.43471 .19653 .43607 .17754 .42493 .17849 .42374 .18211 Metetra
.97 .853 .67 r
.42374 .18211 .42493 .17849 .41375 .16857 .41245 .17876 Metetra
.962 .764 .59 r
.41245 .17876 .41375 .16857 .4024 .15836 .40124 .15854 Metetra
.607 .693 .904 r
.40124 .15854 .4024 .15836 .39103 .1398 .38986 .14012 Metetra
.968 .76 .568 r
.61747 .34476 .6183 .33192 .60981 .31702 .60896 .32949 Metetra
.97 .762 .568 r
.60896 .32949 .60981 .31702 .60128 .30648 .60036 .31562 Metetra
.974 .778 .578 r
.60036 .31562 .60128 .30648 .59267 .29846 .59174 .30758 Metetra
.975 .779 .577 r
.59174 .30758 .59267 .29846 .58394 .28937 .58301 .30025 Metetra
.984 .784 .554 r
.58301 .30025 .58394 .28937 .57509 .28004 .57422 .29991 Metetra
.986 .769 .527 r
.57422 .29991 .57509 .28004 .56614 .27158 .56533 .30397 Metetra
.983 .758 .52 r
.56533 .30397 .56614 .27158 .55708 .26586 .55627 .30592 Metetra
.983 .756 .517 r
.55627 .30592 .55708 .26586 .54792 .26706 .54705 .30784 Metetra
.981 .754 .52 r
.54705 .30784 .54792 .26706 .53858 .26169 .53766 .30423 Metetra
.981 .754 .519 r
.53766 .30423 .53858 .26169 .5291 .25815 .52812 .30117 Metetra
.986 .759 .51 r
.52812 .30117 .5291 .25815 .51948 .25745 .51844 .31648 Metetra
.976 .745 .525 r
.51844 .31648 .51948 .25745 .50971 .24838 .50858 .28598 Metetra
.977 .751 .528 r
.50858 .28598 .50971 .24838 .49981 .23011 .49862 .27003 Metetra
.977 .75 .528 r
.49862 .27003 .49981 .23011 .48978 .21426 .48854 .25235 Metetra
.977 .75 .529 r
.48854 .25235 .48978 .21426 .4796 .20491 .47834 .23414 Metetra
.976 .753 .535 r
.47834 .23414 .4796 .20491 .46927 .19553 .468 .21718 Metetra
.979 .76 .54 r
.468 .21718 .46927 .19553 .45878 .18603 .45748 .20766 Metetra
.978 .761 .54 r
.45748 .20766 .45878 .18603 .44813 .17713 .44679 .19787 Metetra
.972 .755 .55 r
.44679 .19787 .44813 .17713 .43731 .16855 .43607 .17754 Metetra
.986 .8 .568 r
.43607 .17754 .43731 .16855 .42634 .15862 .42493 .17849 Metetra
.978 .762 .543 r
.42493 .17849 .42634 .15862 .41516 .15146 .41375 .16857 Metetra
.978 .765 .55 r
.41375 .16857 .41516 .15146 .4035 .16177 .4024 .15836 Metetra
.905 .536 .084 r
.4024 .15836 .4035 .16177 .39233 .13232 .39103 .1398 Metetra
.727 .731 .854 r
.6183 .33192 .61932 .33137 .61081 .31528 .60981 .31702 Metetra
.89 .816 .769 r
.60981 .31702 .61081 .31528 .60231 .30628 .60128 .30648 Metetra
.608 .801 .974 r
.60128 .30648 .60231 .30628 .59371 .2984 .59267 .29846 Metetra
.543 .753 .974 r
.59267 .29846 .59371 .2984 .585 .29042 .58394 .28937 Metetra
0 .028 .536 r
.58394 .28937 .585 .29042 .57618 .28342 .57509 .28004 Metetra
.946 .586 .231 r
.57509 .28004 .57618 .28342 .56723 .27623 .56614 .27158 Metetra
.963 .639 .34 r
.56614 .27158 .56723 .27623 .55825 .28262 .55708 .26586 Metetra
.975 .714 .473 r
.55708 .26586 .55825 .28262 .54904 .27655 .54792 .26706 Metetra
.976 .695 .429 r
.54792 .26706 .54904 .27655 .5397 .2739 .53858 .26169 Metetra
.976 .705 .45 r
.53858 .26169 .5397 .2739 .53021 .26665 .5291 .25815 Metetra
.969 .685 .435 r
.5291 .25815 .53021 .26665 .52058 .26097 .51948 .25745 Metetra
.947 .588 .235 r
.51948 .25745 .52058 .26097 .5108 .2494 .50971 .24838 Metetra
0 .28 .781 r
.50971 .24838 .5108 .2494 .50089 .24006 .49981 .23011 Metetra
.983 .702 .398 r
.49981 .23011 .50089 .24006 .49084 .22978 .48978 .21426 Metetra
.981 .716 .451 r
.48978 .21426 .49084 .22978 .48067 .21422 .4796 .20491 Metetra
.978 .694 .413 r
.4796 .20491 .48067 .21422 .47034 .20298 .46927 .19553 Metetra
.976 .68 .387 r
.46927 .19553 .47034 .20298 .45982 .19671 .45878 .18603 Metetra
.978 .7 .426 r
.45878 .18603 .45982 .19671 .44918 .18571 .44813 .17713 Metetra
.976 .688 .406 r
.44813 .17713 .44918 .18571 .43839 .17398 .43731 .16855 Metetra
.968 .648 .334 r
.43731 .16855 .43839 .17398 .42741 .16398 .42634 .15862 Metetra
.965 .645 .349 r
.42634 .15862 .42741 .16398 .41632 .15073 .41516 .15146 Metetra
.41516 .15146 .41632 .15073 .40496 .14371 .4035 .16177 Metetra
.965 .75 .562 r
.4035 .16177 .40496 .14371 .39362 .12541 .39233 .13232 Metetra
.93 .771 .662 r
.61932 .33137 .62028 .32723 .61185 .31564 .61081 .31528 Metetra
.214 .567 .938 r
.61081 .31528 .61185 .31564 .60335 .30664 .60231 .30628 Metetra
.145 .551 .925 r
.60231 .30628 .60335 .30664 .59474 .29711 .59371 .2984 Metetra
.872 .855 .822 r
.59371 .2984 .59474 .29711 .58602 .28834 .585 .29042 Metetra
.927 .851 .748 r
.585 .29042 .58602 .28834 .57719 .27961 .57618 .28342 Metetra
.959 .818 .66 r
.57618 .28342 .57719 .27961 .5683 .27719 .56723 .27623 Metetra
.766 .325 .205 r
.56723 .27623 .5683 .27719 .55926 .27413 .55825 .28262 Metetra
.977 .786 .58 r
.55825 .28262 .55926 .27413 .55007 .2699 .54904 .27655 Metetra
.981 .805 .592 r
.54904 .27655 .55007 .2699 .54075 .26583 .5397 .2739 Metetra
.975 .786 .587 r
.5397 .2739 .54075 .26583 .53128 .26416 .53021 .26665 Metetra
.946 .859 .723 r
.53021 .26665 .53128 .26416 .52167 .26167 .52058 .26097 Metetra
0 .359 .825 r
.52058 .26097 .52167 .26167 .5119 .24466 .5108 .2494 Metetra
.961 .804 .642 r
.5108 .2494 .5119 .24466 .50201 .22977 .50089 .24006 Metetra
.974 .775 .576 r
.50089 .24006 .50201 .22977 .49197 .22051 .49084 .22978 Metetra
.965 .77 .59 r
.49084 .22978 .49197 .22051 .48181 .20661 .48067 .21422 Metetra
.968 .783 .6 r
.48067 .21422 .48181 .20661 .47149 .19713 .47034 .20298 Metetra
.973 .807 .616 r
.47034 .20298 .47149 .19713 .461 .18938 .45982 .19671 Metetra
.968 .786 .603 r
.45982 .19671 .461 .18938 .45034 .1821 .44918 .18571 Metetra
.944 .811 .683 r
.44918 .18571 .45034 .1821 .43954 .17281 .43839 .17398 Metetra
.842 .858 .855 r
.43839 .17398 .43954 .17281 .42857 .16294 .42741 .16398 Metetra
.811 .818 .856 r
.42741 .16398 .42857 .16294 .41747 .15094 .41632 .15073 Metetra
.149 .616 .927 r
.41632 .15073 .41747 .15094 .40613 .14268 .40496 .14371 Metetra
.787 .766 .834 r
.40496 .14371 .40613 .14268 .39475 .12713 .39362 .12541 Metetra
.958 .782 .622 r
.62028 .32723 .62121 .32149 .61278 .3088 .61185 .31564 Metetra
.968 .785 .601 r
.61185 .31564 .61278 .3088 .60423 .29487 .60335 .30664 Metetra
.975 .769 .564 r
.60335 .30664 .60423 .29487 .59565 .28677 .59474 .29711 Metetra
.974 .774 .571 r
.59474 .29711 .59565 .28677 .58696 .27874 .58602 .28834 Metetra
.974 .776 .576 r
.58602 .28834 .58696 .27874 .57815 .26954 .57719 .27961 Metetra
.982 .785 .562 r
.57719 .27961 .57815 .26954 .5692 .25897 .5683 .27719 Metetra
.982 .766 .537 r
.5683 .27719 .5692 .25897 .56018 .25397 .55926 .27413 Metetra
.981 .764 .535 r
.55926 .27413 .56018 .25397 .55105 .25364 .55007 .2699 Metetra
.981 .769 .543 r
.55007 .2699 .55105 .25364 .54177 .2519 .54075 .26583 Metetra
.983 .775 .546 r
.54075 .26583 .54177 .2519 .53233 .25174 .53128 .26416 Metetra
.983 .778 .553 r
.53128 .26416 .53233 .25174 .52274 .25131 .52167 .26167 Metetra
.965 .764 .584 r
.52167 .26167 .52274 .25131 .51299 .24188 .5119 .24466 Metetra
.913 .793 .715 r
.5119 .24466 .51299 .24188 .50312 .22523 .50201 .22977 Metetra
.96 .807 .647 r
.50201 .22977 .50312 .22523 .49312 .2083 .49197 .22051 Metetra
.972 .767 .569 r
.49197 .22051 .49312 .2083 .48299 .19333 .48181 .20661 Metetra
.977 .77 .56 r
.48181 .20661 .48299 .19333 .47269 .18362 .47149 .19713 Metetra
.978 .772 .557 r
.47149 .19713 .47269 .18362 .46224 .17493 .461 .18938 Metetra
.979 .771 .553 r
.461 .18938 .46224 .17493 .4516 .16874 .45034 .1821 Metetra
.977 .771 .56 r
.45034 .1821 .4516 .16874 .44082 .15932 .43954 .17281 Metetra
.977 .771 .56 r
.43954 .17281 .44082 .15932 .42979 .15684 .42857 .16294 Metetra
.963 .792 .623 r
.42857 .16294 .42979 .15684 .41866 .1478 .41747 .15094 Metetra
.949 .839 .7 r
.41747 .15094 .41866 .1478 .40722 .14671 .40613 .14268 Metetra
.945 .593 .202 r
.40613 .14268 .40722 .14671 .39607 .118 .39475 .12713 Metetra
.923 .558 .13 r
.62121 .32149 .62229 .32474 .61385 .31177 .61278 .3088 Metetra
.891 .516 .051 r
.61278 .3088 .61385 .31177 .60536 .30206 .60423 .29487 Metetra
.977 .683 .389 r
.60423 .29487 .60536 .30206 .59678 .29411 .59565 .28677 Metetra
.977 .684 .392 r
.59565 .28677 .59678 .29411 .58813 .28974 .58696 .27874 Metetra
.981 .706 .428 r
.58696 .27874 .58813 .28974 .57935 .2847 .57815 .26954 Metetra
.982 .718 .447 r
.57815 .26954 .57935 .2847 .57057 .29613 .5692 .25897 Metetra
.98 .732 .485 r
.5692 .25897 .57057 .29613 .56154 .29508 .56018 .25397 Metetra
.979 .732 .49 r
.56018 .25397 .56154 .29508 .55239 .29991 .55105 .25364 Metetra
.98 .733 .49 r
.55105 .25364 .55239 .29991 .54304 .29645 .54177 .2519 Metetra
.979 .732 .491 r
.54177 .2519 .54304 .29645 .53356 .29991 .53233 .25174 Metetra
.979 .733 .491 r
.53233 .25174 .53356 .29991 .52398 .34427 .52274 .25131 Metetra
.981 .739 .495 r
.52274 .25131 .52398 .34427 .51409 .31061 .51299 .24188 Metetra
.982 .739 .489 r
.51299 .24188 .51409 .31061 .50415 .27399 .50312 .22523 Metetra
.983 .737 .483 r
.50312 .22523 .50415 .27399 .49409 .253 .49312 .2083 Metetra
.983 .735 .482 r
.49312 .2083 .49409 .253 .48393 .23114 .48299 .19333 Metetra
.981 .732 .482 r
.48299 .19333 .48393 .23114 .47361 .21611 .47269 .18362 Metetra
.981 .73 .479 r
.47269 .18362 .47361 .21611 .46312 .20663 .46224 .17493 Metetra
.98 .729 .48 r
.46224 .17493 .46312 .20663 .45247 .197 .4516 .16874 Metetra
.981 .728 .475 r
.4516 .16874 .45247 .197 .44165 .18725 .44082 .15932 Metetra
.979 .725 .48 r
.44082 .15932 .44165 .18725 .43068 .17733 .42979 .15684 Metetra
.981 .721 .463 r
.42979 .15684 .43068 .17733 .41954 .16704 .41866 .1478 Metetra
.976 .716 .47 r
.41866 .1478 .41954 .16704 .40828 .15304 .40722 .14671 Metetra
.96 .654 .237 r
.40722 .14671 .40828 .15304 .39686 .139 .39607 .118 Metetra
.748 .762 .864 r
.62229 .32474 .62331 .32413 .61486 .31043 .61385 .31177 Metetra
.867 .828 .808 r
.61385 .31177 .61486 .31043 .6064 .30204 .60536 .30206 Metetra
.492 .752 .987 r
.60536 .30206 .6064 .30204 .59782 .29378 .59678 .29411 Metetra
.614 .887 .99 r
.59678 .29411 .59782 .29378 .58914 .28615 .58813 .28974 Metetra
.965 .832 .662 r
.58813 .28974 .58914 .28615 .5804 .28465 .57935 .2847 Metetra
.459 .019 .113 r
.57935 .2847 .5804 .28465 .5715 .28104 .57057 .29613 Metetra
.984 .773 .541 r
.57057 .29613 .5715 .28104 .5626 .29411 .56154 .29508 Metetra
.68 .961 .732 r
.56154 .29508 .5626 .29411 .55345 .297 .55239 .29991 Metetra
.963 .861 .691 r
.55239 .29991 .55345 .297 .54411 .29376 .54304 .29645 Metetra
.975 .916 .672 r
.54304 .29645 .54411 .29376 .53462 .28935 .53356 .29991 Metetra
.982 .815 .414 r
.53356 .29991 .53462 .28935 .52509 .34648 .52398 .34427 Metetra
0 .046 .601 r
.52398 .34427 .52509 .34648 .5152 .29367 .51409 .31061 Metetra
.957 .742 .571 r
.51409 .31061 .5152 .29367 .50524 .29014 .50415 .27399 Metetra
.986 .722 .43 r
.50415 .27399 .50524 .29014 .49524 .24128 .49409 .253 Metetra
.962 .758 .581 r
.49409 .253 .49524 .24128 .48504 .23292 .48393 .23114 Metetra
.655 .223 0 r
.48393 .23114 .48504 .23292 .47474 .2151 .47361 .21611 Metetra
.825 .859 .873 r
.47361 .21611 .47474 .2151 .46425 .20563 .46312 .20663 Metetra
.821 .859 .876 r
.46312 .20663 .46425 .20563 .45361 .196 .45247 .197 Metetra
.821 .86 .876 r
.45247 .197 .45361 .196 .44281 .18622 .44165 .18725 Metetra
.825 .859 .873 r
.44165 .18725 .44281 .18622 .43184 .17637 .43068 .17733 Metetra
.811 .856 .882 r
.43068 .17733 .43184 .17637 .42073 .16423 .41954 .16704 Metetra
.921 .81 .72 r
.41954 .16704 .42073 .16423 .40952 .14822 .40828 .15304 Metetra
.952 .796 .651 r
.40828 .15304 .40952 .14822 .39818 .13005 .39686 .139 Metetra
.974 .664 .312 r
.62331 .32413 .62443 .32995 .61595 .3143 .61486 .31043 Metetra
.957 .613 .269 r
.61486 .31043 .61595 .3143 .60743 .30217 .6064 .30204 Metetra
.393 .694 .981 r
.6064 .30204 .60743 .30217 .59885 .29296 .59782 .29378 Metetra
.809 .862 .888 r
.59782 .29378 .59885 .29296 .59017 .28502 .58914 .28615 Metetra
.876 .962 .852 r
.58914 .28615 .59017 .28502 .58145 .28461 .5804 .28465 Metetra
.328 .77 .963 r
.5804 .28465 .58145 .28461 .5726 .28525 .5715 .28104 Metetra
.916 .608 .446 r
.5715 .28104 .5726 .28525 .56373 .30207 .5626 .29411 Metetra
.964 .678 .442 r
.5626 .29411 .56373 .30207 .55463 .31428 .55345 .297 Metetra
.978 .717 .465 r
.55345 .297 .55463 .31428 .54533 .32298 .54411 .29376 Metetra
.98 .728 .48 r
.54411 .29376 .54533 .32298 .53575 .30162 .53462 .28935 Metetra
.913 .655 .534 r
.53462 .28935 .53575 .30162 .52613 .31514 .52509 .34648 Metetra
.962 .737 .551 r
.52509 .34648 .52613 .31514 .5163 .29781 .5152 .29367 Metetra
.954 .616 .331 r
.5152 .29367 .5163 .29781 .50635 .28928 .50524 .29014 Metetra
.686 .576 .726 r
.50524 .29014 .50635 .28928 .49628 .26683 .49524 .24128 Metetra
.981 .727 .472 r
.49524 .24128 .49628 .26683 .48617 .23052 .48504 .23292 Metetra
.889 .779 .734 r
.48504 .23292 .48617 .23052 .47586 .21494 .47474 .2151 Metetra
.561 .789 .984 r
.47474 .2151 .47586 .21494 .46538 .20544 .46425 .20563 Metetra
.576 .794 .982 r
.46425 .20563 .46538 .20544 .45475 .1958 .45361 .196 Metetra
.576 .794 .982 r
.45361 .196 .45475 .1958 .44395 .18604 .44281 .18622 Metetra
.561 .789 .985 r
.44281 .18622 .44395 .18604 .43299 .17619 .43184 .17637 Metetra
.582 .762 .964 r
.43184 .17637 .43299 .17619 .42186 .16608 .42073 .16423 Metetra
.679 .245 0 r
.42073 .16423 .42186 .16608 .41055 .15595 .40952 .14822 Metetra
.979 .682 .351 r
.40952 .14822 .41055 .15595 .39919 .13908 .39818 .13005 Metetra
.738 .728 .842 r
.62443 .32995 .62545 .32933 .61701 .31604 .61595 .3143 Metetra
.686 .251 0 r
.61595 .3143 .61701 .31604 .60851 .30524 .60743 .30217 Metetra
.934 .562 .179 r
.60743 .30217 .60851 .30524 .59987 .29104 .59885 .29296 Metetra
.916 .844 .759 r
.59885 .29296 .59987 .29104 .59121 .28391 .59017 .28502 Metetra
.867 .979 .849 r
.59017 .28502 .59121 .28391 .58248 .28223 .58145 .28461 Metetra
.967 .91 .703 r
.58145 .28461 .58248 .28223 .57362 .28016 .5726 .28525 Metetra
.989 .865 .51 r
.5726 .28525 .57362 .28016 .56471 .29115 .56373 .30207 Metetra
.996 .8 .526 r
.56373 .30207 .56471 .29115 .55567 .30805 .55463 .31428 Metetra
.997 .836 .559 r
.55463 .31428 .55567 .30805 .54634 .30784 .54533 .32298 Metetra
.967 .755 .565 r
.54533 .32298 .54634 .30784 .53707 .36842 .53575 .30162 Metetra
.978 .734 .499 r
.53575 .30162 .53707 .36842 .52737 .38234 .52613 .31514 Metetra
.983 .739 .488 r
.52613 .31514 .52737 .38234 .51741 .29939 .5163 .29781 Metetra
.767 .287 0 r
.5163 .29781 .51741 .29939 .50745 .30028 .50635 .28928 Metetra
.986 .708 .385 r
.50635 .28928 .50745 .30028 .49745 .2445 .49628 .26683 Metetra
.964 .744 .556 r
.49628 .26683 .49745 .2445 .48729 .22883 .48617 .23052 Metetra
.862 .792 .781 r
.48617 .23052 .48729 .22883 .47699 .21465 .47586 .21494 Metetra
.627 .814 .972 r
.47586 .21494 .47699 .21465 .46652 .20509 .46538 .20544 Metetra
.649 .822 .966 r
.46538 .20544 .46652 .20509 .45588 .19548 .45475 .1958 Metetra
.638 .819 .97 r
.45475 .1958 .45588 .19548 .44509 .18577 .44395 .18604 Metetra
.614 .811 .976 r
.44395 .18604 .44509 .18577 .43417 .17357 .43299 .17619 Metetra
.931 .837 .729 r
.43299 .17619 .43417 .17357 .42306 .16231 .42186 .16608 Metetra
.952 .82 .677 r
.42186 .16608 .42306 .16231 .41176 .15284 .41055 .15595 Metetra
.918 .794 .708 r
.41055 .15595 .41176 .15284 .40037 .13802 .39919 .13908 Metetra
.973 .662 .312 r
.62545 .32933 .62657 .33507 .61815 .32296 .61701 .31604 Metetra
.978 .681 .367 r
.61701 .31604 .61815 .32296 .6096 .30872 .60851 .30524 Metetra
.923 .565 .13 r
.60851 .30524 .6096 .30872 .60103 .30028 .59987 .29104 Metetra
.978 .697 .419 r
.59987 .29104 .60103 .30028 .59235 .29249 .59121 .28391 Metetra
.972 .688 .432 r
.59121 .28391 .59235 .29249 .58363 .2915 .58248 .28223 Metetra
.973 .692 .436 r
.58248 .28223 .58363 .2915 .57482 .29572 .57362 .28016 Metetra
.967 .705 .484 r
.57362 .28016 .57482 .29572 .56579 .29267 .56471 .29115 Metetra
.795 .448 .4 r
.56471 .29115 .56579 .29267 .55664 .29221 .55567 .30805 Metetra
.985 .773 .538 r
.55567 .30805 .55664 .29221 .54733 .28943 .54634 .30784 Metetra
.995 .795 .428 r
.54634 .30784 .54733 .28943 .53789 .28886 .53707 .36842 Metetra
.984 .752 .506 r
.53707 .36842 .53789 .28886 .52826 .28039 .52737 .38234 Metetra
.972 .738 .525 r
.52737 .38234 .52826 .28039 .51849 .26619 .51741 .29939 Metetra
.983 .759 .519 r
.51741 .29939 .51849 .26619 .50861 .24222 .50745 .30028 Metetra
.971 .74 .531 r
.50745 .30028 .50861 .24222 .49862 .22197 .49745 .2445 Metetra
.976 .756 .541 r
.49745 .2445 .49862 .22197 .48846 .21451 .48729 .22883 Metetra
.974 .764 .56 r
.48729 .22883 .48846 .21451 .47816 .20522 .47699 .21465 Metetra
.975 .78 .58 r
.47699 .21465 .47816 .20522 .46772 .19396 .46652 .20509 Metetra
.976 .776 .569 r
.46652 .20509 .46772 .19396 .45715 .17968 .45588 .19548 Metetra
.978 .767 .551 r
.45588 .19548 .45715 .17968 .4464 .16971 .44509 .18577 Metetra
.977 .765 .553 r
.44509 .18577 .4464 .16971 .43548 .15976 .43417 .17357 Metetra
.976 .769 .559 r
.43417 .17357 .43548 .15976 .42439 .14986 .42306 .16231 Metetra
.977 .774 .563 r
.42306 .16231 .42439 .14986 .41301 .14698 .41176 .15284 Metetra
.957 .788 .631 r
.41176 .15284 .41301 .14698 .40167 .13029 .40037 .13802 Metetra
.974 .763 .559 r
.62657 .33507 .62737 .32136 .61902 .31265 .61815 .32296 Metetra
.967 .765 .578 r
.61815 .32296 .61902 .31265 .61058 .30479 .6096 .30872 Metetra
.956 .809 .657 r
.6096 .30872 .61058 .30479 .60202 .29611 .60103 .30028 Metetra
.961 .81 .649 r
.60103 .30028 .60202 .29611 .59333 .28657 .59235 .29249 Metetra
.984 .815 .594 r
.59235 .29249 .59333 .28657 .58456 .27978 .58363 .2915 Metetra
.989 .787 .54 r
.58363 .2915 .58456 .27978 .57567 .27243 .57482 .29572 Metetra
.982 .762 .529 r
.57482 .29572 .57567 .27243 .56664 .26417 .56579 .29267 Metetra
.983 .76 .522 r
.56579 .29267 .56664 .26417 .55754 .26414 .55664 .29221 Metetra
.982 .759 .524 r
.55664 .29221 .55754 .26414 .54832 .2714 .54733 .28943 Metetra
.984 .769 .534 r
.54733 .28943 .54832 .2714 .53889 .2671 .53789 .28886 Metetra
.98 .761 .536 r
.53789 .28886 .53889 .2671 .5293 .25751 .52826 .28039 Metetra
.977 .757 .539 r
.52826 .28039 .5293 .25751 .51958 .24433 .51849 .26619 Metetra
.971 .751 .549 r
.51849 .26619 .51958 .24433 .50972 .22817 .50861 .24222 Metetra
.968 .758 .567 r
.50861 .24222 .50972 .22817 .49975 .21198 .49862 .22197 Metetra
.978 .781 .572 r
.49862 .22197 .49975 .21198 .48962 .20182 .48846 .21451 Metetra
.977 .772 .561 r
.48846 .21451 .48962 .20182 .47935 .19206 .47816 .20522 Metetra
.976 .769 .561 r
.47816 .20522 .47935 .19206 .46893 .18135 .46772 .19396 Metetra
.973 .767 .567 r
.46772 .19396 .46893 .18135 .45836 .17164 .45715 .17968 Metetra
.972 .786 .593 r
.45715 .17968 .45836 .17164 .44761 .16292 .4464 .16971 Metetra
.97 .793 .608 r
.4464 .16971 .44761 .16292 .43669 .15375 .43548 .15976 Metetra
.968 .799 .62 r
.43548 .15976 .43669 .15375 .42561 .14416 .42439 .14986 Metetra
.98 .821 .613 r
.42439 .14986 .42561 .14416 .41437 .13393 .41301 .14698 Metetra
.971 .766 .568 r
.41301 .14698 .41437 .13393 .40297 .12268 .40167 .13029 Metetra
.952 .81 .667 r
.62737 .32136 .62834 .31775 .61992 .30418 .61902 .31265 Metetra
.974 .781 .581 r
.61902 .31265 .61992 .30418 .61139 .28912 .61058 .30479 Metetra
.978 .765 .548 r
.61058 .30479 .61139 .28912 .60286 .28087 .60202 .29611 Metetra
.977 .764 .55 r
.60202 .29611 .60286 .28087 .59422 .27276 .59333 .28657 Metetra
.979 .77 .551 r
.59333 .28657 .59422 .27276 .58545 .26453 .58456 .27978 Metetra
.979 .767 .547 r
.58456 .27978 .58545 .26453 .57657 .25626 .57567 .27243 Metetra
.979 .765 .546 r
.57567 .27243 .57657 .25626 .56758 .24841 .56664 .26417 Metetra
.985 .773 .537 r
.56664 .26417 .56758 .24841 .55851 .24961 .55754 .26414 Metetra
.99 .782 .529 r
.55754 .26414 .55851 .24961 .54927 .24697 .54832 .2714 Metetra
.982 .761 .529 r
.54832 .2714 .54927 .24697 .53989 .24388 .53889 .2671 Metetra
.979 .759 .535 r
.53889 .2671 .53989 .24388 .53037 .24613 .5293 .25751 Metetra
.972 .769 .571 r
.5293 .25751 .53037 .24613 .52066 .2335 .51958 .24433 Metetra
.968 .766 .578 r
.51958 .24433 .52066 .2335 .51083 .21119 .50972 .22817 Metetra
.974 .759 .553 r
.50972 .22817 .51083 .21119 .50088 .19868 .49975 .21198 Metetra
.977 .77 .559 r
.49975 .21198 .50088 .19868 .49081 .18085 .48962 .20182 Metetra
.979 .761 .539 r
.48962 .20182 .49081 .18085 .48055 .17576 .47935 .19206 Metetra
.978 .765 .55 r
.47935 .19206 .48055 .17576 .47015 .16766 .46893 .18135 Metetra
.978 .77 .557 r
.46893 .18135 .47015 .16766 .45955 .16362 .45836 .17164 Metetra
.974 .788 .591 r
.45836 .17164 .45955 .16362 .44883 .15384 .44761 .16292 Metetra
.975 .784 .582 r
.44761 .16292 .44883 .15384 .43795 .14378 .43669 .15375 Metetra
.976 .78 .577 r
.43669 .15375 .43795 .14378 .42683 .13967 .42561 .14416 Metetra
.959 .812 .654 r
.42561 .14416 .42683 .13967 .41543 .14076 .41437 .13393 Metetra
.974 .669 .362 r
.41437 .13393 .41543 .14076 .4043 .11259 .40297 .12268 Metetra
.947 .78 .643 r
.62834 .31775 .62928 .31297 .62083 .29672 .61992 .30418 Metetra
.959 .769 .604 r
.61992 .30418 .62083 .29672 .61242 .28877 .61139 .28912 Metetra
.675 .821 .953 r
.61139 .28912 .61242 .28877 .6039 .28074 .60286 .28087 Metetra
.57 .786 .981 r
.60286 .28087 .6039 .28074 .59526 .27252 .59422 .27276 Metetra
.621 .807 .971 r
.59422 .27276 .59526 .27252 .5865 .26398 .58545 .26453 Metetra
.74 .844 .929 r
.58545 .26453 .5865 .26398 .57763 .25617 .57657 .25626 Metetra
.53 .782 .99 r
.57657 .25626 .57763 .25617 .5687 .25643 .56758 .24841 Metetra
.967 .68 .435 r
.56758 .24841 .5687 .25643 .55957 .24801 .55851 .24961 Metetra
.923 .924 .794 r
.55851 .24961 .55957 .24801 .55038 .25163 .54927 .24697 Metetra
.959 .635 .355 r
.54927 .24697 .55038 .25163 .541 .25017 .53989 .24388 Metetra
.96 .66 .419 r
.53989 .24388 .541 .25017 .53148 .2545 .53037 .24613 Metetra
.98 .69 .384 r
.53037 .24613 .53148 .2545 .52177 .24345 .52066 .2335 Metetra
.985 .703 .368 r
.52066 .2335 .52177 .24345 .51193 .22041 .51083 .21119 Metetra
.981 .696 .397 r
.51083 .21119 .51193 .22041 .50197 .20673 .50088 .19868 Metetra
.981 .688 .355 r
.50088 .19868 .50197 .20673 .49188 .1937 .49081 .18085 Metetra
.978 .706 .445 r
.49081 .18085 .49188 .1937 .48163 .1841 .48055 .17576 Metetra
.976 .686 .402 r
.48055 .17576 .48163 .1841 .47123 .17453 .47015 .16766 Metetra
.969 .669 .397 r
.47015 .16766 .47123 .17453 .46064 .16859 .45955 .16362 Metetra
.965 .637 .312 r
.45955 .16362 .46064 .16859 .44992 .15876 .44883 .15384 Metetra
.964 .635 .308 r
.44883 .15384 .44992 .15876 .43903 .14977 .43795 .14378 Metetra
.965 .654 .378 r
.43795 .14378 .43903 .14977 .42788 .14721 .42683 .13967 Metetra
.964 .669 .422 r
.42683 .13967 .42788 .14721 .41665 .1365 .41543 .14076 Metetra
.906 .748 .674 r
.41543 .14076 .41665 .1365 .40545 .11364 .4043 .11259 Metetra
.617 .666 .875 r
.62928 .31297 .63031 .31286 .62189 .29826 .62083 .29672 Metetra
.762 .289 0 r
.62083 .29672 .62189 .29826 .61345 .28843 .61242 .28877 Metetra
.674 .825 .956 r
.61242 .28877 .61345 .28843 .60494 .28039 .6039 .28074 Metetra
.674 .823 .955 r
.6039 .28074 .60494 .28039 .5963 .27231 .59526 .27252 Metetra
.612 .797 .97 r
.59526 .27252 .5963 .27231 .58765 .27292 .5865 .26398 Metetra
.978 .694 .411 r
.5865 .26398 .58765 .27292 .57901 .28949 .57763 .25617 Metetra
.979 .729 .485 r
.57763 .25617 .57901 .28949 .57008 .29359 .5687 .25643 Metetra
.982 .733 .48 r
.5687 .25643 .57008 .29359 .56104 .30366 .55957 .24801 Metetra
.979 .734 .493 r
.55957 .24801 .56104 .30366 .55176 .30597 .55038 .25163 Metetra
.98 .735 .49 r
.55038 .25163 .55176 .30597 .54232 .30567 .541 .25017 Metetra
.979 .734 .493 r
.541 .25017 .54232 .30567 .53279 .33007 .53148 .2545 Metetra
.982 .738 .49 r
.53148 .2545 .53279 .33007 .52294 .29044 .52177 .24345 Metetra
.985 .738 .477 r
.52177 .24345 .52294 .29044 .51303 .27218 .51193 .22041 Metetra
.983 .736 .484 r
.51193 .22041 .51303 .27218 .503 .25421 .50197 .20673 Metetra
.983 .736 .482 r
.50197 .20673 .503 .25421 .49286 .23613 .49188 .1937 Metetra
.982 .734 .482 r
.49188 .1937 .49286 .23613 .4826 .21657 .48163 .1841 Metetra
.982 .73 .476 r
.48163 .1841 .4826 .21657 .47217 .20488 .47123 .17453 Metetra
.981 .728 .477 r
.47123 .17453 .47217 .20488 .46157 .1952 .46064 .16859 Metetra
.982 .727 .47 r
.46064 .16859 .46157 .1952 .45083 .18357 .44992 .15876 Metetra
.981 .726 .468 r
.44992 .15876 .45083 .18357 .43993 .17133 .43903 .14977 Metetra
.978 .72 .47 r
.43903 .14977 .43993 .17133 .42887 .15951 .42788 .14721 Metetra
.98 .706 .429 r
.42788 .14721 .42887 .15951 .41758 .15243 .41665 .1365 Metetra
.986 .72 .425 r
.41665 .1365 .41758 .15243 .40619 .13951 .40545 .11364 Metetra
.985 .722 .44 r
.63031 .31286 .63162 .32917 .62315 .31259 .62189 .29826 Metetra
.983 .716 .442 r
.62189 .29826 .62315 .31259 .61471 .30292 .61345 .28843 Metetra
.981 .716 .447 r
.61345 .28843 .61471 .30292 .60616 .29361 .60494 .28039 Metetra
.981 .712 .441 r
.60494 .28039 .60616 .29361 .59753 .28691 .5963 .27231 Metetra
.975 .71 .464 r
.5963 .27231 .59753 .28691 .58881 .28255 .58765 .27292 Metetra
.95 .677 .484 r
.58765 .27292 .58881 .28255 .58012 .29427 .57901 .28949 Metetra
.947 .634 .407 r
.57901 .28949 .58012 .29427 .57147 .33018 .57008 .29359 Metetra
.976 .727 .492 r
.57008 .29359 .57147 .33018 .56238 .34045 .56104 .30366 Metetra
.979 .729 .487 r
.56104 .30366 .56238 .34045 .55309 .34643 .55176 .30597 Metetra
.98 .731 .487 r
.55176 .30597 .55309 .34643 .54356 .33816 .54232 .30567 Metetra
.97 .72 .5 r
.54232 .30567 .54356 .33816 .53392 .33869 .53279 .33007 Metetra
.954 .674 .23 r
.53279 .33007 .53392 .33869 .52408 .31099 .52294 .29044 Metetra
.985 .726 .448 r
.52294 .29044 .52408 .31099 .51414 .29963 .51303 .27218 Metetra
.985 .731 .463 r
.51303 .27218 .51414 .29963 .50407 .28909 .503 .25421 Metetra
.984 .734 .471 r
.503 .25421 .50407 .28909 .49396 .2445 .49286 .23613 Metetra
.981 .69 .352 r
.49286 .23613 .49396 .2445 .48367 .2285 .4826 .21657 Metetra
.982 .706 .424 r
.4826 .21657 .48367 .2285 .47325 .2129 .47217 .20488 Metetra
.977 .683 .39 r
.47217 .20488 .47325 .2129 .46267 .20004 .46157 .1952 Metetra
.963 .632 .29 r
.46157 .1952 .46267 .20004 .45193 .18836 .45083 .18357 Metetra
.962 .629 .282 r
.45083 .18357 .45193 .18836 .44098 .18124 .43993 .17133 Metetra
.98 .696 .406 r
.43993 .17133 .44098 .18124 .42989 .17036 .42887 .15951 Metetra
.977 .698 .427 r
.42887 .15951 .42989 .17036 .41855 .16594 .41758 .15243 Metetra
.982 .71 .431 r
.41758 .15243 .41855 .16594 .40732 .14173 .40619 .13951 Metetra
.415 .55 .882 r
.63162 .32917 .63265 .32957 .62419 .31258 .62315 .31259 Metetra
.529 .73 .966 r
.62315 .31259 .62419 .31258 .61574 .30222 .61471 .30292 Metetra
.778 .829 .892 r
.61471 .30292 .61574 .30222 .60719 .29293 .60616 .29361 Metetra
.78 .878 .919 r
.60616 .29361 .60719 .29293 .59857 .28554 .59753 .28691 Metetra
.9 .908 .82 r
.59753 .28691 .59857 .28554 .58985 .28091 .58881 .28255 Metetra
.697 .872 .475 r
.58881 .28255 .58985 .28091 .58105 .28088 .58012 .29427 Metetra
.998 .804 .459 r
.58012 .29427 .58105 .28088 .57229 .30042 .57147 .33018 Metetra
.988 .764 .511 r
.57147 .33018 .57229 .30042 .56311 .29141 .56238 .34045 Metetra
.984 .755 .509 r
.56238 .34045 .56311 .29141 .5538 .28311 .55309 .34643 Metetra
.981 .75 .513 r
.55309 .34643 .5538 .28311 .54444 .29074 .54356 .33816 Metetra
.983 .754 .513 r
.54356 .33816 .54444 .29074 .53486 .28593 .53392 .33869 Metetra
.977 .746 .523 r
.53392 .33869 .53486 .28593 .52509 .25719 .52408 .31099 Metetra
.981 .75 .516 r
.52408 .31099 .52509 .25719 .51525 .24469 .51414 .29963 Metetra
.981 .75 .515 r
.51414 .29963 .51525 .24469 .50526 .23474 .50407 .28909 Metetra
.974 .743 .528 r
.50407 .28909 .50526 .23474 .49513 .22551 .49396 .2445 Metetra
.975 .759 .547 r
.49396 .2445 .49513 .22551 .48486 .21391 .48367 .2285 Metetra
.973 .763 .559 r
.48367 .2285 .48486 .21391 .47444 .20362 .47325 .2129 Metetra
.971 .777 .585 r
.47325 .2129 .47444 .20362 .46385 .19465 .46267 .20004 Metetra
.961 .797 .633 r
.46267 .20004 .46385 .19465 .45313 .1821 .45193 .18836 Metetra
.974 .804 .61 r
.45193 .18836 .45313 .1821 .44228 .16754 .44098 .18124 Metetra
.977 .77 .558 r
.44098 .18124 .44228 .16754 .43119 .15899 .42989 .17036 Metetra
.982 .784 .561 r
.42989 .17036 .43119 .15899 .41991 .15193 .41855 .16594 Metetra
.966 .757 .57 r
.41855 .16594 .41991 .15193 .40853 .13927 .40732 .14173 Metetra
.968 .758 .566 r
.63265 .32957 .63345 .31641 .62513 .30666 .62419 .31258 Metetra
.964 .787 .615 r
.62419 .31258 .62513 .30666 .61666 .29496 .61574 .30222 Metetra
.97 .784 .595 r
.61574 .30222 .61666 .29496 .60815 .28649 .60719 .29293 Metetra
.972 .793 .602 r
.60719 .29293 .60815 .28649 .59953 .27901 .59857 .28554 Metetra
.978 .8 .594 r
.59857 .28554 .59953 .27901 .59084 .27493 .58985 .28091 Metetra
.986 .818 .589 r
.58985 .28091 .59084 .27493 .58205 .27444 .58105 .28088 Metetra
.994 .845 .494 r
.58105 .28088 .58205 .27444 .57333 .2976 .57229 .30042 Metetra
.939 .826 .706 r
.57229 .30042 .57333 .2976 .56429 .30545 .56311 .29141 Metetra
.981 .713 .443 r
.56311 .29141 .56429 .30545 .55499 .29974 .5538 .28311 Metetra
.971 .709 .477 r
.5538 .28311 .55499 .29974 .54557 .29706 .54444 .29074 Metetra
.97 .665 .384 r
.54444 .29074 .54557 .29706 .53601 .30003 .53486 .28593 Metetra
.989 .72 .393 r
.53486 .28593 .53601 .30003 .52623 .27567 .52509 .25719 Metetra
.983 .722 .45 r
.52509 .25719 .52623 .27567 .51636 .25583 .51525 .24469 Metetra
.981 .703 .422 r
.51525 .24469 .51636 .25583 .50637 .23755 .50526 .23474 Metetra
.917 .525 .141 r
.50526 .23474 .50637 .23755 .49626 .22241 .49513 .22551 Metetra
.936 .815 .701 r
.49513 .22551 .49626 .22241 .48599 .21323 .48486 .21391 Metetra
.757 .84 .914 r
.48486 .21391 .48599 .21323 .47557 .20322 .47444 .20362 Metetra
.666 .84 .966 r
.47444 .20362 .47557 .20322 .465 .1936 .46385 .19465 Metetra
.817 .824 .855 r
.46385 .19465 .465 .1936 .45426 .18383 .45313 .1821 Metetra
.663 .217 0 r
.45313 .1821 .45426 .18383 .44336 .17379 .44228 .16754 Metetra
.971 .66 .36 r
.44228 .16754 .44336 .17379 .43229 .16373 .43119 .15899 Metetra
.96 .627 .32 r
.43119 .15899 .43229 .16373 .42104 .15462 .41991 .15193 Metetra
.89 .484 .058 r
.41991 .15193 .42104 .15462 .40965 .14248 .40853 .13927 Metetra
.982 .711 .431 r
.63345 .31641 .6347 .32876 .62626 .31259 .62513 .30666 Metetra
.974 .666 .329 r
.62513 .30666 .62626 .31259 .6178 .30127 .61666 .29496 Metetra
.975 .671 .364 r
.61666 .29496 .6178 .30127 .60929 .29313 .60815 .28649 Metetra
.975 .675 .377 r
.60815 .28649 .60929 .29313 .6006 .28064 .59953 .27901 Metetra
.85 .39 .035 r
.59953 .27901 .6006 .28064 .59185 .27071 .59084 .27493 Metetra
.983 .843 .626 r
.59084 .27493 .59185 .27071 .58306 .26872 .58205 .27444 Metetra
.975 .852 .456 r
.58205 .27444 .58306 .26872 .57431 .28711 .57333 .2976 Metetra
.994 .798 .536 r
.57333 .2976 .57431 .28711 .56526 .29142 .56429 .30545 Metetra
.981 .772 .548 r
.56429 .30545 .56526 .29142 .55604 .2929 .55499 .29974 Metetra
.982 .805 .588 r
.55499 .29974 .55604 .2929 .54673 .31046 .54557 .29706 Metetra
.972 .704 .462 r
.54557 .29706 .54673 .31046 .53717 .31523 .53601 .30003 Metetra
.988 .721 .413 r
.53601 .30003 .53717 .31523 .52733 .27007 .52623 .27567 Metetra
.941 .768 .638 r
.52623 .27567 .52733 .27007 .51747 .24925 .51636 .25583 Metetra
.952 .771 .621 r
.51636 .25583 .51747 .24925 .50749 .23204 .50637 .23755 Metetra
.953 .783 .634 r
.50637 .23755 .50749 .23204 .49738 .22416 .49626 .22241 Metetra
.796 .33 0 r
.49626 .22241 .49738 .22416 .48715 .20589 .48599 .21323 Metetra
.971 .789 .599 r
.48599 .21323 .48715 .20589 .47674 .1964 .47557 .20322 Metetra
.971 .793 .605 r
.47557 .20322 .47674 .1964 .46617 .18865 .465 .1936 Metetra
.964 .807 .64 r
.465 .1936 .46617 .18865 .45544 .17993 .45426 .18383 Metetra
.955 .818 .67 r
.45426 .18383 .45544 .17993 .44455 .16991 .44336 .17379 Metetra
.954 .819 .671 r
.44336 .17379 .44455 .16991 .43347 .16164 .43229 .16373 Metetra
.918 .858 .767 r
.43229 .16373 .43347 .16164 .4222 .15479 .42104 .15462 Metetra
.373 .663 .97 r
.42104 .15462 .4222 .15479 .41083 .14179 .40965 .14248 Metetra
.971 .759 .56 r
.6347 .32876 .63547 .31436 .62715 .30418 .62626 .31259 Metetra
.969 .775 .587 r
.62626 .31259 .62715 .30418 .61873 .29401 .6178 .30127 Metetra
.973 .786 .592 r
.6178 .30127 .61873 .29401 .61023 .28598 .60929 .29313 Metetra
.964 .777 .602 r
.60929 .29313 .61023 .28598 .60162 .27783 .6006 .28064 Metetra
.935 .816 .704 r
.6006 .28064 .60162 .27783 .59283 .26503 .59185 .27071 Metetra
.983 .816 .6 r
.59185 .27071 .59283 .26503 .58399 .25671 .58306 .26872 Metetra
.999 .801 .505 r
.58306 .26872 .58399 .25671 .57503 .24817 .57431 .28711 Metetra
.985 .757 .512 r
.57431 .28711 .57503 .24817 .56598 .24445 .56526 .29142 Metetra
.984 .754 .511 r
.56526 .29142 .56598 .24445 .55688 .25605 .55604 .2929 Metetra
.989 .762 .504 r
.55604 .2929 .55688 .25605 .54767 .28009 .54673 .31046 Metetra
.986 .762 .515 r
.54673 .31046 .54767 .28009 .53813 .27553 .53717 .31523 Metetra
.97 .742 .537 r
.53717 .31523 .53813 .27553 .52841 .26053 .52733 .27007 Metetra
.959 .761 .592 r
.52733 .27007 .52841 .26053 .51856 .22653 .51747 .24925 Metetra
.976 .756 .54 r
.51747 .24925 .51856 .22653 .50863 .20308 .50749 .23204 Metetra
.981 .758 .526 r
.50749 .23204 .50863 .20308 .49857 .19361 .49738 .22416 Metetra
.977 .753 .531 r
.49738 .22416 .49857 .19361 .48836 .1841 .48715 .20589 Metetra
.98 .761 .535 r
.48715 .20589 .48836 .1841 .47798 .17775 .47674 .1964 Metetra
.981 .765 .54 r
.47674 .1964 .47798 .17775 .46743 .17066 .46617 .18865 Metetra
.98 .766 .542 r
.46617 .18865 .46743 .17066 .45663 .17399 .45544 .17993 Metetra
.968 .799 .62 r
.45544 .17993 .45663 .17399 .44577 .16365 .44455 .16991 Metetra
.973 .802 .612 r
.44455 .16991 .44577 .16365 .43471 .15549 .43347 .16164 Metetra
.975 .807 .612 r
.43347 .16164 .43471 .15549 .42308 .17544 .4222 .15479 Metetra
.983 .723 .454 r
.4222 .15479 .42308 .17544 .41202 .14088 .41083 .14179 Metetra
.953 .607 .234 r
.63547 .31436 .63657 .31822 .62825 .3082 .62715 .30418 Metetra
.956 .613 .247 r
.62715 .30418 .62825 .3082 .61984 .29833 .61873 .29401 Metetra
.962 .628 .294 r
.61873 .29401 .61984 .29833 .61135 .29109 .61023 .28598 Metetra
.969 .65 .329 r
.61023 .28598 .61135 .29109 .60271 .28084 .60162 .27783 Metetra
.904 .527 .083 r
.60162 .27783 .60271 .28084 .59403 .27646 .59283 .26503 Metetra
.981 .706 .428 r
.59283 .26503 .59403 .27646 .58523 .27384 .58399 .25671 Metetra
.982 .72 .453 r
.58399 .25671 .58523 .27384 .57651 .29235 .57503 .24817 Metetra
.981 .733 .485 r
.57503 .24817 .57651 .29235 .56751 .3023 .56598 .24445 Metetra
.978 .733 .495 r
.56598 .24445 .56751 .3023 .55823 .29527 .55688 .25605 Metetra
.973 .724 .499 r
.55688 .25605 .55823 .29527 .54884 .2937 .54767 .28009 Metetra
.978 .709 .448 r
.54767 .28009 .54884 .2937 .53931 .29814 .53813 .27553 Metetra
.984 .727 .456 r
.53813 .27553 .53931 .29814 .52956 .27831 .52841 .26053 Metetra
.99 .728 .407 r
.52841 .26053 .52956 .27831 .5197 .26949 .51856 .22653 Metetra
.985 .737 .472 r
.51856 .22653 .5197 .26949 .50971 .251 .50863 .20308 Metetra
.982 .735 .482 r
.50863 .20308 .50971 .251 .49961 .22657 .49857 .19361 Metetra
.982 .731 .474 r
.49857 .19361 .49961 .22657 .48937 .2151 .48836 .1841 Metetra
.981 .729 .475 r
.48836 .1841 .48937 .2151 .47897 .20359 .47798 .17775 Metetra
.981 .726 .47 r
.47798 .17775 .47897 .20359 .46844 .19015 .46743 .17066 Metetra
.975 .715 .472 r
.46743 .17066 .46844 .19015 .45772 .18039 .45663 .17399 Metetra
.973 .664 .352 r
.45663 .17399 .45772 .18039 .44685 .17084 .44577 .16365 Metetra
.973 .672 .38 r
.44577 .16365 .44685 .17084 .43581 .16028 .43471 .15549 Metetra
.909 .601 .45 r
.43471 .15549 .43581 .16028 .4246 .15 .42308 .17544 Metetra
.97 .747 .546 r
.42308 .17544 .4246 .15 .41327 .13553 .41202 .14088 Metetra
.983 .721 .448 r
.63657 .31822 .63791 .33497 .62951 .32123 .62825 .3082 Metetra
.983 .713 .433 r
.62825 .3082 .62951 .32123 .62085 .29672 .61984 .29833 Metetra
.904 .859 .787 r
.61984 .29833 .62085 .29672 .61236 .28874 .61135 .29109 Metetra
.92 .818 .729 r
.61135 .29109 .61236 .28874 .6038 .28419 .60271 .28084 Metetra
.946 .589 .278 r
.60271 .28084 .6038 .28419 .59514 .28076 .59403 .27646 Metetra
.957 .627 .346 r
.59403 .27646 .59514 .28076 .58653 .29537 .58523 .27384 Metetra
.968 .712 .494 r
.58523 .27384 .58653 .29537 .57777 .31271 .57651 .29235 Metetra
.972 .714 .483 r
.57651 .29235 .57777 .31271 .5686 .3028 .56751 .3023 Metetra
0 .404 .81 r
.56751 .3023 .5686 .3028 .55938 .30421 .55823 .29527 Metetra
.972 .688 .429 r
.55823 .29527 .55938 .30421 .54996 .29888 .54884 .2937 Metetra
.949 .638 .409 r
.54884 .2937 .54996 .29888 .54053 .327 .53931 .29814 Metetra
.986 .732 .461 r
.53931 .29814 .54053 .327 .5307 .29086 .52956 .27831 Metetra
.981 .708 .432 r
.52956 .27831 .5307 .29086 .52083 .2784 .5197 .26949 Metetra
.982 .694 .363 r
.5197 .26949 .52083 .2784 .51083 .25184 .50971 .251 Metetra
.27 .41 .82 r
.50971 .251 .51083 .25184 .50072 .23624 .49961 .22657 Metetra
.98 .696 .402 r
.49961 .22657 .50072 .23624 .49048 .21841 .48937 .2151 Metetra
.93 .557 .165 r
.48937 .2151 .49048 .21841 .48011 .20319 .47897 .20359 Metetra
.678 .773 .922 r
.47897 .20359 .48011 .20319 .46955 .19377 .46844 .19015 Metetra
.944 .582 .224 r
.46844 .19015 .46955 .19377 .45887 .18001 .45772 .18039 Metetra
.657 .832 .967 r
.45772 .18039 .45887 .18001 .44797 .17382 .44685 .17084 Metetra
.919 .529 .141 r
.44685 .17084 .44797 .17382 .43695 .16176 .43581 .16028 Metetra
.7 .208 0 r
.43581 .16028 .43695 .16176 .42567 .15661 .4246 .15 Metetra
.974 .666 .335 r
.4246 .15 .42567 .15661 .41443 .13652 .41327 .13553 Metetra
.983 .697 .379 r
.63791 .33497 .63911 .34372 .63055 .321 .62951 .32123 Metetra
.646 .616 .805 r
.62951 .32123 .63055 .321 .622 .30348 .62085 .29672 Metetra
.976 .677 .375 r
.62085 .29672 .622 .30348 .61346 .29256 .61236 .28874 Metetra
.955 .612 .306 r
.61236 .28874 .61346 .29256 .6048 .2798 .6038 .28419 Metetra
.976 .828 .63 r
.6038 .28419 .6048 .2798 .59615 .27716 .59514 .28076 Metetra
.96 .894 .513 r
.59514 .28076 .59615 .27716 .58763 .29775 .58653 .29537 Metetra
.85 .522 .432 r
.58653 .29537 .58763 .29775 .57889 .31714 .57777 .31271 Metetra
.961 .625 .277 r
.57777 .31271 .57889 .31714 .56989 .32843 .5686 .3028 Metetra
.978 .724 .478 r
.5686 .3028 .56989 .32843 .56072 .34046 .55938 .30421 Metetra
.981 .731 .479 r
.55938 .30421 .56072 .34046 .55125 .33313 .54996 .29888 Metetra
.97 .72 .501 r
.54996 .29888 .55125 .33313 .54175 .35399 .54053 .327 Metetra
.99 .736 .438 r
.54053 .327 .54175 .35399 .53189 .32155 .5307 .29086 Metetra
.983 .731 .469 r
.5307 .29086 .53189 .32155 .52196 .29429 .52083 .2784 Metetra
.988 .723 .411 r
.52083 .2784 .52196 .29429 .51194 .29721 .51083 .25184 Metetra
.984 .736 .477 r
.51083 .25184 .51194 .29721 .50176 .2845 .50072 .23624 Metetra
.984 .737 .478 r
.50072 .23624 .50176 .2845 .4915 .25094 .49048 .21841 Metetra
.984 .732 .469 r
.49048 .21841 .4915 .25094 .48117 .2169 .48011 .20319 Metetra
.981 .71 .436 r
.48011 .20319 .48117 .2169 .47058 .21122 .46955 .19377 Metetra
.984 .72 .444 r
.46955 .19377 .47058 .21122 .4599 .19528 .45887 .18001 Metetra
.979 .712 .448 r
.45887 .18001 .4599 .19528 .44905 .18162 .44797 .17382 Metetra
.977 .68 .373 r
.44797 .17382 .44905 .18162 .43802 .1699 .43695 .16176 Metetra
.973 .679 .404 r
.43695 .16176 .43802 .1699 .42678 .16093 .42567 .15661 Metetra
.935 .591 .162 r
.42567 .15661 .42678 .16093 .41554 .14016 .41443 .13652 Metetra
.943 .752 .616 r
.63911 .34372 .64001 .33654 .63142 .31163 .63055 .321 Metetra
.962 .762 .588 r
.63055 .321 .63142 .31163 .62291 .29568 .622 .30348 Metetra
.969 .778 .591 r
.622 .30348 .62291 .29568 .61444 .28759 .61346 .29256 Metetra
.953 .785 .637 r
.61346 .29256 .61444 .28759 .60581 .27713 .6048 .2798 Metetra
.965 .873 .696 r
.6048 .2798 .60581 .27713 .59713 .27129 .59615 .27716 Metetra
.986 .851 .476 r
.59615 .27716 .59713 .27129 .58832 .26388 .58763 .29775 Metetra
.99 .764 .501 r
.58763 .29775 .58832 .26388 .57959 .27872 .57889 .31714 Metetra
.987 .76 .506 r
.57889 .31714 .57959 .27872 .5706 .28344 .56989 .32843 Metetra
.987 .758 .505 r
.56989 .32843 .5706 .28344 .56144 .28793 .56072 .34046 Metetra
.982 .751 .513 r
.56072 .34046 .56144 .28793 .55203 .27677 .55125 .33313 Metetra
.987 .757 .5 r
.55125 .33313 .55203 .27677 .54254 .27757 .54175 .35399 Metetra
.978 .745 .516 r
.54175 .35399 .54254 .27757 .53284 .2639 .53189 .32155 Metetra
.978 .747 .519 r
.53189 .32155 .53284 .2639 .52302 .24987 .52196 .29429 Metetra
.985 .756 .511 r
.52196 .29429 .52302 .24987 .51307 .23177 .51194 .29721 Metetra
.981 .749 .512 r
.51194 .29721 .51307 .23177 .503 .21392 .50176 .2845 Metetra
.978 .745 .517 r
.50176 .2845 .503 .21392 .49278 .20481 .4915 .25094 Metetra
.976 .746 .526 r
.4915 .25094 .49278 .20481 .48241 .19512 .48117 .2169 Metetra
.983 .764 .531 r
.48117 .2169 .48241 .19512 .47187 .18769 .47058 .21122 Metetra
.978 .757 .537 r
.47058 .21122 .47187 .18769 .4612 .1759 .4599 .19528 Metetra
.978 .761 .543 r
.4599 .19528 .4612 .1759 .45029 .17218 .44905 .18162 Metetra
.974 .78 .582 r
.44905 .18162 .45029 .17218 .4393 .15945 .43802 .1699 Metetra
.978 .781 .571 r
.43802 .1699 .4393 .15945 .42809 .15046 .42678 .16093 Metetra
.965 .765 .585 r
.42678 .16093 .42809 .15046 .41679 .13518 .41554 .14016 Metetra
.712 .397 0 r
.64001 .33654 .6411 .33989 .6325 .31414 .63142 .31163 Metetra
.775 .393 0 r
.63142 .31163 .6325 .31414 .62411 .30481 .62291 .29568 Metetra
.98 .696 .409 r
.62291 .29568 .62411 .30481 .61562 .29685 .61444 .28759 Metetra
.981 .698 .4 r
.61444 .28759 .61562 .29685 .60703 .28887 .60581 .27713 Metetra
.979 .706 .436 r
.60581 .27713 .60703 .28887 .59833 .28239 .59713 .27129 Metetra
.98 .704 .427 r
.59713 .27129 .59833 .28239 .58964 .28676 .58832 .26388 Metetra
.971 .716 .49 r
.58832 .26388 .58964 .28676 .58073 .28478 .57959 .27872 Metetra
.955 .655 .426 r
.57959 .27872 .58073 .28478 .57166 .28129 .5706 .28344 Metetra
.954 .952 .688 r
.5706 .28344 .57166 .28129 .56252 .28635 .56144 .28793 Metetra
.878 .827 .793 r
.56144 .28793 .56252 .28635 .55312 .2763 .55203 .27677 Metetra
.498 .907 .87 r
.55203 .27677 .55312 .2763 .54362 .27361 .54254 .27757 Metetra
.942 .794 .668 r
.54254 .27757 .54362 .27361 .5339 .24869 .53284 .2639 Metetra
.975 .763 .554 r
.53284 .2639 .5339 .24869 .52411 .23643 .52302 .24987 Metetra
.97 .761 .565 r
.52302 .24987 .52411 .23643 .51419 .22507 .51307 .23177 Metetra
.955 .773 .618 r
.51307 .23177 .51419 .22507 .50412 .21427 .503 .21392 Metetra
.151 .562 .929 r
.503 .21392 .50412 .21427 .49388 .21503 .49278 .20481 Metetra
.98 .698 .412 r
.49278 .20481 .49388 .21503 .48352 .20181 .48241 .19512 Metetra
.972 .667 .373 r
.48241 .19512 .48352 .20181 .47301 .18781 .47187 .18769 Metetra
.42 .683 .972 r
.47187 .18769 .47301 .18781 .46232 .17935 .4612 .1759 Metetra
.941 .578 .28 r
.4612 .1759 .46232 .17935 .45153 .1627 .45029 .17218 Metetra
.972 .778 .582 r
.45029 .17218 .45153 .1627 .44059 .1472 .4393 .15945 Metetra
.979 .776 .561 r
.4393 .15945 .44059 .1472 .42938 .14044 .42809 .15046 Metetra
.971 .774 .582 r
.42809 .15046 .42938 .14044 .41796 .13523 .41679 .13518 Metetra
.965 .749 .562 r
.6411 .33989 .64182 .32336 .63349 .31151 .6325 .31414 Metetra
.933 .82 .711 r
.6325 .31414 .63349 .31151 .62507 .30005 .62411 .30481 Metetra
.965 .804 .632 r
.62411 .30481 .62507 .30005 .6166 .29204 .61562 .29685 Metetra
.966 .804 .631 r
.61562 .29685 .6166 .29204 .60801 .28399 .60703 .28887 Metetra
.97 .81 .626 r
.60703 .28887 .60801 .28399 .59931 .27578 .59833 .28239 Metetra
.994 .822 .565 r
.59833 .28239 .59931 .27578 .59048 .2675 .58964 .28676 Metetra
.984 .767 .529 r
.58964 .28676 .59048 .2675 .58173 .27764 .58073 .28478 Metetra
.982 .801 .584 r
.58073 .28478 .58173 .27764 .5727 .27623 .57166 .28129 Metetra
.994 .848 .585 r
.57166 .28129 .5727 .27623 .56363 .28962 .56252 .28635 Metetra
.934 .563 .178 r
.56252 .28635 .56363 .28962 .55427 .28604 .55312 .2763 Metetra
.974 .693 .43 r
.55312 .2763 .55427 .28604 .54479 .28886 .54362 .27361 Metetra
.988 .721 .409 r
.54362 .27361 .54479 .28886 .53507 .267 .5339 .24869 Metetra
.984 .721 .448 r
.5339 .24869 .53507 .267 .52525 .25009 .52411 .23643 Metetra
.983 .712 .431 r
.52411 .23643 .52525 .25009 .51531 .2354 .51419 .22507 Metetra
.981 .7 .409 r
.51419 .22507 .51531 .2354 .50524 .21668 .50412 .21427 Metetra
.905 .513 .257 r
.50412 .21427 .50524 .21668 .49504 .20617 .49388 .21503 Metetra
.97 .777 .587 r
.49388 .21503 .49504 .20617 .48471 .18944 .48352 .20181 Metetra
.974 .769 .565 r
.48352 .20181 .48471 .18944 .47416 .18665 .47301 .18781 Metetra
.849 .88 .862 r
.47301 .18781 .47416 .18665 .46349 .17644 .46232 .17935 Metetra
.914 .794 .714 r
.46232 .17935 .46349 .17644 .45268 .16352 .45153 .1627 Metetra
0 .333 .816 r
.45153 .1627 .45268 .16352 .44172 .14963 .44059 .1472 Metetra
.899 .482 .124 r
.44059 .1472 .44172 .14963 .43046 .14746 .42938 .14044 Metetra
.97 .667 .386 r
.42938 .14044 .43046 .14746 .41917 .13288 .41796 .13523 Metetra
.968 .775 .591 r
.64182 .32336 .6427 .31538 .63446 .30752 .63349 .31151 Metetra
.947 .795 .659 r
.63349 .31151 .63446 .30752 .62603 .29501 .62507 .30005 Metetra
.967 .802 .626 r
.62507 .30005 .62603 .29501 .61753 .28482 .6166 .29204 Metetra
.974 .788 .592 r
.6166 .29204 .61753 .28482 .60895 .27586 .60801 .28399 Metetra
.975 .784 .583 r
.60801 .28399 .60895 .27586 .60024 .26577 .59931 .27578 Metetra
.977 .777 .568 r
.59931 .27578 .60024 .26577 .59149 .26242 .59048 .2675 Metetra
.997 .858 .554 r
.59048 .2675 .59149 .26242 .58261 .25871 .58173 .27764 Metetra
.985 .768 .529 r
.58173 .27764 .58261 .25871 .57355 .25027 .5727 .27623 Metetra
.99 .768 .507 r
.5727 .27623 .57355 .25027 .56443 .25204 .56363 .28962 Metetra
.983 .756 .515 r
.56363 .28962 .56443 .25204 .55517 .25354 .55427 .28604 Metetra
.985 .76 .514 r
.55427 .28604 .55517 .25354 .54577 .26213 .54479 .28886 Metetra
.975 .752 .536 r
.54479 .28886 .54577 .26213 .53608 .23811 .53507 .267 Metetra
.978 .754 .53 r
.53507 .267 .53608 .23811 .52631 .22406 .52525 .25009 Metetra
.979 .756 .532 r
.52525 .25009 .52631 .22406 .51641 .20499 .51531 .2354 Metetra
.978 .753 .53 r
.51531 .2354 .51641 .20499 .50639 .19108 .50524 .21668 Metetra
.981 .758 .529 r
.50524 .21668 .50639 .19108 .49621 .18832 .49504 .20617 Metetra
.975 .76 .548 r
.49504 .20617 .49621 .18832 .48588 .18066 .48471 .18944 Metetra
.984 .796 .571 r
.48471 .18944 .48588 .18066 .47537 .17559 .47416 .18665 Metetra
.977 .777 .568 r
.47416 .18665 .47537 .17559 .46468 .17057 .46349 .17644 Metetra
.962 .792 .625 r
.46349 .17644 .46468 .17057 .45387 .15975 .45268 .16352 Metetra
.942 .804 .679 r
.45268 .16352 .45387 .15975 .44289 .14868 .44172 .14963 Metetra
.804 .973 .904 r
.44172 .14963 .44289 .14868 .4316 .14962 .43046 .14746 Metetra
.789 .357 0 r
.43046 .14746 .4316 .14962 .42037 .13133 .41917 .13288 Metetra
.555 .78 .982 r
.6427 .31538 .64373 .31527 .63549 .30746 .63446 .30752 Metetra
.583 .703 .925 r
.63446 .30752 .63549 .30746 .62715 .29959 .62603 .29501 Metetra
.964 .633 .28 r
.62603 .29501 .62715 .29959 .61869 .29162 .61753 .28482 Metetra
.976 .676 .367 r
.61753 .28482 .61869 .29162 .61011 .28352 .60895 .27586 Metetra
.979 .685 .378 r
.60895 .27586 .61011 .28352 .60144 .27657 .60024 .26577 Metetra
.977 .7 .436 r
.60024 .26577 .60144 .27657 .59298 .29836 .59149 .26242 Metetra
.981 .731 .479 r
.59149 .26242 .59298 .29836 .5844 .32797 .58261 .25871 Metetra
.983 .738 .486 r
.58261 .25871 .5844 .32797 .57549 .34504 .57355 .25027 Metetra
.982 .738 .492 r
.57355 .25027 .57549 .34504 .56618 .33706 .56443 .25204 Metetra
.981 .738 .491 r
.56443 .25204 .56618 .33706 .55674 .32879 .55517 .25354 Metetra
.98 .736 .493 r
.55517 .25354 .55674 .32879 .54716 .32048 .54577 .26213 Metetra
.985 .739 .477 r
.54577 .26213 .54716 .32048 .53744 .312 .53608 .23811 Metetra
.983 .739 .485 r
.53608 .23811 .53744 .312 .52758 .30342 .52631 .22406 Metetra
.984 .74 .484 r
.52631 .22406 .52758 .30342 .51755 .25592 .51641 .20499 Metetra
.984 .736 .479 r
.51641 .20499 .51755 .25592 .50747 .24142 .50639 .19108 Metetra
.981 .734 .484 r
.50639 .19108 .50747 .24142 .49726 .21974 .49621 .18832 Metetra
.982 .729 .472 r
.49621 .18832 .49726 .21974 .48689 .21151 .48588 .18066 Metetra
.981 .728 .474 r
.48588 .18066 .48689 .21151 .47637 .20007 .47537 .17559 Metetra
.981 .724 .467 r
.47537 .17559 .47637 .20007 .46573 .18403 .46468 .17057 Metetra
.982 .709 .43 r
.46468 .17057 .46573 .18403 .45489 .17505 .45387 .15975 Metetra
.982 .714 .438 r
.45387 .15975 .45489 .17505 .44391 .16203 .44289 .14868 Metetra
.974 .702 .452 r
.44289 .14868 .44391 .16203 .43277 .14943 .4316 .14962 Metetra
.606 .695 .906 r
.4316 .14962 .43277 .14943 .42147 .13633 .42037 .13133 Metetra
.982 .721 .453 r
.64373 .31527 .64511 .33307 .63671 .3171 .63549 .30746 Metetra
.98 .699 .413 r
.63549 .30746 .63671 .3171 .62823 .30183 .62715 .29959 Metetra
.883 .464 .051 r
.62715 .29959 .62823 .30183 .61976 .29328 .61869 .29162 Metetra
.785 .32 0 r
.61869 .29162 .61976 .29328 .6112 .28564 .61011 .28352 Metetra
.88 .453 .056 r
.61011 .28352 .6112 .28564 .60259 .28336 .60144 .27657 Metetra
.927 .645 .487 r
.60144 .27657 .60259 .28336 .59393 .28803 .59298 .29836 Metetra
.997 .816 .46 r
.59298 .29836 .59393 .28803 .58522 .30307 .5844 .32797 Metetra
.992 .771 .503 r
.5844 .32797 .58522 .30307 .57615 .29898 .57549 .34504 Metetra
.982 .752 .514 r
.57549 .34504 .57615 .29898 .56701 .30265 .56618 .33706 Metetra
.982 .755 .519 r
.56618 .33706 .56701 .30265 .55765 .30013 .55674 .32879 Metetra
.982 .757 .524 r
.55674 .32879 .55765 .30013 .54822 .31112 .54716 .32048 Metetra
.977 .782 .575 r
.54716 .32048 .54822 .31112 .53846 .28586 .53744 .312 Metetra
.982 .759 .527 r
.53744 .312 .53846 .28586 .52862 .26466 .52758 .30342 Metetra
.97 .741 .536 r
.52758 .30342 .52862 .26466 .51868 .26002 .51755 .25592 Metetra
.945 .596 .196 r
.51755 .25592 .51868 .26002 .50859 .24507 .50747 .24142 Metetra
.872 .521 .022 r
.50747 .24142 .50859 .24507 .49838 .22613 .49726 .21974 Metetra
.972 .663 .36 r
.49726 .21974 .49838 .22613 .48802 .21264 .48689 .21151 Metetra
0 .032 .544 r
.48689 .21151 .48802 .21264 .47752 .19865 .47637 .20007 Metetra
.84 .793 .806 r
.47637 .20007 .47752 .19865 .46691 .17954 .46573 .18403 Metetra
.964 .817 .649 r
.46573 .18403 .46691 .17954 .45606 .17337 .45489 .17505 Metetra
.877 .827 .795 r
.45489 .17505 .45606 .17337 .44509 .16087 .44391 .16203 Metetra
.83 .833 .85 r
.44391 .16203 .44509 .16087 .43397 .14704 .43277 .14943 Metetra
.913 .824 .745 r
.43277 .14943 .43397 .14704 .42264 .13678 .42147 .13633 Metetra
.693 .308 0 r
.64511 .33307 .64619 .3353 .63779 .31962 .63671 .3171 Metetra
.791 .404 0 r
.63671 .3171 .63779 .31962 .62928 .30254 .62823 .30183 Metetra
0 .286 .757 r
.62823 .30183 .62928 .30254 .62081 .29317 .61976 .29328 Metetra
.545 .787 .988 r
.61976 .29328 .62081 .29317 .61224 .28512 .6112 .28564 Metetra
.677 .948 .958 r
.6112 .28564 .61224 .28512 .60371 .28775 .60259 .28336 Metetra
.943 .623 .4 r
.60259 .28336 .60371 .28775 .59503 .29072 .59393 .28803 Metetra
.872 .543 .425 r
.59393 .28803 .59503 .29072 .58636 .30893 .58522 .30307 Metetra
.968 .659 .374 r
.58522 .30307 .58636 .30893 .5774 .31586 .57615 .29898 Metetra
.975 .712 .468 r
.57615 .29898 .5774 .31586 .56826 .32247 .56701 .30265 Metetra
.979 .719 .464 r
.56701 .30265 .56826 .32247 .55895 .3295 .55765 .30013 Metetra
.976 .723 .486 r
.55765 .30013 .55895 .3295 .54969 .37863 .54822 .31112 Metetra
.985 .74 .479 r
.54822 .31112 .54969 .37863 .53959 .28983 .53846 .28586 Metetra
.896 .552 .07 r
.53846 .28586 .53959 .28983 .52976 .27342 .52862 .26466 Metetra
.975 .687 .413 r
.52862 .26466 .52976 .27342 .5198 .25576 .51868 .26002 Metetra
.943 .791 .662 r
.51868 .26002 .5198 .25576 .50972 .24108 .50859 .24507 Metetra
.927 .776 .674 r
.50859 .24507 .50972 .24108 .49951 .22821 .49838 .22613 Metetra
.78 .346 0 r
.49838 .22613 .49951 .22821 .48914 .21772 .48802 .21264 Metetra
.964 .635 .272 r
.48802 .21264 .48914 .21772 .47866 .19973 .47752 .19865 Metetra
0 .249 .762 r
.47752 .19865 .47866 .19973 .46807 .17885 .46691 .17954 Metetra
.756 .914 .944 r
.46691 .17954 .46807 .17885 .45726 .16851 .45606 .17337 Metetra
.958 .801 .646 r
.45606 .17337 .45726 .16851 .44628 .1581 .44509 .16087 Metetra
.922 .815 .722 r
.44509 .16087 .44628 .1581 .43512 .14816 .43397 .14704 Metetra
.522 .008 0 r
.43397 .14704 .43512 .14816 .42392 .1291 .42264 .13678 Metetra
.962 .767 .594 r
.64619 .3353 .64706 .327 .63848 .30043 .63779 .31962 Metetra
.975 .756 .544 r
.63779 .31962 .63848 .30043 .63015 .29208 .62928 .30254 Metetra
.976 .774 .566 r
.62928 .30254 .63015 .29208 .62171 .28406 .62081 .29317 Metetra
.977 .78 .573 r
.62081 .29317 .62171 .28406 .61316 .27596 .61224 .28512 Metetra
.991 .798 .549 r
.61224 .28512 .61316 .27596 .60453 .27039 .60371 .28775 Metetra
.988 .773 .524 r
.60371 .28775 .60453 .27039 .596 .28287 .59503 .29072 Metetra
.999 .829 .5 r
.59503 .29072 .596 .28287 .58744 .30902 .58636 .30893 Metetra
.436 0 0 r
.58636 .30893 .58744 .30902 .57835 .30225 .5774 .31586 Metetra
.992 .785 .527 r
.5774 .31586 .57835 .30225 .56917 .29958 .56826 .32247 Metetra
.989 .769 .515 r
.56826 .32247 .56917 .29958 .55987 .30288 .55895 .3295 Metetra
.998 .781 .467 r
.55895 .3295 .55987 .30288 .55056 .33285 .54969 .37863 Metetra
.96 .73 .546 r
.54969 .37863 .55056 .33285 .54065 .27775 .53959 .28983 Metetra
.971 .765 .569 r
.53959 .28983 .54065 .27775 .53085 .2643 .52976 .27342 Metetra
.964 .768 .59 r
.52976 .27342 .53085 .2643 .52092 .2498 .5198 .25576 Metetra
.958 .784 .624 r
.5198 .25576 .52092 .2498 .51085 .23265 .50972 .24108 Metetra
.97 .779 .59 r
.50972 .24108 .51085 .23265 .50067 .21562 .49951 .22821 Metetra
.978 .773 .559 r
.49951 .22821 .50067 .21562 .49034 .20135 .48914 .21772 Metetra
.974 .761 .553 r
.48914 .21772 .49034 .20135 .47987 .18649 .47866 .19973 Metetra
.969 .761 .568 r
.47866 .19973 .47987 .18649 .46922 .17789 .46807 .17885 Metetra
.811 .856 .882 r
.46807 .17885 .46922 .17789 .45843 .16628 .45726 .16851 Metetra
.919 .844 .754 r
.45726 .16851 .45843 .16628 .44747 .15503 .44628 .1581 Metetra
.944 .835 .705 r
.44628 .1581 .44747 .15503 .43635 .14366 .43512 .14816 Metetra
.937 .782 .663 r
.43512 .14816 .43635 .14366 .42504 .13274 .42392 .1291 Metetra
.947 .747 .601 r
.64706 .327 .64792 .31789 .63955 .30217 .63848 .30043 Metetra
.795 .338 0 r
.63848 .30043 .63955 .30217 .63123 .2941 .63015 .29208 Metetra
.855 .421 0 r
.63015 .29208 .63123 .2941 .62279 .28607 .62171 .28406 Metetra
.852 .416 0 r
.62171 .28406 .62279 .28607 .61425 .278 .61316 .27596 Metetra
.883 .453 .079 r
.61316 .27596 .61425 .278 .60562 .27206 .60453 .27039 Metetra
.827 .466 .372 r
.60453 .27039 .60562 .27206 .59703 .27926 .596 .28287 Metetra
.778 .785 .286 r
.596 .28287 .59703 .27926 .58826 .28556 .58744 .30902 Metetra
.982 .761 .527 r
.58744 .30902 .58826 .28556 .57943 .30161 .57835 .30225 Metetra
.729 .955 .947 r
.57835 .30225 .57943 .30161 .57021 .29332 .56917 .29958 Metetra
.993 .826 .575 r
.56917 .29958 .57021 .29332 .56088 .28924 .55987 .30288 Metetra
1 .802 .476 r
.55987 .30288 .56088 .28924 .55141 .28615 .55056 .33285 Metetra
.97 .74 .533 r
.55056 .33285 .55141 .28615 .54173 .27001 .54065 .27775 Metetra
.967 .779 .597 r
.54065 .27775 .54173 .27001 .53196 .25931 .53085 .2643 Metetra
.952 .788 .643 r
.53085 .2643 .53196 .25931 .52202 .23472 .52092 .2498 Metetra
.974 .762 .556 r
.52092 .2498 .52202 .23472 .51199 .21483 .51085 .23265 Metetra
.976 .76 .548 r
.51085 .23265 .51199 .21483 .50183 .19894 .50067 .21562 Metetra
.977 .763 .548 r
.50067 .21562 .50183 .19894 .49151 .19173 .49034 .20135 Metetra
.97 .774 .582 r
.49034 .20135 .49151 .19173 .48105 .18032 .47987 .18649 Metetra
.973 .802 .612 r
.47987 .18649 .48105 .18032 .47044 .16745 .46922 .17789 Metetra
.976 .777 .573 r
.46922 .17789 .47044 .16745 .45966 .15765 .45843 .16628 Metetra
.974 .784 .586 r
.45843 .16628 .45966 .15765 .44871 .14745 .44747 .15503 Metetra
.972 .789 .598 r
.44747 .15503 .44871 .14745 .43747 .14737 .43635 .14366 Metetra
.942 .578 .211 r
.43635 .14366 .43747 .14737 .42616 .13692 .42504 .13274 Metetra
.986 .712 .404 r
.64792 .31789 .64919 .32985 .64094 .32113 .63955 .30217 Metetra
.983 .722 .454 r
.63955 .30217 .64094 .32113 .63247 .3052 .63123 .2941 Metetra
.981 .705 .423 r
.63123 .2941 .63247 .3052 .62398 .29429 .62279 .28607 Metetra
.979 .689 .394 r
.62279 .28607 .62398 .29429 .61541 .28489 .61425 .278 Metetra
.974 .675 .384 r
.61425 .278 .61541 .28489 .60674 .2767 .60562 .27206 Metetra
.94 .627 .418 r
.60562 .27206 .60674 .2767 .59799 .27083 .59703 .27926 Metetra
.995 .809 .544 r
.59703 .27926 .59799 .27083 .58912 .26586 .58826 .28556 Metetra
.994 .778 .504 r
.58826 .28556 .58912 .26586 .58019 .26878 .57943 .30161 Metetra
.982 .756 .519 r
.57943 .30161 .58019 .26878 .57102 .2602 .57021 .29332 Metetra
.984 .757 .516 r
.57021 .29332 .57102 .2602 .56177 .26061 .56088 .28924 Metetra
.984 .76 .519 r
.56088 .28924 .56177 .26061 .55239 .26368 .55141 .28615 Metetra
.978 .757 .537 r
.55141 .28615 .55239 .26368 .54272 .24214 .54173 .27001 Metetra
.981 .757 .525 r
.54173 .27001 .54272 .24214 .53298 .22678 .53196 .25931 Metetra
.977 .75 .53 r
.53196 .25931 .53298 .22678 .52311 .21568 .52202 .23472 Metetra
.974 .757 .547 r
.52202 .23472 .52311 .21568 .51311 .20639 .51199 .21483 Metetra
.966 .774 .594 r
.51199 .21483 .51311 .20639 .50296 .19636 .50183 .19894 Metetra
.944 .856 .724 r
.50183 .19894 .50296 .19636 .49266 .18715 .49151 .19173 Metetra
.958 .805 .649 r
.49151 .19173 .49266 .18715 .4822 .17745 .48105 .18032 Metetra
.928 .816 .714 r
.48105 .18032 .4822 .17745 .47159 .16751 .47044 .16745 Metetra
.409 .717 .987 r
.47044 .16745 .47159 .16751 .46086 .15157 .45966 .15765 Metetra
.97 .8 .617 r
.45966 .15765 .46086 .15157 .44987 .14732 .44871 .14745 Metetra
.159 .7 .793 r
.44871 .14745 .44987 .14732 .43876 .13699 .43747 .14737 Metetra
.977 .78 .572 r
.43747 .14737 .43876 .13699 .42757 .1198 .42616 .13692 Metetra
.978 .772 .558 r
.64919 .32985 .64999 .31821 .64159 .30006 .64094 .32113 Metetra
.977 .756 .539 r
.64094 .32113 .64159 .30006 .63324 .28987 .63247 .3052 Metetra
.978 .764 .547 r
.63247 .3052 .63324 .28987 .62479 .27997 .62398 .29429 Metetra
.979 .767 .548 r
.62398 .29429 .62479 .27997 .61624 .27044 .61541 .28489 Metetra
.98 .768 .546 r
.61541 .28489 .61624 .27044 .60759 .26155 .60674 .2767 Metetra
.982 .77 .541 r
.60674 .2767 .60759 .26155 .59886 .25508 .59799 .27083 Metetra
.983 .77 .538 r
.59799 .27083 .59886 .25508 .58999 .24849 .58912 .26586 Metetra
.988 .774 .524 r
.58912 .26586 .58999 .24849 .58108 .24894 .58019 .26878 Metetra
.981 .763 .534 r
.58019 .26878 .58108 .24894 .572 .24832 .57102 .2602 Metetra
.988 .785 .543 r
.57102 .2602 .572 .24832 .5628 .25132 .56177 .26061 Metetra
.991 .8 .55 r
.56177 .26061 .5628 .25132 .55341 .25041 .55239 .26368 Metetra
.967 .758 .568 r
.55239 .26368 .55341 .25041 .54381 .23665 .54272 .24214 Metetra
.953 .782 .633 r
.54272 .24214 .54381 .23665 .53405 .21378 .53298 .22678 Metetra
.978 .77 .557 r
.53298 .22678 .53405 .21378 .52421 .20344 .52311 .21568 Metetra
.979 .774 .558 r
.52311 .21568 .52421 .20344 .51423 .19392 .51311 .20639 Metetra
.979 .773 .558 r
.51311 .20639 .51423 .19392 .50412 .1799 .50296 .19636 Metetra
.981 .767 .543 r
.50296 .19636 .50412 .1799 .49384 .17243 .49266 .18715 Metetra
.98 .77 .549 r
.49266 .18715 .49384 .17243 .48339 .16884 .4822 .17745 Metetra
.976 .786 .584 r
.4822 .17745 .48339 .16884 .4728 .15827 .47159 .16751 Metetra
.969 .774 .587 r
.47159 .16751 .4728 .15827 .46206 .14621 .46086 .15157 Metetra
.979 .823 .618 r
.46086 .15157 .46206 .14621 .45113 .13775 .44987 .14732 Metetra
.977 .783 .577 r
.44987 .14732 .45113 .13775 .43993 .13683 .43876 .13699 Metetra
.595 .703 .918 r
.43876 .13699 .43993 .13683 .4288 .11535 .42757 .1198 Metetra
.987 .717 .405 r
.64999 .31821 .6513 .33144 .64299 .31892 .64159 .30006 Metetra
.984 .723 .45 r
.64159 .30006 .64299 .31892 .63457 .30604 .63324 .28987 Metetra
.984 .719 .442 r
.63324 .28987 .63457 .30604 .62608 .29414 .62479 .27997 Metetra
.983 .715 .435 r
.62479 .27997 .62608 .29414 .61753 .28573 .61624 .27044 Metetra
.983 .717 .441 r
.61624 .27044 .61753 .28573 .60898 .28446 .60759 .26155 Metetra
.982 .725 .463 r
.60759 .26155 .60898 .28446 .60044 .29511 .59886 .25508 Metetra
.983 .733 .477 r
.59886 .25508 .60044 .29511 .59161 .29548 .58999 .24849 Metetra
.981 .733 .484 r
.58999 .24849 .59161 .29548 .5828 .31132 .58108 .24894 Metetra
.982 .736 .486 r
.58108 .24894 .5828 .31132 .57368 .31456 .572 .24832 Metetra
.981 .736 .488 r
.572 .24832 .57368 .31456 .56432 .30849 .5628 .25132 Metetra
.982 .735 .485 r
.5628 .25132 .56432 .30849 .55515 .35503 .55341 .25041 Metetra
.984 .74 .487 r
.55341 .25041 .55515 .35503 .54513 .28286 .54381 .23665 Metetra
.986 .738 .47 r
.54381 .23665 .54513 .28286 .53534 .2706 .53405 .21378 Metetra
.983 .737 .48 r
.53405 .21378 .53534 .2706 .52543 .25952 .52421 .20344 Metetra
.983 .736 .481 r
.52421 .20344 .52543 .25952 .51537 .22898 .51423 .19392 Metetra
.984 .733 .468 r
.51423 .19392 .51537 .22898 .50521 .21007 .50412 .1799 Metetra
.983 .729 .469 r
.50412 .1799 .50521 .21007 .4949 .19773 .49384 .17243 Metetra
.981 .724 .468 r
.49384 .17243 .4949 .19773 .48445 .18692 .48339 .16884 Metetra
.983 .719 .446 r
.48339 .16884 .48445 .18692 .47384 .17638 .4728 .15827 Metetra
.983 .719 .444 r
.4728 .15827 .47384 .17638 .46305 .1672 .46206 .14621 Metetra
.982 .721 .456 r
.46206 .14621 .46305 .1672 .45215 .15269 .45113 .13775 Metetra
.977 .707 .451 r
.45113 .13775 .45215 .15269 .44107 .1401 .43993 .13683 Metetra
.851 .483 0 r
.43993 .13683 .44107 .1401 .4298 .12915 .4288 .11535 Metetra
.985 .715 .423 r
.6513 .33144 .65261 .34487 .6443 .33283 .64299 .31892 Metetra
.985 .716 .425 r
.64299 .31892 .6443 .33283 .63592 .32241 .63457 .30604 Metetra
.985 .72 .438 r
.63457 .30604 .63592 .32241 .62739 .30932 .62608 .29414 Metetra
.983 .716 .441 r
.62608 .29414 .62739 .30932 .61881 .29954 .61753 .28573 Metetra
.977 .709 .452 r
.61753 .28573 .61881 .29954 .61024 .29852 .60898 .28446 Metetra
.968 .702 .475 r
.60898 .28446 .61024 .29852 .60155 .29843 .60044 .29511 Metetra
.938 .586 .325 r
.60044 .29511 .60155 .29843 .59291 .31424 .59161 .29548 Metetra
.969 .709 .485 r
.59161 .29548 .59291 .31424 .58396 .31867 .5828 .31132 Metetra
.963 .67 .428 r
.5828 .31132 .58396 .31867 .57478 .31515 .57368 .31456 Metetra
0 .291 .698 r
.57368 .31456 .57478 .31515 .56572 .34701 .56432 .30849 Metetra
.967 .717 .507 r
.56432 .30849 .56572 .34701 .55658 .40321 .55515 .35503 Metetra
.993 .746 .438 r
.55515 .35503 .55658 .40321 .54667 .36932 .54513 .28286 Metetra
.984 .739 .485 r
.54513 .28286 .54667 .36932 .53652 .28589 .53534 .2706 Metetra
.983 .715 .435 r
.53534 .2706 .53652 .28589 .52656 .2615 .52543 .25952 Metetra
0 .071 .625 r
.52543 .25952 .52656 .2615 .5165 .24514 .51537 .22898 Metetra
.986 .72 .424 r
.51537 .22898 .5165 .24514 .50633 .22222 .50521 .21007 Metetra
.983 .707 .416 r
.50521 .21007 .50633 .22222 .49602 .20797 .4949 .19773 Metetra
.981 .697 .404 r
.4949 .19773 .49602 .20797 .48558 .19024 .48445 .18692 Metetra
.931 .555 .173 r
.48445 .18692 .48558 .19024 .475 .17461 .47384 .17638 Metetra
.902 .864 .792 r
.47384 .17638 .475 .17461 .46422 .16599 .46305 .1672 Metetra
.826 .81 .835 r
.46305 .1672 .46422 .16599 .45327 .15741 .45215 .15269 Metetra
.959 .621 .263 r
.45215 .15269 .45327 .15741 .44212 .15052 .44107 .1401 Metetra
.98 .696 .405 r
.44107 .1401 .44212 .15052 .4309 .13525 .4298 .12915 Metetra
.975 .767 .559 r
.65261 .34487 .65339 .33247 .64508 .31953 .6443 .33283 Metetra
.978 .767 .553 r
.6443 .33283 .64508 .31953 .63665 .30509 .63592 .32241 Metetra
.977 .76 .543 r
.63592 .32241 .63665 .30509 .62819 .29472 .62739 .30932 Metetra
.979 .767 .547 r
.62739 .30932 .62819 .29472 .61963 .28431 .61881 .29954 Metetra
.986 .774 .533 r
.61881 .29954 .61963 .28431 .611 .27721 .61024 .29852 Metetra
.986 .766 .521 r
.61024 .29852 .611 .27721 .60243 .28333 .60155 .29843 Metetra
.996 .788 .504 r
.60155 .29843 .60243 .28333 .59384 .30146 .59291 .31424 Metetra
.991 .786 .531 r
.59291 .31424 .59384 .30146 .58493 .30699 .58396 .31867 Metetra
.984 .781 .55 r
.58396 .31867 .58493 .30699 .5758 .30677 .57478 .31515 Metetra
.983 .827 .433 r
.57478 .31515 .5758 .30677 .56655 .31143 .56572 .34701 Metetra
.997 .774 .467 r
.56572 .34701 .56655 .31143 .5572 .32591 .55658 .40321 Metetra
.979 .745 .512 r
.55658 .40321 .5572 .32591 .54742 .2944 .54667 .36932 Metetra
.971 .737 .526 r
.54667 .36932 .54742 .2944 .53762 .27898 .53652 .28589 Metetra
.944 .758 .621 r
.53652 .28589 .53762 .27898 .52767 .25411 .52656 .2615 Metetra
.962 .776 .606 r
.52656 .2615 .52767 .25411 .51763 .23418 .5165 .24514 Metetra
.963 .76 .582 r
.5165 .24514 .51763 .23418 .50747 .21522 .50633 .22222 Metetra
.965 .783 .608 r
.50633 .22222 .50747 .21522 .49718 .20023 .49602 .20797 Metetra
.962 .774 .604 r
.49602 .20797 .49718 .20023 .48675 .18497 .48558 .19024 Metetra
.953 .788 .639 r
.48558 .19024 .48675 .18497 .47615 .17519 .475 .17461 Metetra
0 .362 .785 r
.475 .17461 .47615 .17519 .46538 .16663 .46422 .16599 Metetra
0 .313 .745 r
.46422 .16599 .46538 .16663 .45446 .15428 .45327 .15741 Metetra
.957 .852 .698 r
.45327 .15741 .45446 .15428 .4433 .15028 .44212 .15052 Metetra
.617 .738 .933 r
.44212 .15052 .4433 .15028 .43207 .13606 .4309 .13525 Metetra
.983 .701 .388 r
.65339 .33247 .65463 .34213 .64621 .32372 .64508 .31953 Metetra
.943 .602 .185 r
.64508 .31953 .64621 .32372 .63767 .30375 .63665 .30509 Metetra
.863 .825 .809 r
.63665 .30509 .63767 .30375 .62918 .29113 .62819 .29472 Metetra
.948 .807 .67 r
.62819 .29472 .62918 .29113 .62063 .28108 .61963 .28431 Metetra
.956 .831 .679 r
.61963 .28431 .62063 .28108 .61206 .27695 .611 .27721 Metetra
.122 0 0 r
.611 .27721 .61206 .27695 .60361 .29127 .60243 .28333 Metetra
.942 .661 .477 r
.60243 .28333 .60361 .29127 .59526 .32942 .59384 .30146 Metetra
.978 .724 .479 r
.59384 .30146 .59526 .32942 .58624 .32725 .58493 .30699 Metetra
.979 .719 .466 r
.58493 .30699 .58624 .32725 .57733 .35249 .5758 .30677 Metetra
.98 .732 .484 r
.5758 .30677 .57733 .35249 .56793 .34455 .56655 .31143 Metetra
.976 .724 .487 r
.56655 .31143 .56793 .34455 .55866 .377 .5572 .32591 Metetra
.987 .74 .466 r
.5572 .32591 .55866 .377 .54871 .32779 .54742 .2944 Metetra
.985 .733 .464 r
.54742 .2944 .54871 .32779 .53889 .31923 .53762 .27898 Metetra
.987 .737 .463 r
.53762 .27898 .53889 .31923 .52885 .27805 .52767 .25411 Metetra
.987 .729 .446 r
.52767 .25411 .52885 .27805 .5188 .29103 .51763 .23418 Metetra
.985 .738 .476 r
.51763 .23418 .5188 .29103 .5086 .22094 .50747 .21522 Metetra
.969 .649 .289 r
.50747 .21522 .5086 .22094 .4983 .20924 .49718 .20023 Metetra
.981 .692 .372 r
.49718 .20023 .4983 .20924 .48787 .19156 .48675 .18497 Metetra
.973 .665 .352 r
.48675 .18497 .48787 .19156 .47728 .1798 .47615 .17519 Metetra
.96 .622 .293 r
.47615 .17519 .47728 .1798 .46653 .16722 .46538 .16663 Metetra
.042 .438 .872 r
.46538 .16663 .46653 .16722 .45561 .15617 .45446 .15428 Metetra
.859 .407 .071 r
.45446 .15428 .45561 .15617 .44451 .14666 .4433 .15028 Metetra
.94 .808 .686 r
.4433 .15028 .44451 .14666 .43333 .12936 .43207 .13606 Metetra
.94 .765 .638 r
.65463 .34213 .65556 .33685 .6472 .32124 .64621 .32372 Metetra
.877 .75 .718 r
.64621 .32372 .6472 .32124 .63871 .3031 .63767 .30375 Metetra
.756 .775 .869 r
.63767 .30375 .63871 .3031 .63027 .29319 .62918 .29113 Metetra
.824 .393 0 r
.62918 .29113 .63027 .29319 .62173 .28386 .62063 .28108 Metetra
.93 .549 .223 r
.62063 .28108 .62173 .28386 .61315 .27884 .61206 .27695 Metetra
.835 .488 .397 r
.61206 .27695 .61315 .27884 .60479 .29947 .60361 .29127 Metetra
.911 .641 .515 r
.60361 .29127 .60479 .29947 .59599 .30001 .59526 .32942 Metetra
.985 .76 .516 r
.59526 .32942 .59599 .30001 .58709 .30532 .58624 .32725 Metetra
.996 .779 .49 r
.58624 .32725 .58709 .30532 .57799 .30603 .57733 .35249 Metetra
.983 .753 .511 r
.57733 .35249 .57799 .30603 .56886 .32306 .56793 .34455 Metetra
.998 .783 .481 r
.56793 .34455 .56886 .32306 .55969 .3636 .55866 .377 Metetra
.939 .728 .591 r
.55866 .377 .55969 .3636 .54968 .29997 .54871 .32779 Metetra
.983 .758 .522 r
.54871 .32779 .54968 .29997 .5398 .26264 .53889 .31923 Metetra
.977 .744 .52 r
.53889 .31923 .5398 .26264 .5299 .24451 .52885 .27805 Metetra
.989 .764 .503 r
.52885 .27805 .5299 .24451 .51989 .2307 .5188 .29103 Metetra
.971 .738 .527 r
.5188 .29103 .51989 .2307 .50974 .21693 .5086 .22094 Metetra
.952 .809 .666 r
.5086 .22094 .50974 .21693 .49945 .20645 .4983 .20924 Metetra
.906 .787 .718 r
.4983 .20924 .49945 .20645 .48902 .18996 .48787 .19156 Metetra
.878 .838 .803 r
.48787 .19156 .48902 .18996 .47843 .18 .47728 .1798 Metetra
.379 .65 .963 r
.47728 .1798 .47843 .18 .4677 .16662 .46653 .16722 Metetra
.73 .834 .929 r
.46653 .16722 .4677 .16662 .45678 .15593 .45561 .15617 Metetra
.581 .811 .987 r
.45561 .15617 .45678 .15593 .44569 .1461 .44451 .14666 Metetra
.708 .751 .886 r
.44451 .14666 .44569 .1461 .43442 .13622 .43333 .12936 Metetra
.968 .765 .576 r
.65556 .33685 .65639 .32661 .64802 .30992 .6472 .32124 Metetra
.967 .76 .573 r
.6472 .32124 .64802 .30992 .63971 .30087 .63871 .3031 Metetra
.919 .824 .736 r
.63871 .3031 .63971 .30087 .63124 .2882 .63027 .29319 Metetra
.964 .799 .629 r
.63027 .29319 .63124 .2882 .62272 .27935 .62173 .28386 Metetra
.974 .822 .629 r
.62173 .28386 .62272 .27935 .6141 .2709 .61315 .27884 Metetra
.997 .829 .483 r
.61315 .27884 .6141 .2709 .60538 .26431 .60479 .29947 Metetra
.986 .758 .51 r
.60479 .29947 .60538 .26431 .59663 .26441 .59599 .30001 Metetra
.987 .759 .506 r
.59599 .30001 .59663 .26441 .58781 .27167 .58709 .30532 Metetra
.986 .759 .511 r
.58709 .30532 .58781 .27167 .57875 .27183 .57799 .30603 Metetra
.99 .764 .499 r
.57799 .30603 .57875 .27183 .56957 .27583 .56886 .32306 Metetra
.993 .764 .484 r
.56886 .32306 .56957 .27583 .56014 .26724 .55969 .3636 Metetra
.977 .741 .515 r
.55969 .3636 .56014 .26724 .55057 .25822 .54968 .29997 Metetra
.975 .745 .527 r
.54968 .29997 .55057 .25822 .5408 .23316 .5398 .26264 Metetra
.979 .754 .527 r
.5398 .26264 .5408 .23316 .53095 .21708 .5299 .24451 Metetra
.981 .756 .526 r
.5299 .24451 .53095 .21708 .52099 .20322 .51989 .2307 Metetra
.981 .757 .526 r
.51989 .2307 .52099 .20322 .51089 .19245 .50974 .21693 Metetra
.982 .76 .528 r
.50974 .21693 .51089 .19245 .50064 .17877 .49945 .20645 Metetra
.98 .756 .528 r
.49945 .20645 .50064 .17877 .49025 .16911 .48902 .18996 Metetra
.982 .763 .533 r
.48902 .18996 .49025 .16911 .47969 .15983 .47843 .18 Metetra
.98 .762 .537 r
.47843 .18 .47969 .15983 .46898 .14826 .4677 .16662 Metetra
.981 .765 .539 r
.4677 .16662 .46898 .14826 .45811 .13699 .45678 .15593 Metetra
.982 .766 .537 r
.45678 .15593 .45811 .13699 .44695 .13728 .44569 .1461 Metetra
.977 .787 .582 r
.44569 .1461 .44695 .13728 .43585 .11524 .43442 .13622 Metetra
.969 .762 .57 r
.65639 .32661 .65718 .31525 .6488 .29702 .64802 .30992 Metetra
.979 .77 .551 r
.64802 .30992 .6488 .29702 .64045 .28448 .63971 .30087 Metetra
.978 .762 .544 r
.63971 .30087 .64045 .28448 .63207 .2757 .63124 .2882 Metetra
.979 .771 .553 r
.63124 .2882 .63207 .2757 .62358 .26746 .62272 .27935 Metetra
.98 .773 .555 r
.62272 .27935 .62358 .26746 .61495 .25678 .6141 .2709 Metetra
.982 .771 .543 r
.6141 .2709 .61495 .25678 .60628 .25161 .60538 .26431 Metetra
.988 .781 .538 r
.60538 .26431 .60628 .25161 .59749 .24741 .59663 .26441 Metetra
.991 .778 .516 r
.59663 .26441 .59749 .24741 .58859 .24498 .58781 .27167 Metetra
.986 .762 .515 r
.58781 .27167 .58859 .24498 .57957 .24364 .57875 .27183 Metetra
.987 .763 .511 r
.57875 .27183 .57957 .24364 .57045 .249 .56957 .27583 Metetra
.983 .759 .523 r
.56957 .27583 .57045 .249 .5611 .24675 .56014 .26724 Metetra
.982 .763 .532 r
.56014 .26724 .5611 .24675 .55154 .23292 .55057 .25822 Metetra
.975 .751 .537 r
.55057 .25822 .55154 .23292 .54182 .2104 .5408 .23316 Metetra
.979 .757 .534 r
.5408 .23316 .54182 .2104 .53202 .19597 .53095 .21708 Metetra
.98 .76 .535 r
.53095 .21708 .53202 .19597 .52209 .18606 .52099 .20322 Metetra
.98 .766 .541 r
.52099 .20322 .52209 .18606 .51202 .17649 .51089 .19245 Metetra
.978 .765 .548 r
.51089 .19245 .51202 .17649 .5018 .16783 .50064 .17877 Metetra
.979 .778 .564 r
.50064 .17877 .5018 .16783 .49143 .1578 .49025 .16911 Metetra
.98 .778 .562 r
.49025 .16911 .49143 .1578 .48089 .14933 .47969 .15983 Metetra
.977 .778 .57 r
.47969 .15983 .48089 .14933 .47019 .14041 .46898 .14826 Metetra
.973 .788 .593 r
.46898 .14826 .47019 .14041 .45928 .13675 .45811 .13699 Metetra
.259 .769 .821 r
.45811 .13699 .45928 .13675 .44804 .14629 .44695 .13728 Metetra
.981 .691 .345 r
.44695 .13728 .44804 .14629 .43709 .1103 .43585 .11524 Metetra
0 0 .533 r
.65718 .31525 .65826 .31702 .65007 .30806 .6488 .29702 Metetra
.984 .707 .403 r
.6488 .29702 .65007 .30806 .64171 .29549 .64045 .28448 Metetra
.982 .705 .416 r
.64045 .28448 .64171 .29549 .63327 .28438 .63207 .2757 Metetra
.98 .692 .396 r
.63207 .2757 .63327 .28438 .62486 .28083 .62358 .26746 Metetra
.984 .713 .425 r
.62358 .26746 .62486 .28083 .61625 .27265 .61495 .25678 Metetra
.981 .715 .448 r
.61495 .25678 .61625 .27265 .60774 .2795 .60628 .25161 Metetra
.982 .728 .469 r
.60628 .25161 .60774 .2795 .59909 .28828 .59749 .24741 Metetra
.982 .732 .478 r
.59749 .24741 .59909 .28828 .5905 .31719 .58859 .24498 Metetra
.983 .737 .485 r
.58859 .24498 .5905 .31719 .58164 .34139 .57957 .24364 Metetra
.982 .738 .489 r
.57957 .24364 .58164 .34139 .57269 .38143 .57045 .249 Metetra
.983 .74 .489 r
.57045 .249 .57269 .38143 .56334 .40202 .5611 .24675 Metetra
.984 .742 .487 r
.5611 .24675 .56334 .40202 .55344 .36827 .55154 .23292 Metetra
.985 .742 .485 r
.55154 .23292 .55344 .36827 .54336 .30786 .54182 .2104 Metetra
.984 .74 .484 r
.54182 .2104 .54336 .30786 .53344 .29913 .53202 .19597 Metetra
.984 .74 .485 r
.53202 .19597 .53344 .29913 .52331 .25171 .52209 .18606 Metetra
.984 .737 .481 r
.52209 .18606 .52331 .25171 .51315 .24175 .51202 .17649 Metetra
.984 .737 .481 r
.51202 .17649 .51315 .24175 .50287 .20852 .5018 .16783 Metetra
.984 .733 .472 r
.5018 .16783 .50287 .20852 .49245 .19596 .49143 .1578 Metetra
.983 .732 .472 r
.49143 .1578 .49245 .19596 .4819 .17947 .48089 .14933 Metetra
.983 .729 .465 r
.48089 .14933 .4819 .17947 .4712 .16321 .47019 .14041 Metetra
.981 .721 .462 r
.47019 .14041 .4712 .16321 .46032 .15192 .45928 .13675 Metetra
.97 .701 .465 r
.45928 .13675 .46032 .15192 .44925 .1421 .44804 .14629 Metetra
.886 .724 .676 r
.44804 .14629 .44925 .1421 .43807 .12766 .43709 .1103 Metetra
.983 .713 .429 r
.65826 .31702 .65958 .33037 .65127 .3159 .65007 .30806 Metetra
.98 .687 .36 r
.65007 .30806 .65127 .3159 .64302 .30931 .64171 .29549 Metetra
.984 .715 .426 r
.64171 .29549 .64302 .30931 .63449 .29357 .63327 .28438 Metetra
.976 .692 .419 r
.63327 .28438 .63449 .29357 .626 .28547 .62486 .28083 Metetra
.964 .633 .297 r
.62486 .28083 .626 .28547 .6174 .2779 .61625 .27265 Metetra
.947 .64 .422 r
.61625 .27265 .6174 .2779 .60915 .30368 .60774 .2795 Metetra
.976 .72 .479 r
.60774 .2795 .60915 .30368 .60026 .29572 .59909 .28828 Metetra
.921 .643 .498 r
.59909 .28828 .60026 .29572 .59147 .30698 .5905 .31719 Metetra
.999 .815 .478 r
.5905 .31719 .59147 .30698 .58233 .30075 .58164 .34139 Metetra
.994 .767 .481 r
.58164 .34139 .58233 .30075 .57329 .32191 .57269 .38143 Metetra
.988 .756 .495 r
.57269 .38143 .57329 .32191 .56405 .34609 .56334 .40202 Metetra
.978 .746 .517 r
.56334 .40202 .56405 .34609 .55412 .29226 .55344 .36827 Metetra
.976 .741 .518 r
.55344 .36827 .55412 .29226 .54437 .28146 .54336 .30786 Metetra
.983 .759 .523 r
.54336 .30786 .54437 .28146 .53443 .25312 .53344 .29913 Metetra
.974 .743 .527 r
.53344 .29913 .53443 .25312 .52444 .24367 .52331 .25171 Metetra
.975 .788 .587 r
.52331 .25171 .52444 .24367 .51429 .2304 .51315 .24175 Metetra
.952 .747 .588 r
.51315 .24175 .51429 .2304 .50401 .21642 .50287 .20852 Metetra
.978 .681 .363 r
.50287 .20852 .50401 .21642 .4936 .1965 .49245 .19596 Metetra
.247 .501 .9 r
.49245 .19596 .4936 .1965 .48305 .1809 .4819 .17947 Metetra
0 0 .549 r
.4819 .17947 .48305 .1809 .47232 .16907 .4712 .16321 Metetra
.97 .651 .32 r
.4712 .16321 .47232 .16907 .46145 .15669 .46032 .15192 Metetra
.96 .624 .287 r
.46032 .15192 .46145 .15669 .45037 .14864 .44925 .1421 Metetra
.973 .662 .322 r
.44925 .1421 .45037 .14864 .43922 .13034 .43807 .12766 Metetra
.78 .387 0 r
.65958 .33037 .66068 .33279 .65229 .31469 .65127 .3159 Metetra
.874 .88 .836 r
.65127 .3159 .65229 .31469 .64403 .30722 .64302 .30931 Metetra
.882 .776 .741 r
.64302 .30931 .64403 .30722 .63554 .29331 .63449 .29357 Metetra
.629 .813 .97 r
.63449 .29357 .63554 .29331 .62708 .28691 .626 .28547 Metetra
.726 .237 0 r
.626 .28547 .62708 .28691 .61859 .28601 .6174 .2779 Metetra
.931 .655 .494 r
.6174 .2779 .61859 .28601 .61006 .29169 .60915 .30368 Metetra
.981 .774 .554 r
.60915 .30368 .61006 .29169 .60157 .31294 .60026 .29572 Metetra
.971 .708 .476 r
.60026 .29572 .60157 .31294 .5927 .3187 .59147 .30698 Metetra
.98 .704 .426 r
.59147 .30698 .5927 .3187 .58384 .34097 .58233 .30075 Metetra
.976 .726 .491 r
.58233 .30075 .58384 .34097 .57426 .30718 .57329 .32191 Metetra
.999 .796 .488 r
.57329 .32191 .57426 .30718 .56506 .33092 .56405 .34609 Metetra
.941 .727 .585 r
.56405 .34609 .56506 .33092 .55524 .29199 .55412 .29226 Metetra
.634 .787 .955 r
.55412 .29226 .55524 .29199 .54545 .27227 .54437 .28146 Metetra
.95 .751 .6 r
.54437 .28146 .54545 .27227 .53559 .26208 .53443 .25312 Metetra
.979 .689 .391 r
.53443 .25312 .53559 .26208 .52557 .24184 .52444 .24367 Metetra
.885 .818 .776 r
.52444 .24367 .52557 .24184 .51543 .22549 .51429 .2304 Metetra
.955 .794 .644 r
.51429 .2304 .51543 .22549 .50517 .20375 .50401 .21642 Metetra
.97 .763 .567 r
.50401 .21642 .50517 .20375 .49477 .18889 .4936 .1965 Metetra
.966 .78 .601 r
.4936 .1965 .49477 .18889 .48423 .17509 .48305 .1809 Metetra
.966 .798 .622 r
.48305 .1809 .48423 .17509 .4735 .16699 .47232 .16907 Metetra
.904 .832 .765 r
.47232 .16907 .4735 .16699 .46262 .15593 .46145 .15669 Metetra
.773 .891 .928 r
.46145 .15669 .46262 .15593 .45157 .14557 .45037 .14864 Metetra
.915 .791 .71 r
.45037 .14864 .45157 .14557 .44038 .13203 .43922 .13034 Metetra
.901 .764 .701 r
.66068 .33279 .66165 .32987 .65332 .31383 .65229 .31469 Metetra
.818 .867 .883 r
.65229 .31469 .65332 .31383 .64507 .30677 .64403 .30722 Metetra
.705 .741 .879 r
.64403 .30722 .64507 .30677 .63657 .29211 .63554 .29331 Metetra
.874 .886 .84 r
.63554 .29331 .63657 .29211 .62811 .28505 .62708 .28691 Metetra
.946 .93 .753 r
.62708 .28691 .62811 .28505 .61952 .27699 .61859 .28601 Metetra
.995 .805 .539 r
.61859 .28601 .61952 .27699 .6112 .29638 .61006 .29169 Metetra
.904 .607 .473 r
.61006 .29169 .6112 .29638 .60256 .30572 .60157 .31294 Metetra
.996 .821 .552 r
.60157 .31294 .60256 .30572 .59369 .30992 .5927 .3187 Metetra
.998 .824 .481 r
.5927 .3187 .59369 .30992 .58495 .34083 .58384 .34097 Metetra
.62 .571 .778 r
.58384 .34097 .58495 .34083 .57583 .35783 .57426 .30718 Metetra
.977 .729 .492 r
.57426 .30718 .57583 .35783 .56653 .37589 .56506 .33092 Metetra
.989 .74 .455 r
.56506 .33092 .56653 .37589 .55651 .31549 .55524 .29199 Metetra
.987 .729 .443 r
.55524 .29199 .55651 .31549 .54662 .28085 .54545 .27227 Metetra
.979 .687 .383 r
.54545 .27227 .54662 .28085 .53699 .33916 .53559 .26208 Metetra
.985 .74 .478 r
.53559 .26208 .53699 .33916 .52672 .25051 .52557 .24184 Metetra
.981 .689 .358 r
.52557 .24184 .52672 .25051 .51657 .22981 .51543 .22549 Metetra
.913 .573 .106 r
.51543 .22549 .51657 .22981 .50631 .20812 .50517 .20375 Metetra
.948 .604 .208 r
.50517 .20375 .50631 .20812 .4959 .19576 .49477 .18889 Metetra
.975 .668 .333 r
.49477 .18889 .4959 .19576 .48537 .17966 .48423 .17509 Metetra
.959 .619 .291 r
.48423 .17509 .48537 .17966 .47465 .16874 .4735 .16699 Metetra
.748 .28 0 r
.4735 .16699 .47465 .16874 .4638 .15471 .46262 .15593 Metetra
.847 .863 .854 r
.46262 .15593 .4638 .15471 .45273 .14726 .45157 .14557 Metetra
.668 .207 0 r
.45157 .14557 .45273 .14726 .44158 .13012 .44038 .13203 Metetra
.885 .773 .733 r
.66165 .32987 .66264 .32766 .65427 .30959 .65332 .31383 Metetra
.967 .815 .641 r
.65332 .31383 .65427 .30959 .64601 .30107 .64507 .30677 Metetra
.955 .778 .624 r
.64507 .30677 .64601 .30107 .63762 .2914 .63657 .29211 Metetra
.785 .875 .913 r
.63657 .29211 .63762 .2914 .62915 .28367 .62811 .28505 Metetra
.882 .86 .815 r
.62811 .28505 .62915 .28367 .62058 .27678 .61952 .27699 Metetra
.475 .118 .28 r
.61952 .27699 .62058 .27678 .61225 .29424 .6112 .29638 Metetra
.894 .946 .588 r
.6112 .29638 .61225 .29424 .60353 .29709 .60256 .30572 Metetra
.994 .806 .546 r
.60256 .30572 .60353 .29709 .59476 .3074 .59369 .30992 Metetra
0 0 .027 r
.59369 .30992 .59476 .3074 .58583 .31996 .58495 .34083 Metetra
.994 .777 .499 r
.58495 .34083 .58583 .31996 .57671 .33201 .57583 .35783 Metetra
.993 .772 .497 r
.57583 .35783 .57671 .33201 .56717 .31451 .56653 .37589 Metetra
.974 .741 .523 r
.56653 .37589 .56717 .31451 .55756 .30434 .55651 .31549 Metetra
.949 .743 .591 r
.55651 .31549 .55756 .30434 .54772 .27614 .54662 .28085 Metetra
0 0 .097 r
.54662 .28085 .54772 .27614 .53782 .25332 .53699 .33916 Metetra
.973 .738 .521 r
.53699 .33916 .53782 .25332 .5278 .22538 .52672 .25051 Metetra
.978 .754 .533 r
.52672 .25051 .5278 .22538 .5177 .21439 .51657 .22981 Metetra
.972 .759 .557 r
.51657 .22981 .5177 .21439 .50746 .20479 .50631 .20812 Metetra
.941 .815 .692 r
.50631 .20812 .50746 .20479 .49708 .18834 .4959 .19576 Metetra
.964 .779 .604 r
.4959 .19576 .49708 .18834 .48654 .17594 .48537 .17966 Metetra
.952 .82 .676 r
.48537 .17966 .48654 .17594 .47584 .1645 .47465 .16874 Metetra
.949 .802 .663 r
.47465 .16874 .47584 .1645 .46497 .15424 .4638 .15471 Metetra
.674 .88 .975 r
.4638 .15471 .46497 .15424 .45393 .14531 .45273 .14726 Metetra
.875 .798 .77 r
.45273 .14726 .45393 .14531 .44272 .1346 .44158 .13012 Metetra
.937 .609 .167 r
.66264 .32766 .66379 .33238 .65556 .32101 .65427 .30959 Metetra
.982 .706 .418 r
.65427 .30959 .65556 .32101 .6472 .30792 .64601 .30107 Metetra
.977 .675 .355 r
.64601 .30107 .6472 .30792 .63871 .29349 .63762 .2914 Metetra
.863 .431 .008 r
.63762 .2914 .63871 .29349 .63022 .28425 .62915 .28367 Metetra
0 .344 .772 r
.62915 .28367 .63022 .28425 .62162 .27539 .62058 .27678 Metetra
.62058 .27678 .62162 .27539 .61292 .26711 .61225 .29424 Metetra
.988 .763 .51 r
.61225 .29424 .61292 .26711 .60423 .26807 .60353 .29709 Metetra
.99 .765 .503 r
.60353 .29709 .60423 .26807 .59553 .28116 .59476 .3074 Metetra
.991 .769 .502 r
.59476 .3074 .59553 .28116 .58675 .30278 .58583 .31996 Metetra
.994 .781 .508 r
.58583 .31996 .58675 .30278 .57755 .3029 .57671 .33201 Metetra
.98 .754 .526 r
.57671 .33201 .57755 .3029 .56796 .27463 .56717 .31451 Metetra
.983 .754 .513 r
.56717 .31451 .56796 .27463 .55837 .25788 .55756 .30434 Metetra
.979 .748 .518 r
.55756 .30434 .55837 .25788 .54865 .23808 .54772 .27614 Metetra
.979 .75 .521 r
.54772 .27614 .54865 .23808 .53886 .22879 .53782 .25332 Metetra
.974 .751 .539 r
.53782 .25332 .53886 .22879 .52892 .21847 .5278 .22538 Metetra
.971 .791 .602 r
.5278 .22538 .52892 .21847 .51884 .20736 .5177 .21439 Metetra
.974 .794 .598 r
.5177 .21439 .51884 .20736 .50861 .19665 .50746 .20479 Metetra
.966 .776 .596 r
.50746 .20479 .50861 .19665 .49823 .18803 .49708 .18834 Metetra
.64 .778 .947 r
.49708 .18834 .49823 .18803 .4877 .17582 .48654 .17594 Metetra
.551 .759 .974 r
.48654 .17594 .4877 .17582 .47704 .15865 .47584 .1645 Metetra
.97 .803 .619 r
.47584 .1645 .47704 .15865 .46619 .14859 .46497 .15424 Metetra
.972 .809 .621 r
.46497 .15424 .46619 .14859 .45517 .1383 .45393 .14531 Metetra
.973 .795 .602 r
.45393 .14531 .45517 .1383 .44398 .12679 .44272 .1346 Metetra
.979 .762 .539 r
.66379 .33238 .66445 .31522 .65629 .30618 .65556 .32101 Metetra
.977 .763 .548 r
.65556 .32101 .65629 .30618 .64795 .29289 .6472 .30792 Metetra
.976 .762 .549 r
.6472 .30792 .64795 .29289 .63944 .27616 .63871 .29349 Metetra
.981 .764 .536 r
.63871 .29349 .63944 .27616 .63093 .26441 .63022 .28425 Metetra
.982 .762 .53 r
.63022 .28425 .63093 .26441 .62239 .25661 .62162 .27539 Metetra
.982 .764 .532 r
.62162 .27539 .62239 .25661 .61366 .24477 .61292 .26711 Metetra
.987 .766 .516 r
.61292 .26711 .61366 .24477 .605 .24581 .60423 .26807 Metetra
.993 .773 .502 r
.60423 .26807 .605 .24581 .59622 .24861 .59553 .28116 Metetra
.992 .767 .492 r
.59553 .28116 .59622 .24861 .5872 .24423 .58675 .30278 Metetra
.985 .753 .502 r
.58675 .30278 .5872 .24423 .5781 .24574 .57755 .3029 Metetra
.98 .747 .513 r
.57755 .3029 .5781 .24574 .56885 .24845 .56796 .27463 Metetra
.98 .755 .528 r
.56796 .27463 .56885 .24845 .55933 .23594 .55837 .25788 Metetra
.977 .756 .537 r
.55837 .25788 .55933 .23594 .54961 .2097 .54865 .23808 Metetra
.983 .758 .52 r
.54865 .23808 .54961 .2097 .53985 .19461 .53886 .22879 Metetra
.983 .756 .516 r
.53886 .22879 .53985 .19461 .52997 .18509 .52892 .21847 Metetra
.983 .756 .517 r
.52892 .21847 .52997 .18509 .51995 .17545 .51884 .20736 Metetra
.983 .757 .518 r
.51884 .20736 .51995 .17545 .50977 .16571 .50861 .19665 Metetra
.984 .758 .517 r
.50861 .19665 .50977 .16571 .49944 .15837 .49823 .18803 Metetra
.982 .757 .521 r
.49823 .18803 .49944 .15837 .48895 .15111 .4877 .17582 Metetra
.98 .757 .53 r
.4877 .17582 .48895 .15111 .47827 .14586 .47704 .15865 Metetra
.981 .775 .554 r
.47704 .15865 .47827 .14586 .46749 .12984 .46619 .14859 Metetra
.982 .766 .536 r
.46619 .14859 .46749 .12984 .45636 .13662 .45517 .1383 Metetra
.885 .849 .802 r
.45517 .1383 .45636 .13662 .44532 .11184 .44398 .12679 Metetra
.952 .603 .233 r
.66445 .31522 .66557 .31907 .65739 .30868 .65629 .30618 Metetra
.822 .425 0 r
.65629 .30618 .65739 .30868 .64906 .29581 .64795 .29289 Metetra
.82 .451 0 r
.64795 .29289 .64906 .29581 .64066 .28507 .63944 .27616 Metetra
.982 .694 .379 r
.63944 .27616 .64066 .28507 .63222 .27714 .63093 .26441 Metetra
.982 .709 .427 r
.63093 .26441 .63222 .27714 .62373 .27383 .62239 .25661 Metetra
.985 .721 .437 r
.62239 .25661 .62373 .27383 .61533 .28456 .61366 .24477 Metetra
.982 .731 .478 r
.61366 .24477 .61533 .28456 .60674 .29375 .605 .24581 Metetra
.982 .733 .481 r
.605 .24581 .60674 .29375 .59805 .30827 .59622 .24861 Metetra
.984 .736 .48 r
.59622 .24861 .59805 .30827 .5892 .32539 .5872 .24423 Metetra
.983 .738 .485 r
.5872 .24423 .5892 .32539 .5801 .33769 .5781 .24574 Metetra
.983 .738 .486 r
.5781 .24574 .5801 .33769 .57092 .36178 .56885 .24845 Metetra
.985 .741 .483 r
.56885 .24845 .57092 .36178 .56104 .32086 .55933 .23594 Metetra
.986 .741 .476 r
.55933 .23594 .56104 .32086 .55124 .30017 .54961 .2097 Metetra
.985 .74 .48 r
.54961 .2097 .55124 .30017 .54131 .2765 .53985 .19461 Metetra
.984 .739 .481 r
.53985 .19461 .54131 .2765 .53125 .24429 .52997 .18509 Metetra
.984 .737 .477 r
.52997 .18509 .53125 .24429 .52112 .212 .51995 .17545 Metetra
.984 .732 .468 r
.51995 .17545 .52112 .212 .5109 .19899 .50977 .16571 Metetra
.983 .73 .467 r
.50977 .16571 .5109 .19899 .50053 .18769 .49944 .15837 Metetra
.983 .728 .464 r
.49944 .15837 .50053 .18769 .49001 .17662 .48895 .15111 Metetra
.982 .724 .461 r
.48895 .15111 .49001 .17662 .47933 .16428 .47827 .14586 Metetra
.986 .721 .434 r
.47827 .14586 .47933 .16428 .46849 .15372 .46749 .12984 Metetra
.977 .718 .471 r
.46749 .12984 .46849 .15372 .45748 .14342 .45636 .13662 Metetra
.966 .659 .261 r
.45636 .13662 .45748 .14342 .44631 .13121 .44532 .11184 Metetra
.553 .725 .954 r
.66557 .31907 .66661 .31904 .6584 .3069 .65739 .30868 Metetra
.881 .799 .764 r
.65739 .30868 .6584 .3069 .65017 .29905 .64906 .29581 Metetra
.924 .553 .139 r
.64906 .29581 .65017 .29905 .64184 .29116 .64066 .28507 Metetra
.973 .664 .347 r
.64066 .28507 .64184 .29116 .63346 .28729 .63222 .27714 Metetra
.977 .697 .424 r
.63222 .27714 .63346 .28729 .62498 .28471 .62373 .27383 Metetra
.964 .689 .465 r
.62373 .27383 .62498 .28471 .61658 .29602 .61533 .28456 Metetra
.967 .693 .462 r
.61533 .28456 .61658 .29602 .60786 .29635 .60674 .29375 Metetra
.871 .535 .412 r
.60674 .29375 .60786 .29635 .59908 .30293 .59805 .30827 Metetra
.987 .861 .497 r
.59805 .30827 .59908 .30293 .59009 .30605 .5892 .32539 Metetra
.993 .777 .505 r
.5892 .32539 .59009 .30605 .58093 .30884 .5801 .33769 Metetra
.994 .771 .49 r
.5801 .33769 .58093 .30884 .57182 .33615 .57092 .36178 Metetra
.968 .743 .546 r
.57092 .36178 .57182 .33615 .56194 .28931 .56104 .32086 Metetra
.979 .752 .524 r
.56104 .32086 .56194 .28931 .55214 .26044 .55124 .30017 Metetra
.98 .75 .519 r
.55124 .30017 .55214 .26044 .54233 .25126 .54131 .2765 Metetra
.972 .748 .54 r
.54131 .2765 .54233 .25126 .53236 .23289 .53125 .24429 Metetra
.954 .748 .586 r
.53125 .24429 .53236 .23289 .52227 .2145 .52112 .212 Metetra
.849 .436 0 r
.52112 .212 .52227 .2145 .51205 .19731 .5109 .19899 Metetra
.886 .842 .796 r
.5109 .19899 .51205 .19731 .50168 .18752 .50053 .18769 Metetra
.575 .773 .973 r
.50053 .18769 .50168 .18752 .49117 .17579 .49001 .17662 Metetra
.781 .826 .888 r
.49001 .17662 .49117 .17579 .4805 .16344 .47933 .16428 Metetra
.787 .854 .901 r
.47933 .16428 .4805 .16344 .46971 .1469 .46849 .15372 Metetra
.974 .797 .603 r
.46849 .15372 .46971 .1469 .45866 .14275 .45748 .14342 Metetra
.743 .827 .916 r
.45748 .14342 .45866 .14275 .44755 .12483 .44631 .13121 Metetra
.954 .618 .228 r
.66661 .31904 .66776 .32344 .6595 .30958 .6584 .3069 Metetra
.913 .519 .123 r
.6584 .3069 .6595 .30958 .65123 .29931 .65017 .29905 Metetra
.25 .619 .958 r
.65017 .29905 .65123 .29931 .64286 .28967 .64184 .29116 Metetra
.914 .914 .804 r
.64184 .29116 .64286 .28967 .63442 .28155 .63346 .28729 Metetra
.984 .816 .594 r
.63346 .28729 .63442 .28155 .62586 .27336 .62498 .28471 Metetra
.997 .798 .513 r
.62498 .28471 .62586 .27336 .61757 .28983 .61658 .29602 Metetra
.99 .82 .579 r
.61658 .29602 .61757 .28983 .60887 .29072 .60786 .29635 Metetra
.997 .843 .562 r
.60786 .29635 .60887 .29072 .5999 .28209 .59908 .30293 Metetra
.989 .77 .515 r
.59908 .30293 .5999 .28209 .59119 .3059 .59009 .30605 Metetra
.028 0 0 r
.59009 .30605 .59119 .3059 .58203 .30805 .58093 .30884 Metetra
.331 .02 .279 r
.58093 .30884 .58203 .30805 .57305 .34799 .57182 .33615 Metetra
.966 .697 .268 r
.57182 .33615 .57305 .34799 .56316 .30256 .56194 .28931 Metetra
.987 .714 .369 r
.56194 .28931 .56316 .30256 .55333 .27123 .55214 .26044 Metetra
.981 .7 .408 r
.55214 .26044 .55333 .27123 .5434 .23688 .54233 .25126 Metetra
.974 .762 .556 r
.54233 .25126 .5434 .23688 .53349 .23105 .53236 .23289 Metetra
.86 .775 .767 r
.53236 .23289 .53349 .23105 .5234 .21278 .52227 .2145 Metetra
.858 .785 .778 r
.52227 .2145 .5234 .21278 .51319 .20127 .51205 .19731 Metetra
.949 .593 .233 r
.51205 .19731 .51319 .20127 .50284 .18409 .50168 .18752 Metetra
.946 .819 .687 r
.50168 .18752 .50284 .18409 .49234 .17289 .49117 .17579 Metetra
.933 .823 .713 r
.49117 .17579 .49234 .17289 .48166 .16511 .4805 .16344 Metetra
0 0 .436 r
.4805 .16344 .48166 .16511 .47084 .15237 .46971 .1469 Metetra
.963 .64 .348 r
.46971 .1469 .47084 .15237 .45985 .14115 .45866 .14275 Metetra
.848 .789 .793 r
.45866 .14275 .45985 .14115 .4487 .12855 .44755 .12483 Metetra
.981 .689 .354 r
.66776 .32344 .66899 .3316 .66052 .30823 .6595 .30958 Metetra
.866 .827 .807 r
.6595 .30958 .66052 .30823 .65225 .29795 .65123 .29931 Metetra
.871 .836 .81 r
.65123 .29931 .65225 .29795 .64382 .28421 .64286 .28967 Metetra
.971 .801 .614 r
.64286 .28967 .64382 .28421 .6354 .27705 .63442 .28155 Metetra
.966 .81 .637 r
.63442 .28155 .6354 .27705 .62692 .27252 .62586 .27336 Metetra
.119 0 .055 r
.62586 .27336 .62692 .27252 .61853 .28246 .61757 .28983 Metetra
.991 .81 .564 r
.61757 .28983 .61853 .28246 .60974 .27536 .60887 .29072 Metetra
.982 .768 .54 r
.60887 .29072 .60974 .27536 .60106 .28687 .5999 .28209 Metetra
.9 .604 .476 r
.5999 .28209 .60106 .28687 .59207 .28728 .59119 .3059 Metetra
.989 .772 .519 r
.59119 .3059 .59207 .28728 .58292 .28627 .58203 .30805 Metetra
.999 .785 .464 r
.58203 .30805 .58292 .28627 .57372 .29752 .57305 .34799 Metetra
.976 .744 .522 r
.57305 .34799 .57372 .29752 .56407 .27313 .56316 .30256 Metetra
.975 .748 .533 r
.56316 .30256 .56407 .27313 .55441 .26312 .55333 .27123 Metetra
.935 .74 .615 r
.55333 .27123 .55441 .26312 .54458 .2481 .5434 .23688 Metetra
.979 .699 .42 r
.5434 .23688 .54458 .2481 .53461 .22441 .53349 .23105 Metetra
.957 .775 .616 r
.53349 .23105 .53461 .22441 .52454 .20968 .5234 .21278 Metetra
.94 .822 .7 r
.5234 .21278 .52454 .20968 .51434 .19451 .51319 .20127 Metetra
.96 .779 .613 r
.51319 .20127 .51434 .19451 .504 .18305 .50284 .18409 Metetra
.82 .845 .868 r
.50284 .18409 .504 .18305 .4935 .17287 .49234 .17289 Metetra
.412 .759 .995 r
.49234 .17289 .4935 .17287 .48283 .16392 .48166 .16511 Metetra
.832 .832 .846 r
.48166 .16511 .48283 .16392 .47201 .15301 .47084 .15237 Metetra
0 .381 .827 r
.47084 .15237 .47201 .15301 .461 .14489 .45985 .14115 Metetra
.936 .571 .18 r
.45985 .14115 .461 .14489 .44992 .12528 .4487 .12855 Metetra
.927 .75 .643 r
.66899 .3316 .66991 .32636 .66151 .30561 .66052 .30823 Metetra
.931 .817 .712 r
.66052 .30823 .66151 .30561 .65329 .29727 .65225 .29795 Metetra
.756 .762 .858 r
.65225 .29795 .65329 .29727 .64489 .28518 .64382 .28421 Metetra
.503 0 0 r
.64382 .28421 .64489 .28518 .63646 .27703 .6354 .27705 Metetra
.357 .768 .981 r
.6354 .27705 .63646 .27703 .62798 .27233 .62692 .27252 Metetra
.343 0 0 r
.62692 .27252 .62798 .27233 .61958 .28052 .61853 .28246 Metetra
.924 .864 .762 r
.61853 .28246 .61958 .28052 .61108 .29325 .60974 .27536 Metetra
.972 .71 .474 r
.60974 .27536 .61108 .29325 .60229 .29762 .60106 .28687 Metetra
.974 .695 .436 r
.60106 .28687 .60229 .29762 .5932 .2899 .59207 .28728 Metetra
.919 .532 .245 r
.59207 .28728 .5932 .2899 .58408 .29182 .58292 .28627 Metetra
.94 .635 .435 r
.58292 .28627 .58408 .29182 .57498 .31259 .57372 .29752 Metetra
.988 .719 .396 r
.57372 .29752 .57498 .31259 .56516 .26922 .56407 .27313 Metetra
.957 .816 .663 r
.56407 .27313 .56516 .26922 .55549 .25707 .55441 .26312 Metetra
.96 .784 .621 r
.55441 .26312 .55549 .25707 .54564 .23209 .54458 .2481 Metetra
.971 .756 .555 r
.54458 .2481 .54564 .23209 .53573 .2215 .53461 .22441 Metetra
.922 .803 .71 r
.53461 .22441 .53573 .2215 .52567 .20466 .52454 .20968 Metetra
.953 .791 .642 r
.52454 .20968 .52567 .20466 .51549 .19489 .51434 .19451 Metetra
.218 .565 .938 r
.51434 .19451 .51549 .19489 .50515 .18051 .504 .18305 Metetra
.932 .841 .731 r
.504 .18305 .50515 .18051 .49467 .16915 .4935 .17287 Metetra
.959 .83 .672 r
.4935 .17287 .49467 .16915 .48403 .15715 .48283 .16392 Metetra
.973 .796 .604 r
.48283 .16392 .48403 .15715 .47323 .14564 .47201 .15301 Metetra
.979 .799 .592 r
.47201 .15301 .47323 .14564 .46225 .13651 .461 .14489 Metetra
.964 .773 .597 r
.461 .14489 .46225 .13651 .4511 .12605 .44992 .12528 Metetra
.89 .559 .064 r
.66991 .32636 .67105 .33064 .66272 .31315 .66151 .30561 Metetra
.978 .682 .373 r
.66151 .30561 .66272 .31315 .6544 .30021 .65329 .29727 Metetra
.892 .509 .055 r
.65329 .29727 .6544 .30021 .64605 .2904 .64489 .28518 Metetra
.968 .647 .316 r
.64489 .28518 .64605 .2904 .63762 .28213 .63646 .27703 Metetra
.966 .645 .341 r
.63646 .27703 .63762 .28213 .62906 .27267 .62798 .27233 Metetra
.593 .121 .102 r
.62798 .27233 .62906 .27267 .62042 .26573 .61958 .28052 Metetra
.996 .787 .505 r
.61958 .28052 .62042 .26573 .61166 .25914 .61108 .29325 Metetra
.988 .76 .504 r
.61108 .29325 .61166 .25914 .6029 .26098 .60229 .29762 Metetra
.984 .755 .511 r
.60229 .29762 .6029 .26098 .59395 .26038 .5932 .2899 Metetra
.988 .762 .508 r
.5932 .2899 .59395 .26038 .58481 .25604 .58408 .29182 Metetra
.992 .765 .491 r
.58408 .29182 .58481 .25604 .57558 .25675 .57498 .31259 Metetra
.977 .744 .518 r
.57498 .31259 .57558 .25675 .56605 .23998 .56516 .26922 Metetra
.983 .757 .52 r
.56516 .26922 .56605 .23998 .55641 .2247 .55549 .25707 Metetra
.978 .751 .525 r
.55549 .25707 .55641 .2247 .54664 .20718 .54564 .23209 Metetra
.983 .76 .523 r
.54564 .23209 .54664 .20718 .53678 .19698 .53573 .2215 Metetra
.98 .757 .529 r
.53573 .2215 .53678 .19698 .52678 .1854 .52567 .20466 Metetra
.983 .765 .532 r
.52567 .20466 .52678 .1854 .51663 .17568 .51549 .19489 Metetra
.98 .762 .537 r
.51549 .19489 .51663 .17568 .50632 .16767 .50515 .18051 Metetra
.98 .773 .554 r
.50515 .18051 .50632 .16767 .49586 .15595 .49467 .16915 Metetra
.98 .772 .553 r
.49467 .16915 .49586 .15595 .48524 .14708 .48403 .15715 Metetra
.978 .78 .571 r
.48403 .15715 .48524 .14708 .47446 .13617 .47323 .14564 Metetra
.98 .787 .572 r
.47323 .14564 .47446 .13617 .46343 .13629 .46225 .13651 Metetra
.576 .796 .983 r
.46225 .13651 .46343 .13629 .45239 .11407 .4511 .12605 Metetra
.976 .757 .542 r
.67105 .33064 .67166 .31225 .66334 .29373 .66272 .31315 Metetra
.98 .76 .534 r
.66272 .31315 .66334 .29373 .65503 .28005 .6544 .30021 Metetra
.982 .761 .529 r
.6544 .30021 .65503 .28005 .64674 .27183 .64605 .2904 Metetra
.983 .764 .53 r
.64605 .2904 .64674 .27183 .63823 .2578 .63762 .28213 Metetra
.983 .759 .522 r
.63762 .28213 .63823 .2578 .62972 .24937 .62906 .27267 Metetra
.984 .761 .521 r
.62906 .27267 .62972 .24937 .62119 .24685 .62042 .26573 Metetra
.984 .765 .528 r
.62042 .26573 .62119 .24685 .61244 .23833 .61166 .25914 Metetra
.989 .769 .515 r
.61166 .25914 .61244 .23833 .60372 .24135 .6029 .26098 Metetra
.988 .769 .52 r
.6029 .26098 .60372 .24135 .59481 .2413 .59395 .26038 Metetra
.986 .767 .525 r
.59395 .26038 .59481 .2413 .58585 .25023 .58481 .25604 Metetra
.991 .828 .585 r
.58481 .25604 .58585 .25023 .57665 .25233 .57558 .25675 Metetra
.941 .783 .657 r
.57558 .25675 .57665 .25233 .56716 .23957 .56605 .23998 Metetra
.685 .74 .893 r
.56605 .23998 .56716 .23957 .55746 .2137 .55641 .2247 Metetra
.971 .767 .572 r
.55641 .2247 .55746 .2137 .54771 .19466 .54664 .20718 Metetra
.98 .774 .553 r
.54664 .20718 .54771 .19466 .53787 .18431 .53678 .19698 Metetra
.979 .772 .555 r
.53678 .19698 .53787 .18431 .52789 .17315 .52678 .1854 Metetra
.981 .776 .554 r
.52678 .1854 .52789 .17315 .51776 .16544 .51663 .17568 Metetra
.982 .784 .563 r
.51663 .17568 .51776 .16544 .50748 .15599 .50632 .16767 Metetra
.979 .775 .56 r
.50632 .16767 .50748 .15599 .49704 .1486 .49586 .15595 Metetra
.977 .796 .592 r
.49586 .15595 .49704 .1486 .48644 .13843 .48524 .14708 Metetra
.977 .786 .581 r
.48524 .14708 .48644 .13843 .47568 .12814 .47446 .13617 Metetra
.99 .81 .567 r
.47446 .13617 .47568 .12814 .46465 .13064 .46343 .13629 Metetra
.944 .772 .638 r
.46343 .13629 .46465 .13064 .45366 .10552 .45239 .11407 Metetra
0 0 .521 r
.67166 .31225 .67275 .3141 .66449 .29846 .66334 .29373 Metetra
.956 .625 .227 r
.66334 .29373 .66449 .29846 .6562 .28576 .65503 .28005 Metetra
.972 .658 .331 r
.65503 .28005 .6562 .28576 .64787 .27542 .64674 .27183 Metetra
.918 .559 .115 r
.64674 .27183 .64787 .27542 .63947 .26707 .63823 .2578 Metetra
.981 .695 .396 r
.63823 .2578 .63947 .26707 .63116 .27071 .62972 .24937 Metetra
.982 .722 .459 r
.62972 .24937 .63116 .27071 .62299 .29148 .62119 .24685 Metetra
.985 .735 .471 r
.62119 .24685 .62299 .29148 .61436 .29442 .61244 .23833 Metetra
.983 .735 .48 r
.61244 .23833 .61436 .29442 .60564 .30215 .60372 .24135 Metetra
.983 .736 .48 r
.60372 .24135 .60564 .30215 .5967 .30514 .59481 .2413 Metetra
.982 .735 .484 r
.59481 .2413 .5967 .30514 .58748 .29777 .58585 .25023 Metetra
.982 .733 .478 r
.58585 .25023 .58748 .29777 .5786 .33989 .57665 .25233 Metetra
.985 .74 .478 r
.57665 .25233 .5786 .33989 .56869 .29019 .56716 .23957 Metetra
.988 .739 .463 r
.56716 .23957 .56869 .29019 .55901 .27642 .55746 .2137 Metetra
.986 .739 .471 r
.55746 .2137 .55901 .27642 .54918 .25955 .54771 .19466 Metetra
.985 .738 .476 r
.54771 .19466 .54918 .25955 .53922 .24088 .53787 .18431 Metetra
.985 .737 .473 r
.53787 .18431 .53922 .24088 .52914 .22262 .52789 .17315 Metetra
.984 .735 .473 r
.52789 .17315 .52914 .22262 .51894 .2036 .51776 .16544 Metetra
.985 .732 .467 r
.51776 .16544 .51894 .2036 .50861 .18617 .50748 .15599 Metetra
.984 .728 .462 r
.50748 .15599 .50861 .18617 .49813 .17612 .49704 .1486 Metetra
.984 .727 .457 r
.49704 .1486 .49813 .17612 .4875 .16506 .48644 .13843 Metetra
.984 .727 .455 r
.48644 .13843 .4875 .16506 .47671 .15191 .47568 .12814 Metetra
.979 .719 .464 r
.47568 .12814 .47671 .15191 .46577 .1384 .46465 .13064 Metetra
.973 .674 .29 r
.46465 .13064 .46577 .1384 .45467 .12419 .45366 .10552 Metetra
.987 .716 .407 r
.67275 .3141 .67412 .32786 .66609 .32295 .66449 .29846 Metetra
.986 .729 .449 r
.66449 .29846 .66609 .32295 .65779 .31077 .6562 .28576 Metetra
.985 .728 .453 r
.6562 .28576 .65779 .31077 .64929 .29338 .64787 .27542 Metetra
.984 .72 .443 r
.64787 .27542 .64929 .29338 .641 .29177 .63947 .26707 Metetra
.98 .723 .47 r
.63947 .26707 .641 .29177 .63248 .285 .63116 .27071 Metetra
.961 .695 .486 r
.63116 .27071 .63248 .285 .62391 .28153 .62299 .29148 Metetra
.993 .796 .539 r
.62299 .29148 .62391 .28153 .6153 .28502 .61436 .29442 Metetra
.997 .806 .529 r
.61436 .29442 .6153 .28502 .60653 .28726 .60564 .30215 Metetra
.991 .78 .523 r
.60564 .30215 .60653 .28726 .59754 .28464 .5967 .30514 Metetra
.984 .764 .526 r
.5967 .30514 .59754 .28464 .58844 .28481 .58748 .29777 Metetra
.991 .805 .423 r
.58748 .29777 .58844 .28481 .57924 .29061 .5786 .33989 Metetra
.975 .743 .523 r
.5786 .33989 .57924 .29061 .56958 .26146 .56869 .29019 Metetra
.982 .756 .521 r
.56869 .29019 .56958 .26146 .55996 .25082 .55901 .27642 Metetra
.98 .756 .527 r
.55901 .27642 .55996 .25082 .55017 .23314 .54918 .25955 Metetra
.98 .755 .527 r
.54918 .25955 .55017 .23314 .54031 .22813 .53922 .24088 Metetra
.973 .765 .563 r
.53922 .24088 .54031 .22813 .53025 .20861 .52914 .22262 Metetra
.974 .763 .557 r
.52914 .22262 .53025 .20861 .52008 .19517 .51894 .2036 Metetra
.967 .774 .593 r
.51894 .2036 .52008 .19517 .50976 .19162 .50861 .18617 Metetra
.967 .641 .306 r
.50861 .18617 .50976 .19162 .4993 .1718 .49813 .17612 Metetra
.96 .814 .655 r
.49813 .17612 .4993 .1718 .48869 .15981 .4875 .16506 Metetra
.962 .8 .635 r
.4875 .16506 .48869 .15981 .47789 .15122 .47671 .15191 Metetra
.746 .808 .901 r
.47671 .15191 .47789 .15122 .46693 .14134 .46577 .1384 Metetra
.885 .489 .041 r
.46577 .1384 .46693 .14134 .4558 .1308 .45467 .12419 Metetra
.983 .791 .568 r
.67412 .32786 .67497 .31965 .66673 .30492 .66609 .32295 Metetra
.98 .761 .536 r
.66609 .32295 .66673 .30492 .65849 .29445 .65779 .31077 Metetra
.975 .759 .547 r
.65779 .31077 .65849 .29445 .65016 .28408 .64929 .29338 Metetra
.988 .792 .552 r
.64929 .29338 .65016 .28408 .64176 .27611 .641 .29177 Metetra
.984 .769 .535 r
.641 .29177 .64176 .27611 .63335 .27332 .63248 .285 Metetra
.986 .781 .544 r
.63248 .285 .63335 .27332 .62482 .27148 .62391 .28153 Metetra
.993 .797 .537 r
.62391 .28153 .62482 .27148 .61619 .27215 .6153 .28502 Metetra
.991 .784 .529 r
.6153 .28502 .61619 .27215 .60758 .28376 .60653 .28726 Metetra
.977 .857 .656 r
.60653 .28726 .60758 .28376 .59853 .27545 .59754 .28464 Metetra
.99 .798 .551 r
.59754 .28464 .59853 .27545 .58942 .27277 .58844 .28481 Metetra
.994 .792 .526 r
.58844 .28481 .58942 .27277 .58025 .27955 .57924 .29061 Metetra
.957 .751 .585 r
.57924 .29061 .58025 .27955 .57055 .24435 .56958 .26146 Metetra
.982 .766 .537 r
.56958 .26146 .57055 .24435 .56101 .24008 .55996 .25082 Metetra
.971 .768 .573 r
.55996 .25082 .56101 .24008 .55129 .23101 .55017 .23314 Metetra
.941 .89 .752 r
.55017 .23314 .55129 .23101 .54139 .21588 .54031 .22813 Metetra
.971 .764 .566 r
.54031 .22813 .54139 .21588 .53137 .19978 .53025 .20861 Metetra
.973 .78 .583 r
.53025 .20861 .53137 .19978 .52122 .18963 .52008 .19517 Metetra
.983 .824 .607 r
.52008 .19517 .52122 .18963 .51093 .17505 .50976 .19162 Metetra
.976 .761 .548 r
.50976 .19162 .51093 .17505 .50048 .16494 .4993 .1718 Metetra
.971 .792 .604 r
.4993 .1718 .50048 .16494 .48988 .15153 .48869 .15981 Metetra
.98 .793 .581 r
.48869 .15981 .48988 .15153 .47912 .14109 .47789 .15122 Metetra
.98 .783 .567 r
.47789 .15122 .47912 .14109 .46822 .12579 .46693 .14134 Metetra
.982 .771 .542 r
.46693 .14134 .46822 .12579 .45723 .10328 .4558 .1308 Metetra
.949 .78 .639 r
.67497 .31965 .67589 .31478 .66771 .30204 .66673 .30492 Metetra
.937 .814 .698 r
.66673 .30492 .66771 .30204 .6595 .29203 .65849 .29445 Metetra
.925 .82 .723 r
.65849 .29445 .6595 .29203 .65116 .28115 .65016 .28408 Metetra
.95 .832 .693 r
.65016 .28408 .65116 .28115 .64278 .27366 .64176 .27611 Metetra
.962 .885 .709 r
.64176 .27611 .64278 .27366 .63438 .27138 .63335 .27332 Metetra
.948 .919 .749 r
.63335 .27332 .63438 .27138 .62615 .28641 .62482 .27148 Metetra
.978 .71 .45 r
.62482 .27148 .62615 .28641 .61759 .29194 .61619 .27215 Metetra
.974 .713 .474 r
.61619 .27215 .61759 .29194 .60879 .29182 .60758 .28376 Metetra
.978 .683 .378 r
.60758 .28376 .60879 .29182 .59969 .28037 .59853 .27545 Metetra
.961 .635 .346 r
.59853 .27545 .59969 .28037 .59049 .26994 .58942 .27277 Metetra
.971 .927 .624 r
.58942 .27277 .59049 .26994 .58139 .28165 .58025 .27955 Metetra
0 .125 .648 r
.58025 .27955 .58139 .28165 .57175 .25369 .57055 .24435 Metetra
.977 .689 .409 r
.57055 .24435 .57175 .25369 .5622 .24933 .56101 .24008 Metetra
.98 .691 .39 r
.56101 .24008 .5622 .24933 .55249 .24281 .55129 .23101 Metetra
.984 .706 .395 r
.55129 .23101 .55249 .24281 .54259 .23012 .54139 .21588 Metetra
.986 .713 .41 r
.54139 .21588 .54259 .23012 .53256 .21793 .53137 .19978 Metetra
.984 .719 .438 r
.53137 .19978 .53256 .21793 .52239 .20325 .52122 .18963 Metetra
.985 .711 .41 r
.52122 .18963 .52239 .20325 .51208 .1903 .51093 .17505 Metetra
.983 .713 .428 r
.51093 .17505 .51208 .1903 .50163 .1683 .50048 .16494 Metetra
.916 .539 .116 r
.50048 .16494 .50163 .1683 .49105 .15188 .48988 .15153 Metetra
.185 .573 .938 r
.48988 .15153 .49105 .15188 .48032 .13606 .47912 .14109 Metetra
.955 .795 .643 r
.47912 .14109 .48032 .13606 .46931 .13963 .46822 .12579 Metetra
.987 .713 .394 r
.46822 .12579 .46931 .13963 .45832 .11477 .45723 .10328 Metetra
.501 .656 .929 r
.67589 .31478 .67694 .3149 .66883 .30517 .66771 .30204 Metetra
.921 .546 .131 r
.66771 .30204 .66883 .30517 .66052 .29074 .6595 .29203 Metetra
.857 .821 .813 r
.6595 .29203 .66052 .29074 .65225 .28267 .65116 .28115 Metetra
.747 .266 0 r
.65116 .28115 .65225 .28267 .64388 .27566 .64278 .27366 Metetra
.89 .465 .146 r
.64278 .27366 .64388 .27566 .63545 .27109 .63438 .27138 Metetra
.396 0 .165 r
.63438 .27138 .63545 .27109 .62713 .28076 .62615 .28641 Metetra
.997 .84 .563 r
.62615 .28641 .62713 .28076 .61846 .27806 .61759 .29194 Metetra
.989 .78 .53 r
.61759 .29194 .61846 .27806 .60995 .29677 .60879 .29182 Metetra
.963 .632 .268 r
.60879 .29182 .60995 .29677 .60092 .29026 .59969 .28037 Metetra
.982 .696 .392 r
.59969 .28037 .60092 .29026 .59189 .29523 .59049 .26994 Metetra
.976 .719 .476 r
.59049 .26994 .59189 .29523 .58267 .2977 .58139 .28165 Metetra
.989 .721 .391 r
.58139 .28165 .58267 .2977 .57296 .26389 .57175 .25369 Metetra
.978 .694 .415 r
.57175 .25369 .57296 .26389 .56329 .24414 .5622 .24933 Metetra
.976 .817 .62 r
.5622 .24933 .56329 .24414 .55353 .2285 .55249 .24281 Metetra
.98 .769 .548 r
.55249 .24281 .55353 .2285 .54366 .21396 .54259 .23012 Metetra
.981 .767 .541 r
.54259 .23012 .54366 .21396 .53367 .20416 .53256 .21793 Metetra
.978 .768 .553 r
.53256 .21793 .53367 .20416 .52352 .19209 .52239 .20325 Metetra
.977 .775 .564 r
.52239 .20325 .52352 .19209 .51324 .17156 .51208 .1903 Metetra
.976 .758 .543 r
.51208 .1903 .51324 .17156 .50281 .16126 .50163 .1683 Metetra
.964 .782 .608 r
.50163 .1683 .50281 .16126 .49221 .15394 .49105 .15188 Metetra
.71 .284 0 r
.49105 .15188 .49221 .15394 .48146 .14276 .48032 .13606 Metetra
.96 .654 .404 r
.48032 .13606 .48146 .14276 .4705 .13824 .46931 .13963 Metetra
.8 .729 .786 r
.46931 .13963 .4705 .13824 .45949 .11618 .45832 .11477 Metetra
.975 .669 .338 r
.67694 .3149 .67814 .32137 .66988 .3052 .66883 .30517 Metetra
.558 .663 .907 r
.66883 .30517 .66988 .3052 .66164 .29355 .66052 .29074 Metetra
.917 .528 .131 r
.66052 .29074 .66164 .29355 .6532 .27768 .65225 .28267 Metetra
.973 .81 .62 r
.65225 .28267 .6532 .27768 .64483 .26938 .64388 .27566 Metetra
.982 .806 .59 r
.64388 .27566 .64483 .26938 .63634 .26118 .63545 .27109 Metetra
.998 .805 .518 r
.63545 .27109 .63634 .26118 .62772 .252 .62713 .28076 Metetra
.986 .76 .51 r
.62713 .28076 .62772 .252 .61914 .2526 .61846 .27806 Metetra
.994 .772 .49 r
.61846 .27806 .61914 .2526 .61036 .249 .60995 .29677 Metetra
.985 .753 .503 r
.60995 .29677 .61036 .249 .60152 .25151 .60092 .29026 Metetra
.988 .759 .5 r
.60092 .29026 .60152 .25151 .59258 .25919 .59189 .29523 Metetra
.988 .759 .503 r
.59189 .29523 .59258 .25919 .58334 .25387 .58267 .2977 Metetra
.978 .747 .519 r
.58267 .2977 .58334 .25387 .57391 .24501 .57296 .26389 Metetra
.977 .758 .541 r
.57296 .26389 .57391 .24501 .56421 .21659 .56329 .24414 Metetra
.982 .756 .522 r
.56329 .24414 .56421 .21659 .55451 .20279 .55353 .2285 Metetra
.982 .758 .524 r
.55353 .2285 .55451 .20279 .54469 .19081 .54366 .21396 Metetra
.984 .762 .523 r
.54366 .21396 .54469 .19081 .53472 .17567 .53367 .20416 Metetra
.983 .758 .519 r
.53367 .20416 .53472 .17567 .52463 .16751 .52352 .19209 Metetra
.979 .756 .53 r
.52352 .19209 .52463 .16751 .51439 .16057 .51324 .17156 Metetra
.98 .779 .561 r
.51324 .17156 .51439 .16057 .50399 .14679 .50281 .16126 Metetra
.984 .775 .541 r
.50281 .16126 .50399 .14679 .49344 .13559 .49221 .15394 Metetra
.983 .766 .534 r
.49221 .15394 .49344 .13559 .48271 .12641 .48146 .14276 Metetra
.986 .774 .532 r
.48146 .14276 .48271 .12641 .47183 .11465 .4705 .13824 Metetra
.979 .756 .533 r
.4705 .13824 .47183 .11465 .46078 .1039 .45949 .11618 Metetra
.97 .766 .573 r
.67814 .32137 .67894 .31114 .6708 .29967 .66988 .3052 Metetra
.963 .789 .619 r
.66988 .3052 .6708 .29967 .66238 .27967 .66164 .29355 Metetra
.975 .762 .553 r
.66164 .29355 .66238 .27967 .65412 .27075 .6532 .27768 Metetra
.976 .792 .59 r
.6532 .27768 .65412 .27075 .64575 .26241 .64483 .26938 Metetra
.977 .792 .589 r
.64483 .26938 .64575 .26241 .63728 .25393 .63634 .26118 Metetra
.976 .789 .588 r
.63634 .26118 .63728 .25393 .62869 .24556 .62772 .252 Metetra
.991 .818 .572 r
.62772 .252 .62869 .24556 .61998 .23706 .61914 .2526 Metetra
.987 .773 .53 r
.61914 .2526 .61998 .23706 .61136 .24302 .61036 .249 Metetra
.994 .829 .573 r
.61036 .249 .61136 .24302 .60242 .23707 .60152 .25151 Metetra
.994 .785 .514 r
.60152 .25151 .60242 .23707 .59343 .23795 .59258 .25919 Metetra
.986 .765 .521 r
.59258 .25919 .59343 .23795 .58435 .24455 .58334 .25387 Metetra
.98 .784 .569 r
.58334 .25387 .58435 .24455 .57483 .2231 .57391 .24501 Metetra
.973 .751 .541 r
.57391 .24501 .57483 .2231 .56525 .20662 .56421 .21659 Metetra
.975 .775 .572 r
.56421 .21659 .56525 .20662 .55555 .18949 .55451 .20279 Metetra
.98 .771 .551 r
.55451 .20279 .55555 .18949 .54576 .17861 .54469 .19081 Metetra
.976 .769 .56 r
.54469 .19081 .54576 .17861 .53583 .1676 .53472 .17567 Metetra
.98 .793 .58 r
.53472 .17567 .53583 .1676 .52577 .15988 .52463 .16751 Metetra
.981 .798 .583 r
.52463 .16751 .52577 .15988 .51554 .15247 .51439 .16057 Metetra
.972 .783 .59 r
.51439 .16057 .51554 .15247 .50515 .14375 .50399 .14679 Metetra
.942 .829 .704 r
.50399 .14679 .50515 .14375 .49461 .13347 .49344 .13559 Metetra
.923 .861 .762 r
.49344 .13559 .49461 .13347 .4839 .12377 .48271 .12641 Metetra
.93 .834 .728 r
.48271 .12641 .4839 .12377 .47292 .12906 .47183 .11465 Metetra
.983 .71 .422 r
.47183 .11465 .47292 .12906 .46198 .10224 .46078 .1039 Metetra
.93 .807 .703 r
.67894 .31114 .67991 .30835 .67168 .29253 .6708 .29967 Metetra
.953 .762 .609 r
.6708 .29967 .67168 .29253 .66352 .28329 .66238 .27967 Metetra
.944 .586 .207 r
.66238 .27967 .66352 .28329 .65526 .27475 .65412 .27075 Metetra
.954 .606 .246 r
.65412 .27075 .65526 .27475 .64693 .26807 .64575 .26241 Metetra
.971 .654 .324 r
.64575 .26241 .64693 .26807 .63851 .26256 .63728 .25393 Metetra
.98 .689 .385 r
.63728 .25393 .63851 .26256 .62996 .2569 .62869 .24556 Metetra
.982 .704 .411 r
.62869 .24556 .62996 .2569 .62176 .28068 .61998 .23706 Metetra
.982 .731 .477 r
.61998 .23706 .62176 .28068 .61303 .28183 .61136 .24302 Metetra
.984 .733 .468 r
.61136 .24302 .61303 .28183 .60409 .27934 .60242 .23707 Metetra
.983 .732 .474 r
.60242 .23707 .60409 .27934 .59495 .27227 .59343 .23795 Metetra
.981 .727 .475 r
.59343 .23795 .59495 .27227 .58576 .27176 .58435 .24455 Metetra
.988 .731 .441 r
.58435 .24455 .58576 .27176 .57623 .25332 .57483 .2231 Metetra
.987 .732 .451 r
.57483 .2231 .57623 .25332 .56666 .24191 .56525 .20662 Metetra
.987 .734 .456 r
.56525 .20662 .56666 .24191 .55694 .23003 .55555 .18949 Metetra
.985 .734 .465 r
.55555 .18949 .55694 .23003 .54708 .21483 .54576 .17861 Metetra
.985 .732 .462 r
.54576 .17861 .54708 .21483 .5371 .20317 .53583 .1676 Metetra
.985 .731 .464 r
.53583 .1676 .5371 .20317 .52696 .18504 .52577 .15988 Metetra
.984 .725 .454 r
.52577 .15988 .52696 .18504 .5167 .17392 .51554 .15247 Metetra
.984 .722 .447 r
.51554 .15247 .5167 .17392 .50629 .16041 .50515 .14375 Metetra
.984 .715 .432 r
.50515 .14375 .50629 .16041 .49573 .14815 .49461 .13347 Metetra
.983 .711 .425 r
.49461 .13347 .49573 .14815 .48504 .13082 .4839 .12377 Metetra
.959 .657 .413 r
.4839 .12377 .48504 .13082 .47414 .1233 .47292 .12906 Metetra
.936 .76 .64 r
.47292 .12906 .47414 .1233 .46317 .10162 .46198 .10224 Metetra
.983 .697 .359 r
.67991 .30835 .68119 .31777 .67301 .3044 .67168 .29253 Metetra
.983 .707 .412 r
.67168 .29253 .67301 .3044 .66483 .29488 .66352 .28329 Metetra
.983 .706 .412 r
.66352 .28329 .66483 .29488 .6565 .28339 .65526 .27475 Metetra
.979 .689 .393 r
.65526 .27475 .6565 .28339 .64816 .27624 .64693 .26807 Metetra
.977 .685 .392 r
.64693 .26807 .64816 .27624 .63976 .2722 .63851 .26256 Metetra
.979 .694 .406 r
.63851 .26256 .63976 .2722 .63139 .27718 .62996 .2569 Metetra
.967 .708 .488 r
.62996 .2569 .63139 .27718 .62278 .27646 .62176 .28068 Metetra
.99 .856 .612 r
.62176 .28068 .62278 .27646 .61413 .28208 .61303 .28183 Metetra
0 .461 .727 r
.61303 .28183 .61413 .28208 .60513 .27469 .60409 .27934 Metetra
.972 .819 .632 r
.60409 .27934 .60513 .27469 .59607 .2731 .59495 .27227 Metetra
.668 .117 0 r
.59495 .27227 .59607 .2731 .58691 .27517 .58576 .27176 Metetra
.864 .501 .002 r
.58576 .27176 .58691 .27517 .57746 .26468 .57623 .25332 Metetra
.983 .703 .4 r
.57623 .25332 .57746 .26468 .56783 .24817 .56666 .24191 Metetra
.972 .659 .316 r
.56666 .24191 .56783 .24817 .55808 .23013 .55694 .23003 Metetra
.5 .658 .931 r
.55694 .23003 .55808 .23013 .54821 .21364 .54708 .21483 Metetra
.84 .837 .842 r
.54708 .21483 .54821 .21364 .53822 .19792 .5371 .20317 Metetra
.949 .781 .64 r
.5371 .20317 .53822 .19792 .52812 .18679 .52696 .18504 Metetra
.731 .265 0 r
.52696 .18504 .52812 .18679 .51786 .18032 .5167 .17392 Metetra
.972 .658 .311 r
.5167 .17392 .51786 .18032 .50746 .16322 .50629 .16041 Metetra
.887 .485 .048 r
.50629 .16041 .50746 .16322 .49688 .15786 .49573 .14815 Metetra
.982 .693 .363 r
.49573 .14815 .49688 .15786 .48615 .14597 .48504 .13082 Metetra
.982 .71 .431 r
.48504 .13082 .48615 .14597 .47525 .13581 .47414 .1233 Metetra
.986 .708 .382 r
.47414 .1233 .47525 .13581 .46428 .11137 .46317 .10162 Metetra
.959 .783 .623 r
.68119 .31777 .6821 .31226 .67386 .29582 .67301 .3044 Metetra
.977 .781 .574 r
.67301 .3044 .67386 .29582 .66564 .28412 .66483 .29488 Metetra
.977 .773 .561 r
.66483 .29488 .66564 .28412 .65738 .27494 .6565 .28339 Metetra
.981 .787 .57 r
.6565 .28339 .65738 .27494 .64904 .26698 .64816 .27624 Metetra
.986 .789 .557 r
.64816 .27624 .64904 .26698 .64066 .26307 .63976 .2722 Metetra
.995 .804 .534 r
.63976 .2722 .64066 .26307 .63224 .2638 .63139 .27718 Metetra
.989 .78 .531 r
.63139 .27718 .63224 .2638 .62385 .27531 .62278 .27646 Metetra
.714 .958 .684 r
.62278 .27646 .62385 .27531 .61505 .2706 .61413 .28208 Metetra
.983 .778 .551 r
.61413 .28208 .61505 .2706 .60612 .26621 .60513 .27469 Metetra
.989 .799 .559 r
.60513 .27469 .60612 .26621 .59709 .26568 .59607 .2731 Metetra
.993 .814 .559 r
.59607 .2731 .59709 .26568 .58785 .25917 .58691 .27517 Metetra
.982 .768 .538 r
.58691 .27517 .58785 .25917 .57843 .24808 .57746 .26468 Metetra
.978 .762 .543 r
.57746 .26468 .57843 .24808 .56887 .23638 .56783 .24817 Metetra
.973 .766 .566 r
.56783 .24817 .56887 .23638 .55915 .22082 .55808 .23013 Metetra
.97 .773 .581 r
.55808 .23013 .55915 .22082 .54935 .21294 .54821 .21364 Metetra
.747 .767 .869 r
.54821 .21364 .54935 .21294 .53938 .2002 .53822 .19792 Metetra
.84 .41 0 r
.53822 .19792 .53938 .2002 .52927 .18799 .52812 .18679 Metetra
.668 .14 0 r
.52812 .18679 .52927 .18799 .519 .15774 .51786 .18032 Metetra
.981 .759 .53 r
.51786 .18032 .519 .15774 .50863 .14341 .50746 .16322 Metetra
.986 .768 .524 r
.50746 .16322 .50863 .14341 .49811 .13302 .49688 .15786 Metetra
.984 .761 .522 r
.49688 .15786 .49811 .13302 .48742 .12271 .48615 .14597 Metetra
.984 .763 .523 r
.48615 .14597 .48742 .12271 .47646 .13116 .47525 .13581 Metetra
.928 .767 .661 r
.47525 .13581 .47646 .13116 .46552 .105 .46428 .11137 Metetra
.617 .665 .874 r
.6821 .31226 .68314 .31215 .67507 .30237 .67386 .29582 Metetra
.975 .669 .323 r
.67386 .29582 .67507 .30237 .66686 .291 .66564 .28412 Metetra
.977 .674 .35 r
.66564 .28412 .66686 .291 .65854 .27951 .65738 .27494 Metetra
.962 .628 .283 r
.65738 .27494 .65854 .27951 .65023 .27288 .64904 .26698 Metetra
.97 .658 .363 r
.64904 .26698 .65023 .27288 .64187 .27002 .64066 .26307 Metetra
.968 .669 .405 r
.64066 .26307 .64187 .27002 .63364 .2819 .63224 .2638 Metetra
.973 .71 .471 r
.63224 .2638 .63364 .2819 .62499 .2782 .62385 .27531 Metetra
.929 .544 .205 r
.62385 .27531 .62499 .2782 .61629 .27999 .61505 .2706 Metetra
.978 .691 .407 r
.61505 .2706 .61629 .27999 .6075 .28664 .60612 .26621 Metetra
.981 .719 .456 r
.60612 .26621 .6075 .28664 .59834 .27669 .59709 .26568 Metetra
.98 .7 .412 r
.59709 .26568 .59834 .27669 .58919 .27919 .58785 .25917 Metetra
.985 .722 .439 r
.58785 .25917 .58919 .27919 .57962 .25534 .57843 .24808 Metetra
.977 .673 .343 r
.57843 .24808 .57962 .25534 .57005 .2432 .56887 .23638 Metetra
.974 .666 .307 r
.56887 .23638 .57005 .2432 .56036 .23147 .55915 .22082 Metetra
.98 .697 .405 r
.55915 .22082 .56036 .23147 .55049 .21326 .54935 .21294 Metetra
.314 .595 .945 r
.54935 .21294 .55049 .21326 .54053 .20187 .53938 .2002 Metetra
.668 .207 0 r
.53938 .2002 .54053 .20187 .53043 .19202 .52927 .18799 Metetra
.779 .463 0 r
.52927 .18799 .53043 .19202 .52019 .18376 .519 .15774 Metetra
.986 .728 .447 r
.519 .15774 .52019 .18376 .50978 .17257 .50863 .14341 Metetra
.985 .728 .455 r
.50863 .14341 .50978 .17257 .49925 .14466 .49811 .13302 Metetra
.982 .701 .405 r
.49811 .13302 .49925 .14466 .48853 .13979 .48742 .12271 Metetra
.974 .706 .459 r
.48742 .12271 .48853 .13979 .47761 .13658 .47646 .13116 Metetra
.932 .61 .156 r
.47646 .13116 .47761 .13658 .46674 .10074 .46552 .105 Metetra
.446 .684 .966 r
.68314 .31215 .68419 .31228 .67613 .30275 .67507 .30237 Metetra
.304 .57 .932 r
.67507 .30237 .67613 .30275 .66791 .29082 .66686 .291 Metetra
.623 .743 .933 r
.66686 .291 .66791 .29082 .6596 .27942 .65854 .27951 Metetra
.505 .794 .997 r
.65854 .27951 .6596 .27942 .65135 .27565 .65023 .27288 Metetra
.928 .545 .228 r
.65023 .27288 .65135 .27565 .64291 .2682 .64187 .27002 Metetra
.727 .873 .462 r
.64187 .27002 .64291 .2682 .63464 .27719 .63364 .2819 Metetra
.981 .829 .618 r
.63364 .2819 .63464 .27719 .62606 .27688 .62499 .2782 Metetra
.875 .994 .792 r
.62499 .2782 .62606 .27688 .61728 .27333 .61629 .27999 Metetra
.998 .83 .547 r
.61629 .27999 .61728 .27333 .60843 .27405 .6075 .28664 Metetra
.981 .773 .549 r
.6075 .28664 .60843 .27405 .5994 .27251 .59834 .27669 Metetra
.991 .865 .609 r
.59834 .27669 .5994 .27251 .59026 .27457 .58919 .27919 Metetra
.924 .758 .658 r
.58919 .27919 .59026 .27457 .58068 .24919 .57962 .25534 Metetra
.968 .792 .612 r
.57962 .25534 .58068 .24919 .57113 .23714 .57005 .2432 Metetra
.969 .795 .613 r
.57005 .2432 .57113 .23714 .5614 .21917 .56036 .23147 Metetra
.973 .766 .563 r
.56036 .23147 .5614 .21917 .55156 .20099 .55049 .21326 Metetra
.98 .774 .554 r
.55049 .21326 .55156 .20099 .5416 .18424 .54053 .20187 Metetra
.984 .767 .533 r
.54053 .20187 .5416 .18424 .53154 .17566 .53043 .19202 Metetra
.984 .77 .534 r
.53043 .19202 .53154 .17566 .52132 .16135 .52019 .18376 Metetra
.984 .762 .524 r
.52019 .18376 .52132 .16135 .51096 .14474 .50978 .17257 Metetra
.978 .752 .529 r
.50978 .17257 .51096 .14474 .50042 .1445 .49925 .14466 Metetra
.425 .82 .984 r
.49925 .14466 .50042 .1445 .48973 .13399 .48853 .13979 Metetra
.985 .825 .602 r
.48853 .13979 .48973 .13399 .47884 .12854 .47761 .13658 Metetra
.938 .744 .615 r
.47761 .13658 .47884 .12854 .46791 .10276 .46674 .10074 Metetra
.983 .701 .397 r
.68419 .31228 .6855 .3227 .67741 .31219 .67613 .30275 Metetra
.983 .697 .376 r
.67613 .30275 .67741 .31219 .6691 .29654 .66791 .29082 Metetra
.97 .654 .297 r
.66791 .29082 .6691 .29654 .66085 .2878 .6596 .27942 Metetra
.976 .686 .401 r
.6596 .27942 .66085 .2878 .65246 .27787 .65135 .27565 Metetra
.875 .45 .034 r
.65135 .27565 .65246 .27787 .64401 .26957 .64291 .2682 Metetra
.814 .415 .296 r
.64291 .2682 .64401 .26957 .6353 .2541 .63464 .27719 Metetra
.988 .766 .511 r
.63464 .27719 .6353 .2541 .62677 .25487 .62606 .27688 Metetra
.987 .765 .516 r
.62606 .27688 .62677 .25487 .61803 .25116 .61728 .27333 Metetra
.989 .767 .511 r
.61728 .27333 .61803 .25116 .60938 .26344 .60843 .27405 Metetra
.989 .789 .544 r
.60843 .27405 .60938 .26344 .60023 .25061 .5994 .27251 Metetra
.99 .769 .51 r
.5994 .27251 .60023 .25061 .59109 .24997 .59026 .27457 Metetra
.977 .752 .532 r
.59026 .27457 .59109 .24997 .58164 .23265 .58068 .24919 Metetra
.982 .766 .538 r
.58068 .24919 .58164 .23265 .57217 .22662 .57113 .23714 Metetra
.971 .768 .573 r
.57113 .23714 .57217 .22662 .56241 .20237 .5614 .21917 Metetra
.978 .761 .544 r
.5614 .21917 .56241 .20237 .55266 .194 .55156 .20099 Metetra
.963 .779 .607 r
.55156 .20099 .55266 .194 .5427 .17465 .5416 .18424 Metetra
.982 .786 .566 r
.5416 .18424 .5427 .17465 .53266 .16423 .53154 .17566 Metetra
.977 .773 .562 r
.53154 .17566 .53266 .16423 .52248 .16476 .52132 .16135 Metetra
.893 .521 .057 r
.52132 .16135 .52248 .16476 .51212 .14983 .51096 .14474 Metetra
.957 .629 .356 r
.51096 .14474 .51212 .14983 .50159 .14345 .50042 .1445 Metetra
.825 .861 .873 r
.50042 .1445 .50159 .14345 .4909 .13444 .48973 .13399 Metetra
0 .382 .734 r
.48973 .13399 .4909 .13444 .48003 .12825 .47884 .12854 Metetra
.638 .646 .841 r
.47884 .12854 .48003 .12825 .46911 .10136 .46791 .10276 Metetra
.98 .769 .546 r
.6855 .3227 .68621 .30949 .67787 .28798 .67741 .31219 Metetra
.981 .756 .525 r
.67741 .31219 .67787 .28798 .66971 .27752 .6691 .29654 Metetra
.984 .764 .526 r
.6691 .29654 .66971 .27752 .6615 .2693 .66085 .2878 Metetra
.983 .764 .529 r
.66085 .2878 .6615 .2693 .65318 .26098 .65246 .27787 Metetra
.984 .767 .531 r
.65246 .27787 .65318 .26098 .64475 .25261 .64401 .26957 Metetra
.979 .761 .54 r
.64401 .26957 .64475 .25261 .63615 .24164 .6353 .2541 Metetra
.991 .784 .53 r
.6353 .2541 .63615 .24164 .62753 .23548 .62677 .25487 Metetra
.987 .768 .52 r
.62677 .25487 .62753 .23548 .61875 .22728 .61803 .25116 Metetra
.993 .771 .496 r
.61803 .25116 .61875 .22728 .61009 .23637 .60938 .26344 Metetra
.983 .757 .518 r
.60938 .26344 .61009 .23637 .60129 .24723 .60023 .25061 Metetra
.981 .874 .652 r
.60023 .25061 .60129 .24723 .59207 .23829 .59109 .24997 Metetra
.973 .767 .565 r
.59109 .24997 .59207 .23829 .58268 .22545 .58164 .23265 Metetra
.982 .801 .583 r
.58164 .23265 .58268 .22545 .5731 .20518 .57217 .22662 Metetra
.976 .754 .537 r
.57217 .22662 .5731 .20518 .56346 .19118 .56241 .20237 Metetra
.983 .78 .554 r
.56241 .20237 .56346 .19118 .5537 .17796 .55266 .194 Metetra
.976 .761 .547 r
.55266 .194 .5537 .17796 .54381 .16731 .5427 .17465 Metetra
.976 .792 .591 r
.5427 .17465 .54381 .16731 .53379 .15823 .53266 .16423 Metetra
.991 .83 .585 r
.53266 .16423 .53379 .15823 .52362 .15319 .52248 .16476 Metetra
.977 .772 .562 r
.52248 .16476 .52362 .15319 .51328 .14305 .51212 .14983 Metetra
.982 .807 .592 r
.51212 .14983 .51328 .14305 .50278 .13257 .50159 .14345 Metetra
.983 .782 .558 r
.50159 .14345 .50278 .13257 .49212 .12243 .4909 .13444 Metetra
.986 .783 .548 r
.4909 .13444 .49212 .12243 .48121 .1284 .48003 .12825 Metetra
.525 .573 .847 r
.48003 .12825 .48121 .1284 .47032 .09823 .46911 .10136 Metetra
.831 .726 .749 r
.68621 .30949 .68721 .30777 .67897 .28999 .67787 .28798 Metetra
.786 .354 0 r
.67787 .28798 .67897 .28999 .67085 .28117 .66971 .27752 Metetra
.946 .588 .216 r
.66971 .27752 .67085 .28117 .66264 .27292 .6615 .2693 Metetra
.945 .586 .213 r
.6615 .2693 .66264 .27292 .6543 .26331 .65318 .26098 Metetra
.875 .457 .028 r
.65318 .26098 .6543 .26331 .64594 .25878 .64475 .25261 Metetra
.973 .661 .316 r
.64475 .25261 .64594 .25878 .63763 .26341 .63615 .24164 Metetra
.984 .723 .449 r
.63615 .24164 .63763 .26341 .62895 .25503 .62753 .23548 Metetra
.985 .721 .442 r
.62753 .23548 .62895 .25503 .62058 .27376 .61875 .22728 Metetra
.982 .731 .477 r
.61875 .22728 .62058 .27376 .61187 .28285 .61009 .23637 Metetra
.981 .731 .478 r
.61009 .23637 .61187 .28285 .60277 .27479 .60129 .24723 Metetra
.985 .728 .454 r
.60129 .24723 .60277 .27479 .5937 .28106 .59207 .23829 Metetra
.986 .735 .462 r
.59207 .23829 .5937 .28106 .58416 .25924 .58268 .22545 Metetra
.988 .734 .449 r
.58268 .22545 .58416 .25924 .57459 .24517 .5731 .20518 Metetra
.986 .734 .46 r
.5731 .20518 .57459 .24517 .5649 .23093 .56346 .19118 Metetra
.986 .734 .46 r
.56346 .19118 .5649 .23093 .55509 .2195 .5537 .17796 Metetra
.986 .734 .463 r
.5537 .17796 .55509 .2195 .5451 .19836 .54381 .16731 Metetra
.985 .729 .457 r
.54381 .16731 .5451 .19836 .53503 .18612 .53379 .15823 Metetra
.984 .726 .457 r
.53379 .15823 .53503 .18612 .52482 .17896 .52362 .15319 Metetra
.985 .726 .45 r
.52362 .15319 .52482 .17896 .51445 .16382 .51328 .14305 Metetra
.985 .721 .44 r
.51328 .14305 .51445 .16382 .50392 .15497 .50278 .13257 Metetra
.985 .723 .444 r
.50278 .13257 .50392 .15497 .49324 .14192 .49212 .12243 Metetra
.977 .712 .459 r
.49212 .12243 .49324 .14192 .48237 .13377 .48121 .1284 Metetra
.906 .59 .102 r
.48121 .1284 .48237 .13377 .47139 .1163 .47032 .09823 Metetra
.988 .726 .424 r
.68721 .30777 .68877 .32752 .68051 .30989 .67897 .28999 Metetra
.985 .723 .441 r
.67897 .28999 .68051 .30989 .67239 .30166 .67085 .28117 Metetra
.985 .723 .444 r
.67085 .28117 .67239 .30166 .66415 .29288 .66264 .27292 Metetra
.985 .723 .44 r
.66264 .27292 .66415 .29288 .65579 .28324 .6543 .26331 Metetra
.983 .721 .448 r
.6543 .26331 .65579 .28324 .64739 .27751 .64594 .25878 Metetra
.978 .715 .461 r
.64594 .25878 .64739 .27751 .63912 .28483 .63763 .26341 Metetra
.985 .724 .445 r
.63763 .26341 .63912 .28483 .63052 .28291 .62895 .25503 Metetra
.975 .719 .481 r
.62895 .25503 .63052 .28291 .62181 .28205 .62058 .27376 Metetra
.961 .672 .443 r
.62058 .27376 .62181 .28205 .6131 .29089 .61187 .28285 Metetra
.978 .682 .374 r
.61187 .28285 .6131 .29089 .60391 .27685 .60277 .27479 Metetra
.875 .485 .295 r
.60277 .27479 .60391 .27685 .59496 .29218 .5937 .28106 Metetra
.984 .703 .357 r
.5937 .28106 .59496 .29218 .58526 .25647 .58416 .25924 Metetra
.922 .806 .715 r
.58416 .25924 .58526 .25647 .57568 .24052 .57459 .24517 Metetra
.954 .795 .647 r
.57459 .24517 .57568 .24052 .56602 .2297 .5649 .23093 Metetra
.847 .839 .837 r
.5649 .23093 .56602 .2297 .55619 .21239 .55509 .2195 Metetra
.956 .769 .611 r
.55509 .2195 .55619 .21239 .54627 .20302 .5451 .19836 Metetra
.956 .615 .24 r
.5451 .19836 .54627 .20302 .53621 .1933 .53503 .18612 Metetra
.974 .669 .363 r
.53503 .18612 .53621 .1933 .52599 .18208 .52482 .17896 Metetra
.883 .498 .035 r
.52482 .17896 .52599 .18208 .51561 .17214 .51445 .16382 Metetra
.977 .68 .373 r
.51445 .16382 .51561 .17214 .50509 .15572 .50392 .15497 Metetra
0 .353 .822 r
.50392 .15497 .50509 .15572 .49441 .14532 .49324 .14192 Metetra
.933 .556 .194 r
.49324 .14192 .49441 .14532 .48356 .13468 .48237 .13377 Metetra
0 .318 .807 r
.48237 .13377 .48356 .13468 .47256 .12075 .47139 .1163 Metetra
.972 .762 .56 r
.68877 .32752 .6895 .31508 .6815 .30719 .68051 .30989 Metetra
.945 .834 .704 r
.68051 .30989 .6815 .30719 .67339 .29902 .67239 .30166 Metetra
.941 .832 .709 r
.67239 .30166 .67339 .29902 .66513 .28891 .66415 .29288 Metetra
.959 .811 .653 r
.66415 .29288 .66513 .28891 .65685 .28302 .65579 .28324 Metetra
.561 .842 .997 r
.65579 .28324 .65685 .28302 .64841 .27493 .64739 .27751 Metetra
.957 .935 .608 r
.64739 .27751 .64841 .27493 .63987 .26724 .63912 .28483 Metetra
.988 .771 .52 r
.63912 .28483 .63987 .26724 .63138 .26938 .63052 .28291 Metetra
.99 .78 .529 r
.63052 .28291 .63138 .26938 .62275 .27184 .62181 .28205 Metetra
.998 .803 .519 r
.62181 .28205 .62275 .27184 .61379 .26274 .6131 .29089 Metetra
.983 .757 .517 r
.6131 .29089 .61379 .26274 .60477 .25848 .60391 .27685 Metetra
.996 .781 .494 r
.60391 .27685 .60477 .25848 .59565 .25752 .59496 .29218 Metetra
.977 .747 .525 r
.59496 .29218 .59565 .25752 .58622 .24191 .58526 .25647 Metetra
.978 .765 .548 r
.58526 .25647 .58622 .24191 .57674 .23301 .57568 .24052 Metetra
.976 .79 .589 r
.57568 .24052 .57674 .23301 .56711 .22268 .56602 .2297 Metetra
.962 .778 .607 r
.56602 .2297 .56711 .22268 .55731 .20829 .55619 .21239 Metetra
.963 .822 .655 r
.55619 .21239 .55731 .20829 .5474 .19812 .54627 .20302 Metetra
.969 .812 .633 r
.54627 .20302 .5474 .19812 .53733 .18448 .53621 .1933 Metetra
.978 .785 .577 r
.53621 .1933 .53733 .18448 .52713 .1737 .52599 .18208 Metetra
.979 .79 .579 r
.52599 .18208 .52713 .1737 .51677 .15348 .51561 .17214 Metetra
.981 .763 .536 r
.51561 .17214 .51677 .15348 .50627 .15519 .50509 .15572 Metetra
.706 .84 .947 r
.50509 .15572 .50627 .15519 .49558 .14836 .49441 .14532 Metetra
.91 .516 .112 r
.49441 .14532 .49558 .14836 .48474 .13693 .48356 .13468 Metetra
.794 .363 0 r
.48356 .13468 .48474 .13693 .47375 .12089 .47256 .12075 Metetra
.97 .651 .317 r
.6895 .31508 .69069 .32055 .68246 .30336 .6815 .30719 Metetra
.963 .818 .654 r
.6815 .30719 .68246 .30336 .67435 .29482 .67339 .29902 Metetra
.96 .806 .646 r
.67339 .29902 .67435 .29482 .66611 .28514 .66513 .28891 Metetra
.97 .832 .65 r
.66513 .28891 .66611 .28514 .65775 .27502 .65685 .28302 Metetra
.98 .788 .575 r
.65685 .28302 .65775 .27502 .64944 .27241 .64841 .27493 Metetra
.944 .846 .717 r
.64841 .27493 .64944 .27241 .64115 .27774 .63987 .26724 Metetra
.974 .693 .434 r
.63987 .26724 .64115 .27774 .63254 .2731 .63138 .26938 Metetra
.94 .597 .345 r
.63138 .26938 .63254 .2731 .62389 .27472 .62275 .27184 Metetra
.911 .519 .112 r
.62275 .27184 .62389 .27472 .61514 .27879 .61379 .26274 Metetra
.982 .713 .438 r
.61379 .26274 .61514 .27879 .60608 .27264 .60477 .25848 Metetra
.979 .707 .439 r
.60477 .25848 .60608 .27264 .59691 .26814 .59565 .25752 Metetra
.984 .7 .374 r
.59565 .25752 .59691 .26814 .58741 .24795 .58622 .24191 Metetra
.971 .655 .326 r
.58622 .24191 .58741 .24795 .57794 .23985 .57674 .23301 Metetra
.975 .667 .338 r
.57674 .23301 .57794 .23985 .56828 .22771 .56711 .22268 Metetra
.957 .624 .237 r
.56711 .22268 .56828 .22771 .55847 .21126 .55731 .20829 Metetra
.909 .516 .106 r
.55731 .20829 .55847 .21126 .54855 .19798 .5474 .19812 Metetra
.586 .731 .944 r
.5474 .19812 .54855 .19798 .5385 .18737 .53733 .18448 Metetra
.901 .503 .084 r
.53733 .18448 .5385 .18737 .52831 .18139 .52713 .1737 Metetra
.975 .673 .302 r
.52713 .1737 .52831 .18139 .51795 .17126 .51677 .15348 Metetra
.979 .712 .45 r
.51677 .15348 .51795 .17126 .50744 .15565 .50627 .15519 Metetra
0 .428 .803 r
.50627 .15519 .50744 .15565 .49677 .14724 .49558 .14836 Metetra
.83 .853 .864 r
.49558 .14836 .49677 .14724 .4859 .14157 .48474 .13693 Metetra
.947 .603 .2 r
.48474 .13693 .4859 .14157 .47495 .12083 .47375 .12089 Metetra
.847 .49 0 r
.69069 .32055 .69183 .32389 .68359 .30633 .68246 .30336 Metetra
.919 .536 .133 r
.68246 .30336 .68359 .30633 .67541 .29477 .67435 .29482 Metetra
.539 .739 .968 r
.67435 .29482 .67541 .29477 .66718 .28552 .66611 .28514 Metetra
.244 .565 .937 r
.66611 .28514 .66718 .28552 .6589 .27841 .65775 .27502 Metetra
.944 .585 .277 r
.65775 .27502 .6589 .27841 .65057 .27518 .64944 .27241 Metetra
.912 .552 .338 r
.64944 .27241 .65057 .27518 .64221 .27636 .64115 .27774 Metetra
.9 .916 .824 r
.64115 .27774 .64221 .27636 .63347 .26458 .63254 .2731 Metetra
.993 .804 .547 r
.63254 .2731 .63347 .26458 .62506 .27878 .62389 .27472 Metetra
.941 .607 .367 r
.62389 .27472 .62506 .27878 .61623 .27763 .61514 .27879 Metetra
.866 .905 .857 r
.61514 .27879 .61623 .27763 .60718 .27154 .60608 .27264 Metetra
.86 .934 .872 r
.60608 .27264 .60718 .27154 .59804 .26955 .59691 .26814 Metetra
0 .147 .691 r
.59691 .26814 .59804 .26955 .58852 .24608 .58741 .24795 Metetra
.917 .867 .775 r
.58741 .24795 .58852 .24608 .57901 .23364 .57794 .23985 Metetra
.969 .793 .61 r
.57794 .23985 .57901 .23364 .56933 .21668 .56828 .22771 Metetra
.974 .77 .567 r
.56828 .22771 .56933 .21668 .55957 .20542 .55847 .21126 Metetra
.966 .794 .619 r
.55847 .21126 .55957 .20542 .54968 .19427 .54855 .19798 Metetra
.956 .822 .672 r
.54855 .19798 .54968 .19427 .53964 .18406 .5385 .18737 Metetra
.966 .854 .68 r
.5385 .18737 .53964 .18406 .52945 .17377 .52831 .18139 Metetra
.978 .793 .587 r
.52831 .18139 .52945 .17377 .51911 .16096 .51795 .17126 Metetra
.975 .775 .571 r
.51795 .17126 .51911 .16096 .50863 .1428 .50744 .15565 Metetra
.984 .778 .546 r
.50744 .15565 .50863 .1428 .49796 .14197 .49677 .14724 Metetra
.98 .826 .618 r
.49677 .14724 .49796 .14197 .48713 .13326 .4859 .14157 Metetra
.964 .773 .596 r
.4859 .14157 .48713 .13326 .4762 .1101 .47495 .12083 Metetra
.974 .761 .554 r
.69183 .32389 .69252 .3104 .68431 .29311 .68359 .30633 Metetra
.98 .768 .546 r
.68359 .30633 .68431 .29311 .67613 .28097 .67541 .29477 Metetra
.983 .77 .54 r
.67541 .29477 .67613 .28097 .66793 .27186 .66718 .28552 Metetra
.985 .773 .537 r
.66718 .28552 .66793 .27186 .6596 .26165 .6589 .27841 Metetra
.988 .771 .522 r
.6589 .27841 .6596 .26165 .65119 .25281 .65057 .27518 Metetra
.99 .767 .508 r
.65057 .27518 .65119 .25281 .64272 .24671 .64221 .27636 Metetra
.984 .757 .513 r
.64221 .27636 .64272 .24671 .63429 .24924 .63347 .26458 Metetra
.997 .787 .495 r
.63347 .26458 .63429 .24924 .62576 .2547 .62506 .27878 Metetra
.988 .765 .509 r
.62506 .27878 .62576 .2547 .61704 .25855 .61623 .27763 Metetra
.986 .767 .522 r
.61623 .27763 .61704 .25855 .60809 .25748 .60718 .27154 Metetra
.989 .779 .529 r
.60718 .27154 .60809 .25748 .59901 .25747 .59804 .26955 Metetra
.968 .759 .569 r
.59804 .26955 .59901 .25747 .5896 .24182 .58852 .24608 Metetra
.955 .805 .654 r
.58852 .24608 .5896 .24182 .58 .2202 .57901 .23364 Metetra
.977 .766 .554 r
.57901 .23364 .58 .2202 .57033 .20066 .56933 .21668 Metetra
.983 .768 .537 r
.56933 .21668 .57033 .20066 .56061 .19111 .55957 .20542 Metetra
.982 .771 .543 r
.55957 .20542 .56061 .19111 .55073 .17791 .54968 .19427 Metetra
.984 .769 .535 r
.54968 .19427 .55073 .17791 .54073 .16801 .53964 .18406 Metetra
.984 .77 .536 r
.53964 .18406 .54073 .16801 .53059 .16379 .52945 .17377 Metetra
.978 .78 .569 r
.52945 .17377 .53059 .16379 .52027 .15171 .51911 .16096 Metetra
.97 .774 .583 r
.51911 .16096 .52027 .15171 .5098 .13246 .50863 .1428 Metetra
.991 .795 .546 r
.50863 .1428 .5098 .13246 .49918 .12442 .49796 .14197 Metetra
.985 .77 .53 r
.49796 .14197 .49918 .12442 .48837 .12052 .48713 .13326 Metetra
.972 .763 .564 r
.48713 .13326 .48837 .12052 .47747 .09722 .4762 .1101 Metetra
.955 .77 .613 r
.69252 .3104 .6934 .30401 .68513 .28435 .68431 .29311 Metetra
.974 .777 .575 r
.68431 .29311 .68513 .28435 .67707 .27606 .67613 .28097 Metetra
.968 .804 .625 r
.67613 .28097 .67707 .27606 .66889 .26734 .66793 .27186 Metetra
.963 .804 .638 r
.66793 .27186 .66889 .26734 .6606 .25853 .6596 .26165 Metetra
.951 .827 .685 r
.6596 .26165 .6606 .25853 .65221 .25003 .65119 .25281 Metetra
.957 .853 .697 r
.65119 .25281 .65221 .25003 .64364 .23834 .64272 .24671 Metetra
.994 .806 .544 r
.64272 .24671 .64364 .23834 .63503 .23 .63429 .24924 Metetra
.992 .774 .506 r
.63429 .24924 .63503 .23 .62647 .2322 .62576 .2547 Metetra
.991 .769 .505 r
.62576 .2547 .62647 .2322 .61771 .23085 .61704 .25855 Metetra
.988 .762 .505 r
.61704 .25855 .61771 .23085 .60892 .23756 .60809 .25748 Metetra
.989 .77 .513 r
.60809 .25748 .60892 .23756 .59993 .24201 .59901 .25747 Metetra
.979 .764 .544 r
.59901 .25747 .59993 .24201 .59056 .22804 .5896 .24182 Metetra
.973 .76 .558 r
.5896 .24182 .59056 .22804 .58098 .2047 .58 .2202 Metetra
.976 .761 .548 r
.58 .2202 .58098 .2047 .57132 .18442 .57033 .20066 Metetra
.984 .769 .534 r
.57033 .20066 .57132 .18442 .56165 .17682 .56061 .19111 Metetra
.981 .769 .545 r
.56061 .19111 .56165 .17682 .5518 .16479 .55073 .17791 Metetra
.983 .775 .546 r
.55073 .17791 .5518 .16479 .54183 .1552 .54073 .16801 Metetra
.988 .782 .539 r
.54073 .16801 .54183 .1552 .53172 .15139 .53059 .16379 Metetra
.981 .775 .552 r
.53059 .16379 .53172 .15139 .52143 .14128 .52027 .15171 Metetra
.971 .77 .574 r
.52027 .15171 .52143 .14128 .51098 .1307 .5098 .13246 Metetra
.909 .883 .796 r
.5098 .13246 .51098 .1307 .50037 .12185 .49918 .12442 Metetra
.958 .893 .721 r
.49918 .12442 .50037 .12185 .48956 .12027 .48837 .12052 Metetra
.627 .659 .862 r
.48837 .12052 .48956 .12027 .47867 .09555 .47747 .09722 Metetra
.688 .672 .829 r
.6934 .30401 .69444 .3036 .68618 .28412 .68513 .28435 Metetra
.623 .803 .968 r
.68513 .28435 .68618 .28412 .67813 .27601 .67707 .27606 Metetra
.525 .753 .979 r
.67707 .27606 .67813 .27601 .66997 .26786 .66889 .26734 Metetra
.047 .459 .88 r
.66889 .26734 .66997 .26786 .66169 .25953 .6606 .25853 Metetra
0 .072 .571 r
.6606 .25853 .66169 .25953 .65331 .25115 .65221 .25003 Metetra
0 .105 .639 r
.65221 .25003 .65331 .25115 .64525 .26516 .64364 .23834 Metetra
.986 .728 .451 r
.64364 .23834 .64525 .26516 .6369 .27298 .63503 .23 Metetra
.984 .732 .47 r
.63503 .23 .6369 .27298 .6284 .28079 .62647 .2322 Metetra
.985 .734 .47 r
.62647 .2322 .6284 .28079 .61966 .28444 .61771 .23085 Metetra
.983 .733 .475 r
.61771 .23085 .61966 .28444 .61071 .28444 .60892 .23756 Metetra
.983 .732 .472 r
.60892 .23756 .61071 .28444 .60171 .29262 .59993 .24201 Metetra
.987 .736 .463 r
.59993 .24201 .60171 .29262 .59215 .26735 .59056 .22804 Metetra
.989 .736 .45 r
.59056 .22804 .59215 .26735 .58262 .25475 .58098 .2047 Metetra
.988 .737 .459 r
.58098 .2047 .58262 .25475 .57295 .24031 .57132 .18442 Metetra
.986 .736 .468 r
.57132 .18442 .57295 .24031 .56315 .2255 .56165 .17682 Metetra
.986 .735 .463 r
.56165 .17682 .56315 .2255 .55321 .20857 .5518 .16479 Metetra
.986 .734 .462 r
.5518 .16479 .55321 .20857 .54316 .19587 .54183 .1552 Metetra
.985 .732 .465 r
.54183 .1552 .54316 .19587 .53296 .18124 .53172 .15139 Metetra
.986 .729 .452 r
.53172 .15139 .53296 .18124 .52263 .1671 .52143 .14128 Metetra
.986 .726 .447 r
.52143 .14128 .52263 .1671 .51215 .15577 .51098 .1307 Metetra
.985 .725 .447 r
.51098 .1307 .51215 .15577 .5015 .14379 .50037 .12185 Metetra
.982 .719 .451 r
.50037 .12185 .5015 .14379 .49069 .1365 .48956 .12027 Metetra
.988 .718 .397 r
.48956 .12027 .49069 .1365 .47978 .11046 .47867 .09555 Metetra
.957 .648 .229 r
.69444 .3036 .69565 .3098 .68768 .30156 .68618 .28412 Metetra
.985 .719 .434 r
.68618 .28412 .68768 .30156 .67962 .29345 .67813 .27601 Metetra
.985 .719 .434 r
.67813 .27601 .67962 .29345 .67144 .28532 .66997 .26786 Metetra
.985 .719 .433 r
.66997 .26786 .67144 .28532 .66316 .27715 .66169 .25953 Metetra
.985 .719 .434 r
.66169 .25953 .66316 .27715 .65476 .269 .65331 .25115 Metetra
.972 .709 .472 r
.65331 .25115 .65476 .269 .6465 .27374 .64525 .26516 Metetra
.964 .677 .44 r
.64525 .26516 .6465 .27374 .63797 .27147 .6369 .27298 Metetra
.774 .945 .606 r
.6369 .27298 .63797 .27147 .62935 .27212 .6284 .28079 Metetra
.995 .807 .539 r
.6284 .28079 .62935 .27212 .62045 .26455 .61966 .28444 Metetra
.99 .77 .512 r
.61966 .28444 .62045 .26455 .61159 .26811 .61071 .28444 Metetra
.994 .782 .506 r
.61071 .28444 .61159 .26811 .60284 .29242 .60171 .29262 Metetra
.63 .623 .825 r
.60171 .29262 .60284 .29242 .59323 .26341 .59215 .26735 Metetra
.951 .807 .664 r
.59215 .26735 .59323 .26341 .58359 .23873 .58262 .25475 Metetra
.981 .766 .54 r
.58262 .25475 .58359 .23873 .57393 .22196 .57295 .24031 Metetra
.982 .763 .533 r
.57295 .24031 .57393 .22196 .56418 .21054 .56315 .2255 Metetra
.978 .765 .547 r
.56315 .2255 .56418 .21054 .5543 .19825 .55321 .20857 Metetra
.979 .778 .565 r
.55321 .20857 .5543 .19825 .54426 .18394 .54316 .19587 Metetra
.978 .773 .558 r
.54316 .19587 .54426 .18394 .5341 .17199 .53296 .18124 Metetra
.976 .78 .577 r
.53296 .18124 .5341 .17199 .52378 .15675 .52263 .1671 Metetra
.98 .781 .564 r
.52263 .1671 .52378 .15675 .51332 .15252 .51215 .15577 Metetra
.945 .826 .696 r
.51215 .15577 .51332 .15252 .50269 .14283 .5015 .14379 Metetra
.816 .91 .904 r
.5015 .14379 .50269 .14283 .49188 .13645 .49069 .1365 Metetra
.581 .613 .849 r
.49069 .1365 .49188 .13645 .48098 .11013 .47978 .11046 Metetra
.951 .602 .233 r
.69565 .3098 .69681 .31374 .68874 .30175 .68768 .30156 Metetra
.334 .662 .973 r
.68768 .30156 .68874 .30175 .68064 .29191 .67962 .29345 Metetra
.896 .859 .796 r
.67962 .29345 .68064 .29191 .67233 .27793 .67144 .28532 Metetra
.979 .791 .581 r
.67144 .28532 .67233 .27793 .66418 .27498 .66316 .27715 Metetra
.931 .849 .741 r
.66316 .27715 .66418 .27498 .65584 .26931 .65476 .269 Metetra
.533 0 0 r
.65476 .269 .65584 .26931 .64783 .28598 .6465 .27374 Metetra
.979 .703 .427 r
.6465 .27374 .64783 .28598 .63924 .2812 .63797 .27147 Metetra
.974 .689 .422 r
.63797 .27147 .63924 .2812 .63045 .27195 .62935 .27212 Metetra
.559 .81 .992 r
.62935 .27212 .63045 .27195 .62183 .2812 .62045 .26455 Metetra
.978 .711 .452 r
.62045 .26455 .62183 .2812 .6127 .26768 .61159 .26811 Metetra
.428 .093 .293 r
.61159 .26811 .6127 .26768 .60398 .29331 .60284 .29242 Metetra
.341 .417 .795 r
.60284 .29242 .60398 .29331 .59435 .26244 .59323 .26341 Metetra
.754 .693 .794 r
.59323 .26341 .59435 .26244 .58477 .24273 .58359 .23873 Metetra
.917 .564 .113 r
.58359 .23873 .58477 .24273 .57515 .23077 .57393 .22196 Metetra
.98 .686 .366 r
.57393 .22196 .57515 .23077 .56536 .21431 .56418 .21054 Metetra
.933 .569 .163 r
.56418 .21054 .56536 .21431 .55544 .1964 .5543 .19825 Metetra
.884 .815 .776 r
.5543 .19825 .55544 .1964 .54543 .18553 .54426 .18394 Metetra
.644 .177 0 r
.54426 .18394 .54543 .18553 .53527 .17299 .5341 .17199 Metetra
0 .242 .754 r
.5341 .17199 .53527 .17299 .52496 .16298 .52378 .15675 Metetra
.968 .652 .354 r
.52378 .15675 .52496 .16298 .5145 .15673 .51332 .15252 Metetra
.95 .596 .235 r
.51332 .15252 .5145 .15673 .50387 .14384 .50269 .14283 Metetra
.575 .024 0 r
.50269 .14283 .50387 .14384 .49308 .13288 .49188 .13645 Metetra
.903 .758 .691 r
.49188 .13645 .49308 .13288 .48214 .11712 .48098 .11013 Metetra
.924 .807 .712 r
.69681 .31374 .69779 .31112 .6898 .30155 .68874 .30175 Metetra
.624 .772 .951 r
.68874 .30175 .6898 .30155 .6816 .288 .68064 .29191 Metetra
.943 .791 .662 r
.68064 .29191 .6816 .288 .67336 .27646 .67233 .27793 Metetra
.916 .933 .805 r
.67233 .27793 .67336 .27646 .66518 .27183 .66418 .27498 Metetra
.965 .847 .675 r
.66418 .27498 .66518 .27183 .65693 .26955 .65584 .26931 Metetra
.598 .219 .296 r
.65584 .26931 .65693 .26955 .64841 .26063 .64783 .28598 Metetra
.987 .762 .51 r
.64783 .28598 .64841 .26063 .6402 .2738 .63924 .2812 Metetra
.978 .791 .584 r
.63924 .2812 .6402 .2738 .63149 .26842 .63045 .27195 Metetra
.979 .902 .566 r
.63045 .27195 .63149 .26842 .62272 .26815 .62183 .2812 Metetra
.979 .769 .55 r
.62183 .2812 .62272 .26815 .61369 .2595 .6127 .26768 Metetra
.989 .828 .447 r
.6127 .26768 .61369 .2595 .60463 .25862 .60398 .29331 Metetra
.979 .749 .52 r
.60398 .29331 .60463 .25862 .5952 .2393 .59435 .26244 Metetra
.98 .757 .527 r
.59435 .26244 .5952 .2393 .58576 .23006 .58477 .24273 Metetra
.981 .773 .55 r
.58477 .24273 .58576 .23006 .57615 .21658 .57515 .23077 Metetra
.978 .766 .549 r
.57515 .23077 .57615 .21658 .56642 .20414 .56536 .21431 Metetra
.972 .771 .574 r
.56536 .21431 .56642 .20414 .55657 .19318 .55544 .1964 Metetra
.948 .828 .692 r
.55544 .1964 .55657 .19318 .54658 .18372 .54543 .18553 Metetra
.891 .833 .783 r
.54543 .18553 .54658 .18372 .53644 .1748 .53527 .17299 Metetra
.766 .299 0 r
.53527 .17299 .53644 .1748 .52613 .16164 .52496 .16298 Metetra
.879 .916 .848 r
.52496 .16298 .52613 .16164 .51568 .15218 .5145 .15673 Metetra
.96 .809 .65 r
.5145 .15673 .51568 .15218 .50506 .14118 .50387 .14384 Metetra
.935 .842 .727 r
.50387 .14384 .50506 .14118 .4943 .12531 .49308 .13288 Metetra
.97 .785 .597 r
.49308 .13288 .4943 .12531 .48342 .09934 .48214 .11712 Metetra
.905 .835 .765 r
.69779 .31112 .69879 .30931 .69083 .3009 .6898 .30155 Metetra
.752 .763 .862 r
.6898 .30155 .69083 .3009 .68279 .29287 .6816 .288 Metetra
.96 .629 .248 r
.6816 .288 .68279 .29287 .67454 .28096 .67336 .27646 Metetra
.961 .626 .307 r
.67336 .27646 .67454 .28096 .66636 .27668 .66518 .27183 Metetra
.962 .636 .341 r
.66518 .27183 .66636 .27668 .658 .26936 .65693 .26955 Metetra
.599 .79 .972 r
.65693 .26955 .658 .26936 .65001 .28592 .64841 .26063 Metetra
.977 .719 .473 r
.64841 .26063 .65001 .28592 .64145 .28177 .6402 .2738 Metetra
.976 .68 .382 r
.6402 .2738 .64145 .28177 .63263 .27079 .63149 .26842 Metetra
.907 .506 .221 r
.63149 .26842 .63263 .27079 .62408 .28333 .62272 .26815 Metetra
.984 .713 .423 r
.62272 .26815 .62408 .28333 .61536 .29644 .61369 .2595 Metetra
.984 .73 .464 r
.61369 .2595 .61536 .29644 .60648 .31111 .60463 .25862 Metetra
.988 .738 .459 r
.60463 .25862 .60648 .31111 .59646 .25029 .5952 .2393 Metetra
.982 .699 .397 r
.5952 .2393 .59646 .25029 .58701 .2406 .58576 .23006 Metetra
.983 .698 .378 r
.58576 .23006 .58701 .2406 .57738 .22593 .57615 .21658 Metetra
.981 .69 .368 r
.57615 .21658 .57738 .22593 .56761 .20847 .56642 .20414 Metetra
.951 .602 .226 r
.56642 .20414 .56761 .20847 .55779 .20359 .55657 .19318 Metetra
.981 .695 .391 r
.55657 .19318 .55779 .20359 .54776 .18771 .54658 .18372 Metetra
.947 .589 .227 r
.54658 .18372 .54776 .18771 .53761 .17772 .53644 .1748 Metetra
.881 .484 .031 r
.53644 .1748 .53761 .17772 .52731 .16459 .52613 .16164 Metetra
.909 .512 .114 r
.52613 .16164 .52731 .16459 .51686 .15599 .51568 .15218 Metetra
.938 .573 .187 r
.51568 .15218 .51686 .15599 .50624 .14664 .50506 .14118 Metetra
.96 .631 .246 r
.50506 .14118 .50624 .14664 .49546 .13524 .4943 .12531 Metetra
.98 .692 .324 r
.4943 .12531 .49546 .13524 .48461 .10223 .48342 .09934 Metetra
.18 .554 .932 r
.69879 .30931 .69985 .30969 .69175 .29556 .69083 .3009 Metetra
.974 .804 .612 r
.69083 .3009 .69175 .29556 .68361 .2834 .68279 .29287 Metetra
.977 .776 .568 r
.68279 .29287 .68361 .2834 .67539 .27194 .67454 .28096 Metetra
.987 .791 .555 r
.67454 .28096 .67539 .27194 .66713 .26333 .66636 .27668 Metetra
.985 .774 .537 r
.66636 .27668 .66713 .26333 .65861 .24767 .658 .26936 Metetra
.996 .776 .485 r
.658 .26936 .65861 .24767 .65014 .23915 .65001 .28592 Metetra
.987 .754 .496 r
.65001 .28592 .65014 .23915 .64178 .24217 .64145 .28177 Metetra
.986 .754 .503 r
.64145 .28177 .64178 .24217 .63313 .23712 .63263 .27079 Metetra
.992 .764 .488 r
.63263 .27079 .63313 .23712 .62443 .23726 .62408 .28333 Metetra
.991 .759 .486 r
.62408 .28333 .62443 .23726 .61568 .24349 .61536 .29644 Metetra
.99 .757 .485 r
.61536 .29644 .61568 .24349 .60661 .23958 .60648 .31111 Metetra
.979 .742 .51 r
.60648 .31111 .60661 .23958 .5972 .21921 .59646 .25029 Metetra
.986 .758 .508 r
.59646 .25029 .5972 .21921 .58776 .20556 .58701 .2406 Metetra
.985 .755 .509 r
.58701 .2406 .58776 .20556 .57811 .18364 .57738 .22593 Metetra
.984 .753 .506 r
.57738 .22593 .57811 .18364 .56845 .17274 .56761 .20847 Metetra
.987 .758 .502 r
.56761 .20847 .56845 .17274 .55867 .16283 .55779 .20359 Metetra
.985 .753 .506 r
.55779 .20359 .55867 .16283 .54872 .15089 .54776 .18771 Metetra
.986 .756 .505 r
.54776 .18771 .54872 .15089 .53865 .14285 .53761 .17772 Metetra
.985 .756 .508 r
.53761 .17772 .53865 .14285 .52841 .13267 .52731 .16459 Metetra
.987 .759 .507 r
.52731 .16459 .52841 .13267 .51801 .12315 .51686 .15599 Metetra
.986 .758 .507 r
.51686 .15599 .51801 .12315 .50746 .11533 .50624 .14664 Metetra
.986 .758 .51 r
.50624 .14664 .50746 .11533 .49673 .10546 .49546 .13524 Metetra
.978 .75 .525 r
.49546 .13524 .49673 .10546 .48589 .08252 .48461 .10223 Metetra
.981 .76 .53 r
.69985 .30969 .70038 .29088 .69247 .28286 .69175 .29556 Metetra
.98 .769 .548 r
.69175 .29556 .69247 .28286 .68436 .27141 .68361 .2834 Metetra
.98 .771 .55 r
.68361 .2834 .68436 .27141 .67623 .26294 .67539 .27194 Metetra
.981 .784 .565 r
.67539 .27194 .67623 .26294 .668 .25455 .66713 .26333 Metetra
.97 .772 .581 r
.66713 .26333 .668 .25455 .65963 .24501 .65861 .24767 Metetra
.944 .838 .709 r
.65861 .24767 .65963 .24501 .65116 .23602 .65014 .23915 Metetra
.985 .899 .633 r
.65014 .23915 .65116 .23602 .64259 .22736 .64178 .24217 Metetra
.987 .774 .529 r
.64178 .24217 .64259 .22736 .63399 .22401 .63313 .23712 Metetra
.991 .783 .525 r
.63313 .23712 .63399 .22401 .62524 .21999 .62443 .23726 Metetra
.993 .778 .506 r
.62443 .23726 .62524 .21999 .6165 .22506 .61568 .24349 Metetra
.988 .77 .519 r
.61568 .24349 .6165 .22506 .60747 .22111 .60661 .23958 Metetra
.978 .758 .538 r
.60661 .23958 .60747 .22111 .59823 .21142 .5972 .21921 Metetra
.972 .783 .589 r
.5972 .21921 .59823 .21142 .58875 .19374 .58776 .20556 Metetra
.97 .762 .567 r
.58776 .20556 .58875 .19374 .57913 .17195 .57811 .18364 Metetra
.982 .777 .552 r
.57811 .18364 .57913 .17195 .5695 .16111 .56845 .17274 Metetra
.983 .778 .551 r
.56845 .17274 .5695 .16111 .55973 .15131 .55867 .16283 Metetra
.981 .776 .555 r
.55867 .16283 .55973 .15131 .54982 .14169 .54872 .15089 Metetra
.983 .79 .565 r
.54872 .15089 .54982 .14169 .53981 .14464 .53865 .14285 Metetra
.756 .289 0 r
.53865 .14285 .53981 .14464 .52958 .13455 .52841 .13267 Metetra
.79 .327 0 r
.52841 .13267 .52958 .13455 .51919 .12509 .51801 .12315 Metetra
.826 .366 0 r
.51801 .12315 .51919 .12509 .50864 .11564 .50746 .11533 Metetra
.189 .589 .942 r
.50746 .11533 .50864 .11564 .4979 .11288 .49673 .10546 Metetra
.97 .665 .275 r
.49673 .10546 .4979 .11288 .48707 .08469 .48589 .08252 Metetra
.977 .677 .356 r
.70038 .29088 .70163 .29813 .69352 .28267 .69247 .28286 Metetra
.625 .742 .931 r
.69247 .28286 .69352 .28267 .6855 .27456 .68436 .27141 Metetra
.926 .55 .152 r
.68436 .27141 .6855 .27456 .67736 .26535 .67623 .26294 Metetra
.879 .465 .034 r
.67623 .26294 .67736 .26535 .66907 .25443 .668 .25455 Metetra
.574 .764 .968 r
.668 .25455 .66907 .25443 .66081 .24975 .65963 .24501 Metetra
.961 .627 .27 r
.65963 .24501 .66081 .24975 .65256 .25119 .65116 .23602 Metetra
.985 .714 .422 r
.65116 .23602 .65256 .25119 .64415 .25172 .64259 .22736 Metetra
.984 .724 .452 r
.64259 .22736 .64415 .25172 .63588 .26781 .63399 .22401 Metetra
.985 .733 .464 r
.63399 .22401 .63588 .26781 .62701 .25941 .62524 .21999 Metetra
.983 .73 .469 r
.62524 .21999 .62701 .25941 .61808 .25451 .6165 .22506 Metetra
.985 .728 .456 r
.6165 .22506 .61808 .25451 .60906 .25425 .60747 .22111 Metetra
.986 .731 .453 r
.60747 .22111 .60906 .25425 .59975 .24242 .59823 .21142 Metetra
.988 .732 .443 r
.59823 .21142 .59975 .24242 .59027 .22746 .58875 .19374 Metetra
.989 .734 .443 r
.58875 .19374 .59027 .22746 .5807 .21472 .57913 .17195 Metetra
.987 .734 .459 r
.57913 .17195 .5807 .21472 .57102 .20484 .5695 .16111 Metetra
.986 .734 .46 r
.5695 .16111 .57102 .20484 .56119 .19483 .55973 .15131 Metetra
.986 .734 .46 r
.55973 .15131 .56119 .19483 .55122 .18493 .54982 .14169 Metetra
.984 .731 .467 r
.54982 .14169 .55122 .18493 .54109 .17285 .53981 .14464 Metetra
.986 .727 .448 r
.53981 .14464 .54109 .17285 .5308 .1537 .52958 .13455 Metetra
.985 .718 .433 r
.52958 .13455 .5308 .1537 .52039 .14455 .51919 .12509 Metetra
.985 .719 .433 r
.51919 .12509 .52039 .14455 .50981 .13084 .50864 .11564 Metetra
.981 .707 .432 r
.50864 .11564 .50981 .13084 .49906 .12792 .4979 .11288 Metetra
.987 .715 .378 r
.4979 .11288 .49906 .12792 .48821 .09821 .48707 .08469 Metetra
.988 .731 .441 r
.70163 .29813 .70347 .3262 .69545 .31539 .69352 .28267 Metetra
.986 .731 .454 r
.69352 .28267 .69545 .31539 .68728 .30242 .6855 .27456 Metetra
.986 .729 .449 r
.6855 .27456 .68728 .30242 .67894 .28623 .67736 .26535 Metetra
.987 .724 .435 r
.67736 .26535 .67894 .28623 .67088 .28619 .66907 .25443 Metetra
.985 .73 .457 r
.66907 .25443 .67088 .28619 .66264 .28375 .66081 .24975 Metetra
.984 .729 .464 r
.66081 .24975 .66264 .28375 .65434 .2842 .65256 .25119 Metetra
.984 .729 .463 r
.65256 .25119 .65434 .2842 .6458 .28006 .64415 .25172 Metetra
.978 .721 .475 r
.64415 .25172 .6458 .28006 .63703 .27037 .63588 .26781 Metetra
.891 .482 .066 r
.63588 .26781 .63703 .27037 .62825 .26654 .62701 .25941 Metetra
.974 .67 .369 r
.62701 .25941 .62825 .26654 .61929 .26059 .61808 .25451 Metetra
.965 .653 .376 r
.61808 .25451 .61929 .26059 .61036 .2664 .60906 .25425 Metetra
.984 .705 .396 r
.60906 .25425 .61036 .2664 .60091 .24469 .59975 .24242 Metetra
.743 .332 0 r
.59975 .24242 .60091 .24469 .59141 .22753 .59027 .22746 Metetra
.486 .687 .956 r
.59027 .22746 .59141 .22753 .58188 .21896 .5807 .21472 Metetra
.95 .6 .23 r
.5807 .21472 .58188 .21896 .57219 .20804 .57102 .20484 Metetra
.919 .535 .132 r
.57102 .20484 .57219 .20804 .56234 .19443 .56119 .19483 Metetra
.67 .828 .96 r
.56119 .19483 .56234 .19443 .55239 .18656 .55122 .18493 Metetra
.646 .181 0 r
.55122 .18493 .55239 .18656 .54227 .17518 .54109 .17285 Metetra
.67 .282 0 r
.54109 .17285 .54227 .17518 .532 .16549 .5308 .1537 Metetra
.982 .7 .401 r
.5308 .1537 .532 .16549 .52157 .15129 .52039 .14455 Metetra
.972 .66 .309 r
.52039 .14455 .52157 .15129 .51099 .14593 .50981 .13084 Metetra
.981 .707 .431 r
.50981 .13084 .51099 .14593 .50023 .13599 .49906 .12792 Metetra
.964 .668 .253 r
.49906 .12792 .50023 .13599 .48933 .12013 .48821 .09821 Metetra
.975 .785 .585 r
.70347 .3262 .70432 .3188 .69611 .30039 .69545 .31539 Metetra
.981 .765 .539 r
.69545 .31539 .69611 .30039 .68808 .29195 .68728 .30242 Metetra
.973 .768 .567 r
.68728 .30242 .68808 .29195 .67989 .28157 .67894 .28623 Metetra
.991 .842 .598 r
.67894 .28623 .67989 .28157 .67171 .27566 .67088 .28619 Metetra
.99 .788 .54 r
.67088 .28619 .67171 .27566 .66339 .26842 .66264 .28375 Metetra
.991 .777 .517 r
.66264 .28375 .66339 .26842 .655 .26399 .65434 .2842 Metetra
.988 .767 .514 r
.65434 .2842 .655 .26399 .64654 .26215 .6458 .28006 Metetra
.985 .766 .526 r
.6458 .28006 .64654 .26215 .63796 .2611 .63703 .27037 Metetra
.988 .793 .553 r
.63703 .27037 .63796 .2611 .62925 .26055 .62825 .26654 Metetra
.982 .81 .596 r
.62825 .26654 .62925 .26055 .62052 .26751 .61929 .26059 Metetra
.961 .66 .415 r
.61929 .26059 .62052 .26751 .61146 .26447 .61036 .2664 Metetra
.85 .749 .752 r
.61036 .2664 .61146 .26447 .60206 .24593 .60091 .24469 Metetra
0 .172 .709 r
.60091 .24469 .60206 .24593 .59257 .22969 .59141 .22753 Metetra
.846 .407 0 r
.59141 .22753 .59257 .22969 .58298 .21514 .58188 .21896 Metetra
.957 .819 .666 r
.58188 .21896 .58298 .21514 .57329 .20255 .57219 .20804 Metetra
.964 .796 .625 r
.57219 .20804 .57329 .20255 .56343 .18591 .56234 .19443 Metetra
.983 .793 .57 r
.56234 .19443 .56343 .18591 .55345 .16917 .55239 .18656 Metetra
.984 .768 .53 r
.55239 .18656 .55345 .16917 .54336 .15889 .54227 .17518 Metetra
.985 .771 .532 r
.54227 .17518 .54336 .15889 .53312 .14634 .532 .16549 Metetra
.983 .764 .529 r
.532 .16549 .53312 .14634 .52274 .14423 .52157 .15129 Metetra
.985 .809 .583 r
.52157 .15129 .52274 .14423 .51218 .14881 .51099 .14593 Metetra
.901 .499 .092 r
.51099 .14593 .51218 .14881 .50144 .13124 .50023 .13599 Metetra
.955 .799 .649 r
.50023 .13599 .50144 .13124 .49059 .10385 .48933 .12013 Metetra
.986 .708 .368 r
.70432 .3188 .70571 .33077 .69761 .31664 .69611 .30039 Metetra
.985 .717 .426 r
.69611 .30039 .69761 .31664 .68941 .3021 .68808 .29195 Metetra
.983 .698 .383 r
.68808 .29195 .68941 .3021 .68127 .29392 .67989 .28157 Metetra
.982 .706 .415 r
.67989 .28157 .68127 .29392 .67303 .28588 .67171 .27566 Metetra
.981 .697 .396 r
.67171 .27566 .67303 .28588 .66494 .28923 .66339 .26842 Metetra
.984 .721 .444 r
.66339 .26842 .66494 .28923 .65663 .28929 .655 .26399 Metetra
.984 .725 .454 r
.655 .26399 .65663 .28929 .64814 .28696 .64654 .26215 Metetra
.983 .724 .454 r
.64654 .26215 .64814 .28696 .63952 .28498 .63796 .2611 Metetra
.983 .723 .453 r
.63796 .2611 .63952 .28498 .6309 .29102 .62925 .26055 Metetra
.982 .725 .466 r
.62925 .26055 .6309 .29102 .62213 .2981 .62052 .26751 Metetra
.985 .728 .456 r
.62052 .26751 .62213 .2981 .61316 .30307 .61146 .26447 Metetra
.988 .735 .449 r
.61146 .26447 .61316 .30307 .60353 .27117 .60206 .24593 Metetra
.988 .728 .435 r
.60206 .24593 .60353 .27117 .59408 .26103 .59257 .22969 Metetra
.987 .731 .446 r
.59257 .22969 .59408 .26103 .58452 .25224 .58298 .21514 Metetra
.987 .733 .453 r
.58298 .21514 .58452 .25224 .57467 .22829 .57329 .20255 Metetra
.988 .728 .436 r
.57329 .20255 .57467 .22829 .56483 .21727 .56343 .18591 Metetra
.988 .731 .444 r
.56343 .18591 .56483 .21727 .55478 .19685 .55345 .16917 Metetra
.986 .727 .446 r
.55345 .16917 .55478 .19685 .54462 .17816 .54336 .15889 Metetra
.986 .72 .427 r
.54336 .15889 .54462 .17816 .53436 .16642 .53312 .14634 Metetra
.982 .717 .444 r
.53312 .14634 .53436 .16642 .52395 .16162 .52274 .14423 Metetra
.978 .709 .448 r
.52274 .14423 .52395 .16162 .51337 .14545 .51218 .14881 Metetra
.928 .798 .696 r
.51218 .14881 .51337 .14545 .50263 .13027 .50144 .13124 Metetra
.745 .692 .801 r
.50144 .13124 .50263 .13027 .49176 .11301 .49059 .10385 Metetra
.978 .768 .553 r
.70571 .33077 .70642 .31868 .6984 .30693 .69761 .31664 Metetra
.974 .772 .57 r
.69761 .31664 .6984 .30693 .69045 .3014 .68941 .3021 Metetra
.782 .857 .906 r
.68941 .3021 .69045 .3014 .68229 .29168 .68127 .29392 Metetra
.934 .849 .735 r
.68127 .29392 .68229 .29168 .67409 .28512 .67303 .28588 Metetra
.584 .931 .749 r
.67303 .28588 .67409 .28512 .66568 .27417 .66494 .28923 Metetra
.991 .778 .518 r
.66494 .28923 .66568 .27417 .65745 .27665 .65663 .28929 Metetra
.99 .782 .53 r
.65663 .28929 .65745 .27665 .64886 .26839 .64814 .28696 Metetra
.989 .771 .514 r
.64814 .28696 .64886 .26839 .64034 .27023 .63952 .28498 Metetra
.995 .784 .509 r
.63952 .28498 .64034 .27023 .63185 .28196 .6309 .29102 Metetra
.998 .81 .525 r
.6309 .29102 .63185 .28196 .62337 .30511 .62213 .2981 Metetra
.962 .661 .411 r
.62213 .2981 .62337 .30511 .61565 .39377 .61316 .30307 Metetra
.989 .742 .462 r
.61316 .30307 .61565 .39377 .60489 .2877 .60353 .27117 Metetra
.985 .715 .422 r
.60353 .27117 .60489 .2877 .59515 .25517 .59408 .26103 Metetra
.976 .807 .607 r
.59408 .26103 .59515 .25517 .58551 .2374 .58452 .25224 Metetra
.973 .759 .553 r
.58452 .25224 .58551 .2374 .57565 .20888 .57467 .22829 Metetra
.985 .765 .524 r
.57467 .22829 .57565 .20888 .56581 .19552 .56483 .21727 Metetra
.981 .758 .529 r
.56483 .21727 .56581 .19552 .5559 .18948 .55478 .19685 Metetra
.964 .777 .602 r
.55478 .19685 .5559 .18948 .54579 .17877 .54462 .17816 Metetra
.023 .427 .865 r
.54462 .17816 .54579 .17877 .53552 .16253 .53436 .16642 Metetra
.976 .851 .652 r
.53436 .16642 .53552 .16253 .52513 .15971 .52395 .16162 Metetra
.88 .807 .774 r
.52395 .16162 .52513 .15971 .51456 .15312 .51337 .14545 Metetra
.976 .671 .323 r
.51337 .14545 .51456 .15312 .50382 .13733 .50263 .13027 Metetra
.972 .662 .296 r
.50263 .13027 .50382 .13733 .49293 .12188 .49176 .11301 Metetra
.967 .79 .611 r
.70642 .31868 .70731 .31289 .69933 .30201 .6984 .30693 Metetra
.979 .818 .612 r
.6984 .30693 .69933 .30201 .69131 .2935 .69045 .3014 Metetra
.978 .786 .577 r
.69045 .3014 .69131 .2935 .68318 .28453 .68229 .29168 Metetra
.983 .797 .578 r
.68229 .29168 .68318 .28453 .67496 .27641 .67409 .28512 Metetra
.978 .781 .571 r
.67409 .28512 .67496 .27641 .66661 .26763 .66568 .27417 Metetra
.996 .823 .557 r
.66568 .27417 .66661 .26763 .6582 .26069 .65745 .27665 Metetra
.986 .769 .528 r
.65745 .27665 .6582 .26069 .6498 .26054 .64886 .26839 Metetra
.995 .81 .547 r
.64886 .26839 .6498 .26054 .64126 .26051 .64034 .27023 Metetra
1 .81 .505 r
.64034 .27023 .64126 .26051 .63255 .25849 .63185 .28196 Metetra
.997 .776 .476 r
.63185 .28196 .63255 .25849 .62368 .25586 .62337 .30511 Metetra
.997 .769 .433 r
.62337 .30511 .62368 .25586 .6148 .26177 .61565 .39377 Metetra
.979 .74 .503 r
.61565 .39377 .6148 .26177 .60534 .23811 .60489 .2877 Metetra
.982 .748 .507 r
.60489 .2877 .60534 .23811 .59588 .22155 .59515 .25517 Metetra
.984 .754 .51 r
.59515 .25517 .59588 .22155 .58635 .20958 .58551 .2374 Metetra
.979 .752 .524 r
.58551 .2374 .58635 .20958 .5767 .1984 .57565 .20888 Metetra
.979 .777 .563 r
.57565 .20888 .5767 .1984 .56691 .18863 .56581 .19552 Metetra
.984 .807 .585 r
.56581 .19552 .56691 .18863 .55699 .17882 .5559 .18948 Metetra
.982 .781 .558 r
.5559 .18948 .55699 .17882 .54691 .16883 .54579 .17877 Metetra
.975 .776 .572 r
.54579 .17877 .54691 .16883 .53667 .15482 .53552 .16253 Metetra
.989 .809 .568 r
.53552 .16253 .53667 .15482 .52629 .14887 .52513 .15971 Metetra
.987 .787 .55 r
.52513 .15971 .52629 .14887 .51574 .14012 .51456 .15312 Metetra
.98 .772 .552 r
.51456 .15312 .51574 .14012 .50504 .12116 .50382 .13733 Metetra
.982 .768 .538 r
.50382 .13733 .50504 .12116 .49418 .10541 .49293 .12188 Metetra
.936 .815 .699 r
.70731 .31289 .70828 .31006 .70027 .29777 .69933 .30201 Metetra
.967 .814 .639 r
.69933 .30201 .70027 .29777 .69223 .28816 .69131 .2935 Metetra
.972 .803 .613 r
.69131 .2935 .69223 .28816 .6841 .27855 .68318 .28453 Metetra
.977 .801 .599 r
.68318 .28453 .6841 .27855 .67587 .26971 .67496 .27641 Metetra
.978 .795 .59 r
.67496 .27641 .67587 .26971 .66754 .26077 .66661 .26763 Metetra
.982 .799 .583 r
.66661 .26763 .66754 .26077 .65902 .24842 .6582 .26069 Metetra
.992 .785 .526 r
.6582 .26069 .65902 .24842 .6505 .24148 .6498 .26054 Metetra
.991 .771 .51 r
.6498 .26054 .6505 .24148 .64197 .23965 .64126 .26051 Metetra
.989 .768 .51 r
.64126 .26051 .64197 .23965 .63327 .2368 .63255 .25849 Metetra
.989 .767 .509 r
.63255 .25849 .63327 .2368 .62452 .23903 .62368 .25586 Metetra
.994 .779 .505 r
.62368 .25586 .62452 .23903 .61562 .24142 .6148 .26177 Metetra
.978 .756 .534 r
.6148 .26177 .61562 .24142 .60629 .22509 .60534 .23811 Metetra
.978 .768 .552 r
.60534 .23811 .60629 .22509 .59677 .20175 .59588 .22155 Metetra
.985 .764 .524 r
.59588 .22155 .59677 .20175 .58727 .19003 .58635 .20958 Metetra
.985 .765 .523 r
.58635 .20958 .58727 .19003 .57764 .1779 .5767 .1984 Metetra
.986 .765 .52 r
.5767 .1984 .57764 .1779 .5679 .16816 .56691 .18863 Metetra
.986 .765 .52 r
.56691 .18863 .5679 .16816 .55803 .16052 .55699 .17882 Metetra
.986 .768 .525 r
.55699 .17882 .55803 .16052 .548 .15302 .54691 .16883 Metetra
.983 .768 .537 r
.54691 .16883 .548 .15302 .5378 .14412 .53667 .15482 Metetra
.987 .788 .55 r
.53667 .15482 .5378 .14412 .52744 .13434 .52629 .14887 Metetra
.986 .775 .536 r
.52629 .14887 .52744 .13434 .51693 .13698 .51574 .14012 Metetra
.918 .791 .705 r
.51574 .14012 .51693 .13698 .50623 .12075 .50504 .12116 Metetra
.669 .757 .916 r
.50504 .12116 .50623 .12075 .49541 .09593 .49418 .10541 Metetra
.971 .783 .594 r
.70828 .31006 .70914 .30316 .70124 .29453 .70027 .29777 Metetra
.951 .82 .678 r
.70027 .29777 .70124 .29453 .69317 .28338 .69223 .28816 Metetra
.968 .805 .628 r
.69223 .28816 .69317 .28338 .68508 .27511 .6841 .27855 Metetra
.958 .823 .669 r
.6841 .27855 .68508 .27511 .67691 .26811 .67587 .26971 Metetra
.897 .852 .791 r
.67587 .26971 .67691 .26811 .66864 .26178 .66754 .26077 Metetra
0 .209 .728 r
.66754 .26077 .66864 .26178 .66067 .2742 .65902 .24842 Metetra
.986 .726 .446 r
.65902 .24842 .66067 .2742 .65236 .27821 .6505 .24148 Metetra
.985 .731 .46 r
.6505 .24148 .65236 .27821 .64381 .27805 .64197 .23965 Metetra
.985 .731 .46 r
.64197 .23965 .64381 .27805 .63529 .28718 .63327 .2368 Metetra
.985 .734 .467 r
.63327 .2368 .63529 .28718 .62663 .29808 .62452 .23903 Metetra
.985 .735 .469 r
.62452 .23903 .62663 .29808 .61816 .33293 .61562 .24142 Metetra
.988 .74 .466 r
.61562 .24142 .61816 .33293 .60821 .28109 .60629 .22509 Metetra
.989 .739 .455 r
.60629 .22509 .60821 .28109 .59857 .2545 .59677 .20175 Metetra
.987 .736 .46 r
.59677 .20175 .59857 .2545 .58896 .23877 .58727 .19003 Metetra
.987 .735 .458 r
.58727 .19003 .58896 .23877 .57908 .20712 .57764 .1779 Metetra
.986 .728 .447 r
.57764 .1779 .57908 .20712 .56927 .1938 .5679 .16816 Metetra
.986 .725 .445 r
.5679 .16816 .56927 .1938 .55933 .18081 .55803 .16052 Metetra
.985 .719 .436 r
.55803 .16052 .55933 .18081 .54927 .17232 .548 .15302 Metetra
.985 .718 .431 r
.548 .15302 .54927 .17232 .53904 .16004 .5378 .14412 Metetra
.984 .712 .419 r
.5378 .14412 .53904 .16004 .52866 .14771 .52744 .13434 Metetra
.977 .699 .433 r
.52744 .13434 .52866 .14771 .51812 .13977 .51693 .13698 Metetra
.831 .433 0 r
.51693 .13698 .51812 .13977 .50742 .12479 .50623 .12075 Metetra
.857 .514 0 r
.50623 .12075 .50742 .12479 .49657 .11175 .49541 .09593 Metetra
.987 .727 .442 r
.70914 .30316 .71091 .32781 .70282 .31316 .70124 .29453 Metetra
.987 .721 .425 r
.70124 .29453 .70282 .31316 .69475 .30261 .69317 .28338 Metetra
.986 .721 .433 r
.69317 .28338 .69475 .30261 .68672 .29717 .68508 .27511 Metetra
.986 .724 .441 r
.68508 .27511 .68672 .29717 .6785 .28893 .67691 .26811 Metetra
.985 .722 .439 r
.67691 .26811 .6785 .28893 .67025 .28436 .66864 .26178 Metetra
.977 .717 .468 r
.66864 .26178 .67025 .28436 .66205 .28699 .66067 .2742 Metetra
.976 .701 .44 r
.66067 .2742 .66205 .28699 .65351 .28085 .65236 .27821 Metetra
.919 .53 .243 r
.65236 .27821 .65351 .28085 .6452 .29256 .64381 .27805 Metetra
.974 .702 .454 r
.64381 .27805 .6452 .29256 .63645 .28934 .63529 .28718 Metetra
.864 .497 .35 r
.63529 .28718 .63645 .28934 .62776 .29818 .62663 .29808 Metetra
.582 .283 .426 r
.62663 .29808 .62776 .29818 .62106 .44583 .61816 .33293 Metetra
.99 .744 .458 r
.61816 .33293 .62106 .44583 .60971 .3061 .60821 .28109 Metetra
.99 .73 .418 r
.60821 .28109 .60971 .3061 .60004 .27965 .59857 .2545 Metetra
.988 .727 .433 r
.59857 .2545 .60004 .27965 .59018 .24501 .58896 .23877 Metetra
.907 .605 .113 r
.58896 .23877 .59018 .24501 .58034 .21818 .57908 .20712 Metetra
.983 .699 .379 r
.57908 .20712 .58034 .21818 .57048 .19985 .56927 .1938 Metetra
.968 .648 .286 r
.56927 .1938 .57048 .19985 .56054 .18733 .55933 .18081 Metetra
.972 .657 .331 r
.55933 .18081 .56054 .18733 .55047 .17744 .54927 .17232 Metetra
.959 .624 .253 r
.54927 .17232 .55047 .17744 .54022 .16168 .53904 .16004 Metetra
.645 .18 0 r
.53904 .16004 .54022 .16168 .52987 .15837 .52866 .14771 Metetra
.98 .693 .393 r
.52866 .14771 .52987 .15837 .51932 .14824 .51812 .13977 Metetra
.978 .679 .338 r
.51812 .13977 .51932 .14824 .50861 .13749 .50742 .12479 Metetra
.984 .703 .394 r
.50742 .12479 .50861 .13749 .49774 .12351 .49657 .11175 Metetra
.949 .785 .644 r
.71091 .32781 .71184 .32329 .70375 .30844 .70282 .31316 Metetra
.964 .801 .631 r
.70282 .31316 .70375 .30844 .69574 .29946 .69475 .30261 Metetra
.967 .849 .672 r
.69475 .30261 .69574 .29946 .68767 .29232 .68672 .29717 Metetra
.972 .811 .622 r
.68672 .29717 .68767 .29232 .67946 .2843 .6785 .28893 Metetra
.981 .828 .617 r
.6785 .28893 .67946 .2843 .67118 .27736 .67025 .28436 Metetra
.996 .819 .55 r
.67025 .28436 .67118 .27736 .66285 .27394 .66205 .28699 Metetra
.987 .777 .534 r
.66205 .28699 .66285 .27394 .65449 .27505 .65351 .28085 Metetra
.997 .85 .517 r
.65351 .28085 .65449 .27505 .64611 .28235 .6452 .29256 Metetra
.989 .79 .543 r
.6452 .29256 .64611 .28235 .63751 .28633 .63645 .28934 Metetra
.962 .921 .578 r
.63645 .28934 .63751 .28633 .62875 .29008 .62776 .29818 Metetra
.053 0 .409 r
.62776 .29818 .62875 .29008 .62031 .32473 .62106 .44583 Metetra
.976 .736 .51 r
.62106 .44583 .62031 .32473 .61037 .27255 .60971 .3061 Metetra
.982 .751 .515 r
.60971 .3061 .61037 .27255 .60085 .25408 .60004 .27965 Metetra
.975 .749 .532 r
.60004 .27965 .60085 .25408 .59127 .23933 .59018 .24501 Metetra
.934 .756 .638 r
.59018 .24501 .59127 .23933 .58151 .21954 .58034 .21818 Metetra
0 .126 .674 r
.58034 .21818 .58151 .21954 .5716 .19574 .57048 .19985 Metetra
.956 .812 .659 r
.57048 .19985 .5716 .19574 .56173 .19194 .56054 .18733 Metetra
.955 .611 .248 r
.56054 .18733 .56173 .19194 .55163 .1759 .55047 .17744 Metetra
.855 .805 .8 r
.55047 .17744 .55163 .1759 .54139 .15989 .54022 .16168 Metetra
.927 .933 .788 r
.54022 .16168 .54139 .15989 .53103 .15052 .52987 .15837 Metetra
.98 .795 .582 r
.52987 .15837 .53103 .15052 .52051 .14154 .51932 .14824 Metetra
.977 .801 .599 r
.51932 .14824 .52051 .14154 .50982 .12994 .50861 .13749 Metetra
.974 .79 .593 r
.50861 .13749 .50982 .12994 .49897 .11152 .49774 .12351 Metetra
.719 .33 0 r
.71184 .32329 .71297 .32566 .70504 .31632 .70375 .30844 Metetra
.979 .682 .356 r
.70375 .30844 .70504 .31632 .69704 .30827 .69574 .29946 Metetra
.98 .689 .379 r
.69574 .29946 .69704 .30827 .68879 .29441 .68767 .29232 Metetra
.84 .403 0 r
.68767 .29232 .68879 .29441 .68071 .29096 .67946 .2843 Metetra
.974 .667 .346 r
.67946 .2843 .68071 .29096 .67251 .28786 .67118 .27736 Metetra
.979 .696 .409 r
.67118 .27736 .67251 .28786 .66429 .28949 .66285 .27394 Metetra
.98 .71 .441 r
.66285 .27394 .66429 .28949 .65595 .29202 .65449 .27505 Metetra
.977 .71 .454 r
.65449 .27505 .65595 .29202 .64742 .29222 .64611 .28235 Metetra
.972 .687 .427 r
.64611 .28235 .64742 .29222 .63868 .28904 .63751 .28633 Metetra
.913 .537 .299 r
.63751 .28633 .63868 .28904 .63047 .32476 .62875 .29008 Metetra
.974 .719 .485 r
.62875 .29008 .63047 .32476 .62338 .44548 .62031 .32473 Metetra
.99 .744 .459 r
.62031 .32473 .62338 .44548 .61192 .30103 .61037 .27255 Metetra
.989 .73 .435 r
.61037 .27255 .61192 .30103 .60215 .26576 .60085 .25408 Metetra
.984 .702 .379 r
.60085 .25408 .60215 .26576 .59242 .23935 .59127 .23933 Metetra
.56 .636 .883 r
.59127 .23933 .59242 .23935 .58275 .22801 .58151 .21954 Metetra
.973 .677 .286 r
.58151 .21954 .58275 .22801 .57287 .20772 .5716 .19574 Metetra
.98 .699 .413 r
.5716 .19574 .57287 .20772 .56288 .18879 .56173 .19194 Metetra
.928 .802 .701 r
.56173 .19194 .56288 .18879 .5528 .17554 .55163 .1759 Metetra
.662 .74 .908 r
.55163 .1759 .5528 .17554 .54256 .15866 .54139 .15989 Metetra
.855 .879 .855 r
.54139 .15989 .54256 .15866 .53224 .15838 .53103 .15052 Metetra
.976 .673 .354 r
.53103 .15052 .53224 .15838 .52171 .14905 .52051 .14154 Metetra
.975 .668 .335 r
.52051 .14154 .52171 .14905 .51101 .13652 .50982 .12994 Metetra
.967 .651 .268 r
.50982 .12994 .51101 .13652 .50017 .11581 .49897 .11152 Metetra
.949 .823 .685 r
.71297 .32566 .71393 .32259 .70587 .30826 .70504 .31632 Metetra
.982 .789 .57 r
.70504 .31632 .70587 .30826 .69787 .29952 .69704 .30827 Metetra
.974 .776 .576 r
.69704 .30827 .69787 .29952 .68975 .28992 .68879 .29441 Metetra
.984 .834 .616 r
.68879 .29441 .68975 .28992 .6816 .28334 .68071 .29096 Metetra
.989 .802 .562 r
.68071 .29096 .6816 .28334 .67344 .2811 .67251 .28786 Metetra
.995 .82 .556 r
.67251 .28786 .67344 .2811 .66525 .2836 .66429 .28949 Metetra
.996 .833 .564 r
.66429 .28949 .66525 .2836 .65687 .28332 .65595 .29202 Metetra
.993 .802 .544 r
.65595 .29202 .65687 .28332 .64854 .29263 .64742 .29222 Metetra
0 .349 .667 r
.64742 .29222 .64854 .29263 .63984 .29146 .63868 .28904 Metetra
.794 .497 .486 r
.63868 .28904 .63984 .29146 .63115 .29863 .63047 .32476 Metetra
.948 .757 .295 r
.63047 .32476 .63115 .29863 .62316 .36014 .62338 .44548 Metetra
.969 .731 .523 r
.62338 .44548 .62316 .36014 .61276 .2802 .61192 .30103 Metetra
.972 .749 .542 r
.61192 .30103 .61276 .2802 .60317 .25629 .60215 .26576 Metetra
.96 .759 .588 r
.60215 .26576 .60317 .25629 .59356 .23891 .59242 .23935 Metetra
.691 .807 .937 r
.59242 .23935 .59356 .23891 .5837 .20852 .58275 .22801 Metetra
.98 .76 .532 r
.58275 .22801 .5837 .20852 .57398 .20233 .57287 .20772 Metetra
.952 .782 .635 r
.57287 .20772 .57398 .20233 .56403 .1876 .56288 .18879 Metetra
.833 .825 .841 r
.56288 .18879 .56403 .1876 .55398 .17673 .5528 .17554 Metetra
0 .175 .708 r
.5528 .17554 .55398 .17673 .54377 .16538 .54256 .15866 Metetra
.966 .656 .376 r
.54256 .15866 .54377 .16538 .53341 .15514 .53224 .15838 Metetra
.956 .843 .692 r
.53224 .15838 .53341 .15514 .5229 .14485 .52171 .14905 Metetra
.959 .816 .659 r
.52171 .14905 .5229 .14485 .51221 .13302 .51101 .13652 Metetra
.922 .785 .692 r
.51101 .13652 .51221 .13302 .50138 .11488 .50017 .11581 Metetra
.987 .713 .393 r
.71393 .32259 .7154 .33629 .70736 .32318 .70587 .30826 Metetra
.985 .714 .416 r
.70587 .30826 .70736 .32318 .69933 .31349 .69787 .29952 Metetra
.985 .712 .409 r
.69787 .29952 .69933 .31349 .69119 .30372 .68975 .28992 Metetra
.984 .71 .417 r
.68975 .28992 .69119 .30372 .68298 .29505 .6816 .28334 Metetra
.98 .701 .419 r
.6816 .28334 .68298 .29505 .67468 .28757 .67344 .2811 Metetra
.965 .66 .396 r
.67344 .2811 .67468 .28757 .66612 .27353 .66525 .2836 Metetra
.992 .794 .536 r
.66525 .2836 .66612 .27353 .65766 .26901 .65687 .28332 Metetra
.997 .787 .5 r
.65687 .28332 .65766 .26901 .64921 .27118 .64854 .29263 Metetra
.99 .768 .506 r
.64854 .29263 .64921 .27118 .64052 .26826 .63984 .29146 Metetra
.993 .771 .494 r
.63984 .29146 .64052 .26826 .63175 .26905 .63115 .29863 Metetra
.997 .777 .427 r
.63115 .29863 .63175 .26905 .62297 .27801 .62316 .36014 Metetra
.978 .74 .508 r
.62316 .36014 .62297 .27801 .61342 .24788 .61276 .2802 Metetra
.982 .753 .514 r
.61276 .2802 .61342 .24788 .60392 .22738 .60317 .25629 Metetra
.984 .756 .513 r
.60317 .25629 .60392 .22738 .59444 .21655 .59356 .23891 Metetra
.976 .752 .534 r
.59356 .23891 .59444 .21655 .58479 .20224 .5837 .20852 Metetra
.983 .812 .593 r
.5837 .20852 .58479 .20224 .57502 .18948 .57398 .20233 Metetra
.981 .772 .549 r
.57398 .20233 .57502 .18948 .56513 .17877 .56403 .1876 Metetra
.981 .788 .571 r
.56403 .1876 .56513 .17877 .5551 .16945 .55398 .17673 Metetra
.977 .795 .59 r
.55398 .17673 .5551 .16945 .54493 .16104 .54377 .16538 Metetra
.966 .822 .649 r
.54377 .16538 .54493 .16104 .53458 .1505 .53341 .15514 Metetra
.969 .819 .641 r
.53341 .15514 .53458 .1505 .52409 .14656 .5229 .14485 Metetra
.69 .22 0 r
.5229 .14485 .52409 .14656 .51341 .13439 .51221 .13302 Metetra
0 .088 .64 r
.51221 .13302 .51341 .13439 .50259 .10816 .50138 .11488 Metetra
.985 .757 .51 r
.7154 .33629 .71562 .30828 .70774 .2993 .70736 .32318 Metetra
.986 .76 .512 r
.70736 .32318 .70774 .2993 .69976 .29039 .69933 .31349 Metetra
.986 .761 .513 r
.69933 .31349 .69976 .29039 .69161 .27883 .69119 .30372 Metetra
.987 .761 .509 r
.69119 .30372 .69161 .27883 .68345 .27111 .68298 .29505 Metetra
.987 .762 .509 r
.68298 .29505 .68345 .27111 .67515 .26202 .67468 .28757 Metetra
.985 .758 .514 r
.67468 .28757 .67515 .26202 .66684 .25707 .66612 .27353 Metetra
.989 .772 .519 r
.66612 .27353 .66684 .25707 .65835 .24966 .65766 .26901 Metetra
.992 .772 .504 r
.65766 .26901 .65835 .24966 .64986 .24828 .64921 .27118 Metetra
.989 .766 .506 r
.64921 .27118 .64986 .24828 .6413 .2505 .64052 .26826 Metetra
.992 .774 .509 r
.64052 .26826 .6413 .2505 .63249 .24758 .63175 .26905 Metetra
.994 .774 .493 r
.63175 .26905 .63249 .24758 .62358 .24645 .62297 .27801 Metetra
.98 .75 .519 r
.62297 .27801 .62358 .24645 .61439 .23736 .61342 .24788 Metetra
.971 .766 .572 r
.61342 .24788 .61439 .23736 .60496 .22013 .60392 .22738 Metetra
.977 .793 .588 r
.60392 .22738 .60496 .22013 .59541 .20239 .59444 .21655 Metetra
.982 .769 .542 r
.59444 .21655 .59541 .20239 .58575 .18499 .58479 .20224 Metetra
.984 .767 .529 r
.58479 .20224 .58575 .18499 .57605 .17611 .57502 .18948 Metetra
.984 .775 .541 r
.57502 .18948 .57605 .17611 .56623 .17077 .56513 .17877 Metetra
.982 .794 .577 r
.56513 .17877 .56623 .17077 .55626 .16642 .5551 .16945 Metetra
.955 .85 .699 r
.5551 .16945 .55626 .16642 .54609 .15717 .54493 .16104 Metetra
.961 .827 .666 r
.54493 .16104 .54609 .15717 .53578 .15183 .53458 .1505 Metetra
.748 .231 0 r
.53458 .1505 .53578 .15183 .52529 .14978 .52409 .14656 Metetra
.905 .516 .09 r
.52409 .14656 .52529 .14978 .51461 .13135 .51341 .13439 Metetra
.889 .756 .709 r
.51341 .13439 .51461 .13135 .5038 .1087 .50259 .10816 Metetra
.965 .638 .279 r
.71562 .30828 .71683 .31341 .7088 .2991 .70774 .2993 Metetra
.615 .788 .964 r
.70774 .2993 .7088 .2991 .70083 .2903 .69976 .29039 Metetra
.584 .725 .941 r
.69976 .29039 .70083 .2903 .69277 .2821 .69161 .27883 Metetra
.931 .557 .17 r
.69161 .27883 .69277 .2821 .6846 .27398 .68345 .27111 Metetra
.904 .512 .09 r
.68345 .27111 .6846 .27398 .67651 .27309 .67515 .26202 Metetra
.981 .699 .406 r
.67515 .26202 .67651 .27309 .66849 .28124 .66684 .25707 Metetra
.986 .725 .441 r
.66684 .25707 .66849 .28124 .66042 .29449 .65835 .24966 Metetra
.986 .733 .461 r
.65835 .24966 .66042 .29449 .65191 .29416 .64986 .24828 Metetra
.985 .733 .464 r
.64986 .24828 .65191 .29416 .64321 .29173 .6413 .2505 Metetra
.986 .732 .459 r
.6413 .2505 .64321 .29173 .63461 .30292 .63249 .24758 Metetra
.986 .735 .464 r
.63249 .24758 .63461 .30292 .62648 .35277 .62358 .24645 Metetra
.987 .74 .467 r
.62358 .24645 .62648 .35277 .61617 .27952 .61439 .23736 Metetra
.988 .735 .449 r
.61439 .23736 .61617 .27952 .60673 .26525 .60496 .22013 Metetra
.989 .736 .45 r
.60496 .22013 .60673 .26525 .59708 .2439 .59541 .20239 Metetra
.988 .735 .448 r
.59541 .20239 .59708 .2439 .58742 .23154 .58575 .18499 Metetra
.987 .734 .457 r
.58575 .18499 .58742 .23154 .57757 .2138 .57605 .17611 Metetra
.986 .731 .455 r
.57605 .17611 .57757 .2138 .56754 .18872 .56623 .17077 Metetra
.983 .714 .432 r
.56623 .17077 .56754 .18872 .5575 .17644 .55626 .16642 Metetra
.98 .69 .38 r
.55626 .16642 .5575 .17644 .54731 .1653 .54609 .15717 Metetra
.975 .674 .373 r
.54609 .15717 .54731 .1653 .537 .16143 .53578 .15183 Metetra
.976 .683 .399 r
.53578 .15183 .537 .16143 .52649 .1512 .52529 .14978 Metetra
0 .073 .629 r
.52529 .14978 .52649 .1512 .51581 .13445 .51461 .13135 Metetra
.767 .403 0 r
.51461 .13135 .51581 .13445 .505 .11387 .5038 .1087 Metetra
.985 .706 .378 r
.71683 .31341 .71825 .32536 .71035 .31606 .7088 .2991 Metetra
.986 .718 .422 r
.7088 .2991 .71035 .31606 .70214 .29897 .70083 .2903 Metetra
.98 .687 .37 r
.70083 .2903 .70214 .29897 .69413 .29283 .69277 .2821 Metetra
.983 .699 .392 r
.69277 .2821 .69413 .29283 .6861 .29007 .6846 .27398 Metetra
.982 .712 .437 r
.6846 .27398 .6861 .29007 .67787 .28424 .67651 .27309 Metetra
.971 .692 .444 r
.67651 .27309 .67787 .28424 .66962 .28269 .66849 .28124 Metetra
.803 .428 .346 r
.66849 .28124 .66962 .28269 .6612 .27976 .66042 .29449 Metetra
.992 .779 .517 r
.66042 .29449 .6612 .27976 .65274 .28071 .65191 .29416 Metetra
.991 .781 .525 r
.65191 .29416 .65274 .28071 .64418 .2842 .64321 .29173 Metetra
1 .828 .512 r
.64321 .29173 .64418 .2842 .63548 .28867 .63461 .30292 Metetra
.979 .794 .382 r
.63461 .30292 .63548 .28867 .62701 .31611 .62648 .35277 Metetra
.967 .735 .536 r
.62648 .35277 .62701 .31611 .61732 .27957 .61617 .27952 Metetra
.515 .676 .938 r
.61617 .27952 .61732 .27957 .60784 .26226 .60673 .26525 Metetra
.901 .769 .706 r
.60673 .26525 .60784 .26226 .59805 .23017 .59708 .2439 Metetra
.983 .772 .541 r
.59708 .2439 .59805 .23017 .58855 .22927 .58742 .23154 Metetra
.89 .79 .744 r
.58742 .23154 .58855 .22927 .57873 .21287 .57757 .2138 Metetra
.747 .696 .803 r
.57757 .2138 .57873 .21287 .56876 .19522 .56754 .18872 Metetra
.971 .655 .302 r
.56754 .18872 .56876 .19522 .55872 .18436 .5575 .17644 Metetra
.977 .674 .343 r
.5575 .17644 .55872 .18436 .54849 .16525 .54731 .1653 Metetra
.278 .751 .939 r
.54731 .1653 .54849 .16525 .53817 .15755 .537 .16143 Metetra
.962 .829 .665 r
.537 .16143 .53817 .15755 .52768 .14753 .52649 .1512 Metetra
.939 .802 .683 r
.52649 .1512 .52768 .14753 .51702 .13504 .51581 .13445 Metetra
.288 .487 .878 r
.51581 .13445 .51702 .13504 .5062 .12027 .505 .11387 Metetra
.66 .195 0 r
.71825 .32536 .71936 .32691 .71142 .31605 .71035 .31606 Metetra
.587 .646 .876 r
.71035 .31606 .71142 .31605 .70341 .30622 .70214 .29897 Metetra
.976 .674 .359 r
.70214 .29897 .70341 .30622 .69533 .29732 .69413 .29283 Metetra
.959 .623 .316 r
.69413 .29283 .69533 .29732 .68719 .29054 .6861 .29007 Metetra
0 .421 .81 r
.6861 .29007 .68719 .29054 .67901 .28659 .67787 .28424 Metetra
.908 .501 .188 r
.67787 .28424 .67901 .28659 .67078 .28553 .66962 .28269 Metetra
.926 .539 .212 r
.66962 .28269 .67078 .28553 .6624 .28393 .6612 .27976 Metetra
.95 .61 .335 r
.6612 .27976 .6624 .28393 .6546 .31662 .65274 .28071 Metetra
.984 .729 .461 r
.65274 .28071 .6546 .31662 .64658 .34956 .64418 .2842 Metetra
.986 .736 .468 r
.64418 .2842 .64658 .34956 .63868 .40196 .63548 .28867 Metetra
.985 .737 .476 r
.63548 .28867 .63868 .40196 .63033 .44441 .62701 .31611 Metetra
.989 .743 .462 r
.62701 .31611 .63033 .44441 .62091 .43661 .61732 .27957 Metetra
.988 .742 .468 r
.61732 .27957 .62091 .43661 .6111 .41047 .60784 .26226 Metetra
.989 .743 .465 r
.60784 .26226 .6111 .41047 .59994 .2873 .59805 .23017 Metetra
.986 .735 .463 r
.59805 .23017 .59994 .2873 .58997 .25215 .58855 .22927 Metetra
.988 .725 .425 r
.58855 .22927 .58997 .25215 .58003 .22716 .57873 .21287 Metetra
.986 .711 .389 r
.57873 .21287 .58003 .22716 .57006 .20961 .56876 .19522 Metetra
.985 .709 .406 r
.56876 .19522 .57006 .20961 .55992 .18667 .55872 .18436 Metetra
.648 .26 0 r
.55872 .18436 .55992 .18667 .54969 .16843 .54849 .16525 Metetra
.922 .534 .159 r
.54849 .16525 .54969 .16843 .53939 .1648 .53817 .15755 Metetra
.974 .665 .334 r
.53817 .15755 .53939 .1648 .52889 .15582 .52768 .14753 Metetra
.977 .676 .342 r
.52768 .14753 .52889 .15582 .51822 .13638 .51702 .13504 Metetra
0 .024 .565 r
.51702 .13504 .51822 .13638 .50741 .12018 .5062 .12027 Metetra
.216 .521 .916 r
.71936 .32691 .72044 .32739 .71247 .31565 .71142 .31605 Metetra
.694 .801 .932 r
.71142 .31605 .71247 .31565 .70453 .30778 .70341 .30622 Metetra
.685 .214 0 r
.70341 .30622 .70453 .30778 .69643 .29826 .69533 .29732 Metetra
.469 0 0 r
.69533 .29732 .69643 .29826 .68826 .28996 .68719 .29054 Metetra
.723 .934 .958 r
.68719 .29054 .68826 .28996 .68002 .28327 .67901 .28659 Metetra
.983 .874 .647 r
.67901 .28659 .68002 .28327 .67185 .28455 .67078 .28553 Metetra
.83 .981 .881 r
.67078 .28553 .67185 .28455 .66339 .27875 .6624 .28393 Metetra
.82 .766 .255 r
.6624 .28393 .66339 .27875 .65514 .2892 .6546 .31662 Metetra
.997 .774 .459 r
.6546 .31662 .65514 .2892 .64645 .28581 .64658 .34956 Metetra
.995 .76 .46 r
.64658 .34956 .64645 .28581 .63777 .2902 .63868 .40196 Metetra
.991 .753 .47 r
.63868 .40196 .63777 .2902 .62997 .35566 .63033 .44441 Metetra
.988 .75 .484 r
.63033 .44441 .62997 .35566 .61946 .27072 .62091 .43661 Metetra
.987 .746 .483 r
.62091 .43661 .61946 .27072 .61013 .26184 .6111 .41047 Metetra
.98 .739 .5 r
.6111 .41047 .61013 .26184 .60038 .23201 .59994 .2873 Metetra
.983 .748 .502 r
.59994 .2873 .60038 .23201 .59076 .22014 .58997 .25215 Metetra
.983 .753 .513 r
.58997 .25215 .59076 .22014 .58103 .21084 .58003 .22716 Metetra
.981 .765 .537 r
.58003 .22716 .58103 .21084 .57111 .19564 .57006 .20961 Metetra
.975 .762 .553 r
.57006 .20961 .57111 .19564 .56106 .18164 .55992 .18667 Metetra
.951 .787 .642 r
.55992 .18667 .56106 .18164 .55085 .16471 .54969 .16843 Metetra
.979 .862 .654 r
.54969 .16843 .55085 .16471 .54055 .15788 .53939 .1648 Metetra
.981 .804 .59 r
.53939 .1648 .54055 .15788 .53007 .14799 .52889 .15582 Metetra
.967 .778 .596 r
.52889 .15582 .53007 .14799 .51942 .13447 .51822 .13638 Metetra
.881 .813 .777 r
.51822 .13638 .51942 .13447 .50862 .11831 .50741 .12018 Metetra
.941 .808 .684 r
.72044 .32739 .7214 .32422 .71341 .31135 .71247 .31565 Metetra
.971 .818 .634 r
.71247 .31565 .71341 .31135 .70533 .29845 .70453 .30778 Metetra
.982 .782 .56 r
.70453 .30778 .70533 .29845 .6971 .28333 .69643 .29826 Metetra
.986 .771 .528 r
.69643 .29826 .6971 .28333 .68909 .28031 .68826 .28996 Metetra
.986 .786 .551 r
.68826 .28996 .68909 .28031 .68089 .27433 .68002 .28327 Metetra
.995 .802 .536 r
.68002 .28327 .68089 .27433 .67282 .2791 .67185 .28455 Metetra
.982 .816 .602 r
.67185 .28455 .67282 .2791 .66445 .27674 .66339 .27875 Metetra
.819 .917 .525 r
.66339 .27875 .66445 .27674 .65623 .28803 .65514 .2892 Metetra
.872 .951 .859 r
.65514 .2892 .65623 .28803 .64748 .28143 .64645 .28581 Metetra
.995 .868 .584 r
.64645 .28581 .64748 .28143 .63873 .28137 .63777 .2902 Metetra
.756 .675 .125 r
.63777 .2902 .63873 .28137 .62995 .28856 .62997 .35566 Metetra
.975 .738 .514 r
.62997 .35566 .62995 .28856 .62048 .26271 .61946 .27072 Metetra
.982 .793 .574 r
.61946 .27072 .62048 .26271 .61099 .24271 .61013 .26184 Metetra
.975 .753 .541 r
.61013 .26184 .61099 .24271 .60139 .22117 .60038 .23201 Metetra
.982 .779 .555 r
.60038 .23201 .60139 .22117 .59174 .20475 .59076 .22014 Metetra
.987 .772 .53 r
.59076 .22014 .59174 .20475 .58204 .19512 .58103 .21084 Metetra
.983 .767 .536 r
.58103 .21084 .58204 .19512 .57218 .18461 .57111 .19564 Metetra
.98 .777 .558 r
.57111 .19564 .57218 .18461 .56212 .16642 .56106 .18164 Metetra
.981 .767 .54 r
.56106 .18164 .56212 .16642 .55197 .15416 .55085 .16471 Metetra
.987 .788 .549 r
.55085 .16471 .55197 .15416 .54173 .15541 .54055 .15788 Metetra
.936 .855 .737 r
.54055 .15788 .54173 .15541 .53125 .14245 .53007 .14799 Metetra
.968 .802 .624 r
.53007 .14799 .53125 .14245 .52062 .12847 .51942 .13447 Metetra
.965 .793 .619 r
.51942 .13447 .52062 .12847 .50983 .11706 .50862 .11831 Metetra
.951 .796 .652 r
.7214 .32422 .72233 .32012 .71434 .30667 .71341 .31135 Metetra
.958 .794 .636 r
.71341 .31135 .71434 .30667 .70641 .29871 .70533 .29845 Metetra
.458 .601 .906 r
.70533 .29845 .70641 .29871 .69838 .2906 .6971 .28333 Metetra
.974 .673 .376 r
.6971 .28333 .69838 .2906 .69023 .28233 .68909 .28031 Metetra
.857 .415 .007 r
.68909 .28031 .69023 .28233 .68197 .27395 .68089 .27433 Metetra
.68089 .27433 .68197 .27395 .67373 .27122 .67282 .2791 Metetra
.991 .803 .556 r
.67282 .2791 .67373 .27122 .66536 .26823 .66445 .27674 Metetra
1 .818 .504 r
.66445 .27674 .66536 .26823 .65684 .26445 .65623 .28803 Metetra
.988 .764 .507 r
.65623 .28803 .65684 .26445 .64826 .2644 .64748 .28143 Metetra
.992 .775 .51 r
.64748 .28143 .64826 .2644 .63943 .25832 .63873 .28137 Metetra
.994 .771 .492 r
.63873 .28137 .63943 .25832 .63051 .25505 .62995 .28856 Metetra
.982 .752 .512 r
.62995 .28856 .63051 .25505 .62126 .24053 .62048 .26271 Metetra
.982 .758 .524 r
.62048 .26271 .62126 .24053 .61187 .22416 .61099 .24271 Metetra
.98 .759 .534 r
.61099 .24271 .61187 .22416 .60234 .20638 .60139 .22117 Metetra
.981 .767 .541 r
.60139 .22117 .60234 .20638 .5928 .1969 .59174 .20475 Metetra
.981 .794 .577 r
.59174 .20475 .5928 .1969 .5831 .18548 .58204 .19512 Metetra
.983 .785 .562 r
.58204 .19512 .5831 .18548 .57327 .17547 .57218 .18461 Metetra
.972 .775 .579 r
.57218 .18461 .57327 .17547 .56329 .16551 .56212 .16642 Metetra
.796 .834 .88 r
.56212 .16642 .56329 .16551 .55316 .15558 .55197 .15416 Metetra
.809 .33 .069 r
.55197 .15416 .55316 .15558 .5429 .15108 .54173 .15541 Metetra
.96 .813 .654 r
.54173 .15541 .5429 .15108 .53243 .13684 .53125 .14245 Metetra
.967 .801 .623 r
.53125 .14245 .53243 .13684 .52182 .13032 .52062 .12847 Metetra
.739 .274 0 r
.52062 .12847 .52182 .13032 .51104 .11552 .50983 .11706 Metetra
.981 .767 .539 r
.72233 .32012 .72296 .30611 .71512 .29713 .71434 .30667 Metetra
.984 .784 .554 r
.71434 .30667 .71512 .29713 .70715 .28708 .70641 .29871 Metetra
.985 .778 .541 r
.70641 .29871 .70715 .28708 .69895 .27242 .69838 .2906 Metetra
.987 .767 .518 r
.69838 .2906 .69895 .27242 .69062 .25637 .69023 .28233 Metetra
.988 .76 .506 r
.69023 .28233 .69062 .25637 .68235 .24601 .68197 .27395 Metetra
.99 .762 .498 r
.68197 .27395 .68235 .24601 .67425 .24731 .67373 .27122 Metetra
.99 .765 .502 r
.67373 .27122 .67425 .24731 .66598 .24698 .66536 .26823 Metetra
.99 .767 .507 r
.66536 .26823 .66598 .24698 .65755 .24607 .65684 .26445 Metetra
.992 .773 .507 r
.65684 .26445 .65755 .24607 .64907 .24911 .64826 .2644 Metetra
.988 .774 .524 r
.64826 .2644 .64907 .24911 .64025 .24253 .63943 .25832 Metetra
.99 .775 .518 r
.63943 .25832 .64025 .24253 .63141 .24224 .63051 .25505 Metetra
.981 .771 .547 r
.63051 .25505 .63141 .24224 .62219 .22771 .62126 .24053 Metetra
.979 .769 .55 r
.62126 .24053 .62219 .22771 .61284 .21292 .61187 .22416 Metetra
.976 .77 .561 r
.61187 .22416 .61284 .21292 .60335 .19587 .60234 .20638 Metetra
.985 .783 .553 r
.60234 .20638 .60335 .19587 .5938 .18383 .5928 .1969 Metetra
.984 .775 .541 r
.5928 .1969 .5938 .18383 .58414 .17422 .5831 .18548 Metetra
.985 .781 .549 r
.5831 .18548 .58414 .17422 .57436 .16684 .57327 .17547 Metetra
.983 .791 .57 r
.57327 .17547 .57436 .16684 .56445 .16347 .56329 .16551 Metetra
.918 .86 .768 r
.56329 .16551 .56445 .16347 .55434 .15466 .55316 .15558 Metetra
.806 .951 .914 r
.55316 .15558 .55434 .15466 .54408 .14972 .5429 .15108 Metetra
.846 .824 .826 r
.5429 .15108 .54408 .14972 .53364 .13911 .53243 .13684 Metetra
.87 .431 .044 r
.53243 .13684 .53364 .13911 .52302 .12535 .52182 .13032 Metetra
.961 .803 .64 r
.52182 .13032 .52302 .12535 .51225 .10164 .51104 .11552 Metetra
.982 .695 .376 r
.72296 .30611 .72432 .31585 .71646 .30619 .71512 .29713 Metetra
.981 .69 .363 r
.71512 .29713 .71646 .30619 .70852 .29744 .70715 .28708 Metetra
.983 .698 .358 r
.70715 .28708 .70852 .29744 .70051 .28992 .69895 .27242 Metetra
.988 .72 .405 r
.69895 .27242 .70051 .28992 .69235 .28078 .69062 .25637 Metetra
.987 .726 .435 r
.69062 .25637 .69235 .28078 .68415 .274 .68235 .24601 Metetra
.984 .725 .453 r
.68235 .24601 .68415 .274 .6763 .28667 .67425 .24731 Metetra
.986 .731 .458 r
.67425 .24731 .6763 .28667 .66851 .30942 .66598 .24698 Metetra
.987 .736 .463 r
.66598 .24698 .66851 .30942 .65984 .30038 .65755 .24607 Metetra
.986 .734 .464 r
.65755 .24607 .65984 .30038 .65105 .29143 .64907 .24911 Metetra
.987 .733 .454 r
.64907 .24911 .65105 .29143 .64288 .32097 .64025 .24253 Metetra
.987 .738 .465 r
.64025 .24253 .64288 .32097 .63496 .37756 .63141 .24224 Metetra
.988 .742 .466 r
.63141 .24224 .63496 .37756 .62458 .30364 .62219 .22771 Metetra
.988 .739 .459 r
.62219 .22771 .62458 .30364 .61523 .29522 .61284 .21292 Metetra
.989 .74 .46 r
.61284 .21292 .61523 .29522 .60532 .25604 .60335 .19587 Metetra
.988 .737 .457 r
.60335 .19587 .60532 .25604 .59563 .23946 .5938 .18383 Metetra
.988 .736 .457 r
.5938 .18383 .59563 .23946 .58571 .21234 .58414 .17422 Metetra
.987 .731 .451 r
.58414 .17422 .58571 .21234 .57582 .19841 .57436 .16684 Metetra
.986 .727 .45 r
.57436 .16684 .57582 .19841 .56576 .18126 .56445 .16347 Metetra
.985 .715 .421 r
.56445 .16347 .56576 .18126 .55558 .16383 .55434 .15466 Metetra
.977 .682 .383 r
.55434 .15466 .55558 .16383 .54536 .16769 .54408 .14972 Metetra
.986 .716 .419 r
.54408 .14972 .54536 .16769 .53488 .15232 .53364 .13911 Metetra
.984 .705 .39 r
.53364 .13911 .53488 .15232 .52423 .12895 .52302 .12535 Metetra
.818 .465 0 r
.52302 .12535 .52423 .12895 .51346 .11205 .51225 .10164 Metetra
.977 .673 .332 r
.72432 .31585 .72561 .32305 .71776 .31402 .71646 .30619 Metetra
.978 .68 .351 r
.71646 .30619 .71776 .31402 .70978 .30383 .70852 .29744 Metetra
.973 .662 .329 r
.70852 .29744 .70978 .30383 .70167 .29273 .70051 .28992 Metetra
.896 .5 .069 r
.70051 .28992 .70167 .29273 .69362 .2875 .69235 .28078 Metetra
.974 .666 .342 r
.69235 .28078 .69362 .2875 .68546 .28268 .68415 .274 Metetra
.96 .673 .447 r
.68415 .274 .68546 .28268 .67714 .27586 .6763 .28667 Metetra
.997 .808 .455 r
.6763 .28667 .67714 .27586 .66906 .28506 .66851 .30942 Metetra
.988 .762 .508 r
.66851 .30942 .66906 .28506 .66039 .27444 .65984 .30038 Metetra
.988 .761 .506 r
.65984 .30038 .66039 .27444 .65197 .28131 .65105 .29143 Metetra
.989 .813 .426 r
.65105 .29143 .65197 .28131 .64318 .27794 .64288 .32097 Metetra
.997 .768 .446 r
.64288 .32097 .64318 .27794 .63481 .30552 .63496 .37756 Metetra
.979 .741 .507 r
.63496 .37756 .63481 .30552 .625 .26038 .62458 .30364 Metetra
.988 .755 .493 r
.62458 .30364 .625 .26038 .61571 .25132 .61523 .29522 Metetra
.981 .747 .509 r
.61523 .29522 .61571 .25132 .60621 .2367 .60532 .25604 Metetra
.983 .763 .526 r
.60532 .25604 .60621 .2367 .59657 .22163 .59563 .23946 Metetra
.976 .756 .541 r
.59563 .23946 .59657 .22163 .58677 .20221 .58571 .21234 Metetra
.98 .779 .563 r
.58571 .21234 .58677 .20221 .57693 .19224 .57582 .19841 Metetra
.963 .786 .616 r
.57582 .19841 .57693 .19224 .56688 .17411 .56576 .18126 Metetra
.968 .783 .601 r
.56576 .18126 .56688 .17411 .55676 .16323 .55558 .16383 Metetra
.402 .841 .717 r
.55558 .16383 .55676 .16323 .54654 .16414 .54536 .16769 Metetra
.941 .809 .685 r
.54536 .16769 .54654 .16414 .53604 .14318 .53488 .15232 Metetra
.966 .769 .586 r
.53488 .15232 .53604 .14318 .52543 .12426 .52423 .12895 Metetra
.954 .798 .65 r
.52423 .12895 .52543 .12426 .51467 .11147 .51346 .11205 Metetra
.973 .805 .615 r
.72561 .32305 .72651 .31792 .71851 .30336 .71776 .31402 Metetra
.983 .777 .55 r
.71776 .31402 .71851 .30336 .7106 .29531 .70978 .30383 Metetra
.979 .782 .57 r
.70978 .30383 .7106 .29531 .70258 .28677 .70167 .29273 Metetra
.985 .811 .588 r
.70167 .29273 .70258 .28677 .69447 .27888 .69362 .2875 Metetra
.988 .794 .554 r
.69362 .2875 .69447 .27888 .68637 .27541 .68546 .28268 Metetra
.984 .798 .574 r
.68546 .28268 .68637 .27541 .67841 .28291 .67714 .27586 Metetra
.958 .66 .426 r
.67714 .27586 .67841 .28291 .67021 .28689 .66906 .28506 Metetra
.721 .271 0 r
.66906 .28506 .67021 .28689 .66156 .27705 .66039 .27444 Metetra
.901 .532 .328 r
.66039 .27444 .66156 .27705 .65308 .28107 .65197 .28131 Metetra
.485 .865 .979 r
.65197 .28131 .65308 .28107 .64439 .28225 .64318 .27794 Metetra
.884 .582 .471 r
.64318 .27794 .64439 .28225 .63604 .31008 .63481 .30552 Metetra
0 0 .327 r
.63481 .30552 .63604 .31008 .62615 .26076 .625 .26038 Metetra
.148 .552 .926 r
.625 .26038 .62615 .26076 .61686 .25119 .61571 .25132 Metetra
.593 .714 .928 r
.61571 .25132 .61686 .25119 .60714 .22097 .60621 .2367 Metetra
.983 .767 .535 r
.60621 .2367 .60714 .22097 .5975 .2028 .59657 .22163 Metetra
.982 .761 .53 r
.59657 .22163 .5975 .2028 .58781 .19149 .58677 .20221 Metetra
.985 .783 .552 r
.58677 .20221 .58781 .19149 .57801 .18286 .57693 .19224 Metetra
.973 .775 .576 r
.57693 .19224 .57801 .18286 .56806 .17351 .56688 .17411 Metetra
.73 .838 .931 r
.56688 .17411 .56806 .17351 .55793 .16165 .55676 .16323 Metetra
.901 .983 .786 r
.55676 .16323 .55793 .16165 .54776 .1697 .54654 .16414 Metetra
.943 .616 .184 r
.54654 .16414 .54776 .1697 .53725 .1465 .53604 .14318 Metetra
.848 .473 0 r
.53604 .14318 .53725 .1465 .52663 .12641 .52543 .12426 Metetra
.775 .333 0 r
.52543 .12426 .52663 .12641 .51588 .11404 .51467 .11147 Metetra
.977 .679 .315 r
.72651 .31792 .72783 .32593 .71991 .31444 .71851 .30336 Metetra
.983 .701 .391 r
.71851 .30336 .71991 .31444 .71194 .30442 .7106 .29531 Metetra
.981 .69 .369 r
.7106 .29531 .71194 .30442 .70389 .29494 .70258 .28677 Metetra
.979 .682 .36 r
.70258 .28677 .70389 .29494 .6958 .2878 .69447 .27888 Metetra
.978 .686 .39 r
.69447 .27888 .6958 .2878 .68766 .28337 .68637 .27541 Metetra
.964 .671 .426 r
.68637 .27541 .68766 .28337 .67958 .28571 .67841 .28291 Metetra
.917 .546 .308 r
.67841 .28291 .67958 .28571 .67136 .28848 .67021 .28689 Metetra
.666 .197 0 r
.67021 .28689 .67136 .28848 .66273 .27941 .66156 .27705 Metetra
.899 .51 .276 r
.66156 .27705 .66273 .27941 .65416 .27871 .65308 .28107 Metetra
.966 .932 .694 r
.65308 .28107 .65416 .27871 .64547 .27947 .64439 .28225 Metetra
.64439 .28225 .64547 .27947 .63726 .31427 .63604 .31008 Metetra
0 0 .439 r
.63604 .31008 .63726 .31427 .62736 .26452 .62615 .26076 Metetra
.937 .571 .18 r
.62615 .26076 .62736 .26452 .61796 .24828 .61686 .25119 Metetra
.865 .725 .705 r
.61686 .25119 .61796 .24828 .60851 .23615 .60714 .22097 Metetra
.987 .713 .389 r
.60714 .22097 .60851 .23615 .59889 .2214 .5975 .2028 Metetra
.986 .718 .418 r
.5975 .2028 .59889 .2214 .58908 .20023 .58781 .19149 Metetra
.978 .681 .363 r
.58781 .19149 .58908 .20023 .57923 .18784 .57801 .18286 Metetra
.959 .62 .263 r
.57801 .18286 .57923 .18784 .56924 .17363 .56806 .17351 Metetra
.423 .685 .972 r
.56806 .17351 .56924 .17363 .55913 .16416 .55793 .16165 Metetra
.887 .505 .307 r
.55793 .16165 .55913 .16416 .549 .1782 .54776 .1697 Metetra
.973 .674 .287 r
.54776 .1697 .549 .1782 .53847 .15174 .53725 .1465 Metetra
.939 .606 .172 r
.53725 .1465 .53847 .15174 .52785 .13188 .52663 .12641 Metetra
.961 .628 .259 r
.52663 .12641 .52785 .13188 .5171 .11834 .51588 .11404 Metetra
.954 .805 .657 r
.72783 .32593 .72877 .32209 .72086 .31041 .71991 .31444 Metetra
.962 .812 .648 r
.71991 .31444 .72086 .31041 .71272 .29423 .71194 .30442 Metetra
.983 .78 .552 r
.71194 .30442 .71272 .29423 .70459 .28166 .70389 .29494 Metetra
.987 .775 .53 r
.70389 .29494 .70459 .28166 .69661 .27783 .6958 .2878 Metetra
.989 .789 .542 r
.6958 .2878 .69661 .27783 .68866 .27963 .68766 .28337 Metetra
.991 .877 .608 r
.68766 .28337 .68866 .27963 .68056 .28118 .67958 .28571 Metetra
.995 .859 .584 r
.67958 .28571 .68056 .28118 .6722 .2772 .67136 .28848 Metetra
.985 .779 .545 r
.67136 .28848 .6722 .2772 .66389 .28123 .66273 .27941 Metetra
.866 .421 .118 r
.66273 .27941 .66389 .28123 .65523 .27626 .65416 .27871 Metetra
.969 .925 .69 r
.65416 .27871 .65523 .27626 .64651 .27494 .64547 .27947 Metetra
.706 .705 .174 r
.64547 .27947 .64651 .27494 .63835 .31129 .63726 .31427 Metetra
.809 .654 .691 r
.63726 .31427 .63835 .31129 .62838 .25713 .62736 .26452 Metetra
.97 .781 .594 r
.62736 .26452 .62838 .25713 .6189 .23483 .61796 .24828 Metetra
.984 .773 .539 r
.61796 .24828 .6189 .23483 .60928 .20913 .60851 .23615 Metetra
.986 .759 .509 r
.60851 .23615 .60928 .20913 .59973 .19627 .59889 .2214 Metetra
.983 .757 .517 r
.59889 .2214 .59973 .19627 .59008 .18645 .58908 .20023 Metetra
.984 .773 .538 r
.58908 .20023 .59008 .18645 .5803 .17684 .57923 .18784 Metetra
.981 .777 .557 r
.57923 .18784 .5803 .17684 .57039 .17108 .56924 .17363 Metetra
.94 .855 .73 r
.56924 .17363 .57039 .17108 .56031 .16295 .55913 .16416 Metetra
.55913 .16416 .56031 .16295 .55007 .15599 .549 .1782 Metetra
.98 .756 .527 r
.549 .1782 .55007 .15599 .53963 .14136 .53847 .15174 Metetra
.974 .773 .57 r
.53847 .15174 .53963 .14136 .52905 .12665 .52785 .13188 Metetra
.967 .806 .631 r
.52785 .13188 .52905 .12665 .51831 .11457 .5171 .11834 Metetra
0 0 .535 r
.72877 .32209 .72988 .32347 .72179 .3062 .72086 .31041 Metetra
.942 .782 .654 r
.72086 .31041 .72179 .3062 .71363 .28874 .71272 .29423 Metetra
.966 .792 .616 r
.71272 .29423 .71363 .28874 .70562 .27989 .70459 .28166 Metetra
.936 .912 .77 r
.70459 .28166 .70562 .27989 .69753 .27155 .69661 .27783 Metetra
.996 .826 .556 r
.69661 .27783 .69753 .27155 .6893 .26254 .68866 .27963 Metetra
.993 .776 .504 r
.68866 .27963 .6893 .26254 .68107 .25742 .68056 .28118 Metetra
.99 .765 .502 r
.68056 .28118 .68107 .25742 .67271 .25229 .6722 .2772 Metetra
.993 .767 .491 r
.6722 .2772 .67271 .25229 .66441 .25515 .66389 .28123 Metetra
.989 .763 .5 r
.66389 .28123 .66441 .25515 .65588 .25432 .65523 .27626 Metetra
.991 .768 .502 r
.65523 .27626 .65588 .25432 .64717 .2514 .64651 .27494 Metetra
.998 .78 .448 r
.64651 .27494 .64717 .2514 .63831 .24792 .63835 .31129 Metetra
.981 .744 .503 r
.63835 .31129 .63831 .24792 .62911 .23343 .62838 .25713 Metetra
.982 .756 .521 r
.62838 .25713 .62911 .23343 .61982 .22053 .6189 .23483 Metetra
.973 .758 .553 r
.6189 .23483 .61982 .22053 .61039 .20679 .60928 .20913 Metetra
.917 .826 .74 r
.60928 .20913 .61039 .20679 .60087 .19495 .59973 .19627 Metetra
.867 .867 .836 r
.59973 .19627 .60087 .19495 .59115 .17835 .59008 .18645 Metetra
.983 .794 .573 r
.59008 .18645 .59115 .17835 .58144 .17443 .5803 .17684 Metetra
.951 .886 .731 r
.5803 .17684 .58144 .17443 .57152 .16534 .57039 .17108 Metetra
.98 .815 .606 r
.57039 .17108 .57152 .16534 .56145 .15611 .56031 .16295 Metetra
.985 .809 .585 r
.56031 .16295 .56145 .15611 .55125 .15301 .55007 .15599 Metetra
.932 .818 .71 r
.55007 .15599 .55125 .15301 .54083 .13986 .53963 .14136 Metetra
.858 .823 .813 r
.53963 .14136 .54083 .13986 .53025 .12587 .52905 .12665 Metetra
.768 .841 .907 r
.52905 .12665 .53025 .12587 .51951 .1027 .51831 .11457 Metetra
.981 .76 .531 r
.72988 .32347 .73038 .30611 .72238 .29056 .72179 .3062 Metetra
.98 .762 .537 r
.72179 .3062 .72238 .29056 .71459 .28516 .71363 .28874 Metetra
.961 .823 .661 r
.71363 .28874 .71459 .28516 .7066 .27629 .70562 .27989 Metetra
.964 .827 .66 r
.70562 .27989 .7066 .27629 .69851 .26781 .69753 .27155 Metetra
.963 .822 .656 r
.69753 .27155 .69851 .26781 .69034 .2603 .6893 .26254 Metetra
.951 .882 .73 r
.6893 .26254 .69034 .2603 .68185 .24484 .68107 .25742 Metetra
.989 .78 .529 r
.68107 .25742 .68185 .24484 .67358 .24226 .67271 .25229 Metetra
.996 .799 .523 r
.67271 .25229 .67358 .24226 .66512 .23728 .66441 .25515 Metetra
.992 .773 .507 r
.66441 .25515 .66512 .23728 .65662 .23651 .65588 .25432 Metetra
.991 .772 .51 r
.65588 .25432 .65662 .23651 .6481 .24155 .64717 .2514 Metetra
.991 .793 .542 r
.64717 .2514 .6481 .24155 .63936 .24357 .63831 .24792 Metetra
.954 .799 .651 r
.63831 .24792 .63936 .24357 .63013 .22647 .62911 .23343 Metetra
.974 .791 .594 r
.62911 .23343 .63013 .22647 .62069 .20369 .61982 .22053 Metetra
.985 .767 .528 r
.61982 .22053 .62069 .20369 .61124 .1863 .61039 .20679 Metetra
.987 .765 .516 r
.61039 .20679 .61124 .1863 .60177 .17579 .60087 .19495 Metetra
.984 .763 .525 r
.60087 .19495 .60177 .17579 .5922 .16893 .59115 .17835 Metetra
.99 .796 .548 r
.59115 .17835 .5922 .16893 .58252 .16542 .58144 .17443 Metetra
.985 .791 .563 r
.58144 .17443 .58252 .16542 .57267 .16159 .57152 .16534 Metetra
.965 .835 .666 r
.57152 .16534 .57267 .16159 .56262 .155 .56145 .15611 Metetra
.843 .968 .881 r
.56145 .15611 .56262 .155 .55245 .15347 .55125 .15301 Metetra
.202 .533 .923 r
.55125 .15301 .55245 .15347 .542 .1324 .54083 .13986 Metetra
.976 .791 .591 r
.54083 .13986 .542 .1324 .53145 .12143 .53025 .12587 Metetra
.934 .776 .663 r
.53025 .12587 .53145 .12143 .52071 .09633 .51951 .1027 Metetra
.982 .694 .34 r
.73038 .30611 .73176 .31587 .7239 .3052 .72238 .29056 Metetra
.984 .711 .417 r
.72238 .29056 .7239 .3052 .71592 .29377 .71459 .28516 Metetra
.98 .686 .359 r
.71459 .28516 .71592 .29377 .70794 .28542 .7066 .27629 Metetra
.981 .689 .368 r
.7066 .27629 .70794 .28542 .69969 .27124 .69851 .26781 Metetra
.935 .565 .181 r
.69851 .26781 .69969 .27124 .69185 .27624 .69034 .2603 Metetra
.987 .716 .397 r
.69034 .2603 .69185 .27624 .68382 .27935 .68185 .24484 Metetra
.986 .73 .451 r
.68185 .24484 .68382 .27935 .67561 .28078 .67358 .24226 Metetra
.987 .732 .451 r
.67358 .24226 .67561 .28078 .66707 .2739 .66512 .23728 Metetra
.986 .73 .453 r
.66512 .23728 .66707 .2739 .65861 .27692 .65662 .23651 Metetra
.985 .73 .459 r
.65662 .23651 .65861 .27692 .64994 .27672 .6481 .24155 Metetra
.985 .728 .455 r
.6481 .24155 .64994 .27672 .64199 .32203 .63936 .24357 Metetra
.989 .739 .456 r
.63936 .24357 .64199 .32203 .63185 .25968 .63013 .22647 Metetra
.99 .733 .43 r
.63013 .22647 .63185 .25968 .62246 .24184 .62069 .20369 Metetra
.989 .733 .44 r
.62069 .20369 .62246 .24184 .61292 .22136 .61124 .1863 Metetra
.988 .731 .444 r
.61124 .1863 .61292 .22136 .60342 .21249 .60177 .17579 Metetra
.987 .731 .448 r
.60177 .17579 .60342 .21249 .59369 .19617 .5922 .16893 Metetra
.986 .724 .443 r
.5922 .16893 .59369 .19617 .58391 .1861 .58252 .16542 Metetra
.984 .718 .434 r
.58252 .16542 .58391 .1861 .57397 .17584 .57267 .16159 Metetra
.983 .706 .41 r
.57267 .16159 .57397 .17584 .56389 .1662 .56262 .155 Metetra
.978 .692 .406 r
.56262 .155 .56389 .1662 .55369 .16246 .55245 .15347 Metetra
.976 .68 .308 r
.55245 .15347 .55369 .16246 .54323 .14085 .542 .1324 Metetra
.977 .676 .346 r
.542 .1324 .54323 .14085 .53267 .12637 .53145 .12143 Metetra
.902 .571 .088 r
.53145 .12143 .53267 .12637 .52194 .11244 .52071 .09633 Metetra
.86 .827 .815 r
.73176 .31587 .73278 .31458 .72485 .30127 .7239 .3052 Metetra
.956 .806 .654 r
.7239 .3052 .72485 .30127 .71699 .29337 .71592 .29377 Metetra
.69 .832 .951 r
.71592 .29377 .71699 .29337 .70901 .28507 .70794 .28542 Metetra
.68 .733 .89 r
.70794 .28542 .70901 .28507 .70083 .27317 .69969 .27124 Metetra
.875 .474 .266 r
.69969 .27124 .70083 .27317 .6928 .27099 .69185 .27624 Metetra
.997 .844 .565 r
.69185 .27624 .6928 .27099 .68478 .27375 .68382 .27935 Metetra
.995 .835 .569 r
.68382 .27935 .68478 .27375 .67654 .27351 .67561 .28078 Metetra
.985 .8 .574 r
.67561 .28078 .67654 .27351 .66833 .28025 .66707 .2739 Metetra
.964 .654 .388 r
.66707 .2739 .66833 .28025 .6597 .27524 .65861 .27692 Metetra
.928 .963 .77 r
.65861 .27692 .6597 .27524 .65107 .27662 .64994 .27672 Metetra
.561 .29 .461 r
.64994 .27672 .65107 .27662 .64283 .30627 .64199 .32203 Metetra
.942 .724 .578 r
.64199 .32203 .64283 .30627 .63299 .25894 .63185 .25968 Metetra
.748 .743 .848 r
.63185 .25968 .63299 .25894 .62374 .24991 .62246 .24184 Metetra
.971 .671 .282 r
.62246 .24184 .62374 .24991 .61428 .23514 .61292 .22136 Metetra
.984 .706 .402 r
.61292 .22136 .61428 .23514 .60461 .21461 .60342 .21249 Metetra
.649 .242 0 r
.60342 .21249 .60461 .21461 .59489 .19887 .59369 .19617 Metetra
.878 .466 .031 r
.59369 .19617 .59489 .19887 .5851 .18747 .58391 .1861 Metetra
.584 .093 0 r
.58391 .1861 .5851 .18747 .57514 .17374 .57397 .17584 Metetra
.923 .863 .763 r
.57397 .17584 .57514 .17374 .56507 .16432 .56389 .1662 Metetra
.933 .929 .779 r
.56389 .1662 .56507 .16432 .55488 .16057 .55369 .16246 Metetra
.854 .768 .766 r
.55369 .16246 .55488 .16057 .54443 .14013 .54323 .14085 Metetra
.75 .802 .895 r
.54323 .14085 .54443 .14013 .53386 .12142 .53267 .12637 Metetra
.964 .807 .638 r
.53267 .12637 .53386 .12142 .52315 .10602 .52194 .11244 Metetra
.973 .668 .298 r
.73278 .31458 .73408 .3217 .72626 .31207 .72485 .30127 Metetra
.983 .699 .386 r
.72485 .30127 .72626 .31207 .71829 .30095 .71699 .29337 Metetra
.977 .676 .345 r
.71699 .29337 .71829 .30095 .71027 .29106 .70901 .28507 Metetra
.967 .65 .276 r
.70901 .28507 .71027 .29106 .70223 .28449 .70083 .27317 Metetra
.98 .698 .41 r
.70083 .27317 .70223 .28449 .69422 .28298 .6928 .27099 Metetra
.977 .698 .427 r
.6928 .27099 .69422 .28298 .68613 .28333 .68478 .27375 Metetra
.976 .688 .405 r
.68478 .27375 .68613 .28333 .67786 .28205 .67654 .27351 Metetra
.967 .675 .423 r
.67654 .27351 .67786 .28205 .66993 .30114 .66833 .28025 Metetra
.985 .72 .433 r
.66833 .28025 .66993 .30114 .66133 .29832 .6597 .27524 Metetra
.984 .72 .445 r
.6597 .27524 .66133 .29832 .65273 .30202 .65107 .27662 Metetra
.973 .712 .477 r
.65107 .27662 .65273 .30202 .6447 .34359 .64283 .30627 Metetra
.992 .737 .409 r
.64283 .30627 .6447 .34359 .63445 .27637 .63299 .25894 Metetra
.986 .715 .416 r
.63299 .25894 .63445 .27637 .62509 .26137 .62374 .24991 Metetra
.984 .699 .367 r
.62374 .24991 .62509 .26137 .61572 .25347 .61428 .23514 Metetra
.988 .719 .397 r
.61428 .23514 .61572 .25347 .60611 .23889 .60461 .21461 Metetra
.988 .725 .423 r
.60461 .21461 .60611 .23889 .5961 .20175 .59489 .19887 Metetra
.881 .479 .033 r
.59489 .19887 .5961 .20175 .58627 .18716 .5851 .18747 Metetra
.643 .761 .935 r
.5851 .18747 .58627 .18716 .57633 .17557 .57514 .17374 Metetra
.763 .293 0 r
.57514 .17374 .57633 .17557 .56628 .16735 .56507 .16432 Metetra
.922 .53 .195 r
.56507 .16432 .56628 .16735 .55617 .17476 .55488 .16057 Metetra
.986 .709 .375 r
.55488 .16057 .55617 .17476 .54565 .14396 .54443 .14013 Metetra
.888 .526 .048 r
.54443 .14013 .54565 .14396 .53509 .12807 .53386 .12142 Metetra
.968 .651 .279 r
.53386 .12142 .53509 .12807 .52437 .11248 .52315 .10602 Metetra
.672 .215 0 r
.73408 .3217 .7352 .32334 .72731 .31151 .72626 .31207 Metetra
.74 .796 .898 r
.72626 .31207 .72731 .31151 .71946 .30409 .71829 .30095 Metetra
.907 .526 .093 r
.71829 .30095 .71946 .30409 .71149 .29577 .71027 .29106 Metetra
.961 .624 .276 r
.71027 .29106 .71149 .29577 .70342 .28821 .70223 .28449 Metetra
.948 .594 .288 r
.70223 .28449 .70342 .28821 .69526 .28116 .69422 .28298 Metetra
.943 .956 .742 r
.69422 .28298 .69526 .28116 .6872 .28227 .68613 .28333 Metetra
.844 .984 .865 r
.68613 .28333 .6872 .28227 .67888 .27852 .67786 .28205 Metetra
.859 .844 .379 r
.67786 .28205 .67888 .27852 .67052 .27849 .66993 .30114 Metetra
.991 .767 .501 r
.66993 .30114 .67052 .27849 .6618 .26868 .66133 .29832 Metetra
.992 .764 .487 r
.66133 .29832 .6618 .26868 .65358 .28813 .65273 .30202 Metetra
.986 .797 .401 r
.65273 .30202 .65358 .28813 .6454 .32054 .6447 .34359 Metetra
.956 .73 .555 r
.6447 .34359 .6454 .32054 .63549 .2704 .63445 .27637 Metetra
.966 .791 .614 r
.63445 .27637 .63549 .2704 .62601 .24759 .62509 .26137 Metetra
.988 .777 .53 r
.62509 .26137 .62601 .24759 .6164 .22224 .61572 .25347 Metetra
.987 .757 .503 r
.61572 .25347 .6164 .22224 .60679 .20433 .60611 .23889 Metetra
.98 .749 .514 r
.60611 .23889 .60679 .20433 .59719 .19574 .5961 .20175 Metetra
.968 .794 .613 r
.5961 .20175 .59719 .19574 .5874 .18301 .58627 .18716 Metetra
.962 .819 .655 r
.58627 .18716 .5874 .18301 .57749 .17305 .57633 .17557 Metetra
.945 .866 .729 r
.57633 .17557 .57749 .17305 .56749 .17014 .56628 .16735 Metetra
.9 .525 .312 r
.56628 .16735 .56749 .17014 .55726 .15882 .55617 .17476 Metetra
.973 .756 .549 r
.55617 .17476 .55726 .15882 .54685 .14244 .54565 .14396 Metetra
.855 .812 .807 r
.54565 .14396 .54685 .14244 .5363 .12876 .53509 .12807 Metetra
.09 .421 .867 r
.53509 .12807 .5363 .12876 .52559 .11513 .52437 .11248 Metetra
.51 .679 .941 r
.7352 .32334 .73627 .32342 .72833 .30983 .72731 .31151 Metetra
.913 .869 .782 r
.72731 .31151 .72833 .30983 .72051 .30307 .71946 .30409 Metetra
.841 .865 .861 r
.71946 .30409 .72051 .30307 .71254 .29475 .71149 .29577 Metetra
.845 .88 .866 r
.71149 .29577 .71254 .29475 .70451 .28803 .70342 .28821 Metetra
.571 .819 .992 r
.70342 .28821 .70451 .28803 .6965 .28632 .69526 .28116 Metetra
.96 .637 .358 r
.69526 .28116 .6965 .28632 .68845 .28792 .6872 .28227 Metetra
.967 .646 .333 r
.6872 .28227 .68845 .28792 .68029 .2903 .67888 .27852 Metetra
.979 .698 .417 r
.67888 .27852 .68029 .2903 .6723 .3064 .67052 .27849 Metetra
.988 .728 .436 r
.67052 .27849 .6723 .3064 .66386 .31035 .6618 .26868 Metetra
.982 .727 .468 r
.6618 .26868 .66386 .31035 .65503 .30326 .65358 .28813 Metetra
.958 .688 .483 r
.65358 .28813 .65503 .30326 .64789 .38845 .6454 .32054 Metetra
.992 .742 .436 r
.6454 .32054 .64789 .38845 .6369 .28462 .63549 .2704 Metetra
.986 .71 .364 r
.63549 .2704 .6369 .28462 .62719 .24941 .62601 .24759 Metetra
0 .084 .641 r
.62601 .24759 .62719 .24941 .6178 .23833 .6164 .22224 Metetra
.987 .715 .391 r
.6164 .22224 .6178 .23833 .60818 .21993 .60679 .20433 Metetra
.985 .711 .41 r
.60679 .20433 .60818 .21993 .59848 .20532 .59719 .19574 Metetra
.98 .687 .353 r
.59719 .19574 .59848 .20532 .58867 .19175 .5874 .18301 Metetra
.978 .68 .353 r
.5874 .18301 .58867 .19175 .57874 .18012 .57749 .17305 Metetra
.971 .66 .36 r
.57749 .17305 .57874 .18012 .56868 .1702 .56749 .17014 Metetra
.44 .708 .98 r
.56749 .17014 .56868 .1702 .55864 .18489 .55726 .15882 Metetra
.988 .726 .425 r
.55726 .15882 .55864 .18489 .54806 .14362 .54685 .14244 Metetra
0 .103 .63 r
.54685 .14244 .54806 .14362 .5375 .12636 .5363 .12876 Metetra
.919 .833 .745 r
.5363 .12876 .5375 .12636 .5268 .11185 .52559 .11513 Metetra
.983 .767 .536 r
.73627 .32342 .73687 .30943 .72903 .29822 .72833 .30983 Metetra
.988 .78 .535 r
.72833 .30983 .72903 .29822 .72138 .29625 .72051 .30307 Metetra
.981 .797 .581 r
.72051 .30307 .72138 .29625 .71319 .28034 .71254 .29475 Metetra
.989 .774 .523 r
.71254 .29475 .71319 .28034 .70514 .27197 .70451 .28803 Metetra
.992 .775 .509 r
.70451 .28803 .70514 .27197 .69725 .27371 .6965 .28632 Metetra
.995 .787 .513 r
.6965 .28632 .69725 .27371 .68915 .27249 .68845 .28792 Metetra
.994 .78 .504 r
.68845 .28792 .68915 .27249 .68092 .2711 .68029 .2903 Metetra
.998 .78 .475 r
.68029 .2903 .68092 .2711 .67229 .25862 .6723 .3064 Metetra
.991 .757 .48 r
.6723 .3064 .67229 .25862 .66378 .25663 .66386 .31035 Metetra
.989 .753 .485 r
.66386 .31035 .66378 .25663 .65509 .25234 .65503 .30326 Metetra
.996 .767 .425 r
.65503 .30326 .65509 .25234 .64643 .2568 .64789 .38845 Metetra
.982 .741 .495 r
.64789 .38845 .64643 .2568 .63708 .23224 .6369 .28462 Metetra
.984 .748 .499 r
.6369 .28462 .63708 .23224 .62785 .22047 .62719 .24941 Metetra
.988 .76 .501 r
.62719 .24941 .62785 .22047 .61834 .19899 .6178 .23833 Metetra
.987 .754 .498 r
.6178 .23833 .61834 .19899 .60881 .18325 .60818 .21993 Metetra
.988 .756 .497 r
.60818 .21993 .60881 .18325 .59928 .17634 .59848 .20532 Metetra
.987 .759 .503 r
.59848 .20532 .59928 .17634 .58952 .1628 .58867 .19175 Metetra
.988 .76 .502 r
.58867 .19175 .58952 .1628 .57971 .15863 .57874 .18012 Metetra
.988 .766 .511 r
.57874 .18012 .57971 .15863 .56976 .15627 .56868 .1702 Metetra
.999 .796 .489 r
.56868 .1702 .56976 .15627 .55961 .15181 .55864 .18489 Metetra
.979 .748 .517 r
.55864 .18489 .55961 .15181 .54925 .14112 .54806 .14362 Metetra
.906 .806 .737 r
.54806 .14362 .54925 .14112 .53872 .12922 .5375 .12636 Metetra
.849 .446 0 r
.5375 .12636 .53872 .12922 .52798 .09557 .5268 .11185 Metetra
.974 .791 .594 r
.73687 .30943 .73772 .30299 .7299 .29208 .72903 .29822 Metetra
.992 .818 .57 r
.72903 .29822 .7299 .29208 .722 .2816 .72138 .29625 Metetra
.981 .765 .537 r
.72138 .29625 .722 .2816 .71398 .27048 .71319 .28034 Metetra
.985 .783 .55 r
.71319 .28034 .71398 .27048 .70593 .26181 .70514 .27197 Metetra
.996 .796 .522 r
.70514 .27197 .70593 .26181 .6978 .25387 .69725 .27371 Metetra
.992 .77 .501 r
.69725 .27371 .6978 .25387 .68953 .24484 .68915 .27249 Metetra
.991 .763 .492 r
.68915 .27249 .68953 .24484 .68125 .24006 .68092 .2711 Metetra
.988 .757 .5 r
.68092 .2711 .68125 .24006 .6728 .23324 .67229 .25862 Metetra
.991 .765 .495 r
.67229 .25862 .6728 .23324 .66455 .24116 .66378 .25663 Metetra
.991 .776 .516 r
.66378 .25663 .66455 .24116 .656 .24202 .65509 .25234 Metetra
.997 .801 .517 r
.65509 .25234 .656 .24202 .64727 .24165 .64643 .2568 Metetra
.976 .759 .546 r
.64643 .2568 .64727 .24165 .63823 .23289 .63708 .23224 Metetra
.042 .419 .864 r
.63708 .23224 .63823 .23289 .62873 .20478 .62785 .22047 Metetra
.979 .762 .54 r
.62785 .22047 .62873 .20478 .61933 .18862 .61834 .19899 Metetra
.979 .776 .561 r
.61834 .19899 .61933 .18862 .6099 .17797 .60881 .18325 Metetra
.982 .822 .61 r
.60881 .18325 .6099 .17797 .60033 .16727 .59928 .17634 Metetra
.98 .784 .569 r
.59928 .17634 .60033 .16727 .59064 .15826 .58952 .1628 Metetra
.984 .843 .622 r
.58952 .1628 .59064 .15826 .58088 .15772 .57971 .15863 Metetra
.79 .978 .906 r
.57971 .15863 .58088 .15772 .57097 .15966 .56976 .15627 Metetra
.933 .553 .214 r
.56976 .15627 .57097 .15966 .56083 .15541 .55961 .15181 Metetra
.925 .548 .145 r
.55961 .15181 .56083 .15541 .55043 .13718 .54925 .14112 Metetra
.96 .825 .665 r
.54925 .14112 .55043 .13718 .5399 .12086 .53872 .12922 Metetra
.949 .753 .604 r
.53872 .12922 .5399 .12086 .52919 .09206 .52798 .09557 Metetra
.969 .653 .285 r
.73772 .30299 .73899 .30909 .7311 .29613 .7299 .29208 Metetra
.94 .588 .179 r
.7299 .29208 .7311 .29613 .72327 .28795 .722 .2816 Metetra
.971 .657 .292 r
.722 .2816 .72327 .28795 .71534 .27982 .71398 .27048 Metetra
.981 .69 .366 r
.71398 .27048 .71534 .27982 .7073 .27157 .70593 .26181 Metetra
.981 .692 .374 r
.70593 .26181 .7073 .27157 .69953 .27679 .6978 .25387 Metetra
.987 .724 .428 r
.6978 .25387 .69953 .27679 .69161 .28187 .68953 .24484 Metetra
.987 .731 .448 r
.68953 .24484 .69161 .28187 .68328 .2768 .68125 .24006 Metetra
.988 .731 .446 r
.68125 .24006 .68328 .2768 .67498 .2776 .6728 .23324 Metetra
.985 .731 .46 r
.6728 .23324 .67498 .2776 .66634 .27011 .66455 .24116 Metetra
.985 .725 .448 r
.66455 .24116 .66634 .27011 .65791 .27846 .656 .24202 Metetra
.986 .729 .451 r
.656 .24202 .65791 .27846 .65008 .32454 .64727 .24165 Metetra
.988 .739 .458 r
.64727 .24165 .65008 .32454 .64 .26604 .63823 .23289 Metetra
.991 .733 .421 r
.63823 .23289 .64 .26604 .63064 .2485 .62873 .20478 Metetra
.989 .735 .442 r
.62873 .20478 .63064 .2485 .62096 .21846 .61933 .18862 Metetra
.988 .728 .436 r
.61933 .18862 .62096 .21846 .61146 .20576 .6099 .17797 Metetra
.988 .727 .433 r
.6099 .17797 .61146 .20576 .60192 .19941 .60033 .16727 Metetra
.988 .729 .44 r
.60033 .16727 .60192 .19941 .59213 .18525 .59064 .15826 Metetra
.985 .723 .443 r
.59064 .15826 .59213 .18525 .58224 .17513 .58088 .15772 Metetra
.981 .71 .433 r
.58088 .15772 .58224 .17513 .57222 .1664 .57097 .15966 Metetra
.97 .655 .345 r
.57097 .15966 .57222 .1664 .56204 .15683 .56083 .15541 Metetra
0 .087 .641 r
.56083 .15541 .56204 .15683 .55166 .14131 .55043 .13718 Metetra
.918 .559 .116 r
.55043 .13718 .55166 .14131 .54114 .12886 .5399 .12086 Metetra
.958 .659 .233 r
.5399 .12086 .54114 .12886 .53045 .11061 .52919 .09206 Metetra
.984 .701 .366 r
.73899 .30909 .74043 .32027 .73265 .31093 .7311 .29613 Metetra
.986 .712 .407 r
.7311 .29613 .73265 .31093 .72471 .29939 .72327 .28795 Metetra
.983 .701 .388 r
.72327 .28795 .72471 .29939 .71683 .29335 .71534 .27982 Metetra
.985 .708 .401 r
.71534 .27982 .71683 .29335 .70885 .28724 .7073 .27157 Metetra
.979 .708 .441 r
.7073 .27157 .70885 .28724 .70066 .27823 .69953 .27679 Metetra
.831 .398 .209 r
.69953 .27679 .70066 .27823 .6926 .27783 .69161 .28187 Metetra
.979 .84 .634 r
.69161 .28187 .6926 .27783 .68449 .28041 .68328 .2768 Metetra
.942 .586 .303 r
.68328 .2768 .68449 .28041 .67597 .27228 .67498 .2776 Metetra
.98 .815 .607 r
.67498 .2776 .67597 .27228 .66758 .27508 .66634 .27011 Metetra
.944 .623 .394 r
.66634 .27011 .66758 .27508 .6592 .28557 .65791 .27846 Metetra
.894 .616 .509 r
.65791 .27846 .6592 .28557 .65161 .34309 .65008 .32454 Metetra
.972 .712 .292 r
.65008 .32454 .65161 .34309 .64122 .26987 .64 .26604 Metetra
.883 .525 .04 r
.64 .26604 .64122 .26987 .63179 .24829 .63064 .2485 Metetra
.628 .6 .802 r
.63064 .2485 .63179 .24829 .62214 .21985 .62096 .21846 Metetra
0 0 .525 r
.62096 .21846 .62214 .21985 .61267 .20841 .61146 .20576 Metetra
.9 .487 .103 r
.61146 .20576 .61267 .20841 .60315 .20355 .60192 .19941 Metetra
.927 .57 .141 r
.60192 .19941 .60315 .20355 .59338 .19127 .59213 .18525 Metetra
.967 .643 .29 r
.59213 .18525 .59338 .19127 .58347 .17931 .58224 .17513 Metetra
.946 .587 .217 r
.58224 .17513 .58347 .17931 .57347 .17241 .57222 .1664 Metetra
.967 .642 .294 r
.57222 .1664 .57347 .17241 .56334 .17062 .56204 .15683 Metetra
.985 .706 .382 r
.56204 .15683 .56334 .17062 .55286 .14096 .55166 .14131 Metetra
.645 .794 .954 r
.55166 .14131 .55286 .14096 .54232 .1212 .54114 .12886 Metetra
.971 .783 .594 r
.54114 .12886 .54232 .1212 .53167 .10895 .53045 .11061 Metetra
.629 .784 .956 r
.74043 .32027 .74149 .32004 .73353 .30486 .73265 .31093 Metetra
.973 .793 .601 r
.73265 .31093 .73353 .30486 .72566 .29537 .72471 .29939 Metetra
.976 .833 .635 r
.72471 .29939 .72566 .29537 .71777 .28862 .71683 .29335 Metetra
.98 .823 .615 r
.71683 .29335 .71777 .28862 .70976 .28126 .70885 .28724 Metetra
.978 .802 .596 r
.70885 .28724 .70976 .28126 .70158 .27177 .70066 .27823 Metetra
.994 .82 .561 r
.70066 .27823 .70158 .27177 .6938 .28141 .6926 .27783 Metetra
.939 .586 .322 r
.6926 .27783 .6938 .28141 .68557 .27935 .68449 .28041 Metetra
.845 .878 .865 r
.68449 .28041 .68557 .27935 .67736 .28377 .67597 .27228 Metetra
.977 .695 .421 r
.67597 .27228 .67736 .28377 .66873 .27608 .66758 .27508 Metetra
.753 .332 .249 r
.66758 .27508 .66873 .27608 .66029 .28336 .6592 .28557 Metetra
.269 .063 .405 r
.6592 .28557 .66029 .28336 .65213 .31207 .65161 .34309 Metetra
.964 .733 .54 r
.65161 .34309 .65213 .31207 .64227 .26468 .64122 .26987 Metetra
.944 .773 .64 r
.64122 .26987 .64227 .26468 .63292 .24708 .63179 .24829 Metetra
.767 .685 .772 r
.63179 .24829 .63292 .24708 .62347 .23004 .62214 .21985 Metetra
.981 .691 .363 r
.62214 .21985 .62347 .23004 .61393 .21476 .61267 .20841 Metetra
.969 .652 .335 r
.61267 .20841 .61393 .21476 .6043 .20207 .60315 .20355 Metetra
.869 .841 .815 r
.60315 .20355 .6043 .20207 .59453 .18926 .59338 .19127 Metetra
.908 .843 .769 r
.59338 .19127 .59453 .18926 .58466 .17913 .58347 .17931 Metetra
.503 .823 1 r
.58347 .17931 .58466 .17913 .57473 .17915 .57347 .17241 Metetra
.968 .654 .357 r
.57347 .17241 .57473 .17915 .56445 .15818 .56334 .17062 Metetra
.969 .759 .565 r
.56334 .17062 .56445 .15818 .5541 .14612 .55286 .14096 Metetra
.935 .6 .16 r
.55286 .14096 .5541 .14612 .54358 .13175 .54232 .1212 Metetra
.981 .69 .364 r
.54232 .1212 .54358 .13175 .5329 .11483 .53167 .10895 Metetra
0 0 .559 r
.74149 .32004 .74261 .32166 .73468 .30745 .73353 .30486 Metetra
.867 .461 .003 r
.73353 .30486 .73468 .30745 .7268 .29747 .72566 .29537 Metetra
.851 .414 0 r
.72566 .29537 .7268 .29747 .71888 .28937 .71777 .28862 Metetra
0 .245 .709 r
.71777 .28862 .71888 .28937 .71098 .28558 .70976 .28126 Metetra
.949 .602 .214 r
.70976 .28126 .71098 .28558 .70299 .28281 .70158 .27177 Metetra
.971 .689 .44 r
.70158 .27177 .70299 .28281 .6949 .28085 .6938 .28141 Metetra
.67 .956 .947 r
.6938 .28141 .6949 .28085 .68666 .27849 .68557 .27935 Metetra
.572 .913 .693 r
.68557 .27935 .68666 .27849 .67855 .28639 .67736 .28377 Metetra
.89 .48 .065 r
.67736 .28377 .67855 .28639 .66984 .27533 .66873 .27608 Metetra
.66873 .27608 .66984 .27533 .66108 .26768 .66029 .28336 Metetra
.998 .793 .445 r
.66029 .28336 .66108 .26768 .65294 .296 .65213 .31207 Metetra
.958 .739 .564 r
.65213 .31207 .65294 .296 .64319 .25273 .64227 .26468 Metetra
.979 .77 .553 r
.64227 .26468 .64319 .25273 .63394 .23922 .63292 .24708 Metetra
.971 .78 .588 r
.63292 .24708 .63394 .23922 .62453 .22411 .62347 .23004 Metetra
.967 .792 .615 r
.62347 .23004 .62453 .22411 .61507 .21296 .61393 .21476 Metetra
.892 .834 .783 r
.61393 .21476 .61507 .21296 .6054 .19666 .6043 .20207 Metetra
.97 .804 .621 r
.6043 .20207 .6054 .19666 .59571 .1895 .59453 .18926 Metetra
.284 .633 .964 r
.59453 .18926 .59571 .1895 .58586 .18086 .58466 .17913 Metetra
.843 .382 .089 r
.58466 .17913 .58586 .18086 .57615 .204 .57473 .17915 Metetra
.989 .726 .414 r
.57473 .17915 .57615 .204 .56593 .19469 .56445 .15818 Metetra
.988 .731 .439 r
.56445 .15818 .56593 .19469 .55531 .14672 .5541 .14612 Metetra
.135 .469 .893 r
.5541 .14612 .55531 .14672 .54478 .12934 .54358 .13175 Metetra
.905 .811 .744 r
.54358 .13175 .54478 .12934 .53411 .11127 .5329 .11483 Metetra
.778 .766 .842 r
.74261 .32166 .74365 .32084 .73568 .30506 .73468 .30745 Metetra
.932 .832 .724 r
.73468 .30745 .73568 .30506 .72784 .29602 .7268 .29747 Metetra
.892 .867 .808 r
.7268 .29747 .72784 .29602 .71993 .28835 .71888 .28937 Metetra
.855 .946 .876 r
.71888 .28937 .71993 .28835 .71191 .2802 .71098 .28558 Metetra
.99 .827 .587 r
.71098 .28558 .71191 .2802 .70369 .26884 .70299 .28281 Metetra
.992 .78 .514 r
.70299 .28281 .70369 .26884 .6959 .27708 .6949 .28085 Metetra
.985 .859 .632 r
.6949 .28085 .6959 .27708 .68788 .28242 .68666 .27849 Metetra
.932 .596 .376 r
.68666 .27849 .68788 .28242 .67987 .29451 .67855 .28639 Metetra
.978 .677 .333 r
.67855 .28639 .67987 .29451 .67155 .30045 .66984 .27533 Metetra
.987 .725 .432 r
.66984 .27533 .67155 .30045 .6624 .27601 .66108 .26768 Metetra
.936 .651 .476 r
.66108 .26768 .6624 .27601 .65445 .31297 .65294 .296 Metetra
.981 .714 .321 r
.65294 .296 .65445 .31297 .64449 .26018 .64319 .25273 Metetra
.974 .667 .305 r
.64319 .25273 .64449 .26018 .63519 .24444 .63394 .23922 Metetra
.949 .616 .205 r
.63394 .23922 .63519 .24444 .62584 .23311 .62453 .22411 Metetra
.979 .682 .348 r
.62453 .22411 .62584 .23311 .61619 .21027 .61507 .21296 Metetra
.915 .803 .721 r
.61507 .21296 .61619 .21027 .60656 .19628 .6054 .19666 Metetra
.634 .869 .986 r
.6054 .19666 .60656 .19628 .59677 .17978 .59571 .1895 Metetra
.987 .79 .553 r
.59571 .1895 .59677 .17978 .58693 .17018 .58586 .18086 Metetra
.997 .814 .463 r
.58586 .18086 .58693 .17018 .57698 .16472 .57615 .204 Metetra
.989 .757 .49 r
.57615 .204 .57698 .16472 .56687 .16129 .56593 .19469 Metetra
.978 .746 .519 r
.56593 .19469 .56687 .16129 .55648 .14067 .55531 .14672 Metetra
.965 .791 .617 r
.55531 .14672 .55648 .14067 .54595 .1209 .54478 .12934 Metetra
.974 .782 .583 r
.54478 .12934 .54595 .1209 .5353 .10403 .53411 .11127 Metetra
.912 .57 .104 r
.74365 .32084 .74487 .32516 .73705 .31396 .73568 .30506 Metetra
.98 .687 .356 r
.73568 .30506 .73705 .31396 .72916 .30379 .72784 .29602 Metetra
.978 .677 .347 r
.72784 .29602 .72916 .30379 .72125 .29587 .71993 .28835 Metetra
.977 .674 .34 r
.71993 .28835 .72125 .29587 .71322 .28758 .71191 .2802 Metetra
.975 .67 .315 r
.71191 .2802 .71322 .28758 .70496 .27491 .70369 .26884 Metetra
.955 .647 .41 r
.70369 .26884 .70496 .27491 .69659 .26191 .6959 .27708 Metetra
.996 .783 .496 r
.6959 .27708 .69659 .26191 .68832 .25658 .68788 .28242 Metetra
.995 .77 .476 r
.68788 .28242 .68832 .25658 .68011 .25869 .67987 .29451 Metetra
.993 .761 .479 r
.67987 .29451 .68011 .25869 .67165 .25677 .67155 .30045 Metetra
.986 .751 .497 r
.67155 .30045 .67165 .25677 .66307 .25496 .6624 .27601 Metetra
.997 .783 .436 r
.6624 .27601 .66307 .25496 .65436 .25435 .65445 .31297 Metetra
.982 .744 .501 r
.65445 .31297 .65436 .25435 .64507 .23135 .64449 .26018 Metetra
.987 .758 .503 r
.64449 .26018 .64507 .23135 .63588 .2191 .63519 .24444 Metetra
.988 .762 .504 r
.63519 .24444 .63588 .2191 .6266 .20937 .62584 .23311 Metetra
.983 .757 .517 r
.62584 .23311 .6266 .20937 .6172 .20008 .61619 .21027 Metetra
.981 .78 .559 r
.61619 .21027 .6172 .20008 .60757 .18483 .60656 .19628 Metetra
.98 .774 .554 r
.60656 .19628 .60757 .18483 .59789 .17521 .59677 .17978 Metetra
.972 .823 .636 r
.59677 .17978 .59789 .17521 .58812 .1705 .58693 .17018 Metetra
0 .511 .839 r
.58693 .17018 .58812 .1705 .57815 .16295 .57698 .16472 Metetra
.926 .938 .789 r
.57698 .16472 .57815 .16295 .56801 .15332 .56687 .16129 Metetra
.968 .777 .592 r
.56687 .16129 .56801 .15332 .55767 .13887 .55648 .14067 Metetra
.858 .783 .777 r
.55648 .14067 .55767 .13887 .54719 .12461 .54595 .1209 Metetra
.893 .523 .057 r
.54595 .1209 .54719 .12461 .53657 .11631 .5353 .10403 Metetra
.986 .767 .523 r
.74487 .32516 .74539 .30914 .73749 .295 .73705 .31396 Metetra
.988 .765 .513 r
.73705 .31396 .73749 .295 .72967 .28585 .72916 .30379 Metetra
.989 .768 .512 r
.72916 .30379 .72967 .28585 .72176 .27711 .72125 .29587 Metetra
.989 .767 .511 r
.72125 .29587 .72176 .27711 .71375 .26871 .71322 .28758 Metetra
.986 .764 .517 r
.71322 .28758 .71375 .26871 .70564 .26038 .70496 .27491 Metetra
.985 .769 .531 r
.70496 .27491 .70564 .26038 .69744 .25267 .69659 .26191 Metetra
.99 .792 .546 r
.69659 .26191 .69744 .25267 .68907 .24308 .68832 .25658 Metetra
.995 .785 .507 r
.68832 .25658 .68907 .24308 .68091 .24612 .68011 .25869 Metetra
.993 .785 .52 r
.68011 .25869 .68091 .24612 .67253 .24616 .67165 .25677 Metetra
.993 .792 .529 r
.67165 .25677 .67253 .24616 .66405 .24844 .66307 .25496 Metetra
.994 .822 .563 r
.66307 .25496 .66405 .24844 .65534 .24673 .65436 .25435 Metetra
.96 .767 .6 r
.65436 .25435 .65534 .24673 .64626 .23382 .64507 .23135 Metetra
.814 .397 0 r
.64507 .23135 .64626 .23382 .63695 .21472 .63588 .2191 Metetra
.97 .822 .64 r
.63588 .2191 .63695 .21472 .62758 .19888 .6266 .20937 Metetra
.987 .785 .547 r
.6266 .20937 .62758 .19888 .61813 .18518 .6172 .20008 Metetra
.984 .769 .534 r
.6172 .20008 .61813 .18518 .60859 .17399 .60757 .18483 Metetra
.987 .784 .546 r
.60757 .18483 .60859 .17399 .59894 .16524 .59789 .17521 Metetra
.991 .794 .543 r
.59789 .17521 .59894 .16524 .58929 .16888 .58812 .1705 Metetra
.904 .898 .81 r
.58812 .1705 .58929 .16888 .5794 .1679 .57815 .16295 Metetra
.956 .614 .248 r
.57815 .16295 .5794 .1679 .56925 .15809 .56801 .15332 Metetra
.943 .597 .188 r
.56801 .15332 .56925 .15809 .5589 .14215 .55767 .13887 Metetra
.884 .497 .038 r
.55767 .13887 .5589 .14215 .54842 .12896 .54719 .12461 Metetra
.948 .591 .228 r
.54719 .12461 .54842 .12896 .53776 .1083 .53657 .11631 Metetra
.983 .696 .348 r
.74539 .30914 .74681 .3195 .73889 .30487 .73749 .295 Metetra
.982 .693 .367 r
.73749 .295 .73889 .30487 .73109 .29659 .72967 .28585 Metetra
.983 .698 .377 r
.72967 .28585 .73109 .29659 .72321 .28903 .72176 .27711 Metetra
.984 .702 .388 r
.72176 .27711 .72321 .28903 .71521 .28086 .71375 .26871 Metetra
.984 .703 .389 r
.71375 .26871 .71521 .28086 .70727 .27866 .70564 .26038 Metetra
.986 .718 .417 r
.70564 .26038 .70727 .27866 .69937 .28248 .69744 .25267 Metetra
.988 .729 .434 r
.69744 .25267 .69937 .28248 .69139 .28861 .68907 .24308 Metetra
.987 .732 .455 r
.68907 .24308 .69139 .28861 .68293 .28199 .68091 .24612 Metetra
.986 .729 .449 r
.68091 .24612 .68293 .28199 .6744 .27733 .67253 .24616 Metetra
.985 .726 .448 r
.67253 .24616 .6744 .27733 .66577 .27414 .66405 .24844 Metetra
.986 .723 .439 r
.66405 .24844 .66577 .27414 .65822 .328 .65534 .24673 Metetra
.989 .739 .453 r
.65534 .24673 .65822 .328 .64806 .26627 .64626 .23382 Metetra
.99 .731 .427 r
.64626 .23382 .64806 .26627 .6387 .24711 .63695 .21472 Metetra
.989 .73 .43 r
.63695 .21472 .6387 .24711 .62921 .22623 .62758 .19888 Metetra
.988 .727 .426 r
.62758 .19888 .62921 .22623 .61966 .20834 .61813 .18518 Metetra
.988 .723 .422 r
.61813 .18518 .61966 .20834 .61007 .19556 .60859 .17399 Metetra
.987 .72 .423 r
.60859 .17399 .61007 .19556 .60042 .1881 .59894 .16524 Metetra
.983 .717 .441 r
.59894 .16524 .60042 .1881 .5906 .1801 .58929 .16888 Metetra
.978 .691 .403 r
.58929 .16888 .5906 .1801 .5807 .17912 .5794 .1679 Metetra
.982 .694 .376 r
.5794 .1679 .5807 .17912 .57059 .17394 .56925 .15809 Metetra
.986 .711 .39 r
.56925 .15809 .57059 .17394 .56012 .14436 .5589 .14215 Metetra
.766 .329 0 r
.5589 .14215 .56012 .14436 .54964 .12893 .54842 .12896 Metetra
.56 .65 .895 r
.54842 .12896 .54964 .12893 .539 .11337 .53776 .1083 Metetra
.956 .788 .634 r
.74681 .3195 .74772 .31471 .74002 .30652 .73889 .30487 Metetra
.719 .251 0 r
.73889 .30487 .74002 .30652 .73216 .29628 .73109 .29659 Metetra
.644 .833 .973 r
.73109 .29659 .73216 .29628 .72431 .28937 .72321 .28903 Metetra
.199 .58 .941 r
.72321 .28903 .72431 .28937 .71645 .28589 .71521 .28086 Metetra
.963 .634 .324 r
.71521 .28086 .71645 .28589 .70829 .27611 .70727 .27866 Metetra
.969 .933 .641 r
.70727 .27866 .70829 .27611 .70032 .27684 .69937 .28248 Metetra
.999 .846 .54 r
.69937 .28248 .70032 .27684 .69238 .28417 .69139 .28861 Metetra
.978 .829 .626 r
.69139 .28861 .69238 .28417 .68429 .29112 .68293 .28199 Metetra
.979 .684 .377 r
.68293 .28199 .68429 .29112 .67566 .28254 .6744 .27733 Metetra
.963 .633 .318 r
.6744 .27733 .67566 .28254 .667 .2783 .66577 .27414 Metetra
.821 .545 .521 r
.66577 .27414 .667 .2783 .65884 .30285 .65822 .328 Metetra
.964 .736 .544 r
.65822 .328 .65884 .30285 .64907 .25923 .64806 .26627 Metetra
.965 .777 .602 r
.64806 .26627 .64907 .25923 .63976 .24157 .6387 .24711 Metetra
.951 .776 .631 r
.6387 .24711 .63976 .24157 .63041 .22837 .62921 .22623 Metetra
0 0 .373 r
.62921 .22623 .63041 .22837 .62098 .21762 .61966 .20834 Metetra
.98 .684 .342 r
.61966 .20834 .62098 .21762 .61128 .19766 .61007 .19556 Metetra
.837 .386 0 r
.61007 .19556 .61128 .19766 .60159 .18743 .60042 .1881 Metetra
.75 .89 .942 r
.60042 .1881 .60159 .18743 .59175 .17638 .5906 .1801 Metetra
.985 .877 .638 r
.5906 .1801 .59175 .17638 .582 .18816 .5807 .17912 Metetra
.977 .679 .37 r
.5807 .17912 .582 .18816 .57175 .16882 .57059 .17394 Metetra
.927 .756 .65 r
.57059 .17394 .57175 .16882 .56133 .14358 .56012 .14436 Metetra
.758 .795 .883 r
.56012 .14436 .56133 .14358 .55083 .12552 .54964 .12893 Metetra
.941 .815 .692 r
.54964 .12893 .55083 .12552 .54021 .11146 .539 .11337 Metetra
.954 .612 .235 r
.74772 .31471 .74894 .31917 .74122 .31002 .74002 .30652 Metetra
.919 .551 .122 r
.74002 .30652 .74122 .31002 .73324 .29612 .73216 .29628 Metetra
.557 .812 .993 r
.73216 .29628 .73324 .29612 .7254 .2893 .72431 .28937 Metetra
.344 .783 .964 r
.72431 .28937 .7254 .2893 .71744 .28246 .71645 .28589 Metetra
.958 .824 .67 r
.71645 .28589 .71744 .28246 .70932 .2737 .70829 .27611 Metetra
.97 .926 .684 r
.70829 .27611 .70932 .2737 .70158 .28254 .70032 .27684 Metetra
.954 .641 .399 r
.70032 .27684 .70158 .28254 .69381 .29558 .69238 .28417 Metetra
.974 .692 .43 r
.69238 .28417 .69381 .29558 .68531 .28707 .68429 .29112 Metetra
.97 .827 .645 r
.68429 .29112 .68531 .28707 .67672 .2796 .67566 .28254 Metetra
.971 .875 .682 r
.67566 .28254 .67672 .2796 .6682 .28061 .667 .2783 Metetra
.823 .496 .437 r
.667 .2783 .6682 .28061 .66036 .32014 .65884 .30285 Metetra
.98 .714 .32 r
.65884 .30285 .66036 .32014 .6503 .26303 .64907 .25923 Metetra
.876 .518 .026 r
.64907 .25923 .6503 .26303 .64101 .24677 .63976 .24157 Metetra
.953 .618 .221 r
.63976 .24157 .64101 .24677 .63164 .23225 .63041 .22837 Metetra
.932 .566 .159 r
.63041 .22837 .63164 .23225 .62216 .21807 .62098 .21762 Metetra
.386 .534 .882 r
.62098 .21762 .62216 .21807 .61247 .19898 .61128 .19766 Metetra
.544 .054 0 r
.61128 .19766 .61247 .19898 .60282 .19112 .60159 .18743 Metetra
.924 .551 .139 r
.60159 .18743 .60282 .19112 .59301 .18234 .59175 .17638 Metetra
.946 .632 .406 r
.59175 .17638 .59301 .18234 .58315 .18354 .582 .18816 Metetra
.947 .789 .652 r
.582 .18816 .58315 .18354 .57304 .17894 .57175 .16882 Metetra
.976 .685 .301 r
.57175 .16882 .57304 .17894 .56254 .14412 .56133 .14358 Metetra
.277 .508 .898 r
.56133 .14358 .56254 .14412 .55205 .12609 .55083 .12552 Metetra
.141 .481 .899 r
.55083 .12552 .55205 .12609 .54144 .1121 .54021 .11146 Metetra
.971 .812 .626 r
.74894 .31917 .74985 .31459 .74218 .30663 .74122 .31002 Metetra
.939 .798 .677 r
.74122 .31002 .74218 .30663 .73432 .29603 .73324 .29612 Metetra
.508 .791 .997 r
.73324 .29612 .73432 .29603 .72642 .28746 .7254 .2893 Metetra
.927 .877 .767 r
.7254 .2893 .72642 .28746 .71851 .28174 .71744 .28246 Metetra
.782 .855 .905 r
.71744 .28246 .71851 .28174 .71043 .27399 .70932 .2737 Metetra
.574 .103 .099 r
.70932 .2737 .71043 .27399 .70265 .28104 .70158 .28254 Metetra
.70158 .28254 .70265 .28104 .69467 .28614 .69381 .29558 Metetra
.986 .787 .552 r
.69381 .29558 .69467 .28614 .68637 .28442 .68531 .28707 Metetra
.953 .858 .71 r
.68531 .28707 .68637 .28442 .67763 .27049 .67672 .2796 Metetra
.996 .804 .53 r
.67672 .2796 .67763 .27049 .66908 .26943 .6682 .28061 Metetra
.971 .799 .375 r
.6682 .28061 .66908 .26943 .66084 .28905 .66036 .32014 Metetra
.972 .74 .529 r
.66036 .32014 .66084 .28905 .65106 .24408 .6503 .26303 Metetra
.985 .764 .52 r
.6503 .26303 .65106 .24408 .64211 .24336 .64101 .24677 Metetra
.942 .809 .685 r
.64101 .24677 .64211 .24336 .63253 .21664 .63164 .23225 Metetra
.986 .769 .528 r
.63164 .23225 .63253 .21664 .62312 .20571 .62216 .21807 Metetra
.979 .769 .551 r
.62216 .21807 .62312 .20571 .6135 .18928 .61247 .19898 Metetra
.988 .791 .55 r
.61247 .19898 .6135 .18928 .60386 .18036 .60282 .19112 Metetra
.988 .786 .544 r
.60282 .19112 .60386 .18036 .59411 .1751 .59301 .18234 Metetra
.996 .823 .552 r
.59301 .18234 .59411 .1751 .58433 .18189 .58315 .18354 Metetra
.914 .933 .808 r
.58315 .18354 .58433 .18189 .57419 .1719 .57304 .17894 Metetra
.938 .748 .621 r
.57304 .17894 .57419 .1719 .56372 .14006 .56254 .14412 Metetra
.944 .798 .668 r
.56254 .14412 .56372 .14006 .55325 .12352 .55205 .12609 Metetra
.925 .831 .734 r
.55205 .12609 .55325 .12352 .54264 .10841 .54144 .1121 Metetra
.745 .282 0 r
.74985 .31459 .75098 .3163 .74313 .30307 .74218 .30663 Metetra
.956 .816 .664 r
.74218 .30663 .74313 .30307 .73526 .29179 .73432 .29603 Metetra
.971 .819 .635 r
.73432 .29603 .73526 .29179 .72739 .28362 .72642 .28746 Metetra
.977 .839 .64 r
.72642 .28746 .72739 .28362 .71953 .27935 .71851 .28174 Metetra
.945 .856 .723 r
.71851 .28174 .71953 .27935 .71156 .27499 .71043 .27399 Metetra
.763 .316 .189 r
.71043 .27399 .71156 .27499 .70379 .28223 .70265 .28104 Metetra
.794 .339 .162 r
.70265 .28104 .70379 .28223 .69568 .2821 .69467 .28614 Metetra
.988 .857 .619 r
.69467 .28614 .69568 .2821 .68754 .28623 .68637 .28442 Metetra
0 0 .403 r
.68637 .28442 .68754 .28623 .67903 .28167 .67763 .27049 Metetra
.979 .694 .404 r
.67763 .27049 .67903 .28167 .67055 .28365 .66908 .26943 Metetra
.968 .694 .459 r
.66908 .26943 .67055 .28365 .66222 .29958 .66084 .28905 Metetra
.93 .658 .18 r
.66084 .28905 .66222 .29958 .65231 .24871 .65106 .24408 Metetra
.955 .615 .316 r
.65106 .24408 .65231 .24871 .64292 .22548 .64211 .24336 Metetra
.978 .757 .535 r
.64211 .24336 .64292 .22548 .63353 .20794 .63253 .21664 Metetra
.983 .79 .565 r
.63253 .21664 .63353 .20794 .62418 .19883 .62312 .20571 Metetra
.97 .786 .599 r
.62312 .20571 .62418 .19883 .61469 .19007 .6135 .18928 Metetra
0 .247 .71 r
.6135 .18928 .61469 .19007 .60504 .18021 .60386 .18036 Metetra
.438 .819 .99 r
.60386 .18036 .60504 .18021 .59525 .17073 .59411 .1751 Metetra
.992 .882 .572 r
.59411 .1751 .59525 .17073 .58547 .17614 .58433 .18189 Metetra
.979 .813 .608 r
.58433 .18189 .58547 .17614 .57521 .15222 .57419 .1719 Metetra
.978 .755 .533 r
.57419 .1719 .57521 .15222 .56492 .1382 .56372 .14006 Metetra
.877 .812 .78 r
.56372 .14006 .56492 .1382 .55447 .12314 .55325 .12352 Metetra
.66 .765 .927 r
.55325 .12352 .55447 .12314 .54388 .11215 .54264 .10841 Metetra
.909 .552 .093 r
.75098 .3163 .75219 .32012 .74447 .31076 .74313 .30307 Metetra
.976 .674 .318 r
.74313 .30307 .74447 .31076 .7366 .29968 .73526 .29179 Metetra
.978 .677 .342 r
.73526 .29179 .7366 .29968 .72855 .28588 .72739 .28362 Metetra
.889 .464 .089 r
.72739 .28362 .72855 .28588 .72057 .27742 .71953 .27935 Metetra
.943 .904 .755 r
.71953 .27935 .72057 .27742 .71255 .2713 .71156 .27499 Metetra
.985 .892 .559 r
.71156 .27499 .71255 .2713 .70457 .27054 .70379 .28223 Metetra
.995 .789 .517 r
.70379 .28223 .70457 .27054 .69635 .26576 .69568 .2821 Metetra
.996 .78 .495 r
.69568 .2821 .69635 .26576 .68791 .25724 .68754 .28623 Metetra
.991 .762 .491 r
.68754 .28623 .68791 .25724 .67947 .25373 .67903 .28167 Metetra
.993 .765 .485 r
.67903 .28167 .67947 .25373 .67092 .25094 .67055 .28365 Metetra
.995 .766 .469 r
.67055 .28365 .67092 .25094 .66232 .25237 .66222 .29958 Metetra
.981 .745 .506 r
.66222 .29958 .66232 .25237 .65316 .23444 .65231 .24871 Metetra
.977 .762 .546 r
.65231 .24871 .65316 .23444 .6439 .2165 .64292 .22548 Metetra
.975 .777 .574 r
.64292 .22548 .6439 .2165 .63457 .20132 .63353 .20794 Metetra
.983 .805 .587 r
.63353 .20794 .63457 .20132 .62512 .18565 .62418 .19883 Metetra
.989 .779 .53 r
.62418 .19883 .62512 .18565 .61564 .17578 .61469 .19007 Metetra
.988 .776 .527 r
.61469 .19007 .61564 .17578 .60602 .1659 .60504 .18021 Metetra
.989 .776 .526 r
.60504 .18021 .60602 .1659 .59635 .16412 .59525 .17073 Metetra
.999 .837 .543 r
.59525 .17073 .59635 .16412 .58662 .17241 .58547 .17614 Metetra
.918 .771 .683 r
.58547 .17614 .58662 .17241 .57646 .15667 .57521 .15222 Metetra
.935 .582 .165 r
.57521 .15222 .57646 .15667 .56618 .14517 .56492 .1382 Metetra
.969 .653 .28 r
.56492 .1382 .56618 .14517 .55576 .13493 .55447 .12314 Metetra
.982 .696 .375 r
.55447 .12314 .55576 .13493 .54512 .11492 .54388 .11215 Metetra
.986 .78 .543 r
.75219 .32012 .75289 .30958 .74503 .29577 .74447 .31076 Metetra
.987 .769 .524 r
.74447 .31076 .74503 .29577 .73716 .28402 .7366 .29968 Metetra
.985 .766 .526 r
.7366 .29968 .73716 .28402 .7293 .27538 .72855 .28588 Metetra
.987 .782 .542 r
.72855 .28588 .7293 .27538 .72134 .26698 .72057 .27742 Metetra
.99 .786 .537 r
.72057 .27742 .72134 .26698 .71335 .26108 .71255 .2713 Metetra
.994 .794 .525 r
.71255 .2713 .71335 .26108 .70516 .25251 .70457 .27054 Metetra
.991 .771 .506 r
.70457 .27054 .70516 .25251 .6968 .24166 .69635 .26576 Metetra
.99 .763 .5 r
.69635 .26576 .6968 .24166 .68867 .24377 .68791 .25724 Metetra
.992 .781 .517 r
.68791 .25724 .68867 .24377 .68036 .24429 .67947 .25373 Metetra
.993 .797 .537 r
.67947 .25373 .68036 .24429 .67182 .2411 .67092 .25094 Metetra
.996 .8 .524 r
.67092 .25094 .67182 .2411 .66315 .23842 .66232 .25237 Metetra
.982 .767 .54 r
.66232 .25237 .66315 .23842 .65414 .22646 .65316 .23444 Metetra
.971 .778 .586 r
.65316 .23444 .65414 .22646 .64488 .20788 .6439 .2165 Metetra
.978 .782 .573 r
.6439 .2165 .64488 .20788 .63565 .19691 .63457 .20132 Metetra
.954 .799 .651 r
.63457 .20132 .63565 .19691 .62631 .18683 .62512 .18565 Metetra
0 .022 .527 r
.62512 .18565 .62631 .18683 .61678 .17384 .61564 .17578 Metetra
.915 .864 .775 r
.61564 .17578 .61678 .17384 .60724 .16847 .60602 .1659 Metetra
.904 .493 .171 r
.60602 .1659 .60724 .16847 .59752 .16254 .59635 .16412 Metetra
.757 .944 .613 r
.59635 .16412 .59752 .16254 .58777 .16786 .58662 .17241 Metetra
.957 .803 .649 r
.58662 .17241 .58777 .16786 .57767 .15763 .57646 .15667 Metetra
0 .191 .688 r
.57646 .15667 .57767 .15763 .56732 .13627 .56618 .14517 Metetra
.986 .793 .563 r
.56618 .14517 .56732 .13627 .55689 .12221 .55576 .13493 Metetra
.98 .771 .549 r
.55576 .13493 .55689 .12221 .54626 .0976 .54512 .11492 Metetra
.973 .782 .586 r
.75289 .30958 .7537 .30234 .74612 .29621 .74503 .29577 Metetra
.29 .553 .925 r
.74503 .29577 .74612 .29621 .73831 .28612 .73716 .28402 Metetra
.812 .375 0 r
.73716 .28402 .73831 .28612 .73047 .27792 .7293 .27538 Metetra
.873 .461 .019 r
.7293 .27538 .73047 .27792 .72251 .26965 .72134 .26698 Metetra
.905 .502 .11 r
.72134 .26698 .72251 .26965 .71474 .27098 .71335 .26108 Metetra
.981 .691 .366 r
.71335 .26108 .71474 .27098 .70701 .27833 .70516 .25251 Metetra
.988 .726 .425 r
.70516 .25251 .70701 .27833 .69927 .29085 .6968 .24166 Metetra
.987 .733 .452 r
.6968 .24166 .69927 .29085 .6917 .31595 .68867 .24377 Metetra
.988 .737 .455 r
.68867 .24377 .6917 .31595 .68298 .30346 .68036 .24429 Metetra
.988 .736 .451 r
.68036 .24429 .68298 .30346 .67583 .36162 .67182 .2411 Metetra
.989 .74 .458 r
.67182 .2411 .67583 .36162 .66882 .43852 .66315 .23842 Metetra
.99 .742 .459 r
.66315 .23842 .66882 .43852 .6565 .28327 .65414 .22646 Metetra
.99 .737 .442 r
.65414 .22646 .6565 .28327 .6472 .26644 .64488 .20788 Metetra
.989 .736 .447 r
.64488 .20788 .6472 .26644 .63786 .25304 .63565 .19691 Metetra
.989 .736 .446 r
.63565 .19691 .63786 .25304 .62804 .21928 .62631 .18683 Metetra
.989 .729 .431 r
.62631 .18683 .62804 .21928 .61836 .19896 .61678 .17384 Metetra
.987 .723 .43 r
.61678 .17384 .61836 .19896 .60871 .18891 .60724 .16847 Metetra
.986 .717 .422 r
.60724 .16847 .60871 .18891 .59898 .18318 .59752 .16254 Metetra
.982 .713 .438 r
.59752 .16254 .59898 .18318 .5892 .18809 .58777 .16786 Metetra
.987 .718 .414 r
.58777 .16786 .5892 .18809 .57899 .16923 .57767 .15763 Metetra
.982 .696 .337 r
.57767 .15763 .57899 .16923 .56856 .1396 .56732 .13627 Metetra
.887 .501 .043 r
.56732 .13627 .56856 .1396 .55811 .12156 .55689 .12221 Metetra
.707 .693 .834 r
.55689 .12221 .55811 .12156 .54754 .10767 .54626 .0976 Metetra
.981 .691 .375 r
.7537 .30234 .75512 .31203 .74729 .29885 .74612 .29621 Metetra
.858 .455 0 r
.74612 .29621 .74729 .29885 .73952 .28971 .73831 .28612 Metetra
.933 .566 .166 r
.73831 .28612 .73952 .28971 .73168 .28169 .73047 .27792 Metetra
.938 .576 .182 r
.73047 .27792 .73168 .28169 .72375 .27414 .72251 .26965 Metetra
.954 .619 .337 r
.72251 .26965 .72375 .27414 .71585 .27116 .71474 .27098 Metetra
.498 0 0 r
.71474 .27098 .71585 .27116 .70812 .27821 .70701 .27833 Metetra
.433 .002 .118 r
.70701 .27833 .70812 .27821 .70036 .28966 .69927 .29085 Metetra
.18 0 .216 r
.69927 .29085 .70036 .28966 .692 .28454 .6917 .31595 Metetra
.989 .758 .495 r
.6917 .31595 .692 .28454 .68342 .27581 .68298 .30346 Metetra
.994 .775 .407 r
.68298 .30346 .68342 .27581 .67476 .26908 .67583 .36162 Metetra
.995 .757 .443 r
.67583 .36162 .67476 .26908 .66694 .30446 .66882 .43852 Metetra
.979 .737 .499 r
.66882 .43852 .66694 .30446 .65695 .25005 .6565 .28327 Metetra
.988 .756 .497 r
.6565 .28327 .65695 .25005 .64794 .24538 .6472 .26644 Metetra
.988 .764 .511 r
.6472 .26644 .64794 .24538 .63863 .23187 .63786 .25304 Metetra
.977 .752 .531 r
.63786 .25304 .63863 .23187 .629 .20716 .62804 .21928 Metetra
.978 .769 .553 r
.62804 .21928 .629 .20716 .6194 .19082 .61836 .19896 Metetra
.984 .795 .569 r
.61836 .19896 .6194 .19082 .60976 .17975 .60871 .18891 Metetra
.991 .797 .549 r
.60871 .18891 .60976 .17975 .59999 .16994 .59898 .18318 Metetra
.997 .792 .504 r
.59898 .18318 .59999 .16994 .59031 .17975 .5892 .18809 Metetra
.973 .78 .583 r
.5892 .18809 .59031 .17975 .58016 .16551 .57899 .16923 Metetra
.9 .749 .684 r
.57899 .16923 .58016 .16551 .56974 .13589 .56856 .1396 Metetra
.939 .8 .681 r
.56856 .1396 .56974 .13589 .55934 .12331 .55811 .12156 Metetra
.618 .167 0 r
.55811 .12156 .55934 .12331 .54875 .10509 .54754 .10767 Metetra
.981 .776 .554 r
.75512 .31203 .75582 .30195 .74809 .29088 .74729 .29885 Metetra
.984 .79 .565 r
.74729 .29885 .74809 .29088 .74036 .2827 .73952 .28971 Metetra
.984 .798 .574 r
.73952 .28971 .74036 .2827 .73245 .2721 .73168 .28169 Metetra
.988 .787 .546 r
.73168 .28169 .73245 .2721 .72452 .26375 .72375 .27414 Metetra
.993 .79 .529 r
.72375 .27414 .72452 .26375 .71647 .25533 .71585 .27116 Metetra
.997 .782 .487 r
.71585 .27116 .71647 .25533 .70873 .26122 .70812 .27821 Metetra
.998 .782 .477 r
.70812 .27821 .70873 .26122 .70045 .25287 .70036 .28966 Metetra
.991 .758 .484 r
.70036 .28966 .70045 .25287 .69244 .25893 .692 .28454 Metetra
.99 .762 .497 r
.692 .28454 .69244 .25893 .68399 .25395 .68342 .27581 Metetra
.991 .766 .501 r
.68342 .27581 .68399 .25395 .67535 .24622 .67476 .26908 Metetra
.997 .779 .437 r
.67476 .26908 .67535 .24622 .66653 .23612 .66694 .30446 Metetra
.984 .745 .494 r
.66694 .30446 .66653 .23612 .65763 .22815 .65695 .25005 Metetra
.992 .768 .498 r
.65695 .25005 .65763 .22815 .64859 .22023 .64794 .24538 Metetra
.988 .761 .503 r
.64794 .24538 .64859 .22023 .63927 .20376 .63863 .23187 Metetra
.985 .755 .509 r
.63863 .23187 .63927 .20376 .63 .19773 .629 .20716 Metetra
.978 .779 .567 r
.629 .20716 .63 .19773 .62047 .18377 .6194 .19082 Metetra
.981 .799 .585 r
.6194 .19082 .62047 .18377 .61092 .17821 .60976 .17975 Metetra
.888 .873 .817 r
.60976 .17975 .61092 .17821 .60141 .18673 .59999 .16994 Metetra
.978 .704 .439 r
.59999 .16994 .60141 .18673 .59144 .17399 .59031 .17975 Metetra
.971 .801 .616 r
.59031 .17975 .59144 .17399 .58133 .16213 .58016 .16551 Metetra
.89 .746 .695 r
.58016 .16551 .58133 .16213 .57098 .13955 .56974 .13589 Metetra
.914 .537 .109 r
.56974 .13589 .57098 .13955 .56058 .12639 .55934 .12331 Metetra
.816 .431 0 r
.55934 .12331 .56058 .12639 .55002 .11299 .54875 .10509 Metetra
.794 .813 .866 r
.75582 .30195 .75687 .30113 .74916 .29063 .74809 .29088 Metetra
.63 .812 .97 r
.74809 .29088 .74916 .29063 .74144 .28242 .74036 .2827 Metetra
.654 .776 .938 r
.74036 .2827 .74144 .28242 .73353 .27184 .73245 .2721 Metetra
.629 .813 .971 r
.73245 .2721 .73353 .27184 .7256 .26351 .72452 .26375 Metetra
.617 .809 .974 r
.72452 .26375 .7256 .26351 .71756 .25514 .71647 .25533 Metetra
.187 0 0 r
.71647 .25533 .71756 .25514 .71015 .2718 .70873 .26122 Metetra
.982 .694 .372 r
.70873 .26122 .71015 .2718 .70223 .27667 .70045 .25287 Metetra
.983 .719 .444 r
.70045 .25287 .70223 .27667 .6939 .27145 .69244 .25893 Metetra
.983 .701 .397 r
.69244 .25893 .6939 .27145 .68549 .26829 .68399 .25395 Metetra
.985 .708 .398 r
.68399 .25395 .68549 .26829 .67696 .26561 .67535 .24622 Metetra
.987 .718 .411 r
.67535 .24622 .67696 .26561 .6687 .28086 .66653 .23612 Metetra
.989 .733 .442 r
.66653 .23612 .6687 .28086 .65922 .24833 .65763 .22815 Metetra
.987 .718 .417 r
.65763 .22815 .65922 .24833 .65003 .23358 .64859 .22023 Metetra
.985 .705 .367 r
.64859 .22023 .65003 .23358 .64064 .21476 .63927 .20376 Metetra
.981 .693 .383 r
.63927 .20376 .64064 .21476 .63126 .20238 .63 .19773 Metetra
.939 .593 .174 r
.63 .19773 .63126 .20238 .62172 .18826 .62047 .18377 Metetra
.953 .603 .26 r
.62047 .18377 .62172 .18826 .6121 .17759 .61092 .17821 Metetra
.61092 .17821 .6121 .17759 .60237 .16934 .60141 .18673 Metetra
.988 .769 .519 r
.60141 .18673 .60237 .16934 .59269 .17824 .59144 .17399 Metetra
.937 .578 .173 r
.59144 .17399 .59269 .17824 .58248 .15636 .58133 .16213 Metetra
.953 .778 .629 r
.58133 .16213 .58248 .15636 .57211 .12941 .57098 .13955 Metetra
.984 .785 .556 r
.57098 .13955 .57211 .12941 .56172 .11521 .56058 .12639 Metetra
.985 .782 .548 r
.56058 .12639 .56172 .11521 .55117 .10092 .55002 .11299 Metetra
.988 .719 .408 r
.75687 .30113 .75862 .31994 .75073 .30471 .74916 .29063 Metetra
.985 .709 .396 r
.74916 .29063 .75073 .30471 .74285 .29208 .74144 .28242 Metetra
.981 .69 .352 r
.74144 .28242 .74285 .29208 .73492 .28103 .73353 .27184 Metetra
.98 .687 .357 r
.73353 .27184 .73492 .28103 .72717 .27843 .7256 .26351 Metetra
.986 .711 .399 r
.7256 .26351 .72717 .27843 .71925 .2741 .71756 .25514 Metetra
.976 .709 .457 r
.71756 .25514 .71925 .2741 .7115 .27974 .71015 .2718 Metetra
.969 .671 .404 r
.71015 .2718 .7115 .27974 .70359 .28486 .70223 .27667 Metetra
.977 .677 .359 r
.70223 .27667 .70359 .28486 .69517 .2769 .6939 .27145 Metetra
.965 .638 .32 r
.6939 .27145 .69517 .2769 .68663 .26857 .68549 .26829 Metetra
0 .457 .734 r
.68549 .26829 .68663 .26857 .67811 .26599 .67696 .26561 Metetra
.617 .211 .251 r
.67696 .26561 .67811 .26599 .66979 .27814 .6687 .28086 Metetra
.85 .711 .709 r
.6687 .28086 .66979 .27814 .66017 .23934 .65922 .24833 Metetra
.979 .782 .568 r
.65922 .24833 .66017 .23934 .6511 .22933 .65003 .23358 Metetra
.942 .786 .659 r
.65003 .23358 .6511 .22933 .64158 .20304 .64064 .21476 Metetra
.986 .778 .542 r
.64064 .21476 .64158 .20304 .63223 .19125 .63126 .20238 Metetra
.983 .778 .549 r
.63126 .20238 .63223 .19125 .62276 .18022 .62172 .18826 Metetra
.984 .795 .571 r
.62172 .18826 .62276 .18022 .61317 .17044 .6121 .17759 Metetra
.986 .805 .577 r
.6121 .17759 .61317 .17044 .60347 .16301 .60237 .16934 Metetra
.998 .846 .528 r
.60237 .16934 .60347 .16301 .5938 .17088 .59269 .17824 Metetra
.964 .776 .6 r
.59269 .17824 .5938 .17088 .58374 .16082 .58248 .15636 Metetra
.835 .506 0 r
.58248 .15636 .58374 .16082 .57335 .13306 .57211 .12941 Metetra
.903 .527 .08 r
.57211 .12941 .57335 .13306 .56297 .12044 .56172 .11521 Metetra
.95 .611 .212 r
.56172 .11521 .56297 .12044 .55245 .10898 .55117 .10092 Metetra
.899 .79 .731 r
.75862 .31994 .75961 .31768 .75159 .29837 .75073 .30471 Metetra
.973 .79 .596 r
.75073 .30471 .75159 .29837 .74378 .28772 .74285 .29208 Metetra
.965 .808 .637 r
.74285 .29208 .74378 .28772 .73604 .28189 .73492 .28103 Metetra
.614 .053 0 r
.73492 .28103 .73604 .28189 .72811 .2734 .72717 .27843 Metetra
.987 .828 .598 r
.72717 .27843 .72811 .2734 .72 .26272 .71925 .2741 Metetra
.998 .795 .5 r
.71925 .2741 .72 .26272 .71185 .25415 .7115 .27974 Metetra
.994 .767 .48 r
.7115 .27974 .71185 .25415 .70394 .25786 .70359 .28486 Metetra
.99 .761 .494 r
.70359 .28486 .70394 .25786 .69574 .25649 .69517 .2769 Metetra
.99 .767 .504 r
.69517 .2769 .69574 .25649 .6873 .25079 .68663 .26857 Metetra
.993 .773 .502 r
.68663 .26857 .6873 .25079 .67891 .25226 .67811 .26599 Metetra
.999 .792 .481 r
.67811 .26599 .67891 .25226 .67024 .24808 .66979 .27814 Metetra
.98 .748 .516 r
.66979 .27814 .67024 .24808 .66101 .22509 .66017 .23934 Metetra
.989 .775 .525 r
.66017 .23934 .66101 .22509 .6518 .20719 .6511 .22933 Metetra
.982 .756 .52 r
.6511 .22933 .6518 .20719 .64261 .1964 .64158 .20304 Metetra
.979 .799 .592 r
.64158 .20304 .64261 .1964 .63338 .19017 .63223 .19125 Metetra
.83 .853 .864 r
.63223 .19125 .63338 .19017 .6239 .1777 .62276 .18022 Metetra
.941 .855 .729 r
.62276 .18022 .6239 .1777 .61436 .17055 .61317 .17044 Metetra
.298 .697 .976 r
.61317 .17044 .61436 .17055 .60471 .166 .60347 .16301 Metetra
.906 .536 .319 r
.60347 .16301 .60471 .166 .59487 .15967 .5938 .17088 Metetra
.988 .785 .542 r
.5938 .17088 .59487 .15967 .58475 .14294 .58374 .16082 Metetra
.98 .759 .533 r
.58374 .16082 .58475 .14294 .57453 .12933 .57335 .13306 Metetra
.957 .826 .673 r
.57335 .13306 .57453 .12933 .56413 .11274 .56297 .12044 Metetra
.983 .798 .578 r
.56297 .12044 .56413 .11274 .55359 .09505 .55245 .10898 Metetra
.983 .759 .522 r
.75961 .31768 .75999 .29882 .75216 .28427 .75159 .29837 Metetra
.987 .771 .525 r
.75159 .29837 .75216 .28427 .74446 .27602 .74378 .28772 Metetra
.991 .782 .527 r
.74378 .28772 .74446 .27602 .73662 .26663 .73604 .28189 Metetra
.989 .772 .517 r
.73604 .28189 .73662 .26663 .72872 .25824 .72811 .2734 Metetra
.988 .77 .521 r
.72811 .2734 .72872 .25824 .72068 .24908 .72 .26272 Metetra
.989 .775 .524 r
.72 .26272 .72068 .24908 .71255 .24053 .71185 .25415 Metetra
.997 .786 .498 r
.71185 .25415 .71255 .24053 .70438 .23435 .70394 .25786 Metetra
.993 .767 .49 r
.70394 .25786 .70438 .23435 .69621 .23234 .69574 .25649 Metetra
.991 .764 .494 r
.69574 .25649 .69621 .23234 .68783 .22755 .6873 .25079 Metetra
.994 .769 .487 r
.6873 .25079 .68783 .22755 .67958 .23333 .67891 .25226 Metetra
.992 .771 .501 r
.67891 .25226 .67958 .23333 .6711 .236 .67024 .24808 Metetra
.975 .764 .556 r
.67024 .24808 .6711 .236 .66214 .22427 .66101 .22509 Metetra
.761 .749 .842 r
.66101 .22509 .66214 .22427 .65276 .19799 .6518 .20719 Metetra
.985 .788 .557 r
.6518 .20719 .65276 .19799 .64344 .1792 .64261 .1964 Metetra
.991 .773 .509 r
.64261 .1964 .64344 .1792 .63417 .16941 .63338 .19017 Metetra
.989 .765 .509 r
.63338 .19017 .63417 .16941 .62477 .15952 .6239 .1777 Metetra
.991 .771 .508 r
.6239 .1777 .62477 .15952 .61522 .14959 .61436 .17055 Metetra
.992 .77 .499 r
.61436 .17055 .61522 .14959 .60576 .15633 .60471 .166 Metetra
.991 .795 .545 r
.60471 .166 .60576 .15633 .59606 .15872 .59487 .15967 Metetra
.784 .785 .854 r
.59487 .15967 .59606 .15872 .58599 .1454 .58475 .14294 Metetra
.794 .373 0 r
.58475 .14294 .58599 .1454 .5757 .1253 .57453 .12933 Metetra
.949 .806 .667 r
.57453 .12933 .5757 .1253 .56537 .11441 .56413 .11274 Metetra
0 0 .525 r
.56413 .11274 .56537 .11441 .55476 .08663 .55359 .09505 Metetra
0 0 .522 r
.75999 .29882 .76113 .3005 .75346 .29053 .75216 .28427 Metetra
.971 .655 .301 r
.75216 .28427 .75346 .29053 .74559 .27735 .74446 .27602 Metetra
0 0 .463 r
.74446 .27602 .74559 .27735 .73779 .26912 .73662 .26663 Metetra
.866 .45 .003 r
.73662 .26663 .73779 .26912 .7299 .261 .72872 .25824 Metetra
.882 .481 .035 r
.72872 .25824 .7299 .261 .7221 .25937 .72068 .24908 Metetra
.982 .693 .367 r
.72068 .24908 .7221 .25937 .71466 .27412 .71255 .24053 Metetra
.988 .729 .436 r
.71255 .24053 .71466 .27412 .70689 .28298 .70438 .23435 Metetra
.988 .733 .447 r
.70438 .23435 .70689 .28298 .69864 .2798 .69621 .23234 Metetra
.989 .734 .444 r
.69621 .23234 .69864 .2798 .69012 .27174 .68783 .22755 Metetra
.987 .731 .451 r
.68783 .22755 .69012 .27174 .68135 .25847 .67958 .23333 Metetra
.985 .721 .439 r
.67958 .23333 .68135 .25847 .67295 .26567 .6711 .236 Metetra
.989 .728 .426 r
.6711 .236 .67295 .26567 .66365 .24027 .66214 .22427 Metetra
.986 .713 .356 r
.66214 .22427 .66365 .24027 .65463 .23157 .65276 .19799 Metetra
.99 .731 .423 r
.65276 .19799 .65463 .23157 .64536 .21783 .64344 .1792 Metetra
.989 .731 .436 r
.64344 .1792 .64536 .21783 .63588 .1989 .63417 .16941 Metetra
.988 .727 .428 r
.63417 .16941 .63588 .1989 .62633 .18256 .62477 .15952 Metetra
.988 .721 .418 r
.62477 .15952 .62633 .18256 .61677 .17292 .61522 .14959 Metetra
.983 .717 .44 r
.61522 .14959 .61677 .17292 .6071 .16665 .60576 .15633 Metetra
.975 .684 .401 r
.60576 .15633 .6071 .16665 .59744 .17309 .59606 .15872 Metetra
.985 .706 .382 r
.59606 .15872 .59744 .17309 .58731 .15547 .58599 .1454 Metetra
.978 .685 .316 r
.58599 .1454 .58731 .15547 .57697 .13107 .5757 .1253 Metetra
.962 .631 .264 r
.5757 .1253 .57697 .13107 .56659 .11424 .56537 .11441 Metetra
.609 .619 .836 r
.56537 .11441 .56659 .11424 .55604 .09463 .55476 .08663 Metetra
.956 .622 .233 r
.76113 .3005 .76238 .30549 .75457 .29146 .75346 .29053 Metetra
0 .31 .802 r
.75346 .29053 .75457 .29146 .74685 .28236 .74559 .27735 Metetra
.96 .626 .256 r
.74559 .27735 .74685 .28236 .73905 .27408 .73779 .26912 Metetra
.959 .624 .255 r
.73779 .26912 .73905 .27408 .73115 .26565 .7299 .261 Metetra
.959 .622 .311 r
.7299 .261 .73115 .26565 .72359 .27185 .7221 .25937 Metetra
.97 .692 .448 r
.7221 .25937 .72359 .27185 .71571 .27198 .71466 .27412 Metetra
.865 .932 .551 r
.71466 .27412 .71571 .27198 .70796 .28095 .70689 .28298 Metetra
.951 .917 .744 r
.70689 .28298 .70796 .28095 .6996 .27388 .69864 .2798 Metetra
.983 .81 .593 r
.69864 .2798 .6996 .27388 .69112 .26673 .69012 .27174 Metetra
.966 .801 .627 r
.69012 .27174 .69112 .26673 .68252 .25971 .68135 .25847 Metetra
.793 .352 .201 r
.68135 .25847 .68252 .25971 .67448 .28162 .67295 .26567 Metetra
.986 .713 .356 r
.67295 .26567 .67448 .28162 .66481 .24034 .66365 .24027 Metetra
.4 .719 .988 r
.66365 .24027 .66481 .24034 .65566 .22562 .65463 .23157 Metetra
.972 .797 .608 r
.65463 .23157 .65566 .22562 .64633 .20761 .64536 .21783 Metetra
.977 .773 .563 r
.64536 .21783 .64633 .20761 .63702 .197 .63588 .1989 Metetra
.881 .803 .769 r
.63588 .1989 .63702 .197 .62752 .18304 .62633 .18256 Metetra
.072 .496 .896 r
.62633 .18256 .62752 .18304 .61795 .17296 .61677 .17292 Metetra
.32 .734 .977 r
.61677 .17292 .61795 .17296 .60827 .16504 .6071 .16665 Metetra
.815 .972 .668 r
.6071 .16665 .60827 .16504 .59858 .16797 .59744 .17309 Metetra
.959 .795 .636 r
.59744 .17309 .59858 .16797 .58846 .15019 .58731 .15547 Metetra
.944 .773 .641 r
.58731 .15547 .58846 .15019 .57813 .12497 .57697 .13107 Metetra
.968 .794 .613 r
.57697 .13107 .57813 .12497 .56779 .11254 .56659 .11424 Metetra
.853 .787 .786 r
.56659 .11424 .56779 .11254 .55726 .09437 .55604 .09463 Metetra
0 0 .431 r
.76238 .30549 .76353 .30734 .75568 .29234 .75457 .29146 Metetra
0 .222 .72 r
.75457 .29146 .75568 .29234 .74791 .28165 .74685 .28236 Metetra
.783 .861 .908 r
.74685 .28236 .74791 .28165 .74012 .27348 .73905 .27408 Metetra
.752 .853 .926 r
.73905 .27408 .74012 .27348 .73234 .26853 .73115 .26565 Metetra
.914 .551 .328 r
.73115 .26565 .73234 .26853 .72439 .26197 .72359 .27185 Metetra
.996 .797 .522 r
.72359 .27185 .72439 .26197 .7169 .27437 .71571 .27198 Metetra
.885 .514 .333 r
.71571 .27198 .7169 .27437 .70912 .28234 .70796 .28095 Metetra
.674 .172 0 r
.70796 .28095 .70912 .28234 .7007 .27288 .6996 .27388 Metetra
.837 .9 .882 r
.6996 .27388 .7007 .27288 .69238 .27121 .69112 .26673 Metetra
.953 .605 .242 r
.69112 .26673 .69238 .27121 .68385 .26716 .68252 .25971 Metetra
.941 .647 .454 r
.68252 .25971 .68385 .26716 .67541 .27215 .67448 .28162 Metetra
.941 .737 .598 r
.67448 .28162 .67541 .27215 .66613 .24741 .66481 .24034 Metetra
.968 .656 .274 r
.66481 .24034 .66613 .24741 .65693 .23068 .65566 .22562 Metetra
.929 .593 .144 r
.65566 .22562 .65693 .23068 .64761 .21325 .64633 .20761 Metetra
.962 .632 .259 r
.64633 .20761 .64761 .21325 .63825 .19986 .63702 .197 Metetra
.836 .437 0 r
.63702 .197 .63825 .19986 .62872 .18454 .62752 .18304 Metetra
.621 .137 0 r
.62752 .18304 .62872 .18454 .61915 .17383 .61795 .17296 Metetra
0 .158 .616 r
.61795 .17296 .61915 .17383 .60949 .16658 .60827 .16504 Metetra
.823 .359 .116 r
.60827 .16504 .60949 .16658 .59989 .17615 .59858 .16797 Metetra
.972 .667 .288 r
.59858 .16797 .59989 .17615 .58971 .15408 .58846 .15019 Metetra
.797 .458 0 r
.58846 .15019 .58971 .15408 .57936 .12642 .57813 .12497 Metetra
0 0 .468 r
.57813 .12497 .57936 .12642 .56903 .11501 .56779 .11254 Metetra
.707 .308 0 r
.56779 .11254 .56903 .11501 .55853 .10006 .55726 .09437 Metetra
.943 .792 .664 r
.76353 .30734 .76446 .30359 .75672 .29104 .75568 .29234 Metetra
.862 .833 .816 r
.75568 .29234 .75672 .29104 .74899 .28158 .74791 .28165 Metetra
.525 .768 .986 r
.74791 .28165 .74899 .28158 .74119 .27281 .74012 .27348 Metetra
.767 .925 .939 r
.74012 .27348 .74119 .27281 .73336 .26648 .73234 .26853 Metetra
.939 .878 .748 r
.73234 .26853 .73336 .26648 .72548 .26161 .72439 .26197 Metetra
.306 0 .055 r
.72439 .26197 .72548 .26161 .71814 .27862 .7169 .27437 Metetra
.938 .606 .377 r
.7169 .27437 .71814 .27862 .71025 .28264 .70912 .28234 Metetra
.273 .61 .956 r
.70912 .28234 .71025 .28264 .70197 .27801 .7007 .27288 Metetra
.961 .63 .32 r
.7007 .27288 .70197 .27801 .69359 .27401 .69238 .27121 Metetra
.915 .514 .155 r
.69238 .27121 .69359 .27401 .68511 .2717 .68385 .26716 Metetra
.947 .612 .355 r
.68385 .26716 .68511 .2717 .67708 .29326 .67541 .27215 Metetra
.989 .722 .385 r
.67541 .27215 .67708 .29326 .66743 .25363 .66613 .24741 Metetra
.956 .636 .225 r
.66613 .24741 .66743 .25363 .65831 .24051 .65693 .23068 Metetra
.978 .685 .319 r
.65693 .23068 .65831 .24051 .64909 .22874 .64761 .21325 Metetra
.986 .71 .386 r
.64761 .21325 .64909 .22874 .63967 .21292 .63825 .19986 Metetra
.984 .703 .365 r
.63825 .19986 .63967 .21292 .63004 .19236 .62872 .18454 Metetra
.975 .668 .319 r
.62872 .18454 .63004 .19236 .62042 .17893 .61915 .17383 Metetra
.959 .619 .267 r
.61915 .17383 .62042 .17893 .61089 .18084 .60949 .16658 Metetra
.976 .697 .431 r
.60949 .16658 .61089 .18084 .60166 .21876 .59989 .17615 Metetra
.99 .734 .428 r
.59989 .17615 .60166 .21876 .59099 .16037 .58971 .15408 Metetra
.921 .608 .134 r
.58971 .15408 .59099 .16037 .58066 .13491 .57936 .12642 Metetra
.976 .672 .328 r
.57936 .12642 .58066 .13491 .57026 .11593 .56903 .11501 Metetra
0 .3 .792 r
.56903 .11501 .57026 .11593 .55971 .0943 .55853 .10006 Metetra
.981 .69 .338 r
.76446 .30359 .7659 .31332 .7579 .29382 .75672 .29104 Metetra
.876 .478 .022 r
.75672 .29104 .7579 .29382 .75014 .28356 .74899 .28158 Metetra
.781 .337 0 r
.74899 .28158 .75014 .28356 .74237 .27543 .74119 .27281 Metetra
.896 .488 .082 r
.74119 .27281 .74237 .27543 .73465 .27215 .73336 .26648 Metetra
.967 .644 .311 r
.73336 .26648 .73465 .27215 .72692 .27239 .72548 .26161 Metetra
.964 .682 .451 r
.72548 .26161 .72692 .27239 .71925 .27833 .71814 .27862 Metetra
.71814 .27862 .71925 .27833 .71119 .27651 .71025 .28264 Metetra
.99 .817 .577 r
.71025 .28264 .71119 .27651 .7028 .26734 .70197 .27801 Metetra
.993 .79 .529 r
.70197 .27801 .7028 .26734 .69432 .25904 .69359 .27401 Metetra
.994 .779 .507 r
.69359 .27401 .69432 .25904 .68573 .25146 .68511 .2717 Metetra
.998 .78 .456 r
.68511 .2717 .68573 .25146 .67715 .24885 .67708 .29326 Metetra
.984 .748 .499 r
.67708 .29326 .67715 .24885 .66808 .23173 .66743 .25363 Metetra
.989 .764 .506 r
.66743 .25363 .66808 .23173 .65897 .21743 .65831 .24051 Metetra
.989 .763 .502 r
.65831 .24051 .65897 .21743 .64972 .20236 .64909 .22874 Metetra
.988 .76 .501 r
.64909 .22874 .64972 .20236 .6404 .18987 .63967 .21292 Metetra
.986 .759 .511 r
.63967 .21292 .6404 .18987 .63101 .18015 .63004 .19236 Metetra
.986 .777 .539 r
.63004 .19236 .63101 .18015 .62146 .16991 .62042 .17893 Metetra
.997 .809 .528 r
.62042 .17893 .62146 .16991 .61176 .15872 .61089 .18084 Metetra
.997 .783 .436 r
.61089 .18084 .61176 .15872 .60212 .16258 .60166 .21876 Metetra
.983 .744 .498 r
.60166 .21876 .60212 .16258 .59212 .15331 .59099 .16037 Metetra
.957 .77 .609 r
.59099 .16037 .59212 .15331 .58185 .13311 .58066 .13491 Metetra
.863 .792 .78 r
.58066 .13491 .58185 .13311 .57148 .11576 .57026 .11593 Metetra
.604 .665 .882 r
.57026 .11593 .57148 .11576 .56103 .10627 .55971 .0943 Metetra
.394 .503 .851 r
.7659 .31332 .767 .3139 .75917 .29922 .7579 .29382 Metetra
.96 .632 .248 r
.7579 .29382 .75917 .29922 .75135 .28701 .75014 .28356 Metetra
.926 .553 .146 r
.75014 .28356 .75135 .28701 .74356 .27821 .74237 .27543 Metetra
.92 .526 .175 r
.74237 .27543 .74356 .27821 .73565 .2693 .73465 .27215 Metetra
.981 .903 .654 r
.73465 .27215 .73565 .2693 .72768 .26158 .72692 .27239 Metetra
.999 .798 .499 r
.72692 .27239 .72768 .26158 .71959 .25319 .71925 .27833 Metetra
.993 .765 .486 r
.71925 .27833 .71959 .25319 .71156 .25092 .71119 .27651 Metetra
.99 .762 .494 r
.71119 .27651 .71156 .25092 .70337 .24775 .7028 .26734 Metetra
.99 .768 .504 r
.7028 .26734 .70337 .24775 .69511 .24641 .69432 .25904 Metetra
.99 .78 .525 r
.69432 .25904 .69511 .24641 .68655 .23895 .68573 .25146 Metetra
.994 .786 .516 r
.68573 .25146 .68655 .23895 .67799 .23652 .67715 .24885 Metetra
.982 .771 .544 r
.67715 .24885 .67799 .23652 .66897 .22027 .66808 .23173 Metetra
.984 .776 .545 r
.66808 .23173 .66897 .22027 .65989 .20653 .65897 .21743 Metetra
.983 .777 .55 r
.65897 .21743 .65989 .20653 .65073 .1947 .64972 .20236 Metetra
.981 .792 .577 r
.64972 .20236 .65073 .1947 .64133 .17737 .6404 .18987 Metetra
.989 .78 .531 r
.6404 .18987 .64133 .17737 .63196 .16761 .63101 .18015 Metetra
.989 .78 .532 r
.63101 .18015 .63196 .16761 .62243 .15651 .62146 .16991 Metetra
.988 .777 .529 r
.62146 .16991 .62243 .15651 .6129 .15514 .61176 .15872 Metetra
.986 .9 .611 r
.61176 .15872 .6129 .15514 .60344 .17144 .60212 .16258 Metetra
.977 .676 .343 r
.60212 .16258 .60344 .17144 .59319 .14196 .59212 .15331 Metetra
.979 .773 .555 r
.59212 .15331 .59319 .14196 .583 .12633 .58185 .13311 Metetra
.971 .79 .601 r
.58185 .13311 .583 .12633 .57271 .11565 .57148 .11576 Metetra
.498 .782 .996 r
.57148 .11576 .57271 .11565 .56216 .09317 .56103 .10627 Metetra
.982 .771 .543 r
.767 .3139 .76763 .30207 .75991 .28989 .75917 .29922 Metetra
.982 .78 .556 r
.75917 .29922 .75991 .28989 .75221 .28056 .75135 .28701 Metetra
.983 .801 .582 r
.75135 .28701 .75221 .28056 .74429 .26792 .74356 .27821 Metetra
.988 .783 .541 r
.74356 .27821 .74429 .26792 .73639 .25835 .73565 .2693 Metetra
.989 .783 .534 r
.73565 .2693 .73639 .25835 .72849 .25214 .72768 .26158 Metetra
.988 .788 .547 r
.72768 .26158 .72849 .25214 .72039 .24315 .71959 .25319 Metetra
.994 .794 .527 r
.71959 .25319 .72039 .24315 .7123 .23816 .71156 .25092 Metetra
.993 .783 .515 r
.71156 .25092 .7123 .23816 .70414 .23524 .70337 .24775 Metetra
.995 .786 .512 r
.70337 .24775 .70414 .23524 .69599 .23701 .69511 .24641 Metetra
.989 .791 .546 r
.69511 .24641 .69599 .23701 .68767 .23804 .68655 .23895 Metetra
.806 .977 .9 r
.68655 .23895 .68767 .23804 .67922 .23997 .67799 .23652 Metetra
.854 .485 0 r
.67799 .23652 .67922 .23997 .6702 .2237 .66897 .22027 Metetra
.884 .507 .037 r
.66897 .22027 .6702 .2237 .66098 .20367 .65989 .20653 Metetra
.942 .832 .707 r
.65989 .20653 .66098 .20367 .65172 .18662 .65073 .1947 Metetra
.975 .781 .581 r
.65073 .1947 .65172 .18662 .64244 .1741 .64133 .17737 Metetra
.959 .842 .683 r
.64133 .17737 .64244 .1741 .63309 .16497 .63196 .16761 Metetra
.94 .844 .721 r
.63196 .16761 .63309 .16497 .62366 .15963 .62243 .15651 Metetra
.925 .537 .22 r
.62243 .15651 .62366 .15963 .61422 .16317 .6129 .15514 Metetra
.954 .655 .429 r
.6129 .15514 .61422 .16317 .60472 .17653 .60344 .17144 Metetra
.847 .531 .001 r
.60344 .17144 .60472 .17653 .59466 .16251 .59319 .14196 Metetra
.988 .718 .4 r
.59319 .14196 .59466 .16251 .58421 .1256 .583 .12633 Metetra
.758 .86 .925 r
.583 .12633 .58421 .1256 .57391 .11375 .57271 .11565 Metetra
.854 .769 .767 r
.57271 .11565 .57391 .11375 .5634 .09468 .56216 .09317 Metetra
.983 .697 .355 r
.76763 .30207 .76912 .31314 .76117 .29481 .75991 .28989 Metetra
.956 .62 .234 r
.75991 .28989 .76117 .29481 .75336 .28226 .75221 .28056 Metetra
0 0 .438 r
.75221 .28056 .75336 .28226 .74563 .27493 .74429 .26792 Metetra
.973 .663 .306 r
.74429 .26792 .74563 .27493 .7378 .26793 .73639 .25835 Metetra
.98 .688 .367 r
.73639 .25835 .7378 .26793 .7301 .26793 .72849 .25214 Metetra
.986 .712 .397 r
.72849 .25214 .7301 .26793 .72268 .2813 .72039 .24315 Metetra
.989 .731 .437 r
.72039 .24315 .72268 .2813 .71495 .28933 .7123 .23816 Metetra
.989 .734 .444 r
.7123 .23816 .71495 .28933 .70645 .27639 .70414 .23524 Metetra
.987 .73 .444 r
.70414 .23524 .70645 .27639 .69795 .26716 .69599 .23701 Metetra
.987 .725 .438 r
.69599 .23701 .69795 .26716 .6894 .26064 .68767 .23804 Metetra
.985 .718 .433 r
.68767 .23804 .6894 .26064 .68148 .28429 .67922 .23997 Metetra
.99 .734 .431 r
.67922 .23997 .68148 .28429 .6719 .24652 .6702 .2237 Metetra
.989 .723 .398 r
.6702 .2237 .6719 .24652 .66272 .22939 .66098 .20367 Metetra
.989 .725 .41 r
.66098 .20367 .66272 .22939 .65348 .2146 .65172 .18662 Metetra
.989 .726 .42 r
.65172 .18662 .65348 .2146 .64412 .19985 .64244 .1741 Metetra
.988 .724 .421 r
.64244 .1741 .64412 .19985 .63468 .18759 .63309 .16497 Metetra
.987 .719 .421 r
.63309 .16497 .63468 .18759 .62515 .1776 .62366 .15963 Metetra
.982 .709 .426 r
.62366 .15963 .62515 .1776 .61568 .18061 .61422 .16317 Metetra
.977 .704 .441 r
.61422 .16317 .61568 .18061 .60596 .17906 .60472 .17653 Metetra
.791 .374 0 r
.60472 .17653 .60596 .17906 .59586 .16173 .59466 .16251 Metetra
.696 .623 .771 r
.59466 .16251 .59586 .16173 .58554 .13583 .58421 .1256 Metetra
.98 .686 .349 r
.58421 .1256 .58554 .13583 .57517 .1178 .57391 .11375 Metetra
.886 .527 .044 r
.57391 .11375 .57517 .1178 .56469 .10249 .5634 .09468 Metetra
.613 .647 .86 r
.76912 .31314 .77019 .31305 .76229 .2957 .76117 .29481 Metetra
0 .325 .811 r
.76117 .29481 .76229 .2957 .75451 .28413 .75336 .28226 Metetra
.791 .334 0 r
.75336 .28226 .75451 .28413 .74675 .27591 .74563 .27493 Metetra
0 .061 .542 r
.74563 .27493 .74675 .27591 .73898 .27005 .7378 .26793 Metetra
.892 .471 .168 r
.7378 .26793 .73898 .27005 .73134 .27193 .7301 .26793 Metetra
.92 .594 .408 r
.7301 .26793 .73134 .27193 .72358 .27433 .72268 .2813 Metetra
1 .83 .509 r
.72268 .2813 .72358 .27433 .71591 .28383 .71495 .28933 Metetra
.971 .799 .613 r
.71495 .28933 .71591 .28383 .70761 .27755 .70645 .27639 Metetra
0 .034 .544 r
.70645 .27639 .70761 .27755 .69919 .27077 .69795 .26716 Metetra
.935 .563 .186 r
.69795 .26716 .69919 .27077 .69062 .2633 .6894 .26064 Metetra
.844 .517 .435 r
.6894 .26064 .69062 .2633 .68249 .2783 .68148 .28429 Metetra
.916 .731 .637 r
.68148 .28429 .68249 .2783 .67296 .24267 .6719 .24652 Metetra
.942 .795 .669 r
.6719 .24652 .67296 .24267 .66391 .23044 .66272 .22939 Metetra
0 .248 .76 r
.66272 .22939 .66391 .23044 .65466 .21508 .65348 .2146 Metetra
.278 .534 .915 r
.65348 .2146 .65466 .21508 .64535 .20249 .64412 .19985 Metetra
.83 .418 0 r
.64412 .19985 .64535 .20249 .63587 .18758 .63468 .18759 Metetra
.474 .743 .987 r
.63468 .18759 .63587 .18758 .62634 .17756 .62515 .1776 Metetra
.131 0 0 r
.62515 .1776 .62634 .17756 .61693 .18375 .61568 .18061 Metetra
.924 .536 .216 r
.61568 .18061 .61693 .18375 .60724 .18449 .60596 .17906 Metetra
.942 .608 .181 r
.60596 .17906 .60724 .18449 .59697 .15324 .59586 .16173 Metetra
.965 .768 .589 r
.59586 .16173 .59697 .15324 .58671 .13227 .58554 .13583 Metetra
.937 .803 .686 r
.58554 .13583 .58671 .13227 .57641 .11893 .57517 .1178 Metetra
0 .183 .708 r
.57517 .1178 .57641 .11893 .56593 .10384 .56469 .10249 Metetra
.837 .76 .778 r
.77019 .31305 .77121 .31159 .76361 .30223 .76229 .2957 Metetra
.968 .654 .275 r
.76229 .2957 .76361 .30223 .75592 .29313 .75451 .28413 Metetra
.98 .684 .349 r
.75451 .28413 .75592 .29313 .7482 .28602 .74675 .27591 Metetra
.981 .691 .372 r
.74675 .27591 .7482 .28602 .74035 .27807 .73898 .27005 Metetra
.973 .673 .388 r
.73898 .27005 .74035 .27807 .73252 .27422 .73134 .27193 Metetra
.9 .497 .233 r
.73134 .27193 .73252 .27422 .72518 .2897 .72358 .27433 Metetra
.978 .704 .437 r
.72358 .27433 .72518 .2897 .71726 .29133 .71591 .28383 Metetra
.975 .668 .337 r
.71591 .28383 .71726 .29133 .70879 .27893 .70761 .27755 Metetra
.675 .17 0 r
.70761 .27755 .70879 .27893 .70022 .26689 .69919 .27077 Metetra
.974 .838 .646 r
.69919 .27077 .70022 .26689 .69178 .26373 .69062 .2633 Metetra
.628 .221 .251 r
.69062 .2633 .69178 .26373 .68401 .29273 .68249 .2783 Metetra
.976 .702 .302 r
.68249 .2783 .68401 .29273 .6742 .24585 .67296 .24267 Metetra
.88 .492 .028 r
.67296 .24267 .6742 .24585 .66515 .23373 .66391 .23044 Metetra
.854 .475 0 r
.66391 .23044 .66515 .23373 .65588 .21735 .65466 .21508 Metetra
.762 .335 0 r
.65466 .21508 .65588 .21735 .64651 .20193 .64535 .20249 Metetra
.717 .773 .896 r
.64535 .20249 .64651 .20193 .63709 .18965 .63587 .18758 Metetra
.783 .332 0 r
.63587 .18758 .63709 .18965 .62754 .17764 .62634 .17756 Metetra
.37 0 0 r
.62634 .17756 .62754 .17764 .61796 .17285 .61693 .18375 Metetra
.997 .798 .518 r
.61693 .18375 .61796 .17285 .60869 .201 .60724 .18449 Metetra
.985 .712 .345 r
.60724 .18449 .60869 .201 .59833 .16476 .59697 .15324 Metetra
.981 .693 .328 r
.59697 .15324 .59833 .16476 .58794 .13292 .58671 .13227 Metetra
.065 .436 .874 r
.58671 .13227 .58794 .13292 .57763 .11885 .57641 .11893 Metetra
.551 .715 .949 r
.57641 .11893 .57763 .11885 .56713 .09962 .56593 .10384 Metetra
.906 .526 .089 r
.77121 .31159 .77242 .31482 .76453 .29792 .76361 .30223 Metetra
.972 .818 .632 r
.76361 .30223 .76453 .29792 .75686 .28892 .75592 .29313 Metetra
.977 .829 .629 r
.75592 .29313 .75686 .28892 .74902 .27818 .7482 .28602 Metetra
.987 .795 .56 r
.7482 .28602 .74902 .27818 .74136 .2755 .74035 .27807 Metetra
.968 .887 .697 r
.74035 .27807 .74136 .2755 .73359 .27305 .73252 .27422 Metetra
.73252 .27422 .73359 .27305 .72593 .27812 .72518 .2897 Metetra
.997 .792 .507 r
.72518 .2897 .72593 .27812 .71808 .28147 .71726 .29133 Metetra
.984 .781 .552 r
.71726 .29133 .71808 .28147 .70974 .27292 .70879 .27893 Metetra
.976 .799 .6 r
.70879 .27893 .70974 .27292 .70129 .26465 .70022 .26689 Metetra
.958 .912 .726 r
.70022 .26689 .70129 .26465 .69292 .26368 .69178 .26373 Metetra
.546 .226 .378 r
.69178 .26373 .69292 .26368 .6849 .28229 .68401 .29273 Metetra
.94 .732 .594 r
.68401 .29273 .6849 .28229 .67535 .24571 .6742 .24585 Metetra
.578 .745 .956 r
.6742 .24585 .67535 .24571 .6662 .22875 .66515 .23373 Metetra
.96 .795 .634 r
.66515 .23373 .6662 .22875 .657 .21496 .65588 .21735 Metetra
.911 .812 .737 r
.65588 .21735 .657 .21496 .64772 .20327 .64651 .20193 Metetra
0 .011 .546 r
.64651 .20193 .64772 .20327 .63825 .18854 .63709 .18965 Metetra
.83 .844 .858 r
.63709 .18965 .63825 .18854 .62878 .18078 .62754 .17764 Metetra
.921 .528 .168 r
.62754 .17764 .62878 .18078 .61927 .18018 .61796 .17285 Metetra
.932 .634 .457 r
.61796 .17285 .61927 .18018 .60958 .17863 .60869 .201 Metetra
.979 .752 .525 r
.60869 .201 .60958 .17863 .59947 .15919 .59833 .16476 Metetra
.93 .753 .641 r
.59833 .16476 .59947 .15919 .58918 .1344 .58794 .13292 Metetra
0 0 .514 r
.58794 .13292 .58918 .1344 .57882 .11497 .57763 .11885 Metetra
.94 .798 .675 r
.57763 .11885 .57882 .11497 .56838 .10149 .56713 .09962 Metetra
.903 .781 .716 r
.77242 .31482 .7734 .31227 .76569 .29976 .76453 .29792 Metetra
.735 .284 0 r
.76453 .29792 .76569 .29976 .75789 .28749 .75686 .28892 Metetra
.875 .836 .804 r
.75686 .28892 .75789 .28749 .75008 .27719 .74902 .27818 Metetra
.841 .969 .882 r
.74902 .27818 .75008 .27719 .74226 .26957 .74136 .2755 Metetra
.993 .823 .569 r
.74136 .2755 .74226 .26957 .73461 .27039 .73359 .27305 Metetra
.964 .931 .612 r
.73359 .27305 .73461 .27039 .7274 .28897 .72593 .27812 Metetra
.977 .69 .409 r
.72593 .27812 .7274 .28897 .71949 .29059 .71808 .28147 Metetra
.979 .683 .347 r
.71808 .28147 .71949 .29059 .71097 .27615 .70974 .27292 Metetra
.914 .528 .116 r
.70974 .27292 .71097 .27615 .70254 .26838 .70129 .26465 Metetra
.943 .582 .27 r
.70129 .26465 .70254 .26838 .69418 .26767 .69292 .26368 Metetra
.904 .581 .425 r
.69292 .26368 .69418 .26767 .68628 .29067 .6849 .28229 Metetra
.913 .628 .136 r
.6849 .28229 .68628 .29067 .67644 .2426 .67535 .24571 Metetra
.927 .798 .698 r
.67535 .24571 .67644 .2426 .66741 .2306 .6662 .22875 Metetra
.604 .175 0 r
.6662 .22875 .66741 .2306 .65816 .2143 .657 .21496 Metetra
.748 .825 .912 r
.657 .21496 .65816 .2143 .64881 .19915 .64772 .20327 Metetra
.956 .808 .657 r
.64772 .20327 .64881 .19915 .63941 .18719 .63825 .18854 Metetra
.879 .903 .843 r
.63825 .18854 .63941 .18719 .62993 .17819 .62878 .18078 Metetra
.969 .922 .692 r
.62878 .18078 .62993 .17819 .62035 .17217 .61927 .18018 Metetra
.995 .813 .546 r
.61927 .18018 .62035 .17217 .6108 .17977 .60958 .17863 Metetra
0 .268 .774 r
.60958 .17863 .6108 .17977 .60062 .15414 .59947 .15919 Metetra
.941 .773 .646 r
.59947 .15919 .60062 .15414 .59037 .1324 .58918 .1344 Metetra
.874 .792 .766 r
.58918 .1344 .59037 .1324 .58006 .11654 .57882 .11497 Metetra
0 0 .451 r
.57882 .11497 .58006 .11654 .56966 .10687 .56838 .10149 Metetra
.977 .68 .317 r
.7734 .31227 .77481 .32093 .76701 .30607 .76569 .29976 Metetra
.964 .648 .258 r
.76569 .29976 .76701 .30607 .75925 .29494 .75789 .28749 Metetra
.974 .668 .308 r
.75789 .28749 .75925 .29494 .7514 .28355 .75008 .27719 Metetra
.97 .654 .302 r
.75008 .27719 .7514 .28355 .74355 .27505 .74226 .26957 Metetra
.963 .64 .347 r
.74226 .26957 .74355 .27505 .73567 .26886 .73461 .27039 Metetra
.73461 .27039 .73567 .26886 .72761 .26074 .7274 .28897 Metetra
.994 .764 .477 r
.7274 .28897 .72761 .26074 .71971 .26125 .71949 .29059 Metetra
.989 .758 .493 r
.71949 .29059 .71971 .26125 .71147 .25477 .71097 .27615 Metetra
.991 .766 .497 r
.71097 .27615 .71147 .25477 .7033 .25501 .70254 .26838 Metetra
.995 .785 .506 r
.70254 .26838 .7033 .25501 .69488 .25121 .69418 .26767 Metetra
.998 .788 .447 r
.69418 .26767 .69488 .25121 .68657 .25725 .68628 .29067 Metetra
.979 .745 .514 r
.68628 .29067 .68657 .25725 .67728 .22973 .67644 .2426 Metetra
.988 .776 .531 r
.67644 .2426 .67728 .22973 .66806 .2088 .66741 .2306 Metetra
.988 .762 .507 r
.66741 .2306 .66806 .2088 .65876 .18848 .65816 .2143 Metetra
.989 .76 .498 r
.65816 .2143 .65876 .18848 .64971 .1855 .64881 .19915 Metetra
.988 .776 .527 r
.64881 .19915 .64971 .1855 .64034 .1738 .63941 .18719 Metetra
.99 .779 .523 r
.63941 .18719 .64034 .1738 .63091 .16668 .62993 .17819 Metetra
.992 .788 .528 r
.62993 .17819 .63091 .16668 .62147 .16759 .62035 .17217 Metetra
.991 .879 .555 r
.62035 .17217 .62147 .16759 .61191 .1727 .6108 .17977 Metetra
.958 .77 .608 r
.6108 .17977 .61191 .1727 .60173 .14603 .60062 .15414 Metetra
.97 .777 .588 r
.60062 .15414 .60173 .14603 .59152 .12645 .59037 .1324 Metetra
.971 .799 .613 r
.59037 .1324 .59152 .12645 .58124 .11199 .58006 .11654 Metetra
.976 .832 .636 r
.58006 .11654 .58124 .11199 .57087 .10425 .56966 .10687 Metetra
.984 .769 .532 r
.77481 .32093 .77537 .30747 .76771 .29594 .76701 .30607 Metetra
.985 .78 .545 r
.76701 .30607 .76771 .29594 .75995 .28412 .75925 .29494 Metetra
.986 .778 .541 r
.75925 .29494 .75995 .28412 .75211 .27278 .7514 .28355 Metetra
.989 .782 .535 r
.7514 .28355 .75211 .27278 .74435 .26643 .74355 .27505 Metetra
.99 .795 .546 r
.74355 .27505 .74435 .26643 .73642 .25814 .73567 .26886 Metetra
.989 .784 .535 r
.73567 .26886 .73642 .25814 .72845 .25194 .72761 .26074 Metetra
.997 .805 .525 r
.72761 .26074 .72845 .25194 .72035 .2455 .71971 .26125 Metetra
.992 .774 .508 r
.71971 .26125 .72035 .2455 .71225 .24281 .71147 .25477 Metetra
.996 .79 .509 r
.71147 .25477 .71225 .24281 .70399 .23947 .7033 .25501 Metetra
.993 .777 .505 r
.7033 .25501 .70399 .23947 .69591 .24711 .69488 .25121 Metetra
.991 .883 .563 r
.69488 .25121 .69591 .24711 .68751 .24898 .68657 .25725 Metetra
.958 .76 .594 r
.68657 .25725 .68751 .24898 .67831 .22436 .67728 .22973 Metetra
.951 .778 .631 r
.67728 .22973 .67831 .22436 .66913 .20482 .66806 .2088 Metetra
.934 .782 .668 r
.66806 .2088 .66913 .20482 .65997 .19008 .65876 .18848 Metetra
.808 .321 0 r
.65876 .18848 .65997 .19008 .65073 .17774 .64971 .1855 Metetra
.983 .795 .573 r
.64971 .1855 .65073 .17774 .6414 .16733 .64034 .1738 Metetra
.988 .814 .581 r
.64034 .1738 .6414 .16733 .63197 .15914 .63091 .16668 Metetra
.997 .82 .541 r
.63091 .16668 .63197 .15914 .62276 .17327 .62147 .16759 Metetra
.956 .63 .362 r
.62147 .16759 .62276 .17327 .61332 .18569 .61191 .1727 Metetra
.981 .699 .323 r
.61191 .1727 .61332 .18569 .60301 .15092 .60173 .14603 Metetra
.916 .575 .113 r
.60173 .14603 .60301 .15092 .59276 .12798 .59152 .12645 Metetra
0 0 .505 r
.59152 .12645 .59276 .12798 .58254 .11926 .58124 .11199 Metetra
.972 .656 .319 r
.58124 .11199 .58254 .11926 .57207 .10035 .57087 .10425 Metetra
.976 .795 .595 r
.77537 .30747 .77621 .30142 .76861 .29102 .76771 .29594 Metetra
.969 .802 .621 r
.76771 .29594 .76861 .29102 .76085 .2791 .75995 .28412 Metetra
.971 .804 .618 r
.75995 .28412 .76085 .2791 .75314 .27093 .75211 .27278 Metetra
.931 .887 .766 r
.75211 .27278 .75314 .27093 .74537 .26401 .74435 .26643 Metetra
.945 .855 .721 r
.74435 .26643 .74537 .26401 .73758 .25975 .73642 .25814 Metetra
.758 .274 0 r
.73642 .25814 .73758 .25975 .7302 .2717 .72845 .25194 Metetra
.987 .718 .412 r
.72845 .25194 .7302 .2717 .72254 .27977 .72035 .2455 Metetra
.988 .728 .435 r
.72035 .2455 .72254 .27977 .71446 .27909 .71225 .24281 Metetra
.988 .729 .435 r
.71225 .24281 .71446 .27909 .70626 .27889 .70399 .23947 Metetra
.987 .728 .446 r
.70399 .23947 .70626 .27889 .69749 .26307 .69591 .24711 Metetra
.982 .707 .419 r
.69591 .24711 .69749 .26307 .68965 .2863 .68751 .24898 Metetra
.991 .733 .415 r
.68751 .24898 .68965 .2863 .6799 .24192 .67831 .22436 Metetra
.987 .715 .376 r
.67831 .22436 .6799 .24192 .67106 .23688 .66913 .20482 Metetra
.99 .729 .419 r
.66913 .20482 .67106 .23688 .66177 .21863 .65997 .19008 Metetra
.989 .726 .418 r
.65997 .19008 .66177 .21863 .65241 .20218 .65073 .17774 Metetra
.988 .722 .414 r
.65073 .17774 .65241 .20218 .64305 .19164 .6414 .16733 Metetra
.988 .722 .417 r
.6414 .16733 .64305 .19164 .63356 .18132 .63197 .15914 Metetra
.98 .712 .444 r
.63197 .15914 .63356 .18132 .62412 .18243 .62276 .17327 Metetra
.964 .668 .419 r
.62276 .17327 .62412 .18243 .61471 .19753 .61332 .18569 Metetra
.969 .687 .271 r
.61332 .18569 .61471 .19753 .60431 .15743 .60301 .15092 Metetra
.942 .625 .184 r
.60301 .15092 .60431 .15743 .59403 .13218 .59276 .12798 Metetra
.94 .577 .196 r
.59276 .12798 .59403 .13218 .5837 .11289 .58254 .11926 Metetra
.968 .79 .61 r
.58254 .11926 .5837 .11289 .57329 .09873 .57207 .10035 Metetra
.987 .713 .391 r
.77621 .30142 .77792 .31753 .77035 .30848 .76861 .29102 Metetra
.988 .716 .392 r
.76861 .29102 .77035 .30848 .76267 .29882 .76085 .2791 Metetra
.987 .719 .408 r
.76085 .2791 .76267 .29882 .75492 .28986 .75314 .27093 Metetra
.987 .717 .409 r
.75314 .27093 .75492 .28986 .7471 .28204 .74537 .26401 Metetra
.986 .715 .412 r
.74537 .26401 .7471 .28204 .73927 .27687 .73758 .25975 Metetra
.978 .707 .442 r
.73758 .25975 .73927 .27687 .73174 .2848 .7302 .2717 Metetra
.977 .697 .428 r
.7302 .2717 .73174 .2848 .72423 .29789 .72254 .27977 Metetra
.985 .713 .419 r
.72254 .27977 .72423 .29789 .71615 .29744 .71446 .27909 Metetra
.985 .713 .42 r
.71446 .27909 .71615 .29744 .70745 .28061 .70626 .27889 Metetra
0 0 .519 r
.70626 .27889 .70745 .28061 .69868 .2646 .69749 .26307 Metetra
.772 .431 .408 r
.69749 .26307 .69868 .2646 .69093 .29088 .68965 .2863 Metetra
0 0 .352 r
.68965 .2863 .69093 .29088 .6811 .24325 .6799 .24192 Metetra
.708 .189 0 r
.6799 .24192 .6811 .24325 .67235 .24218 .67106 .23688 Metetra
.93 .598 .148 r
.67106 .23688 .67235 .24218 .66328 .23358 .66177 .21863 Metetra
.986 .708 .369 r
.66177 .21863 .66328 .23358 .65373 .20845 .65241 .20218 Metetra
.966 .642 .274 r
.65241 .20218 .65373 .20845 .64424 .19142 .64305 .19164 Metetra
.592 .795 .977 r
.64305 .19164 .64424 .19142 .63479 .18328 .63356 .18132 Metetra
.864 .422 .136 r
.63356 .18132 .63479 .18328 .62547 .19107 .62412 .18243 Metetra
.959 .661 .424 r
.62412 .18243 .62547 .19107 .61586 .19339 .61471 .19753 Metetra
.881 .717 .674 r
.61471 .19753 .61586 .19339 .60555 .15859 .60431 .15743 Metetra
.121 .316 .786 r
.60431 .15743 .60555 .15859 .59532 .13717 .59403 .13218 Metetra
.922 .581 .126 r
.59403 .13218 .59532 .13717 .58503 .1214 .5837 .11289 Metetra
.975 .67 .308 r
.5837 .11289 .58503 .1214 .5746 .10687 .57329 .09873 Metetra
.968 .823 .646 r
.77792 .31753 .77885 .31369 .77121 .30232 .77035 .30848 Metetra
.981 .801 .588 r
.77035 .30848 .77121 .30232 .76351 .29208 .76267 .29882 Metetra
.984 .799 .576 r
.76267 .29882 .76351 .29208 .75566 .27993 .75492 .28986 Metetra
.989 .786 .538 r
.75492 .28986 .75566 .27993 .74796 .27508 .7471 .28204 Metetra
.991 .807 .562 r
.7471 .28204 .74796 .27508 .7402 .27177 .73927 .27687 Metetra
.995 .858 .521 r
.73927 .27687 .7402 .27177 .73292 .28661 .73174 .2848 Metetra
.835 .462 .348 r
.73174 .2848 .73292 .28661 .72539 .29875 .72423 .29789 Metetra
.658 .103 0 r
.72423 .29789 .72539 .29875 .71712 .29192 .71615 .29744 Metetra
.962 .788 .62 r
.71615 .29744 .71712 .29192 .70879 .28726 .70745 .28061 Metetra
.96 .644 .237 r
.70745 .28061 .70879 .28726 .70025 .27953 .69868 .2646 Metetra
.966 .691 .462 r
.69868 .2646 .70025 .27953 .69235 .30066 .69093 .29088 Metetra
.889 .621 .106 r
.69093 .29088 .69235 .30066 .68233 .24615 .6811 .24325 Metetra
.92 .526 .207 r
.6811 .24325 .68233 .24615 .67339 .23664 .67235 .24218 Metetra
.982 .817 .602 r
.67235 .24218 .67339 .23664 .66434 .22818 .66328 .23358 Metetra
.942 .767 .636 r
.66328 .23358 .66434 .22818 .65505 .21503 .65373 .20845 Metetra
.958 .639 .231 r
.65373 .20845 .65505 .21503 .64557 .1986 .64424 .19142 Metetra
.972 .658 .314 r
.64424 .19142 .64557 .1986 .63611 .18987 .63479 .18328 Metetra
.959 .644 .387 r
.63479 .18328 .63611 .18987 .62666 .19012 .62547 .19107 Metetra
.691 .978 .808 r
.62547 .19107 .62666 .19012 .61715 .19823 .61586 .19339 Metetra
.749 .454 0 r
.61586 .19339 .61715 .19823 .60686 .16507 .60555 .15859 Metetra
.946 .627 .194 r
.60555 .15859 .60686 .16507 .59656 .13871 .59532 .13717 Metetra
0 0 .544 r
.59532 .13717 .59656 .13871 .58624 .12045 .58503 .1214 Metetra
.792 .821 .875 r
.58503 .1214 .58624 .12045 .57579 .10187 .5746 .10687 Metetra
.891 .517 .052 r
.77885 .31369 .78006 .31705 .77241 .30553 .77121 .30232 Metetra
.894 .512 .059 r
.77121 .30232 .77241 .30553 .7648 .29735 .76351 .29208 Metetra
.951 .62 .21 r
.76351 .29208 .7648 .29735 .757 .28685 .75566 .27993 Metetra
.973 .663 .333 r
.75566 .27993 .757 .28685 .74927 .28095 .74796 .27508 Metetra
.968 .646 .322 r
.74796 .27508 .74927 .28095 .74152 .27778 .7402 .27177 Metetra
.944 .638 .429 r
.7402 .27177 .74152 .27778 .73367 .2753 .73292 .28661 Metetra
1 .801 .473 r
.73292 .28661 .73367 .2753 .7264 .29482 .72539 .29875 Metetra
.977 .84 .64 r
.72539 .29875 .7264 .29482 .71835 .29505 .71712 .29192 Metetra
.924 .536 .169 r
.71712 .29192 .71835 .29505 .70992 .28665 .70879 .28726 Metetra
.741 .88 .944 r
.70879 .28726 .70992 .28665 .70112 .26961 .70025 .27953 Metetra
.993 .812 .441 r
.70025 .27953 .70112 .26961 .69337 .29544 .69235 .30066 Metetra
.866 .684 .655 r
.69235 .30066 .69337 .29544 .68415 .2718 .68233 .24615 Metetra
.988 .723 .416 r
.68233 .24615 .68415 .2718 .6745 .23425 .67339 .23664 Metetra
.943 .868 .734 r
.67339 .23664 .6745 .23425 .6656 .23208 .66434 .22818 Metetra
.912 .545 .1 r
.66434 .22818 .6656 .23208 .65616 .21167 .65505 .21503 Metetra
.937 .805 .689 r
.65505 .21503 .65616 .21167 .64665 .19331 .64557 .1986 Metetra
.982 .822 .609 r
.64557 .1986 .64665 .19331 .63729 .18882 .63611 .18987 Metetra
.788 .998 .852 r
.63611 .18987 .63729 .18882 .62804 .2003 .62666 .19012 Metetra
.971 .678 .41 r
.62666 .19012 .62804 .2003 .61859 .21213 .61715 .19823 Metetra
.978 .7 .308 r
.61715 .19823 .61859 .21213 .60814 .16959 .60686 .16507 Metetra
.834 .504 0 r
.60686 .16507 .60814 .16959 .59776 .13717 .59656 .13871 Metetra
.846 .795 .802 r
.59656 .13871 .59776 .13717 .58748 .12123 .58624 .12045 Metetra
.141 .412 .857 r
.58624 .12045 .58748 .12123 .57705 .10448 .57579 .10187 Metetra
.954 .814 .667 r
.78006 .31705 .781 .31357 .77322 .29816 .77241 .30553 Metetra
.986 .797 .564 r
.77241 .30553 .77322 .29816 .76549 .2866 .7648 .29735 Metetra
.987 .78 .538 r
.7648 .29735 .76549 .2866 .75776 .27743 .757 .28685 Metetra
.991 .791 .537 r
.757 .28685 .75776 .27743 .74999 .26994 .74927 .28095 Metetra
.994 .789 .519 r
.74927 .28095 .74999 .26994 .74237 .27006 .74152 .27778 Metetra
.995 .807 .543 r
.74152 .27778 .74237 .27006 .73477 .27449 .73367 .2753 Metetra
.239 0 .174 r
.73367 .2753 .73477 .27449 .72705 .27993 .7264 .29482 Metetra
.996 .781 .497 r
.7264 .29482 .72705 .27993 .71877 .27158 .71835 .29505 Metetra
.991 .764 .493 r
.71835 .29505 .71877 .27158 .71036 .26268 .70992 .28665 Metetra
.988 .76 .502 r
.70992 .28665 .71036 .26268 .70216 .26549 .70112 .26961 Metetra
.784 .773 .266 r
.70112 .26961 .70216 .26549 .69409 .27871 .69337 .29544 Metetra
.982 .761 .529 r
.69337 .29544 .69409 .27871 .68455 .24165 .68415 .2718 Metetra
.982 .75 .509 r
.68415 .2718 .68455 .24165 .67568 .23466 .6745 .23425 Metetra
.286 0 0 r
.6745 .23425 .67568 .23466 .66629 .21086 .6656 .23208 Metetra
.986 .761 .511 r
.6656 .23208 .66629 .21086 .65691 .19182 .65616 .21167 Metetra
.987 .763 .512 r
.65616 .21167 .65691 .19182 .64757 .18025 .64665 .19331 Metetra
.994 .785 .515 r
.64665 .19331 .64757 .18025 .63814 .17074 .63729 .18882 Metetra
.998 .782 .474 r
.63729 .18882 .63814 .17074 .62882 .17573 .62804 .2003 Metetra
.997 .773 .469 r
.62804 .2003 .62882 .17573 .61919 .17333 .61859 .21213 Metetra
.984 .749 .5 r
.61859 .21213 .61919 .17333 .60895 .14154 .60814 .16959 Metetra
.984 .753 .507 r
.60814 .16959 .60895 .14154 .59883 .1253 .59776 .13717 Metetra
.985 .778 .542 r
.59776 .13717 .59883 .1253 .5886 .11157 .58748 .12123 Metetra
.982 .783 .561 r
.58748 .12123 .5886 .11157 .57823 .09889 .57705 .10448 Metetra
.984 .769 .535 r
.781 .31357 .78157 .30069 .77416 .29445 .77322 .29816 Metetra
.958 .813 .658 r
.77322 .29816 .77416 .29445 .76651 .28472 .76549 .2866 Metetra
.918 .853 .763 r
.76549 .2866 .76651 .28472 .75882 .27644 .75776 .27743 Metetra
.839 .887 .875 r
.75776 .27743 .75882 .27644 .75103 .2681 .74999 .26994 Metetra
.944 .957 .734 r
.74999 .26994 .75103 .2681 .74313 .25982 .74237 .27006 Metetra
.999 .8 .501 r
.74237 .27006 .74313 .25982 .73521 .25421 .73477 .27449 Metetra
.996 .773 .476 r
.73477 .27449 .73521 .25421 .72698 .24233 .72705 .27993 Metetra
.991 .757 .478 r
.72705 .27993 .72698 .24233 .71928 .25129 .71877 .27158 Metetra
.991 .767 .499 r
.71877 .27158 .71928 .25129 .71133 .25689 .71036 .26268 Metetra
.998 .841 .549 r
.71036 .26268 .71133 .25689 .70314 .25949 .70216 .26549 Metetra
.99 .848 .482 r
.70216 .26549 .70314 .25949 .69462 .25548 .69409 .27871 Metetra
.979 .75 .523 r
.69409 .27871 .69462 .25548 .68574 .24285 .68455 .24165 Metetra
.591 .069 0 r
.68455 .24165 .68574 .24285 .67644 .21785 .67568 .23466 Metetra
.982 .761 .528 r
.67568 .23466 .67644 .21785 .66712 .19577 .66629 .21086 Metetra
.984 .767 .529 r
.66629 .21086 .66712 .19577 .65792 .18411 .65691 .19182 Metetra
.984 .796 .572 r
.65691 .19182 .65792 .18411 .64864 .17411 .64757 .18025 Metetra
.983 .811 .592 r
.64757 .18025 .64864 .17411 .63938 .1733 .63814 .17074 Metetra
.897 .501 .258 r
.63814 .17074 .63938 .1733 .63023 .18741 .62882 .17573 Metetra
.98 .691 .387 r
.62882 .17573 .63023 .18741 .62045 .1764 .61919 .17333 Metetra
0 0 .409 r
.61919 .17333 .62045 .1764 .61011 .13752 .60895 .14154 Metetra
.952 .809 .665 r
.60895 .14154 .61011 .13752 .59998 .11941 .59883 .1253 Metetra
.976 .806 .609 r
.59883 .1253 .59998 .11941 .58984 .11178 .5886 .11157 Metetra
.358 .647 .965 r
.5886 .11157 .58984 .11178 .57937 .08882 .57823 .09889 Metetra
.653 .864 .979 r
.78157 .30069 .78264 .30034 .77491 .28579 .77416 .29445 Metetra
.986 .788 .553 r
.77416 .29445 .77491 .28579 .76721 .27422 .76651 .28472 Metetra
.99 .784 .534 r
.76651 .28472 .76721 .27422 .75952 .26562 .75882 .27644 Metetra
.99 .783 .532 r
.75882 .27644 .75952 .26562 .75172 .25659 .75103 .2681 Metetra
.99 .781 .528 r
.75103 .2681 .75172 .25659 .74378 .24659 .74313 .25982 Metetra
.993 .78 .513 r
.74313 .25982 .74378 .24659 .73585 .2397 .73521 .25421 Metetra
.989 .772 .52 r
.73521 .25421 .73585 .2397 .72782 .23342 .72698 .24233 Metetra
1 .813 .49 r
.72698 .24233 .72782 .23342 .71984 .23283 .71928 .25129 Metetra
.997 .777 .479 r
.71928 .25129 .71984 .23283 .71155 .22577 .71133 .25689 Metetra
.994 .763 .472 r
.71133 .25689 .71155 .22577 .70342 .22912 .70314 .25949 Metetra
.993 .762 .479 r
.70314 .25949 .70342 .22912 .69518 .23366 .69462 .25548 Metetra
.99 .764 .5 r
.69462 .25548 .69518 .23366 .68621 .216 .68574 .24285 Metetra
.986 .756 .504 r
.68574 .24285 .68621 .216 .67715 .19922 .67644 .21785 Metetra
.985 .761 .52 r
.67644 .21785 .67715 .19922 .66794 .18072 .66712 .19577 Metetra
.99 .773 .518 r
.66712 .19577 .66794 .18072 .65882 .17104 .65792 .18411 Metetra
.99 .779 .524 r
.65792 .18411 .65882 .17104 .64977 .17154 .64864 .17411 Metetra
.969 .922 .692 r
.64864 .17411 .64977 .17154 .64065 .17692 .63938 .1733 Metetra
.908 .563 .378 r
.63938 .1733 .64065 .17692 .63142 .1868 .63023 .18741 Metetra
.728 .841 .934 r
.63023 .18741 .63142 .1868 .62134 .15678 .62045 .1764 Metetra
.976 .751 .533 r
.62045 .1764 .62134 .15678 .61124 .13152 .61011 .13752 Metetra
.967 .792 .614 r
.61011 .13752 .61124 .13152 .60121 .11994 .59998 .11941 Metetra
0 .406 .804 r
.59998 .11941 .60121 .11994 .59104 .10942 .58984 .11178 Metetra
.88 .774 .741 r
.58984 .11178 .59104 .10942 .58061 .08995 .57937 .08882 Metetra
.973 .673 .291 r
.78264 .30034 .78405 .30867 .77643 .29687 .77491 .28579 Metetra
.983 .696 .35 r
.77491 .28579 .77643 .29687 .76876 .28635 .76721 .27422 Metetra
.984 .7 .372 r
.76721 .27422 .76876 .28635 .76108 .27801 .75952 .26562 Metetra
.984 .701 .372 r
.75952 .26562 .76108 .27801 .75323 .26801 .75172 .25659 Metetra
.983 .697 .361 r
.75172 .25659 .75323 .26801 .74578 .27221 .74378 .24659 Metetra
.988 .724 .418 r
.74378 .24659 .74578 .27221 .73823 .27766 .73585 .2397 Metetra
.989 .73 .431 r
.73585 .2397 .73823 .27766 .73147 .31163 .72782 .23342 Metetra
.99 .737 .445 r
.72782 .23342 .73147 .31163 .72312 .30172 .71984 .23283 Metetra
.99 .737 .44 r
.71984 .23283 .72312 .30172 .71459 .28959 .71155 .22577 Metetra
.989 .735 .445 r
.71155 .22577 .71459 .28959 .7062 .28609 .70342 .22912 Metetra
.989 .733 .444 r
.70342 .22912 .7062 .28609 .69835 .30693 .69518 .23366 Metetra
.991 .738 .436 r
.69518 .23366 .69835 .30693 .68871 .26734 .68621 .216 Metetra
.991 .735 .429 r
.68621 .216 .68871 .26734 .67977 .258 .67715 .19922 Metetra
.991 .736 .431 r
.67715 .19922 .67977 .258 .6707 .24854 .66794 .18072 Metetra
.99 .736 .439 r
.66794 .18072 .6707 .24854 .66112 .22169 .65882 .17104 Metetra
.989 .732 .44 r
.65882 .17104 .66112 .22169 .65195 .21951 .64977 .17154 Metetra
.988 .731 .442 r
.64977 .17154 .65195 .21951 .6432 .24672 .64065 .17692 Metetra
.988 .734 .448 r
.64065 .17692 .6432 .24672 .63402 .26403 .63142 .1868 Metetra
.991 .739 .432 r
.63142 .1868 .63402 .26403 .62372 .22744 .62134 .15678 Metetra
.991 .738 .432 r
.62134 .15678 .62372 .22744 .61284 .15722 .61124 .13152 Metetra
.988 .722 .411 r
.61124 .13152 .61284 .15722 .60264 .1352 .60121 .11994 Metetra
.985 .706 .383 r
.60121 .11994 .60264 .1352 .59242 .12168 .59104 .10942 Metetra
.982 .695 .337 r
.59104 .10942 .59242 .12168 .58202 .10598 .58061 .08995 Metetra
.983 .785 .561 r
.78405 .30867 .7848 .30033 .77707 .28568 .77643 .29687 Metetra
.988 .779 .534 r
.77643 .29687 .77707 .28568 .76928 .27139 .76876 .28635 Metetra
.991 .773 .511 r
.76876 .28635 .76928 .27139 .76167 .26433 .76108 .27801 Metetra
.99 .774 .519 r
.76108 .27801 .76167 .26433 .7541 .26154 .75323 .26801 Metetra
1 .831 .526 r
.75323 .26801 .7541 .26154 .74634 .25623 .74578 .27221 Metetra
.997 .781 .481 r
.74578 .27221 .74634 .25623 .73903 .26811 .73823 .27766 Metetra
.956 .795 .35 r
.73823 .27766 .73903 .26811 .73153 .27867 .73147 .31163 Metetra
.991 .758 .482 r
.73147 .31163 .73153 .27867 .7235 .27736 .72312 .30172 Metetra
.99 .762 .494 r
.72312 .30172 .7235 .27736 .71523 .27276 .71459 .28959 Metetra
.994 .775 .498 r
.71459 .28959 .71523 .27276 .70695 .27188 .7062 .28609 Metetra
.998 .794 .447 r
.7062 .28609 .70695 .27188 .69896 .28672 .69835 .30693 Metetra
.975 .749 .533 r
.69835 .30693 .69896 .28672 .68939 .24876 .68871 .26734 Metetra
.991 .77 .503 r
.68871 .26734 .68939 .24876 .68056 .24236 .67977 .258 Metetra
.991 .774 .512 r
.67977 .258 .68056 .24236 .67119 .21931 .6707 .24854 Metetra
.986 .755 .501 r
.6707 .24854 .67119 .21931 .6621 .21251 .66112 .22169 Metetra
.996 .803 .532 r
.66112 .22169 .6621 .21251 .6528 .2031 .65195 .21951 Metetra
.997 .791 .439 r
.65195 .21951 .6528 .2031 .64384 .21754 .6432 .24672 Metetra
.997 .77 .459 r
.6432 .24672 .64384 .21754 .63463 .2302 .63402 .26403 Metetra
.985 .751 .501 r
.63402 .26403 .63463 .2302 .62427 .18732 .62372 .22744 Metetra
.977 .74 .512 r
.62372 .22744 .62427 .18732 .61401 .15383 .61284 .15722 Metetra
.92 .784 .694 r
.61284 .15722 .61401 .15383 .6038 .13055 .60264 .1352 Metetra
.968 .817 .64 r
.60264 .1352 .6038 .13055 .59355 .11369 .59242 .12168 Metetra
.98 .791 .577 r
.59242 .12168 .59355 .11369 .58302 .08371 .58202 .10598 Metetra
.887 .795 .752 r
.7848 .30033 .7858 .2984 .77801 .282 .77707 .28568 Metetra
.947 .799 .664 r
.77707 .28568 .77801 .282 .77033 .27038 .76928 .27139 Metetra
.845 .893 .873 r
.76928 .27139 .77033 .27038 .76268 .26214 .76167 .26433 Metetra
.961 .912 .72 r
.76167 .26433 .76268 .26214 .75501 .25613 .7541 .26154 Metetra
.988 .822 .588 r
.7541 .26154 .75501 .25613 .74747 .25699 .74634 .25623 Metetra
.709 .294 .257 r
.74634 .25623 .74747 .25699 .73999 .26331 .73903 .26811 Metetra
.985 .865 .499 r
.73903 .26811 .73999 .26331 .73209 .26117 .73153 .27867 Metetra
.995 .775 .491 r
.73153 .27867 .73209 .26117 .72424 .2649 .7235 .27736 Metetra
.994 .784 .515 r
.7235 .27736 .72424 .2649 .71588 .2564 .71523 .27276 Metetra
.995 .778 .494 r
.71523 .27276 .71588 .2564 .70765 .25641 .70695 .27188 Metetra
.999 .788 .462 r
.70695 .27188 .70765 .25641 .69937 .25975 .69896 .28672 Metetra
.981 .75 .514 r
.69896 .28672 .69937 .25975 .6902 .23548 .68939 .24876 Metetra
.993 .781 .515 r
.68939 .24876 .6902 .23548 .68128 .22454 .68056 .24236 Metetra
.984 .761 .523 r
.68056 .24236 .68128 .22454 .67211 .20826 .67119 .21931 Metetra
.992 .788 .529 r
.67119 .21931 .67211 .20826 .66281 .19161 .6621 .21251 Metetra
.992 .767 .497 r
.6621 .21251 .66281 .19161 .65378 .19261 .6528 .2031 Metetra
.999 .81 .474 r
.6528 .2031 .65378 .19261 .64458 .19411 .64384 .21754 Metetra
.997 .774 .466 r
.64384 .21754 .64458 .19411 .63536 .20413 .63463 .2302 Metetra
.979 .749 .518 r
.63463 .2302 .63536 .20413 .62514 .16632 .62427 .18732 Metetra
.981 .755 .523 r
.62427 .18732 .62514 .16632 .61492 .13353 .61401 .15383 Metetra
.986 .761 .515 r
.61401 .15383 .61492 .13353 .60482 .116 .6038 .13055 Metetra
.987 .772 .528 r
.6038 .13055 .60482 .116 .59468 .10529 .59355 .11369 Metetra
.96 .764 .593 r
.59355 .11369 .59468 .10529 .58438 .09487 .58302 .08371 Metetra
.913 .579 .108 r
.7858 .2984 .78708 .30321 .77942 .29016 .77801 .282 Metetra
.975 .674 .307 r
.77801 .282 .77942 .29016 .77175 .27877 .77033 .27038 Metetra
.978 .677 .333 r
.77033 .27038 .77175 .27877 .76421 .27363 .76268 .26214 Metetra
.983 .697 .376 r
.76268 .26214 .76421 .27363 .75645 .26532 .75501 .25613 Metetra
.977 .682 .387 r
.75501 .25613 .75645 .26532 .74864 .25845 .74747 .25699 Metetra
.828 .4 .222 r
.74747 .25699 .74864 .25845 .74046 .24415 .73999 .26331 Metetra
.994 .771 .489 r
.73999 .26331 .74046 .24415 .73257 .24144 .73209 .26117 Metetra
.996 .774 .478 r
.73209 .26117 .73257 .24144 .72474 .2446 .72424 .2649 Metetra
.992 .767 .496 r
.72424 .2649 .72474 .2446 .7165 .23912 .71588 .2564 Metetra
.995 .776 .49 r
.71588 .2564 .7165 .23912 .70807 .23136 .70765 .25641 Metetra
.995 .768 .474 r
.70765 .25641 .70807 .23136 .69957 .2252 .69937 .25975 Metetra
.988 .754 .492 r
.69937 .25975 .69957 .2252 .69072 .21104 .6902 .23548 Metetra
.991 .763 .492 r
.6902 .23548 .69072 .21104 .68175 .19663 .68128 .22454 Metetra
.99 .759 .493 r
.68128 .22454 .68175 .19663 .67282 .18889 .67211 .20826 Metetra
.988 .765 .51 r
.67211 .20826 .67282 .18889 .66373 .17975 .66281 .19161 Metetra
.997 .793 .506 r
.66281 .19161 .66373 .17975 .65451 .17123 .65378 .19261 Metetra
.995 .772 .482 r
.65378 .19261 .65451 .17123 .64551 .18038 .64458 .19411 Metetra
.999 .793 .48 r
.64458 .19411 .64551 .18038 .63608 .17751 .63536 .20413 Metetra
.982 .751 .513 r
.63536 .20413 .63608 .17751 .62621 .15784 .62514 .16632 Metetra
.955 .757 .596 r
.62514 .16632 .62621 .15784 .61642 .15178 .61492 .13353 Metetra
.987 .714 .38 r
.61492 .13353 .61642 .15178 .60614 .12267 .60482 .116 Metetra
.967 .645 .28 r
.60482 .116 .60614 .12267 .59593 .10685 .59468 .10529 Metetra
.636 .149 0 r
.59468 .10529 .59593 .10685 .58562 .09532 .58438 .09487 Metetra
.84 .802 .813 r
.78708 .30321 .78811 .30199 .78034 .28584 .77942 .29016 Metetra
.966 .809 .635 r
.77942 .29016 .78034 .28584 .77271 .27538 .77175 .27877 Metetra
.978 .855 .651 r
.77175 .27877 .77271 .27538 .76506 .26697 .76421 .27363 Metetra
.986 .803 .574 r
.76421 .27363 .76506 .26697 .75734 .25934 .75645 .26532 Metetra
.987 .812 .581 r
.75645 .26532 .75734 .25934 .74984 .26105 .74864 .25845 Metetra
.753 .361 0 r
.74864 .25845 .74984 .26105 .74249 .27088 .74046 .24415 Metetra
.988 .724 .424 r
.74046 .24415 .74249 .27088 .73469 .2717 .73257 .24144 Metetra
.987 .725 .434 r
.73257 .24144 .73469 .2717 .72675 .27211 .72474 .2446 Metetra
.988 .724 .421 r
.72474 .2446 .72675 .27211 .71857 .26957 .7165 .23912 Metetra
.989 .727 .421 r
.7165 .23912 .71857 .26957 .71025 .26635 .70807 .23136 Metetra
.989 .729 .427 r
.70807 .23136 .71025 .26635 .70168 .25923 .69957 .2252 Metetra
.99 .729 .417 r
.69957 .2252 .70168 .25923 .69253 .23542 .69072 .21104 Metetra
.989 .723 .403 r
.69072 .21104 .69253 .23542 .68371 .22768 .68175 .19663 Metetra
.989 .726 .421 r
.68175 .19663 .68371 .22768 .67442 .20666 .67282 .18889 Metetra
.986 .713 .395 r
.67282 .18889 .67442 .20666 .66521 .19273 .66373 .17975 Metetra
.984 .699 .375 r
.66373 .17975 .66521 .19273 .65595 .18306 .65451 .17123 Metetra
.974 .687 .417 r
.65451 .17123 .65595 .18306 .64716 .20301 .64551 .18038 Metetra
.986 .718 .417 r
.64551 .18038 .64716 .20301 .63766 .19745 .63608 .17751 Metetra
.988 .717 .381 r
.63608 .17751 .63766 .19745 .62765 .17105 .62621 .15784 Metetra
.983 .698 .382 r
.62621 .15784 .62765 .17105 .61761 .14974 .61642 .15178 Metetra
.835 .727 .746 r
.61642 .15178 .61761 .14974 .60736 .12243 .60614 .12267 Metetra
.618 .736 .93 r
.60614 .12267 .60736 .12243 .59722 .11167 .59593 .10685 Metetra
.944 .594 .196 r
.59593 .10685 .59722 .11167 .58688 .09697 .58562 .09532 Metetra
.986 .709 .36 r
.78811 .30199 .7898 .31683 .78212 .30318 .78034 .28584 Metetra
.987 .715 .39 r
.78034 .28584 .78212 .30318 .77439 .29067 .77271 .27538 Metetra
.986 .71 .388 r
.77271 .27538 .77439 .29067 .76667 .28056 .76506 .26697 Metetra
.985 .705 .382 r
.76506 .26697 .76667 .28056 .75879 .26893 .75734 .25934 Metetra
.977 .684 .392 r
.75734 .25934 .75879 .26893 .75094 .26054 .74984 .26105 Metetra
.117 0 0 r
.74984 .26105 .75094 .26054 .74288 .24961 .74249 .27088 Metetra
.995 .77 .48 r
.74249 .27088 .74288 .24961 .73532 .25646 .73469 .2717 Metetra
.996 .78 .492 r
.73469 .2717 .73532 .25646 .72717 .24958 .72675 .27211 Metetra
.994 .768 .484 r
.72675 .27211 .72717 .24958 .71904 .24742 .71857 .26957 Metetra
.994 .768 .485 r
.71857 .26957 .71904 .24742 .71114 .25742 .71025 .26635 Metetra
.991 .795 .544 r
.71025 .26635 .71114 .25742 .70268 .25375 .70168 .25923 Metetra
.946 .77 .632 r
.70168 .25923 .70268 .25375 .69369 .23528 .69253 .23542 Metetra
.516 .801 .997 r
.69253 .23542 .69369 .23528 .68444 .21068 .68371 .22768 Metetra
.985 .764 .522 r
.68371 .22768 .68444 .21068 .67525 .19211 .67442 .20666 Metetra
.988 .773 .522 r
.67442 .20666 .67525 .19211 .66611 .1807 .66521 .19273 Metetra
.991 .782 .528 r
.66521 .19273 .66611 .1807 .65702 .17728 .65595 .18306 Metetra
.964 .848 .435 r
.65595 .18306 .65702 .17728 .64831 .20055 .64716 .20301 Metetra
.957 .896 .725 r
.64716 .20301 .64831 .20055 .63879 .1928 .63766 .19745 Metetra
.931 .767 .656 r
.63766 .19745 .63879 .1928 .62873 .16344 .62765 .17105 Metetra
.97 .78 .591 r
.62765 .17105 .62873 .16344 .61864 .13811 .61761 .14974 Metetra
.974 .765 .558 r
.61761 .14974 .61864 .13811 .60855 .11965 .60736 .12243 Metetra
.948 .855 .717 r
.60736 .12243 .60855 .11965 .59848 .11324 .59722 .11167 Metetra
0 0 .501 r
.59722 .11167 .59848 .11324 .58813 .09765 .58688 .09697 Metetra
.987 .77 .523 r
.7898 .31683 .7903 .30274 .78263 .28872 .78212 .30318 Metetra
.988 .77 .519 r
.78212 .30318 .78263 .28872 .77505 .27931 .77439 .29067 Metetra
.989 .779 .531 r
.77439 .29067 .77505 .27931 .76734 .26906 .76667 .28056 Metetra
.987 .777 .533 r
.76667 .28056 .76734 .26906 .75959 .2606 .75879 .26893 Metetra
.989 .793 .552 r
.75879 .26893 .75959 .2606 .75159 .24778 .75094 .26054 Metetra
.989 .776 .525 r
.75094 .26054 .75159 .24778 .74363 .23876 .74288 .24961 Metetra
.999 .799 .488 r
.74288 .24961 .74363 .23876 .73556 .22988 .73532 .25646 Metetra
.992 .762 .483 r
.73532 .25646 .73556 .22988 .72767 .22991 .72717 .24958 Metetra
.994 .771 .487 r
.72717 .24958 .72767 .22991 .71975 .23347 .71904 .24742 Metetra
.999 .79 .474 r
.71904 .24742 .71975 .23347 .71141 .22791 .71114 .25742 Metetra
.993 .762 .477 r
.71114 .25742 .71141 .22791 .70319 .23062 .70268 .25375 Metetra
.988 .76 .502 r
.70268 .25375 .70319 .23062 .69421 .21162 .69369 .23528 Metetra
.986 .757 .507 r
.69369 .23528 .69421 .21162 .68518 .19421 .68444 .21068 Metetra
.986 .766 .521 r
.68444 .21068 .68518 .19421 .67602 .17571 .67525 .19211 Metetra
.99 .772 .511 r
.67525 .19211 .67602 .17571 .66695 .16597 .66611 .1807 Metetra
.995 .781 .503 r
.66611 .1807 .66695 .16597 .65806 .17031 .65702 .17728 Metetra
.969 .833 .418 r
.65702 .17728 .65806 .17031 .64934 .19166 .64831 .20055 Metetra
.991 .798 .548 r
.64831 .20055 .64934 .19166 .63999 .19258 .63879 .1928 Metetra
.626 .613 .817 r
.63879 .1928 .63999 .19258 .63014 .17474 .62873 .16344 Metetra
.975 .687 .296 r
.62873 .16344 .63014 .17474 .61986 .13776 .61864 .13811 Metetra
.654 .718 .896 r
.61864 .13811 .61986 .13776 .60983 .12377 .60855 .11965 Metetra
.941 .574 .209 r
.60855 .11965 .60983 .12377 .59971 .11342 .59848 .11324 Metetra
.428 .641 .946 r
.59848 .11324 .59971 .11342 .58935 .09608 .58813 .09765 Metetra
.958 .642 .231 r
.7903 .30274 .79165 .30911 .78381 .29111 .78263 .28872 Metetra
.822 .402 0 r
.78263 .28872 .78381 .29111 .77622 .28125 .77505 .27931 Metetra
.712 .274 0 r
.77505 .27931 .77622 .28125 .76855 .2721 .76734 .26906 Metetra
.898 .506 .071 r
.76734 .26906 .76855 .2721 .76082 .26372 .75959 .2606 Metetra
.851 .469 0 r
.75959 .2606 .76082 .26372 .75344 .26821 .75159 .24778 Metetra
.988 .718 .402 r
.75159 .24778 .75344 .26821 .74631 .28384 .74363 .23876 Metetra
.99 .733 .429 r
.74363 .23876 .74631 .28384 .73876 .29183 .73556 .22988 Metetra
.989 .735 .44 r
.73556 .22988 .73876 .29183 .73045 .28094 .72767 .22991 Metetra
.989 .732 .44 r
.72767 .22991 .73045 .28094 .72211 .27271 .71975 .23347 Metetra
.989 .73 .429 r
.71975 .23347 .72211 .27271 .71381 .26959 .71141 .22791 Metetra
.988 .73 .437 r
.71141 .22791 .71381 .26959 .7062 .29535 .70319 .23062 Metetra
.991 .737 .43 r
.70319 .23062 .7062 .29535 .69656 .25494 .69421 .21162 Metetra
.991 .733 .421 r
.69421 .21162 .69656 .25494 .6874 .23431 .68518 .19421 Metetra
.991 .732 .418 r
.68518 .19421 .6874 .23431 .67813 .21363 .67602 .17571 Metetra
.99 .73 .424 r
.67602 .17571 .67813 .21363 .66901 .20344 .66695 .16597 Metetra
.987 .727 .436 r
.66695 .16597 .66901 .20344 .6598 .19556 .65806 .17031 Metetra
.98 .713 .448 r
.65806 .17031 .6598 .19556 .65177 .25104 .64934 .19166 Metetra
.989 .734 .439 r
.64934 .19166 .65177 .25104 .64197 .23235 .63999 .19258 Metetra
.99 .731 .418 r
.63999 .19258 .64197 .23235 .63146 .18011 .63014 .17474 Metetra
.764 .476 0 r
.63014 .17474 .63146 .18011 .6213 .15134 .61986 .13776 Metetra
.984 .7 .361 r
.61986 .13776 .6213 .15134 .61105 .12333 .60983 .12377 Metetra
.665 .839 .966 r
.60983 .12377 .61105 .12333 .6009 .10986 .59971 .11342 Metetra
.942 .81 .685 r
.59971 .11342 .6009 .10986 .5906 .09722 .58935 .09608 Metetra
.968 .776 .591 r
.79165 .30911 .79244 .30204 .78499 .29324 .78381 .29111 Metetra
.765 .334 0 r
.78381 .29111 .78499 .29324 .77735 .28216 .77622 .28125 Metetra
0 .213 .713 r
.77622 .28125 .77735 .28216 .7697 .27328 .76855 .2721 Metetra
0 .004 .515 r
.76855 .2721 .7697 .27328 .762 .26585 .76082 .26372 Metetra
.887 .485 .25 r
.76082 .26372 .762 .26585 .75449 .26645 .75344 .26821 Metetra
.75344 .26821 .75449 .26645 .74681 .26583 .74631 .28384 Metetra
.998 .778 .47 r
.74631 .28384 .74681 .26583 .73933 .27517 .73876 .29183 Metetra
.99 .77 .508 r
.73876 .29183 .73933 .27517 .73154 .27938 .73045 .28094 Metetra
.901 .882 .806 r
.73045 .28094 .73154 .27938 .72312 .26819 .72211 .27271 Metetra
.99 .847 .604 r
.72211 .27271 .72312 .26819 .71488 .26676 .71381 .26959 Metetra
.71381 .26959 .71488 .26676 .70667 .27106 .7062 .29535 Metetra
.979 .749 .521 r
.7062 .29535 .70667 .27106 .69733 .24036 .69656 .25494 Metetra
.983 .766 .532 r
.69656 .25494 .69733 .24036 .68839 .22726 .6874 .23431 Metetra
.967 .778 .598 r
.6874 .23431 .68839 .22726 .67932 .21414 .67813 .21363 Metetra
.093 .492 .9 r
.67813 .21363 .67932 .21414 .67019 .20301 .66901 .20344 Metetra
.663 .868 .976 r
.66901 .20344 .67019 .20301 .66096 .19363 .6598 .19556 Metetra
.28 .056 .385 r
.6598 .19556 .66096 .19363 .65255 .23025 .65177 .25104 Metetra
.988 .763 .507 r
.65177 .25104 .65255 .23025 .64294 .21944 .64197 .23235 Metetra
.951 .736 .576 r
.64197 .23235 .64294 .21944 .63268 .18047 .63146 .18011 Metetra
.485 .532 .83 r
.63146 .18011 .63268 .18047 .62246 .14744 .6213 .15134 Metetra
.913 .76 .678 r
.6213 .15134 .62246 .14744 .61227 .12268 .61105 .12333 Metetra
.734 .816 .915 r
.61105 .12333 .61227 .12268 .60216 .11178 .6009 .10986 Metetra
.683 .23 0 r
.6009 .10986 .60216 .11178 .59186 .09841 .5906 .09722 Metetra
.985 .704 .373 r
.79244 .30204 .79407 .31517 .78651 .30383 .78499 .29324 Metetra
.981 .692 .343 r
.78499 .29324 .78651 .30383 .77899 .29596 .77735 .28216 Metetra
.985 .705 .377 r
.77735 .28216 .77899 .29596 .77132 .28674 .7697 .27328 Metetra
.985 .704 .38 r
.7697 .27328 .77132 .28674 .7636 .2789 .762 .26585 Metetra
.982 .7 .403 r
.762 .26585 .7636 .2789 .75584 .27289 .75449 .26645 Metetra
.969 .653 .345 r
.75449 .26645 .75584 .27289 .74854 .28323 .74681 .26583 Metetra
.981 .708 .431 r
.74681 .26583 .74854 .28323 .74073 .28288 .73933 .27517 Metetra
.97 .666 .385 r
.73933 .27517 .74073 .28288 .73262 .27753 .73154 .27938 Metetra
.906 .844 .773 r
.73154 .27938 .73262 .27753 .72427 .26819 .72312 .26819 Metetra
.104 .653 .818 r
.72312 .26819 .72427 .26819 .716 .26564 .71488 .26676 Metetra
.702 .961 .708 r
.71488 .26676 .716 .26564 .70783 .27088 .70667 .27106 Metetra
.624 .592 .797 r
.70667 .27106 .70783 .27088 .69849 .24015 .69733 .24036 Metetra
.615 .748 .94 r
.69733 .24036 .69849 .24015 .68962 .22933 .68839 .22726 Metetra
.68 .251 0 r
.68839 .22726 .68962 .22933 .68052 .21452 .67932 .21414 Metetra
.239 .574 .941 r
.67932 .21414 .68052 .21452 .67145 .20606 .67019 .20301 Metetra
.89 .49 .057 r
.67019 .20301 .67145 .20606 .66224 .19756 .66096 .19363 Metetra
.856 .55 .47 r
.66096 .19363 .66224 .19756 .65406 .24456 .65255 .23025 Metetra
.984 .703 .373 r
.65255 .23025 .65406 .24456 .64455 .23937 .64294 .21944 Metetra
.984 .716 .337 r
.64294 .21944 .64455 .23937 .63394 .1826 .63268 .18047 Metetra
0 .093 .638 r
.63268 .18047 .63394 .1826 .6239 .16058 .62246 .14744 Metetra
.98 .697 .322 r
.62246 .14744 .6239 .16058 .61358 .12816 .61227 .12268 Metetra
.955 .616 .232 r
.61227 .12268 .61358 .12816 .60343 .1143 .60216 .11178 Metetra
.794 .37 0 r
.60216 .11178 .60343 .1143 .59308 .09616 .59186 .09841 Metetra
.969 .808 .629 r
.79407 .31517 .79497 .31066 .78714 .29263 .78651 .30383 Metetra
.991 .782 .525 r
.78651 .30383 .78714 .29263 .77949 .28107 .77899 .29596 Metetra
.991 .773 .51 r
.77899 .29596 .77949 .28107 .77188 .27271 .77132 .28674 Metetra
.992 .776 .511 r
.77132 .28674 .77188 .27271 .76421 .26554 .7636 .2789 Metetra
.993 .779 .51 r
.7636 .2789 .76421 .26554 .75674 .26687 .75584 .27289 Metetra
.994 .843 .489 r
.75584 .27289 .75674 .26687 .74932 .2734 .74854 .28323 Metetra
.997 .798 .515 r
.74854 .28323 .74932 .2734 .74185 .28249 .74073 .28288 Metetra
.64 .893 .985 r
.74073 .28288 .74185 .28249 .73369 .27544 .73262 .27753 Metetra
.928 .861 .753 r
.73262 .27753 .73369 .27544 .72549 .27064 .72427 .26819 Metetra
.897 .478 .127 r
.72427 .26819 .72549 .27064 .71711 .26401 .716 .26564 Metetra
.841 .973 .664 r
.716 .26564 .71711 .26401 .70861 .25792 .70783 .27088 Metetra
.972 .757 .554 r
.70783 .27088 .70861 .25792 .69981 .24561 .69849 .24015 Metetra
.955 .62 .229 r
.69849 .24015 .69981 .24561 .69092 .23422 .68962 .22933 Metetra
.931 .588 .15 r
.68962 .22933 .69092 .23422 .68178 .21784 .68052 .21452 Metetra
.911 .522 .108 r
.68052 .21452 .68178 .21784 .67267 .20748 .67145 .20606 Metetra
.628 .129 0 r
.67145 .20606 .67267 .20748 .6638 .21372 .66224 .19756 Metetra
.955 .681 .48 r
.66224 .19756 .6638 .21372 .65509 .23615 .65406 .24456 Metetra
.994 .806 .546 r
.65406 .24456 .65509 .23615 .64558 .22965 .64455 .23937 Metetra
.928 .721 .603 r
.64455 .23937 .64558 .22965 .63494 .17037 .63394 .1826 Metetra
.981 .77 .546 r
.63394 .1826 .63494 .17037 .62499 .1524 .6239 .16058 Metetra
.955 .758 .598 r
.6239 .16058 .62499 .1524 .61485 .1304 .61358 .12816 Metetra
.729 .298 0 r
.61358 .12816 .61485 .1304 .60467 .11427 .60343 .1143 Metetra
.549 .674 .921 r
.60343 .1143 .60467 .11427 .59435 .09869 .59308 .09616 Metetra
.95 .64 .207 r
.79497 .31066 .79634 .31753 .78892 .30943 .78714 .29263 Metetra
.987 .713 .382 r
.78714 .29263 .78892 .30943 .78124 .29746 .77949 .28107 Metetra
.987 .712 .389 r
.77949 .28107 .78124 .29746 .77356 .28762 .77188 .27271 Metetra
.986 .708 .387 r
.77188 .27271 .77356 .28762 .76592 .28156 .76421 .26554 Metetra
.984 .708 .412 r
.76421 .26554 .76592 .28156 .75831 .27942 .75674 .26687 Metetra
.978 .696 .417 r
.75674 .26687 .75831 .27942 .75081 .28378 .74932 .2734 Metetra
.972 .684 .417 r
.74932 .2734 .75081 .28378 .74335 .2933 .74185 .28249 Metetra
.982 .691 .361 r
.74185 .28249 .74335 .2933 .7352 .2864 .73369 .27544 Metetra
.981 .691 .371 r
.73369 .27544 .7352 .2864 .72696 .28077 .72549 .27064 Metetra
.98 .686 .356 r
.72549 .27064 .72696 .28077 .71858 .2743 .71711 .26401 Metetra
.98 .687 .36 r
.71711 .26401 .71858 .2743 .71022 .27312 .70861 .25792 Metetra
.986 .707 .373 r
.70861 .25792 .71022 .27312 .70114 .2511 .69981 .24561 Metetra
.954 .62 .224 r
.69981 .24561 .70114 .2511 .69236 .24408 .69092 .23422 Metetra
.977 .681 .308 r
.69092 .23422 .69236 .24408 .68301 .21984 .68178 .21784 Metetra
.742 .289 0 r
.68178 .21784 .68301 .21984 .67379 .20462 .67267 .20748 Metetra
.959 .932 .602 r
.67267 .20748 .67379 .20462 .66464 .19809 .6638 .21372 Metetra
.998 .792 .445 r
.6638 .21372 .66464 .19809 .65706 .27128 .65509 .23615 Metetra
.989 .727 .423 r
.65509 .23615 .65706 .27128 .64701 .2399 .64558 .22965 Metetra
.848 .594 .053 r
.64558 .22965 .64701 .2399 .63611 .16766 .63494 .17037 Metetra
.915 .806 .724 r
.63494 .17037 .63611 .16766 .62634 .15983 .62499 .1524 Metetra
.954 .643 .218 r
.62499 .1524 .62634 .15983 .61609 .13086 .61485 .1304 Metetra
.288 .543 .919 r
.61485 .1304 .61609 .13086 .60602 .12232 .60467 .11427 Metetra
.97 .66 .281 r
.60467 .11427 .60602 .12232 .59568 .10519 .59435 .09869 Metetra
.983 .698 .364 r
.79634 .31753 .79792 .32922 .79019 .31366 .78892 .30943 Metetra
.922 .57 .126 r
.78892 .30943 .79019 .31366 .78267 .30557 .78124 .29746 Metetra
.975 .672 .312 r
.78124 .29746 .78267 .30557 .77491 .29404 .77356 .28762 Metetra
.97 .652 .305 r
.77356 .28762 .77491 .29404 .76715 .28486 .76592 .28156 Metetra
.935 .558 .221 r
.76592 .28156 .76715 .28486 .75932 .27635 .75831 .27942 Metetra
.978 .912 .596 r
.75831 .27942 .75932 .27635 .75116 .26171 .75081 .28378 Metetra
.997 .773 .463 r
.75081 .28378 .75116 .26171 .74318 .25503 .74335 .2933 Metetra
.992 .757 .472 r
.74335 .2933 .74318 .25503 .73518 .25133 .7352 .2864 Metetra
.993 .759 .473 r
.7352 .2864 .73518 .25133 .72712 .24971 .72696 .28077 Metetra
.993 .76 .476 r
.72696 .28077 .72712 .24971 .71923 .25779 .71858 .2743 Metetra
.996 .778 .491 r
.71858 .2743 .71923 .25779 .71087 .25545 .71022 .27312 Metetra
.985 .762 .52 r
.71022 .27312 .71087 .25545 .70197 .23923 .70114 .2511 Metetra
.993 .785 .521 r
.70114 .2511 .70197 .23923 .6926 .20923 .69236 .24408 Metetra
.989 .754 .488 r
.69236 .24408 .6926 .20923 .68356 .19503 .68301 .21984 Metetra
.99 .762 .493 r
.68301 .21984 .68356 .19503 .6745 .18495 .67379 .20462 Metetra
.993 .771 .493 r
.67379 .20462 .6745 .18495 .66544 .18082 .66464 .19809 Metetra
.942 .763 .295 r
.66464 .19809 .66544 .18082 .65671 .19883 .65706 .27128 Metetra
.99 .749 .471 r
.65706 .27128 .65671 .19883 .6472 .18911 .64701 .2399 Metetra
.981 .742 .499 r
.64701 .2399 .6472 .18911 .63719 .16034 .63611 .16766 Metetra
.99 .809 .566 r
.63611 .16766 .63719 .16034 .62715 .13561 .62634 .15983 Metetra
.986 .757 .508 r
.62634 .15983 .62715 .13561 .61722 .12494 .61609 .13086 Metetra
.986 .821 .593 r
.61609 .13086 .61722 .12494 .60722 .11973 .60602 .12232 Metetra
.916 .816 .733 r
.60602 .12232 .60722 .11973 .59682 .09758 .59568 .10519 Metetra
.988 .764 .51 r
.79792 .32922 .79825 .31121 .79084 .3029 .79019 .31366 Metetra
.991 .784 .528 r
.79019 .31366 .79084 .3029 .78333 .29458 .78267 .30557 Metetra
.988 .779 .535 r
.78267 .30557 .78333 .29458 .77567 .28508 .77491 .29404 Metetra
.989 .789 .546 r
.77491 .29404 .77567 .28508 .76793 .27587 .76715 .28486 Metetra
.99 .791 .544 r
.76715 .28486 .76793 .27587 .75997 .26361 .75932 .27635 Metetra
.986 .773 .53 r
.75932 .27635 .75997 .26361 .75188 .25037 .75116 .26171 Metetra
.993 .785 .521 r
.75116 .26171 .75188 .25037 .74372 .23792 .74318 .25503 Metetra
.994 .774 .493 r
.74318 .25503 .74372 .23792 .73571 .23309 .73518 .25133 Metetra
.995 .774 .487 r
.73518 .25133 .73571 .23309 .72757 .22797 .72712 .24971 Metetra
.997 .773 .466 r
.72712 .24971 .72757 .22797 .71941 .22607 .71923 .25779 Metetra
.994 .761 .472 r
.71923 .25779 .71941 .22607 .71123 .22835 .71087 .25545 Metetra
.99 .759 .491 r
.71087 .25545 .71123 .22835 .70224 .20741 .70197 .23923 Metetra
.987 .753 .496 r
.70197 .23923 .70224 .20741 .69343 .19637 .6926 .20923 Metetra
.988 .775 .529 r
.6926 .20923 .69343 .19637 .68451 .18613 .68356 .19503 Metetra
.989 .793 .551 r
.68356 .19503 .68451 .18613 .67547 .17625 .6745 .18495 Metetra
.995 .804 .538 r
.6745 .18495 .67547 .17625 .66635 .16837 .66544 .18082 Metetra
.998 .801 .455 r
.66544 .18082 .66635 .16837 .65747 .17825 .65671 .19883 Metetra
.992 .768 .495 r
.65671 .19883 .65747 .17825 .6482 .17855 .6472 .18911 Metetra
.97 .763 .568 r
.6472 .18911 .6482 .17855 .63847 .16351 .63719 .16034 Metetra
.66 .322 0 r
.63719 .16034 .63847 .16351 .62842 .13811 .62715 .13561 Metetra
.827 .397 0 r
.62715 .13561 .62842 .13811 .6185 .12756 .61722 .12494 Metetra
.886 .461 .079 r
.61722 .12494 .6185 .12756 .60863 .13146 .60722 .11973 Metetra
.978 .69 .313 r
.60722 .11973 .60863 .13146 .59809 .09949 .59682 .09758 Metetra
.744 .851 .929 r
.79825 .31121 .79932 .31064 .79163 .29556 .79084 .3029 Metetra
.988 .798 .561 r
.79084 .3029 .79163 .29556 .78381 .27921 .78333 .29458 Metetra
.991 .772 .508 r
.78333 .29458 .78381 .27921 .77611 .26808 .77567 .28508 Metetra
.992 .77 .502 r
.77567 .28508 .77611 .26808 .76847 .26095 .76793 .27587 Metetra
.989 .771 .515 r
.76793 .27587 .76847 .26095 .76104 .26237 .75997 .26361 Metetra
.842 .811 .819 r
.75997 .26361 .76104 .26237 .75394 .27663 .75188 .25037 Metetra
.989 .724 .405 r
.75188 .25037 .75394 .27663 .74638 .2821 .74372 .23792 Metetra
.99 .732 .429 r
.74372 .23792 .74638 .2821 .73837 .27849 .73571 .23309 Metetra
.99 .732 .429 r
.73571 .23309 .73837 .27849 .73013 .27176 .72757 .22797 Metetra
.989 .731 .431 r
.72757 .22797 .73013 .27176 .72181 .26646 .71941 .22607 Metetra
.988 .729 .433 r
.71941 .22607 .72181 .26646 .71334 .26017 .71123 .22835 Metetra
.99 .728 .402 r
.71123 .22835 .71334 .26017 .70449 .24549 .70224 .20741 Metetra
.99 .73 .42 r
.70224 .20741 .70449 .24549 .69528 .22145 .69343 .19637 Metetra
.989 .722 .406 r
.69343 .19637 .69528 .22145 .6864 .21346 .68451 .18613 Metetra
.989 .724 .41 r
.68451 .18613 .6864 .21346 .67724 .19987 .67547 .17625 Metetra
.988 .72 .407 r
.67547 .17625 .67724 .19987 .66824 .19826 .66635 .16837 Metetra
.985 .721 .435 r
.66635 .16837 .66824 .19826 .66071 .27074 .65747 .17825 Metetra
.99 .737 .44 r
.65747 .17825 .66071 .27074 .65084 .24803 .6482 .17855 Metetra
.991 .736 .431 r
.6482 .17855 .65084 .24803 .64034 .19769 .63847 .16351 Metetra
.99 .729 .402 r
.63847 .16351 .64034 .19769 .62993 .15476 .62842 .13811 Metetra
.986 .708 .383 r
.62842 .13811 .62993 .15476 .61973 .12747 .6185 .12756 Metetra
.126 0 0 r
.6185 .12756 .61973 .12747 .60965 .11669 .60863 .13146 Metetra
.977 .759 .542 r
.60863 .13146 .60965 .11669 .59933 .09882 .59809 .09949 Metetra
.987 .715 .375 r
.79932 .31064 .80117 .32861 .79336 .311 .79163 .29556 Metetra
.986 .709 .359 r
.79163 .29556 .79336 .311 .78577 .30072 .78381 .27921 Metetra
.988 .72 .397 r
.78381 .27921 .78577 .30072 .77814 .29173 .77611 .26808 Metetra
.988 .722 .409 r
.77611 .26808 .77814 .29173 .77047 .28435 .76847 .26095 Metetra
.986 .719 .422 r
.76847 .26095 .77047 .28435 .76277 .27876 .76104 .26237 Metetra
.978 .703 .438 r
.76104 .26237 .76277 .27876 .7555 .28851 .75394 .27663 Metetra
.978 .693 .409 r
.75394 .27663 .7555 .28851 .74839 .30728 .74638 .2821 Metetra
.988 .722 .416 r
.74638 .2821 .74839 .30728 .7402 .29887 .73837 .27849 Metetra
.987 .717 .402 r
.73837 .27849 .7402 .29887 .7317 .28475 .73013 .27176 Metetra
.983 .699 .38 r
.73013 .27176 .7317 .28475 .72424 .30703 .72181 .26646 Metetra
.99 .73 .425 r
.72181 .26646 .72424 .30703 .71682 .33723 .71334 .26017 Metetra
.991 .737 .432 r
.71334 .26017 .71682 .33723 .70694 .28965 .70449 .24549 Metetra
.991 .733 .412 r
.70449 .24549 .70694 .28965 .69809 .28067 .69528 .22145 Metetra
.99 .735 .431 r
.69528 .22145 .69809 .28067 .68935 .28111 .6864 .21346 Metetra
.991 .736 .43 r
.6864 .21346 .68935 .28111 .67956 .24524 .67724 .19987 Metetra
.989 .731 .431 r
.67724 .19987 .67956 .24524 .6704 .23931 .66824 .19826 Metetra
.973 .713 .478 r
.66824 .19826 .6704 .23931 .66436 .38074 .66071 .27074 Metetra
.991 .74 .434 r
.66071 .27074 .66436 .38074 .65348 .31604 .65084 .24803 Metetra
.992 .739 .411 r
.65084 .24803 .65348 .31604 .64286 .26491 .64034 .19769 Metetra
.992 .738 .415 r
.64034 .19769 .64286 .26491 .63147 .17189 .62993 .15476 Metetra
.985 .71 .345 r
.62993 .15476 .63147 .17189 .62116 .14002 .61973 .12747 Metetra
.982 .695 .359 r
.61973 .12747 .62116 .14002 .61109 .1297 .60965 .11669 Metetra
.982 .697 .341 r
.60965 .11669 .61109 .1297 .60076 .11268 .59933 .09882 Metetra
.976 .774 .568 r
.80117 .32861 .80189 .31992 .79436 .30858 .79336 .311 Metetra
.936 .837 .722 r
.79336 .311 .79436 .30858 .78675 .29754 .78577 .30072 Metetra
.962 .838 .674 r
.78577 .30072 .78675 .29754 .77911 .28815 .77814 .29173 Metetra
.974 .841 .65 r
.77814 .29173 .77911 .28815 .77149 .28177 .77047 .28435 Metetra
.964 .877 .701 r
.77047 .28435 .77149 .28177 .76378 .27592 .76277 .27876 Metetra
.918 .908 .51 r
.76277 .27876 .76378 .27592 .75714 .30256 .7555 .28851 Metetra
.972 .694 .445 r
.7555 .28851 .75714 .30256 .75046 .33383 .74839 .30728 Metetra
.989 .723 .41 r
.74839 .30728 .75046 .33383 .74221 .32435 .7402 .29887 Metetra
.989 .723 .399 r
.7402 .29887 .74221 .32435 .73391 .31706 .7317 .28475 Metetra
.983 .721 .449 r
.7317 .28475 .73391 .31706 .72622 .33283 .72424 .30703 Metetra
.977 .712 .457 r
.72424 .30703 .72622 .33283 .71762 .32456 .71682 .33723 Metetra
.953 .738 .574 r
.71682 .33723 .71762 .32456 .70817 .29162 .70694 .28965 Metetra
.761 .302 0 r
.70694 .28965 .70817 .29162 .69882 .26423 .69809 .28067 Metetra
.996 .78 .488 r
.69809 .28067 .69882 .26423 .68962 .24588 .68935 .28111 Metetra
.986 .751 .495 r
.68935 .28111 .68962 .24588 .68058 .23792 .67956 .24524 Metetra
.992 .811 .559 r
.67956 .24524 .68058 .23792 .67161 .23912 .6704 .23931 Metetra
.573 .358 .55 r
.6704 .23931 .67161 .23912 .66543 .37315 .66436 .38074 Metetra
.893 .696 .629 r
.66436 .38074 .66543 .37315 .65516 .33736 .65348 .31604 Metetra
.978 .714 .313 r
.65348 .31604 .65516 .33736 .6433 .22356 .64286 .26491 Metetra
.973 .734 .517 r
.64286 .26491 .6433 .22356 .63265 .1694 .63147 .17189 Metetra
.85 .725 .725 r
.63147 .17189 .63265 .1694 .62247 .14437 .62116 .14002 Metetra
.935 .573 .17 r
.62116 .14002 .62247 .14437 .61232 .12872 .61109 .1297 Metetra
.787 .795 .859 r
.61109 .1297 .61232 .12872 .60197 .10984 .60076 .11268 Metetra
.987 .712 .379 r
.80189 .31992 .80369 .33648 .79575 .31575 .79436 .30858 Metetra
.969 .659 .279 r
.79436 .30858 .79575 .31575 .78796 .30022 .78675 .29754 Metetra
.854 .447 0 r
.78675 .29754 .78796 .30022 .78021 .28796 .77911 .28815 Metetra
.554 .829 .997 r
.77911 .28815 .78021 .28796 .77259 .28143 .77149 .28177 Metetra
.627 .873 .988 r
.77149 .28177 .77259 .28143 .76529 .2862 .76378 .27592 Metetra
.953 .67 .463 r
.76378 .27592 .76529 .2862 .75738 .27822 .75714 .30256 Metetra
.996 .774 .423 r
.75714 .30256 .75738 .27822 .75066 .3069 .75046 .33383 Metetra
.992 .762 .482 r
.75046 .33383 .75066 .3069 .74203 .28537 .74221 .32435 Metetra
.993 .757 .47 r
.74221 .32435 .74203 .28537 .73373 .27631 .73391 .31706 Metetra
.995 .761 .45 r
.73391 .31706 .73373 .27631 .72605 .29038 .72622 .33283 Metetra
.992 .756 .469 r
.72622 .33283 .72605 .29038 .71786 .2939 .71762 .32456 Metetra
.986 .752 .499 r
.71762 .32456 .71786 .2939 .70868 .26842 .70817 .29162 Metetra
.985 .757 .508 r
.70817 .29162 .70868 .26842 .69929 .23867 .69882 .26423 Metetra
.99 .76 .494 r
.69882 .26423 .69929 .23867 .6903 .22663 .68962 .24588 Metetra
.993 .77 .494 r
.68962 .24588 .6903 .22663 .6812 .21523 .68058 .23792 Metetra
.996 .771 .476 r
.68058 .23792 .6812 .21523 .67216 .21184 .67161 .23912 Metetra
.911 .729 .232 r
.67161 .23912 .67216 .21184 .66497 .2972 .66543 .37315 Metetra
.99 .748 .47 r
.66543 .37315 .66497 .2972 .65615 .32534 .65516 .33736 Metetra
.88 .668 .611 r
.65516 .33736 .65615 .32534 .64451 .22281 .6433 .22356 Metetra
.666 .562 .728 r
.6433 .22356 .64451 .22281 .63395 .17264 .63265 .1694 Metetra
.67 .331 0 r
.63265 .1694 .63395 .17264 .62367 .14244 .62247 .14437 Metetra
.89 .827 .779 r
.62247 .14437 .62367 .14244 .61362 .13249 .61232 .12872 Metetra
.852 .486 0 r
.61232 .12872 .61362 .13249 .60337 .12072 .60197 .10984 Metetra
.216 .372 .805 r
.80369 .33648 .80482 .33752 .79674 .31331 .79575 .31575 Metetra
.909 .795 .722 r
.79575 .31575 .79674 .31331 .78918 .30313 .78796 .30022 Metetra
.828 .438 0 r
.78796 .30022 .78918 .30313 .7815 .29262 .78021 .28796 Metetra
.953 .609 .235 r
.78021 .28796 .7815 .29262 .77388 .2859 .77259 .28143 Metetra
.949 .612 .345 r
.77259 .28143 .77388 .2859 .76621 .28079 .76529 .2862 Metetra
.985 .817 .595 r
.76529 .2862 .76621 .28079 .75909 .29392 .75738 .27822 Metetra
.967 .693 .462 r
.75738 .27822 .75909 .29392 .75269 .33205 .75066 .3069 Metetra
.989 .724 .385 r
.75066 .3069 .75269 .33205 .74492 .33625 .74203 .28537 Metetra
.99 .733 .427 r
.74203 .28537 .74492 .33625 .73641 .32249 .73373 .27631 Metetra
.987 .729 .442 r
.73373 .27631 .73641 .32249 .72855 .33239 .72605 .29038 Metetra
.988 .729 .433 r
.72605 .29038 .72855 .33239 .71995 .32369 .71786 .2939 Metetra
.99 .727 .39 r
.71786 .2939 .71995 .32369 .7104 .28686 .70868 .26842 Metetra
.984 .713 .341 r
.70868 .26842 .7104 .28686 .70126 .26677 .69929 .23867 Metetra
.989 .724 .406 r
.69929 .23867 .70126 .26677 .69157 .22971 .6903 .22663 Metetra
.87 .472 .007 r
.6903 .22663 .69157 .22971 .68247 .21835 .6812 .21523 Metetra
.92 .525 .17 r
.6812 .21523 .68247 .21835 .67328 .20825 .67216 .21184 Metetra
.205 .035 .415 r
.67216 .21184 .67328 .20825 .66605 .29079 .66497 .2972 Metetra
.927 .822 .364 r
.66497 .2972 .66605 .29079 .65661 .28863 .65615 .32534 Metetra
.966 .729 .529 r
.65615 .32534 .65661 .28863 .64532 .20136 .64451 .22281 Metetra
.973 .745 .532 r
.64451 .22281 .64532 .20136 .63528 .17792 .63395 .17264 Metetra
.836 .522 0 r
.63395 .17264 .63528 .17792 .62517 .15792 .62367 .14244 Metetra
.985 .704 .377 r
.62367 .14244 .62517 .15792 .61512 .1492 .61362 .13249 Metetra
.986 .707 .378 r
.61362 .13249 .61512 .1492 .60476 .1304 .60337 .12072 Metetra
.99 .727 .386 r
.80482 .33752 .80713 .36567 .79852 .32935 .79674 .31331 Metetra
.986 .711 .379 r
.79674 .31331 .79852 .32935 .79033 .3043 .78918 .30313 Metetra
0 .104 .635 r
.78918 .30313 .79033 .3043 .78263 .29314 .7815 .29262 Metetra
0 .431 .84 r
.7815 .29262 .78263 .29314 .77489 .28337 .77388 .2859 Metetra
.964 .883 .702 r
.77388 .2859 .77489 .28337 .76727 .27932 .76621 .28079 Metetra
.76621 .28079 .76727 .27932 .75931 .26906 .75909 .29392 Metetra
.995 .773 .41 r
.75909 .29392 .75931 .26906 .75137 .26238 .75269 .33205 Metetra
.993 .752 .453 r
.75269 .33205 .75137 .26238 .74413 .27964 .74492 .33625 Metetra
.992 .752 .466 r
.74492 .33625 .74413 .27964 .73604 .27639 .73641 .32249 Metetra
.995 .758 .453 r
.73641 .32249 .73604 .27639 .72794 .27667 .72855 .33239 Metetra
.992 .753 .463 r
.72855 .33239 .72794 .27667 .71945 .26937 .71995 .32369 Metetra
.988 .749 .479 r
.71995 .32369 .71945 .26937 .71048 .24956 .7104 .28686 Metetra
.99 .755 .48 r
.7104 .28686 .71048 .24956 .70159 .23627 .70126 .26677 Metetra
.984 .751 .502 r
.70126 .26677 .70159 .23627 .69222 .20971 .69157 .22971 Metetra
.992 .768 .496 r
.69157 .22971 .69222 .20971 .68312 .19685 .68247 .21835 Metetra
.992 .767 .491 r
.68247 .21835 .68312 .19685 .67455 .21102 .67328 .20825 Metetra
.73 .469 .534 r
.67328 .20825 .67455 .21102 .66608 .23847 .66605 .29079 Metetra
.993 .755 .461 r
.66605 .29079 .66608 .23847 .65665 .23268 .65661 .28863 Metetra
.98 .739 .499 r
.65661 .28863 .65665 .23268 .64698 .22291 .64532 .20136 Metetra
.988 .718 .373 r
.64532 .20136 .64698 .22291 .6366 .18305 .63528 .17792 Metetra
.912 .573 .105 r
.63528 .17792 .6366 .18305 .62647 .16135 .62517 .15792 Metetra
.91 .519 .109 r
.62517 .15792 .62647 .16135 .61663 .16603 .61512 .1492 Metetra
.986 .708 .362 r
.61512 .1492 .61663 .16603 .60623 .14566 .60476 .1304 Metetra
.987 .748 .484 r
.80713 .36567 .80615 .31773 .79864 .30626 .79852 .32935 Metetra
.985 .756 .507 r
.79852 .32935 .79864 .30626 .79098 .29344 .79033 .3043 Metetra
.989 .78 .533 r
.79033 .3043 .79098 .29344 .78335 .28353 .78263 .29314 Metetra
.989 .786 .54 r
.78263 .29314 .78335 .28353 .77556 .27198 .77489 .28337 Metetra
.995 .787 .512 r
.77489 .28337 .77556 .27198 .7677 .26104 .76727 .27932 Metetra
.992 .768 .498 r
.76727 .27932 .7677 .26104 .75956 .24534 .75931 .26906 Metetra
.993 .765 .482 r
.75931 .26906 .75956 .24534 .75158 .23657 .75137 .26238 Metetra
.997 .77 .446 r
.75137 .26238 .75158 .23657 .74395 .24112 .74413 .27964 Metetra
.993 .758 .465 r
.74413 .27964 .74395 .24112 .73597 .23966 .73604 .27639 Metetra
.994 .759 .463 r
.73604 .27639 .73597 .23966 .72826 .25055 .72794 .27667 Metetra
.993 .763 .48 r
.72794 .27667 .72826 .25055 .72052 .26588 .71945 .26937 Metetra
.927 .785 .684 r
.71945 .26937 .72052 .26588 .71128 .23687 .71048 .24956 Metetra
.989 .777 .526 r
.71048 .24956 .71128 .23687 .70188 .20487 .70159 .23627 Metetra
.988 .754 .492 r
.70159 .23627 .70188 .20487 .69286 .18945 .69222 .20971 Metetra
.991 .767 .497 r
.69222 .20971 .69286 .18945 .6839 .18083 .68312 .19685 Metetra
.999 .787 .459 r
.68312 .19685 .6839 .18083 .67517 .18731 .67455 .21102 Metetra
.997 .777 .436 r
.67455 .21102 .67517 .18731 .66681 .21722 .66608 .23847 Metetra
.994 .77 .487 r
.66608 .23847 .66681 .21722 .65721 .20188 .65665 .23268 Metetra
.993 .761 .478 r
.65665 .23268 .65721 .20188 .6475 .18763 .64698 .22291 Metetra
.986 .75 .496 r
.64698 .22291 .6475 .18763 .63736 .15749 .6366 .18305 Metetra
.989 .76 .496 r
.6366 .18305 .63736 .15749 .62728 .13603 .62647 .16135 Metetra
.996 .77 .469 r
.62647 .16135 .62728 .13603 .61741 .1364 .61663 .16603 Metetra
.99 .759 .488 r
.61663 .16603 .61741 .1364 .60706 .11592 .60623 .14566 Metetra
.959 .816 .658 r
.80615 .31773 .80709 .31409 .79958 .3025 .79864 .30626 Metetra
.956 .809 .657 r
.79864 .30626 .79958 .3025 .79208 .29332 .79098 .29344 Metetra
.575 .757 .964 r
.79098 .29344 .79208 .29332 .78452 .28504 .78335 .28353 Metetra
0 0 .505 r
.78335 .28353 .78452 .28504 .77686 .27674 .77556 .27198 Metetra
.941 .597 .179 r
.77556 .27198 .77686 .27674 .76909 .26822 .7677 .26104 Metetra
.96 .649 .239 r
.7677 .26104 .76909 .26822 .76236 .29058 .75956 .24534 Metetra
.99 .732 .423 r
.75956 .24534 .76236 .29058 .75573 .3208 .75158 .23657 Metetra
.99 .736 .439 r
.75158 .23657 .75573 .3208 .74716 .30076 .74395 .24112 Metetra
.99 .734 .433 r
.74395 .24112 .74716 .30076 .73898 .29518 .73597 .23966 Metetra
.989 .732 .44 r
.73597 .23966 .73898 .29518 .73115 .30405 .72826 .25055 Metetra
.988 .731 .442 r
.72826 .25055 .73115 .30405 .72269 .29814 .72052 .26588 Metetra
.99 .729 .389 r
.72052 .26588 .72269 .29814 .71376 .28076 .71128 .23687 Metetra
.991 .733 .402 r
.71128 .23687 .71376 .28076 .70466 .26119 .70188 .20487 Metetra
.991 .735 .423 r
.70188 .20487 .70466 .26119 .69514 .22997 .69286 .18945 Metetra
.99 .73 .421 r
.69286 .18945 .69514 .22997 .68608 .21908 .6839 .18083 Metetra
.988 .727 .432 r
.6839 .18083 .68608 .21908 .67716 .21936 .67517 .18731 Metetra
.981 .717 .451 r
.67517 .18731 .67716 .21936 .66957 .28396 .66681 .21722 Metetra
.991 .736 .427 r
.66681 .21722 .66957 .28396 .66004 .27565 .65721 .20188 Metetra
.991 .736 .429 r
.65721 .20188 .66004 .27565 .6486 .18118 .6475 .18763 Metetra
.947 .762 .62 r
.6475 .18763 .6486 .18118 .63891 .17446 .63736 .15749 Metetra
.985 .709 .355 r
.63736 .15749 .63891 .17446 .62864 .14323 .62728 .13603 Metetra
.968 .651 .344 r
.62728 .13603 .62864 .14323 .61854 .12862 .61741 .1364 Metetra
.975 .784 .585 r
.61741 .1364 .61854 .12862 .60822 .10921 .60706 .11592 Metetra
.987 .711 .375 r
.80709 .31409 .80889 .33049 .80113 .31318 .79958 .3025 Metetra
.981 .691 .345 r
.79958 .3025 .80113 .31318 .79353 .30161 .79208 .29332 Metetra
.976 .673 .32 r
.79208 .29332 .79353 .30161 .7859 .29177 .78452 .28504 Metetra
.969 .653 .288 r
.78452 .28504 .7859 .29177 .77823 .28321 .77686 .27674 Metetra
.967 .648 .279 r
.77686 .27674 .77823 .28321 .77063 .27913 .76909 .26822 Metetra
.961 .677 .452 r
.76909 .26822 .77063 .27913 .76343 .28882 .76236 .29058 Metetra
.093 0 .24 r
.76236 .29058 .76343 .28882 .75683 .31957 .75573 .3208 Metetra
.803 .743 .797 r
.75573 .3208 .75683 .31957 .74838 .3027 .74716 .30076 Metetra
.819 .356 0 r
.74716 .30076 .74838 .3027 .74035 .30144 .73898 .29518 Metetra
.957 .642 .387 r
.73898 .29518 .74035 .30144 .73214 .29863 .73115 .30405 Metetra
.989 .828 .59 r
.73115 .30405 .73214 .29863 .72405 .30391 .72269 .29814 Metetra
.935 .607 .162 r
.72269 .29814 .72405 .30391 .71486 .27804 .71376 .28076 Metetra
.906 .786 .718 r
.71376 .28076 .71486 .27804 .70599 .26601 .70466 .26119 Metetra
.748 .449 0 r
.70466 .26119 .70599 .26601 .69667 .24222 .69514 .22997 Metetra
.982 .695 .352 r
.69514 .22997 .69667 .24222 .68732 .22076 .68608 .21908 Metetra
.831 .359 .055 r
.68608 .21908 .68732 .22076 .6785 .22465 .67716 .21936 Metetra
.835 .557 .517 r
.67716 .21936 .6785 .22465 .67132 .30615 .66957 .28396 Metetra
.987 .717 .399 r
.66957 .28396 .67132 .30615 .66167 .29344 .66004 .27565 Metetra
.873 .639 .111 r
.66004 .27565 .66167 .29344 .64991 .18514 .6486 .18118 Metetra
.934 .562 .183 r
.6486 .18118 .64991 .18514 .64007 .17031 .63891 .17446 Metetra
.91 .751 .672 r
.63891 .17446 .64007 .17031 .62987 .14277 .62864 .14323 Metetra
.682 .783 .926 r
.62864 .14323 .62987 .14277 .61988 .13459 .61854 .12862 Metetra
.938 .608 .168 r
.61854 .12862 .61988 .13459 .60958 .11715 .60822 .10921 Metetra
0 0 .464 r
.80889 .33049 .81008 .33264 .80205 .30898 .80113 .31318 Metetra
.966 .812 .638 r
.80113 .31318 .80205 .30898 .79442 .29654 .79353 .30161 Metetra
.979 .812 .608 r
.79353 .30161 .79442 .29654 .78674 .285 .7859 .29177 Metetra
.987 .803 .569 r
.7859 .29177 .78674 .285 .7791 .27679 .77823 .28321 Metetra
.994 .817 .559 r
.77823 .28321 .7791 .27679 .7715 .27254 .77063 .27913 Metetra
.996 .835 .485 r
.77063 .27913 .7715 .27254 .76457 .28892 .76343 .28882 Metetra
.584 .279 .416 r
.76343 .28882 .76457 .28892 .75777 .31387 .75683 .31957 Metetra
.966 .789 .613 r
.75683 .31957 .75777 .31387 .74935 .29762 .74838 .3027 Metetra
.995 .845 .576 r
.74838 .3027 .74935 .29762 .74112 .28993 .74035 .30144 Metetra
.996 .79 .509 r
.74035 .30144 .74112 .28993 .73307 .29123 .73214 .29863 Metetra
1 .826 .511 r
.73214 .29863 .73307 .29123 .72501 .29717 .72405 .30391 Metetra
.955 .767 .609 r
.72405 .30391 .72501 .29717 .71581 .27056 .71486 .27804 Metetra
.985 .797 .571 r
.71486 .27804 .71581 .27056 .70682 .25383 .70599 .26601 Metetra
.979 .767 .547 r
.70599 .26601 .70682 .25383 .69754 .23056 .69667 .24222 Metetra
.981 .771 .547 r
.69667 .24222 .69754 .23056 .68853 .22115 .68732 .22076 Metetra
.498 0 0 r
.68732 .22076 .68853 .22115 .67987 .23133 .6785 .22465 Metetra
.839 .57 .531 r
.6785 .22465 .67987 .23133 .67214 .28882 .67132 .30615 Metetra
.991 .772 .505 r
.67132 .30615 .67214 .28882 .66232 .26732 .66167 .29344 Metetra
.949 .717 .553 r
.66167 .29344 .66232 .26732 .65148 .20186 .64991 .18514 Metetra
.986 .708 .369 r
.64991 .18514 .65148 .20186 .64127 .16863 .64007 .17031 Metetra
.816 .728 .767 r
.64007 .17031 .64127 .16863 .63115 .14536 .62987 .14277 Metetra
.86 .43 0 r
.62987 .14277 .63115 .14536 .62108 .13182 .61988 .13459 Metetra
.922 .816 .723 r
.61988 .13459 .62108 .13182 .61077 .11244 .60958 .11715 Metetra
.982 .76 .527 r
.81008 .33264 .81048 .3167 .80281 .30125 .80205 .30898 Metetra
.983 .788 .566 r
.80205 .30898 .80281 .30125 .79538 .2931 .79442 .29654 Metetra
.957 .82 .667 r
.79442 .29654 .79538 .2931 .78777 .28313 .78674 .285 Metetra
.924 .87 .767 r
.78674 .285 .78777 .28313 .78012 .27445 .7791 .27679 Metetra
.962 .898 .714 r
.7791 .27679 .78012 .27445 .77257 .27102 .7715 .27254 Metetra
.7715 .27254 .77257 .27102 .76554 .28457 .76457 .28892 Metetra
.792 .764 .251 r
.76457 .28892 .76554 .28457 .75861 .30534 .75777 .31387 Metetra
.98 .782 .566 r
.75777 .31387 .75861 .30534 .75014 .28739 .74935 .29762 Metetra
.992 .789 .529 r
.74935 .29762 .75014 .28739 .74184 .27689 .74112 .28993 Metetra
.998 .788 .491 r
.74112 .28993 .74184 .27689 .73376 .27686 .73307 .29123 Metetra
.999 .787 .477 r
.73307 .29123 .73376 .27686 .72595 .2895 .72501 .29717 Metetra
.96 .765 .596 r
.72501 .29717 .72595 .2895 .71664 .25893 .71581 .27056 Metetra
.985 .776 .539 r
.71581 .27056 .71664 .25893 .70766 .24189 .70682 .25383 Metetra
.98 .768 .547 r
.70682 .25383 .70766 .24189 .69823 .21236 .69754 .23056 Metetra
.993 .771 .497 r
.69754 .23056 .69823 .21236 .68929 .2048 .68853 .22115 Metetra
.999 .785 .466 r
.68853 .22115 .68929 .2048 .68092 .22485 .67987 .23133 Metetra
.67987 .23133 .68092 .22485 .67353 .29568 .67214 .28882 Metetra
.942 .626 .183 r
.67214 .28882 .67353 .29568 .66276 .23158 .66232 .26732 Metetra
.978 .742 .51 r
.66232 .26732 .66276 .23158 .65238 .18597 .65148 .20186 Metetra
.978 .758 .536 r
.65148 .20186 .65238 .18597 .64237 .16182 .64127 .16863 Metetra
.965 .78 .604 r
.64127 .16863 .64237 .16182 .63231 .1407 .63115 .14536 Metetra
.97 .82 .637 r
.63115 .14536 .63231 .1407 .62225 .12728 .62108 .13182 Metetra
.954 .799 .651 r
.62108 .13182 .62225 .12728 .61194 .10705 .61077 .11244 Metetra
.977 .685 .306 r
.81048 .3167 .81202 .32698 .8042 .30784 .80281 .30125 Metetra
.969 .652 .283 r
.80281 .30125 .8042 .30784 .79673 .29885 .79538 .2931 Metetra
.959 .631 .238 r
.79538 .2931 .79673 .29885 .78914 .28945 .78777 .28313 Metetra
.966 .645 .271 r
.78777 .28313 .78914 .28945 .78154 .28204 .78012 .27445 Metetra
.974 .666 .338 r
.78012 .27445 .78154 .28204 .77394 .27751 .77257 .27102 Metetra
.952 .645 .416 r
.77257 .27102 .77394 .27751 .76668 .28495 .76554 .28457 Metetra
.627 .271 .347 r
.76554 .28457 .76668 .28495 .75972 .30439 .75861 .30534 Metetra
.78 .75 .826 r
.75861 .30534 .75972 .30439 .75159 .29583 .75014 .28739 Metetra
.975 .67 .307 r
.75014 .28739 .75159 .29583 .74334 .28703 .74184 .27689 Metetra
.978 .684 .377 r
.74184 .27689 .74334 .28703 .73531 .28864 .73376 .27686 Metetra
.973 .686 .422 r
.73376 .27686 .73531 .28864 .72773 .30868 .72595 .2895 Metetra
.984 .713 .339 r
.72595 .2895 .72773 .30868 .71807 .26694 .71664 .25893 Metetra
.965 .657 .255 r
.71664 .25893 .71807 .26694 .70902 .24791 .70766 .24189 Metetra
.862 .556 .031 r
.70766 .24189 .70902 .24791 .69988 .22908 .69823 .21236 Metetra
.986 .708 .385 r
.69823 .21236 .69988 .22908 .69068 .21196 .68929 .2048 Metetra
.946 .641 .428 r
.68929 .2048 .69068 .21196 .68221 .22801 .68092 .22485 Metetra
.761 .49 .523 r
.68092 .22485 .68221 .22801 .67509 .30912 .67353 .29568 Metetra
.897 .641 .13 r
.67353 .29568 .67509 .30912 .66557 .30153 .66276 .23158 Metetra
.992 .738 .41 r
.66276 .23158 .66557 .30153 .65415 .21137 .65238 .18597 Metetra
.989 .722 .381 r
.65238 .18597 .65415 .21137 .64404 .18391 .64237 .16182 Metetra
.988 .718 .376 r
.64237 .16182 .64404 .18391 .6339 .15982 .63231 .1407 Metetra
.987 .712 .381 r
.63231 .1407 .6339 .15982 .62357 .13144 .62225 .12728 Metetra
.863 .507 .003 r
.62225 .12728 .62357 .13144 .61325 .11091 .61194 .10705 Metetra
.956 .777 .621 r
.81202 .32698 .81287 .32153 .80532 .3083 .8042 .30784 Metetra
.155 .523 .918 r
.8042 .30784 .80532 .3083 .79767 .29502 .79673 .29885 Metetra
.97 .827 .645 r
.79673 .29885 .79767 .29502 .79011 .2861 .78914 .28945 Metetra
.972 .847 .66 r
.78914 .28945 .79011 .2861 .78248 .27765 .78154 .28204 Metetra
.988 .842 .607 r
.78154 .28204 .78248 .27765 .77474 .26898 .77394 .27751 Metetra
1 .814 .486 r
.77394 .27751 .77474 .26898 .7667 .25543 .76668 .28495 Metetra
.997 .767 .441 r
.76668 .28495 .7667 .25543 .75891 .25106 .75972 .30439 Metetra
.993 .753 .461 r
.75972 .30439 .75891 .25106 .75091 .24429 .75159 .29583 Metetra
.993 .753 .462 r
.75159 .29583 .75091 .24429 .74321 .24967 .74334 .28703 Metetra
.994 .759 .46 r
.74334 .28703 .74321 .24967 .7351 .24697 .73531 .28864 Metetra
.996 .761 .442 r
.73531 .28864 .7351 .24697 .72671 .23982 .72773 .30868 Metetra
.989 .747 .472 r
.72773 .30868 .72671 .23982 .71802 .22689 .71807 .26694 Metetra
.991 .754 .475 r
.71807 .26694 .71802 .22689 .70917 .21277 .70902 .24791 Metetra
.991 .756 .479 r
.70902 .24791 .70917 .21277 .69999 .19063 .69988 .22908 Metetra
.991 .755 .475 r
.69988 .22908 .69999 .19063 .69108 .18209 .69068 .21196 Metetra
.997 .768 .449 r
.69068 .21196 .69108 .18209 .6829 .20776 .68221 .22801 Metetra
.945 .758 .293 r
.68221 .22801 .6829 .20776 .67441 .23007 .67509 .30912 Metetra
.993 .751 .455 r
.67509 .30912 .67441 .23007 .66477 .21204 .66557 .30153 Metetra
.986 .742 .479 r
.66557 .30153 .66477 .21204 .65471 .18014 .65415 .21137 Metetra
.989 .755 .49 r
.65415 .21137 .65471 .18014 .64452 .14558 .64404 .18391 Metetra
.99 .754 .479 r
.64404 .18391 .64452 .14558 .63467 .13415 .6339 .15982 Metetra
.987 .757 .5 r
.6339 .15982 .63467 .13415 .62471 .12497 .62357 .13144 Metetra
.969 .789 .606 r
.62357 .13144 .62471 .12497 .61448 .10926 .61325 .11091 Metetra
.989 .772 .521 r
.81287 .32153 .81338 .30837 .80583 .29485 .80532 .3083 Metetra
.989 .772 .52 r
.80532 .3083 .80583 .29485 .79832 .28422 .79767 .29502 Metetra
.991 .783 .526 r
.79767 .29502 .79832 .28422 .79063 .27159 .79011 .2861 Metetra
.993 .775 .505 r
.79011 .2861 .79063 .27159 .78292 .2608 .78248 .27765 Metetra
.993 .771 .497 r
.78248 .27765 .78292 .2608 .77504 .24803 .77474 .26898 Metetra
.991 .764 .494 r
.77474 .26898 .77504 .24803 .76708 .23566 .7667 .25543 Metetra
.995 .77 .483 r
.7667 .25543 .76708 .23566 .75917 .22725 .75891 .25106 Metetra
.994 .765 .48 r
.75891 .25106 .75917 .22725 .75141 .22621 .75091 .24429 Metetra
.997 .777 .469 r
.75091 .24429 .75141 .22621 .7435 .22458 .74321 .24967 Metetra
.995 .766 .473 r
.74321 .24967 .7435 .22458 .73563 .22796 .7351 .24697 Metetra
.994 .77 .49 r
.7351 .24697 .73563 .22796 .72752 .22884 .72671 .23982 Metetra
.989 .781 .535 r
.72671 .23982 .72752 .22884 .71865 .20924 .71802 .22689 Metetra
.991 .768 .504 r
.71802 .22689 .71865 .20924 .7096 .18731 .70917 .21277 Metetra
.989 .758 .495 r
.70917 .21277 .7096 .18731 .70064 .17183 .69999 .19063 Metetra
.993 .771 .493 r
.69999 .19063 .70064 .17183 .69174 .16249 .69108 .18209 Metetra
.997 .782 .432 r
.69108 .18209 .69174 .16249 .68325 .17449 .6829 .20776 Metetra
.997 .766 .442 r
.6829 .20776 .68325 .17449 .67433 .17683 .67441 .23007 Metetra
.992 .752 .466 r
.67441 .23007 .67433 .17683 .66497 .16745 .66477 .21204 Metetra
.989 .751 .479 r
.66477 .21204 .66497 .16745 .65537 .15356 .65471 .18014 Metetra
.985 .754 .503 r
.65471 .18014 .65537 .15356 .64554 .13498 .64452 .14558 Metetra
.991 .788 .536 r
.64452 .14558 .64554 .13498 .63572 .12419 .63467 .13415 Metetra
.992 .794 .537 r
.63467 .13415 .63572 .12419 .62585 .1189 .62471 .12497 Metetra
.976 .803 .605 r
.62471 .12497 .62585 .1189 .61546 .09167 .61448 .10926 Metetra
.251 .49 .891 r
.81338 .30837 .8145 .30897 .80711 .2991 .80583 .29485 Metetra
.927 .573 .139 r
.80583 .29485 .80711 .2991 .79956 .28764 .79832 .28422 Metetra
.867 .494 .005 r
.79832 .28422 .79956 .28764 .79203 .27864 .79063 .27159 Metetra
.968 .654 .272 r
.79063 .27159 .79203 .27864 .78442 .27041 .78292 .2608 Metetra
.977 .681 .311 r
.78292 .2608 .78442 .27041 .7769 .26692 .77504 .24803 Metetra
.987 .715 .38 r
.77504 .24803 .7769 .26692 .76997 .28178 .76708 .23566 Metetra
.99 .732 .421 r
.76708 .23566 .76997 .28178 .76296 .29896 .75917 .22725 Metetra
.99 .736 .433 r
.75917 .22725 .76296 .29896 .7549 .29169 .75141 .22621 Metetra
.99 .735 .431 r
.75141 .22621 .7549 .29169 .74659 .28059 .7435 .22458 Metetra
.99 .733 .433 r
.7435 .22458 .74659 .28059 .73853 .27996 .73563 .22796 Metetra
.99 .732 .43 r
.73563 .22796 .73853 .27996 .731 .30046 .72752 .22884 Metetra
.991 .737 .423 r
.72752 .22884 .731 .30046 .72165 .26809 .71865 .20924 Metetra
.991 .735 .417 r
.71865 .20924 .72165 .26809 .71267 .25099 .7096 .18731 Metetra
.991 .735 .423 r
.7096 .18731 .71267 .25099 .70346 .22922 .70064 .17183 Metetra
.991 .734 .425 r
.70064 .17183 .70346 .22922 .69436 .21496 .69174 .16249 Metetra
.988 .73 .436 r
.69174 .16249 .69436 .21496 .68571 .22313 .68325 .17449 Metetra
.989 .73 .429 r
.68325 .17449 .68571 .22313 .67881 .3102 .67433 .17683 Metetra
.991 .739 .435 r
.67433 .17683 .67881 .3102 .66906 .29126 .66497 .16745 Metetra
.991 .739 .433 r
.66497 .16745 .66906 .29126 .65746 .19339 .65537 .15356 Metetra
.99 .73 .408 r
.65537 .15356 .65746 .19339 .64721 .15655 .64554 .13498 Metetra
.987 .716 .391 r
.64554 .13498 .64721 .15655 .63723 .13861 .63572 .12419 Metetra
.983 .699 .378 r
.63572 .12419 .63723 .13861 .62724 .12718 .62585 .1189 Metetra
.947 .645 .201 r
.62585 .1189 .62724 .12718 .6169 .10342 .61546 .09167 Metetra
.817 .405 0 r
.8145 .30897 .81571 .31149 .80852 .30607 .80711 .2991 Metetra
.966 .652 .263 r
.80711 .2991 .80852 .30607 .80105 .29648 .79956 .28764 Metetra
.977 .677 .32 r
.79956 .28764 .80105 .29648 .79337 .28427 .79203 .27864 Metetra
.96 .631 .25 r
.79203 .27864 .79337 .28427 .78577 .27619 .78442 .27041 Metetra
.966 .639 .3 r
.78442 .27041 .78577 .27619 .77822 .27186 .7769 .26692 Metetra
.934 .615 .412 r
.7769 .26692 .77822 .27186 .7711 .28173 .76997 .28178 Metetra
.51 .128 .251 r
.76997 .28178 .7711 .28173 .76402 .29675 .76296 .29896 Metetra
.945 .88 .739 r
.76296 .29896 .76402 .29675 .75577 .28382 .7549 .29169 Metetra
.987 .795 .561 r
.7549 .29169 .75577 .28382 .74763 .27708 .74659 .28059 Metetra
.989 .884 .623 r
.74659 .28059 .74763 .27708 .73964 .27826 .73853 .27996 Metetra
.73853 .27996 .73964 .27826 .73189 .29132 .731 .30046 Metetra
.959 .755 .585 r
.731 .30046 .73189 .29132 .7225 .25752 .72165 .26809 Metetra
.984 .778 .546 r
.72165 .26809 .7225 .25752 .71364 .24346 .71267 .25099 Metetra
.969 .777 .589 r
.71267 .25099 .71364 .24346 .70424 .21466 .70346 .22922 Metetra
.99 .774 .516 r
.70346 .22922 .70424 .21466 .69537 .20813 .69436 .21496 Metetra
.998 .838 .504 r
.69436 .21496 .69537 .20813 .68704 .22787 .68571 .22313 Metetra
.789 .524 .537 r
.68571 .22313 .68704 .22787 .6798 .30023 .67881 .3102 Metetra
.982 .78 .556 r
.67881 .3102 .6798 .30023 .66979 .26969 .66906 .29126 Metetra
.944 .715 .561 r
.66906 .29126 .66979 .26969 .6584 .18009 .65746 .19339 Metetra
.971 .755 .554 r
.65746 .19339 .6584 .18009 .64859 .16388 .64721 .15655 Metetra
.958 .643 .232 r
.64721 .15655 .64859 .16388 .63837 .13284 .63723 .13861 Metetra
.982 .817 .601 r
.63723 .13861 .63837 .13284 .6283 .1161 .62724 .12718 Metetra
.98 .773 .553 r
.62724 .12718 .6283 .1161 .61806 .09735 .6169 .10342 Metetra
.903 .501 .096 r
.81571 .31149 .81693 .31429 .80933 .29952 .80852 .30607 Metetra
.985 .801 .574 r
.80852 .30607 .80933 .29952 .80188 .29004 .80105 .29648 Metetra
.98 .796 .584 r
.80105 .29648 .80188 .29004 .79435 .28112 .79337 .28427 Metetra
.966 .847 .672 r
.79337 .28427 .79435 .28112 .78674 .27241 .78577 .27619 Metetra
.986 .856 .627 r
.78577 .27619 .78674 .27241 .77915 .26678 .77822 .27186 Metetra
.987 .858 .489 r
.77822 .27186 .77915 .26678 .77193 .27386 .7711 .28173 Metetra
.991 .822 .446 r
.7711 .28173 .77193 .27386 .76422 .27136 .76402 .29675 Metetra
.992 .761 .484 r
.76402 .29675 .76422 .27136 .75666 .27674 .75577 .28382 Metetra
.992 .808 .559 r
.75577 .28382 .75666 .27674 .74867 .27372 .74763 .27708 Metetra
.987 .897 .617 r
.74763 .27708 .74867 .27372 .74037 .26541 .73964 .27826 Metetra
.999 .795 .457 r
.73964 .27826 .74037 .26541 .73251 .2744 .73189 .29132 Metetra
.978 .755 .533 r
.73189 .29132 .73251 .2744 .72336 .24732 .7225 .25752 Metetra
.987 .783 .543 r
.7225 .25752 .72336 .24732 .71466 .23798 .71364 .24346 Metetra
.937 .759 .636 r
.71364 .24346 .71466 .23798 .70585 .22933 .70424 .21466 Metetra
.984 .702 .377 r
.70424 .21466 .70585 .22933 .69692 .22082 .69537 .20813 Metetra
.969 .684 .434 r
.69537 .20813 .69692 .22082 .68841 .23375 .68704 .22787 Metetra
.836 .562 .523 r
.68704 .22787 .68841 .23375 .68063 .28406 .6798 .30023 Metetra
.981 .76 .531 r
.6798 .30023 .68063 .28406 .67074 .25732 .66979 .26969 Metetra
.909 .694 .599 r
.66979 .26969 .67074 .25732 .65965 .18075 .6584 .18009 Metetra
.182 .464 .886 r
.6584 .18009 .65965 .18075 .6498 .16247 .64859 .16388 Metetra
.78 .695 .77 r
.64859 .16388 .6498 .16247 .6396 .1324 .63837 .13284 Metetra
.675 .753 .909 r
.63837 .13284 .6396 .1324 .62959 .11878 .6283 .1161 Metetra
.697 .309 0 r
.6283 .1161 .62959 .11878 .61928 .09539 .61806 .09735 Metetra
.899 .799 .741 r
.81693 .31429 .81793 .31217 .81045 .30007 .80933 .29952 Metetra
.102 .473 .894 r
.80933 .29952 .81045 .30007 .80319 .29497 .80188 .29004 Metetra
.949 .609 .209 r
.80188 .29004 .80319 .29497 .79557 .28372 .79435 .28112 Metetra
.85 .436 0 r
.79435 .28112 .79557 .28372 .7881 .27837 .78674 .27241 Metetra
.966 .64 .285 r
.78674 .27241 .7881 .27837 .78041 .27031 .77915 .26678 Metetra
.929 .576 .336 r
.77915 .26678 .78041 .27031 .77316 .27634 .77193 .27386 Metetra
.898 .48 .121 r
.77193 .27386 .77316 .27634 .7656 .27777 .76422 .27136 Metetra
.963 .647 .369 r
.76422 .27136 .7656 .27777 .75791 .27932 .75666 .27674 Metetra
.899 .483 .118 r
.75666 .27674 .75791 .27932 .74975 .27158 .74867 .27372 Metetra
.937 .875 .749 r
.74867 .27372 .74975 .27158 .74151 .2648 .74037 .26541 Metetra
.74037 .26541 .74151 .2648 .73334 .26377 .73251 .2744 Metetra
.972 .764 .563 r
.73251 .2744 .73334 .26377 .72448 .2454 .72336 .24732 Metetra
.921 .874 .773 r
.72336 .24732 .72448 .2454 .71584 .23766 .71466 .23798 Metetra
.624 .835 .981 r
.71466 .23798 .71584 .23766 .70701 .22801 .70585 .22933 Metetra
.874 .896 .846 r
.70585 .22933 .70701 .22801 .69796 .21508 .69692 .22082 Metetra
.985 .854 .479 r
.69692 .22082 .69796 .21508 .6897 .23655 .68841 .23375 Metetra
.781 .489 .493 r
.68841 .23375 .6897 .23655 .68178 .28047 .68063 .28406 Metetra
.909 .763 .687 r
.68063 .28406 .68178 .28047 .67133 .22979 .67074 .25732 Metetra
.968 .734 .531 r
.67074 .25732 .67133 .22979 .66075 .17499 .65965 .18075 Metetra
.968 .796 .616 r
.65965 .18075 .66075 .17499 .65095 .15802 .6498 .16247 Metetra
.921 .758 .663 r
.6498 .16247 .65095 .15802 .64082 .13134 .6396 .1324 Metetra
.813 .839 .869 r
.6396 .1324 .64082 .13134 .63083 .11806 .62959 .11878 Metetra
.721 .713 .842 r
.62959 .11878 .63083 .11806 .62056 .09711 .61928 .09539 Metetra
.673 .758 .915 r
.81793 .31217 .81901 .31185 .81144 .29751 .81045 .30007 Metetra
.967 .881 .696 r
.81045 .30007 .81144 .29751 .80383 .28407 .80319 .29497 Metetra
.989 .781 .529 r
.80319 .29497 .80383 .28407 .79632 .27501 .79557 .28372 Metetra
.994 .798 .532 r
.79557 .28372 .79632 .27501 .78876 .2672 .7881 .27837 Metetra
.993 .784 .52 r
.7881 .27837 .78876 .2672 .78132 .26489 .78041 .27031 Metetra
.997 .85 .517 r
.78041 .27031 .78132 .26489 .77427 .2756 .77316 .27634 Metetra
.622 .957 .819 r
.77316 .27634 .77427 .2756 .76678 .27865 .7656 .27777 Metetra
.693 .157 0 r
.7656 .27777 .76678 .27865 .75884 .27339 .75791 .27932 Metetra
.988 .816 .581 r
.75791 .27932 .75884 .27339 .75064 .26396 .74975 .27158 Metetra
.992 .805 .551 r
.74975 .27158 .75064 .26396 .74266 .26413 .74151 .2648 Metetra
.664 .969 .911 r
.74151 .2648 .74266 .26413 .73451 .26372 .73334 .26377 Metetra
.583 .659 .89 r
.73334 .26377 .73451 .26372 .72563 .24462 .72448 .2454 Metetra
.783 .899 .924 r
.72448 .2454 .72563 .24462 .71674 .22835 .71584 .23766 Metetra
.991 .793 .541 r
.71584 .23766 .71674 .22835 .7078 .21405 .70701 .22801 Metetra
.991 .776 .516 r
.70701 .22801 .7078 .21405 .69872 .19913 .69796 .21508 Metetra
.997 .789 .437 r
.69796 .21508 .69872 .19913 .68977 .19364 .6897 .23655 Metetra
.996 .763 .421 r
.6897 .23655 .68977 .19364 .68186 .23488 .68178 .28047 Metetra
.986 .747 .488 r
.68178 .28047 .68186 .23488 .67168 .19288 .67133 .22979 Metetra
.983 .746 .499 r
.67133 .22979 .67168 .19288 .66164 .15968 .66075 .17499 Metetra
.989 .772 .516 r
.66075 .17499 .66164 .15968 .65184 .14183 .65095 .15802 Metetra
.984 .763 .525 r
.65095 .15802 .65184 .14183 .6418 .11791 .64082 .13134 Metetra
.991 .779 .519 r
.64082 .13134 .6418 .11791 .63187 .10651 .63083 .11806 Metetra
.984 .775 .544 r
.63083 .11806 .63187 .10651 .62172 .09124 .62056 .09711 Metetra
.989 .767 .508 r
.81901 .31185 .81937 .29583 .8121 .28765 .81144 .29751 Metetra
.986 .78 .543 r
.81144 .29751 .8121 .28765 .80451 .27421 .80383 .28407 Metetra
.991 .787 .532 r
.80383 .28407 .80451 .27421 .79698 .26435 .79632 .27501 Metetra
.993 .786 .522 r
.79632 .27501 .79698 .26435 .78939 .25545 .78876 .2672 Metetra
.997 .788 .501 r
.78876 .2672 .78939 .25545 .78168 .24594 .78132 .26489 Metetra
.998 .777 .453 r
.78132 .26489 .78168 .24594 .77387 .23632 .77427 .2756 Metetra
.995 .758 .454 r
.77427 .2756 .77387 .23632 .76632 .23655 .76678 .27865 Metetra
.993 .756 .46 r
.76678 .27865 .76632 .23655 .75871 .23856 .75884 .27339 Metetra
.993 .758 .469 r
.75884 .27339 .75871 .23856 .75097 .24066 .75064 .26396 Metetra
.996 .768 .469 r
.75064 .26396 .75097 .24066 .74271 .23184 .74266 .26413 Metetra
.995 .761 .462 r
.74266 .26413 .74271 .23184 .73462 .23166 .73451 .26372 Metetra
.991 .757 .48 r
.73451 .26372 .73462 .23166 .72562 .2072 .72563 .24462 Metetra
.992 .756 .472 r
.72563 .24462 .72562 .2072 .71692 .19555 .71674 .22835 Metetra
.992 .758 .475 r
.71674 .22835 .71692 .19555 .70788 .17626 .7078 .21405 Metetra
.992 .756 .471 r
.7078 .21405 .70788 .17626 .69915 .17188 .69872 .19913 Metetra
.994 .764 .472 r
.69872 .19913 .69915 .17188 .69036 .17073 .68977 .19364 Metetra
.993 .777 .403 r
.68977 .19364 .69036 .17073 .68199 .19194 .68186 .23488 Metetra
.987 .749 .485 r
.68186 .23488 .68199 .19194 .67241 .17251 .67168 .19288 Metetra
.983 .756 .517 r
.67168 .19288 .67241 .17251 .66223 .13155 .66164 .15968 Metetra
.991 .76 .484 r
.66164 .15968 .66223 .13155 .65229 .10489 .65184 .14183 Metetra
.991 .755 .478 r
.65184 .14183 .65229 .10489 .64254 .0926 .6418 .11791 Metetra
.993 .764 .482 r
.6418 .11791 .64254 .0926 .63277 .08727 .63187 .10651 Metetra
.992 .768 .499 r
.63187 .10651 .63277 .08727 .62263 .07042 .62172 .09124 Metetra
.936 .579 .168 r
.81937 .29583 .82065 .29998 .81291 .28112 .8121 .28765 Metetra
.978 .792 .585 r
.8121 .28765 .81291 .28112 .80554 .27263 .80451 .27421 Metetra
.896 .854 .792 r
.80451 .27421 .80554 .27263 .79806 .26358 .79698 .26435 Metetra
.793 .86 .9 r
.79698 .26435 .79806 .26358 .79029 .25018 .78939 .25545 Metetra
.982 .814 .6 r
.78939 .25545 .79029 .25018 .78263 .24149 .78168 .24594 Metetra
.977 .822 .624 r
.78168 .24594 .78263 .24149 .77445 .22237 .77387 .23632 Metetra
.997 .783 .486 r
.77387 .23632 .77445 .22237 .76673 .21736 .76632 .23655 Metetra
.997 .774 .47 r
.76632 .23655 .76673 .21736 .75932 .22397 .75871 .23856 Metetra
.998 .783 .48 r
.75871 .23856 .75932 .22397 .75165 .22746 .75097 .24066 Metetra
.993 .779 .51 r
.75097 .24066 .75165 .22746 .74347 .22008 .74271 .23184 Metetra
.998 .792 .497 r
.74271 .23184 .74347 .22008 .7353 .21679 .73462 .23166 Metetra
.983 .763 .529 r
.73462 .23166 .7353 .21679 .72669 .20389 .72562 .2072 Metetra
.958 .834 .679 r
.72562 .2072 .72669 .20389 .71796 .1909 .71692 .19555 Metetra
.953 .79 .643 r
.71692 .19555 .71796 .1909 .70915 .17916 .70788 .17626 Metetra
.906 .5 .122 r
.70788 .17626 .70915 .17916 .70022 .16735 .69915 .17188 Metetra
.994 .861 .593 r
.69915 .17188 .70022 .16735 .69143 .16554 .69036 .17073 Metetra
.927 .84 .393 r
.69036 .17073 .69143 .16554 .68264 .16993 .68199 .19194 Metetra
.99 .763 .497 r
.68199 .19194 .68264 .16993 .67337 .16183 .67241 .17251 Metetra
.958 .748 .578 r
.67241 .17251 .67337 .16183 .66384 .14865 .66223 .13155 Metetra
.983 .707 .335 r
.66223 .13155 .66384 .14865 .65402 .12827 .65229 .10489 Metetra
.988 .718 .39 r
.65229 .10489 .65402 .12827 .64427 .11747 .64254 .0926 Metetra
.988 .718 .403 r
.64254 .0926 .64427 .11747 .63439 .10762 .63277 .08727 Metetra
.987 .714 .374 r
.63277 .08727 .63439 .10762 .62416 .08681 .62263 .07042 Metetra
0 0 .417 r
.82065 .29998 .82186 .30244 .81437 .28912 .81291 .28112 Metetra
.974 .669 .306 r
.81291 .28112 .81437 .28912 .80681 .2764 .80554 .27263 Metetra
.919 .552 .121 r
.80554 .27263 .80681 .2764 .79917 .26358 .79806 .26358 Metetra
.556 .687 .926 r
.79806 .26358 .79917 .26358 .79163 .25559 .79029 .25018 Metetra
.956 .622 .233 r
.79029 .25018 .79163 .25559 .78446 .25905 .78263 .24149 Metetra
.986 .711 .353 r
.78263 .24149 .78446 .25905 .77739 .26848 .77445 .22237 Metetra
.99 .731 .421 r
.77445 .22237 .77739 .26848 .77055 .28745 .76673 .21736 Metetra
.99 .734 .433 r
.76673 .21736 .77055 .28745 .76326 .29941 .75932 .22397 Metetra
.99 .735 .432 r
.75932 .22397 .76326 .29941 .75516 .29291 .75165 .22746 Metetra
.991 .735 .425 r
.75165 .22746 .75516 .29291 .74731 .29732 .74347 .22008 Metetra
.991 .736 .429 r
.74347 .22008 .74731 .29732 .74058 .33934 .7353 .21679 Metetra
.992 .739 .43 r
.7353 .21679 .74058 .33934 .72989 .2666 .72669 .20389 Metetra
.991 .735 .421 r
.72669 .20389 .72989 .2666 .72109 .25393 .71796 .1909 Metetra
.991 .735 .422 r
.71796 .1909 .72109 .25393 .71226 .24369 .70915 .17916 Metetra
.991 .735 .422 r
.70915 .17916 .71226 .24369 .70339 .23688 .70022 .16735 Metetra
.991 .735 .428 r
.70022 .16735 .70339 .23688 .69449 .23417 .69143 .16554 Metetra
.99 .734 .431 r
.69143 .16554 .69449 .23417 .68919 .37673 .68264 .16993 Metetra
.992 .74 .435 r
.68264 .16993 .68919 .37673 .67754 .28246 .67337 .16183 Metetra
.992 .739 .43 r
.67337 .16183 .67754 .28246 .66618 .19679 .66384 .14865 Metetra
.991 .732 .41 r
.66384 .14865 .66618 .19679 .65574 .15079 .65402 .12827 Metetra
.988 .716 .39 r
.65402 .12827 .65574 .15079 .64577 .13014 .64427 .11747 Metetra
.982 .693 .352 r
.64427 .11747 .64577 .13014 .6357 .11083 .63439 .10762 Metetra
.748 .38 0 r
.63439 .10762 .6357 .11083 .62556 .09556 .62416 .08681 Metetra
.896 .543 .067 r
.82186 .30244 .82314 .30655 .81557 .2914 .81437 .28912 Metetra
.69 .287 0 r
.81437 .28912 .81557 .2914 .80815 .28172 .80681 .2764 Metetra
.94 .607 .175 r
.80681 .2764 .80815 .28172 .80069 .27323 .79917 .26358 Metetra
.979 .683 .333 r
.79917 .26358 .80069 .27323 .7932 .26644 .79163 .25559 Metetra
.979 .688 .392 r
.79163 .25559 .7932 .26644 .78554 .25797 .78446 .25905 Metetra
.78446 .25905 .78554 .25797 .7787 .27278 .77739 .26848 Metetra
.912 .592 .424 r
.77739 .26848 .7787 .27278 .77133 .27796 .77055 .28745 Metetra
.998 .81 .46 r
.77055 .28745 .77133 .27796 .76431 .29644 .76326 .29941 Metetra
.97 .869 .682 r
.76326 .29941 .76431 .29644 .75607 .2859 .75516 .29291 Metetra
1 .829 .513 r
.75516 .29291 .75607 .2859 .74778 .27705 .74731 .29732 Metetra
.988 .777 .385 r
.74731 .29732 .74778 .27705 .73968 .27755 .74058 .33934 Metetra
.985 .742 .486 r
.74058 .33934 .73968 .27755 .73082 .25889 .72989 .2666 Metetra
.985 .795 .566 r
.72989 .2666 .73082 .25889 .72215 .24968 .72109 .25393 Metetra
.975 .831 .637 r
.72109 .25393 .72215 .24968 .71336 .24039 .71226 .24369 Metetra
.974 .865 .669 r
.71226 .24369 .71336 .24039 .70443 .23096 .70339 .23688 Metetra
.996 .834 .566 r
.70339 .23688 .70443 .23096 .69542 .22349 .69449 .23417 Metetra
0 0 .288 r
.69449 .23417 .69542 .22349 .68802 .28364 .68919 .37673 Metetra
.986 .741 .476 r
.68919 .37673 .68802 .28364 .67814 .2561 .67754 .28246 Metetra
.962 .729 .538 r
.67754 .28246 .67814 .2561 .66687 .17306 .66618 .19679 Metetra
.98 .749 .517 r
.66618 .19679 .66687 .17306 .65679 .14208 .65574 .15079 Metetra
.978 .782 .57 r
.65574 .15079 .65679 .14208 .64701 .12984 .64577 .13014 Metetra
.639 .707 .896 r
.64577 .13014 .64701 .12984 .6371 .11892 .6357 .11083 Metetra
.967 .656 .267 r
.6357 .11083 .6371 .11892 .6268 .09443 .62556 .09556 Metetra
.508 .626 .903 r
.82314 .30655 .82425 .30673 .81679 .29418 .81557 .2914 Metetra
.85 .448 0 r
.81557 .2914 .81679 .29418 .80932 .28305 .80815 .28172 Metetra
.532 .054 0 r
.80815 .28172 .80932 .28305 .80186 .27459 .80069 .27323 Metetra
.631 .131 0 r
.80069 .27323 .80186 .27459 .79431 .26622 .7932 .26644 Metetra
.603 .806 .978 r
.7932 .26644 .79431 .26622 .78689 .26341 .78554 .25797 Metetra
.94 .625 .412 r
.78554 .25797 .78689 .26341 .77968 .26883 .7787 .27278 Metetra
.988 .884 .552 r
.7787 .27278 .77968 .26883 .7725 .27876 .77133 .27796 Metetra
.702 .331 .343 r
.77133 .27796 .7725 .27876 .76461 .27352 .76431 .29644 Metetra
.993 .764 .483 r
.76431 .29644 .76461 .27352 .7565 .26561 .75607 .2859 Metetra
.994 .768 .486 r
.75607 .2859 .7565 .26561 .74833 .25952 .74778 .27705 Metetra
.997 .777 .476 r
.74778 .27705 .74833 .25952 .74035 .26235 .73968 .27755 Metetra
.988 .768 .518 r
.73968 .27755 .74035 .26235 .73143 .24117 .73082 .25889 Metetra
.994 .772 .493 r
.73082 .25889 .73143 .24117 .72278 .2317 .72215 .24968 Metetra
.994 .772 .493 r
.72215 .24968 .72278 .2317 .71398 .22115 .71336 .24039 Metetra
.994 .77 .49 r
.71336 .24039 .71398 .22115 .70502 .20985 .70443 .23096 Metetra
.994 .769 .483 r
.70443 .23096 .70502 .20985 .69626 .20991 .69542 .22349 Metetra
.922 .76 .276 r
.69542 .22349 .69626 .20991 .68823 .24457 .68802 .28364 Metetra
.99 .753 .478 r
.68802 .28364 .68823 .24457 .67781 .1931 .67814 .2561 Metetra
.984 .741 .487 r
.67814 .2561 .67781 .1931 .66796 .16707 .66687 .17306 Metetra
.942 .76 .628 r
.66687 .17306 .66796 .16707 .65807 .14395 .65679 .14208 Metetra
.651 .197 0 r
.65679 .14208 .65807 .14395 .64824 .12951 .64701 .12984 Metetra
.624 .816 .974 r
.64701 .12984 .64824 .12951 .63818 .10986 .6371 .11892 Metetra
.975 .776 .572 r
.6371 .11892 .63818 .10986 .62803 .09294 .6268 .09443 Metetra
.956 .812 .66 r
.82425 .30673 .82518 .3031 .81779 .29179 .81679 .29418 Metetra
.933 .833 .723 r
.81679 .29418 .81779 .29179 .81041 .28277 .80932 .28305 Metetra
.639 .817 .968 r
.80932 .28305 .81041 .28277 .80278 .27001 .80186 .27459 Metetra
.981 .825 .614 r
.80186 .27459 .80278 .27001 .79543 .266 .79431 .26622 Metetra
.44 .851 .964 r
.79431 .26622 .79543 .266 .78788 .26 .78689 .26341 Metetra
.979 .9 .561 r
.78689 .26341 .78788 .26 .78069 .26573 .77968 .26883 Metetra
.927 .9 .497 r
.77968 .26883 .78069 .26573 .77344 .27343 .7725 .27876 Metetra
.991 .829 .583 r
.7725 .27876 .77344 .27343 .76563 .26997 .76461 .27352 Metetra
.974 .847 .655 r
.76461 .27352 .76563 .26997 .75745 .25997 .7565 .26561 Metetra
.991 .825 .581 r
.7565 .26561 .75745 .25997 .7492 .25108 .74833 .25952 Metetra
1 .814 .507 r
.74833 .25952 .7492 .25108 .7413 .25571 .74035 .26235 Metetra
.966 .779 .601 r
.74035 .26235 .7413 .25571 .73248 .23716 .73143 .24117 Metetra
.975 .836 .643 r
.73143 .24117 .73248 .23716 .72384 .22758 .72278 .2317 Metetra
.973 .831 .642 r
.72278 .2317 .72384 .22758 .71508 .2182 .71398 .22115 Metetra
.952 .844 .7 r
.71398 .22115 .71508 .2182 .70611 .20573 .70502 .20985 Metetra
.993 .875 .599 r
.70502 .20985 .70611 .20573 .69741 .20767 .69626 .20991 Metetra
0 0 .161 r
.69626 .20991 .69741 .20767 .68928 .23785 .68823 .24457 Metetra
.907 .714 .631 r
.68823 .24457 .68928 .23785 .67912 .19632 .67781 .1931 Metetra
0 0 .305 r
.67781 .1931 .67912 .19632 .669 .15896 .66796 .16707 Metetra
.973 .778 .582 r
.66796 .16707 .669 .15896 .65917 .13786 .65807 .14395 Metetra
.979 .806 .599 r
.65807 .14395 .65917 .13786 .64921 .11626 .64824 .12951 Metetra
.987 .774 .529 r
.64824 .12951 .64921 .11626 .63947 .11221 .63818 .10986 Metetra
.659 .253 0 r
.63818 .10986 .63947 .11221 .62921 .08843 .62803 .09294 Metetra
.92 .567 .12 r
.82518 .3031 .82647 .30739 .81921 .29893 .81779 .29179 Metetra
.969 .656 .281 r
.81779 .29179 .81921 .29893 .81181 .28924 .81041 .28277 Metetra
.957 .638 .227 r
.81041 .28277 .81181 .28924 .80413 .27541 .80278 .27001 Metetra
.963 .63 .28 r
.80278 .27001 .80413 .27541 .79672 .2701 .79543 .266 Metetra
.942 .582 .196 r
.79543 .266 .79672 .2701 .78922 .26506 .78788 .26 Metetra
.954 .624 .353 r
.78788 .26 .78922 .26506 .78218 .27442 .78069 .26573 Metetra
.971 .671 .395 r
.78069 .26573 .78218 .27442 .77535 .29293 .77344 .27343 Metetra
.987 .713 .396 r
.77344 .27343 .77535 .29293 .76761 .29193 .76563 .26997 Metetra
.988 .717 .388 r
.76563 .26997 .76761 .29193 .75916 .27491 .75745 .25997 Metetra
.985 .704 .367 r
.75745 .25997 .75916 .27491 .75127 .27649 .7492 .25108 Metetra
.987 .718 .417 r
.7492 .25108 .75127 .27649 .74294 .26946 .7413 .25571 Metetra
.981 .698 .327 r
.7413 .25571 .74294 .26946 .73404 .24871 .73248 .23716 Metetra
.981 .69 .342 r
.73248 .23716 .73404 .24871 .7253 .23607 .72384 .22758 Metetra
.974 .667 .306 r
.72384 .22758 .7253 .23607 .71614 .21361 .71508 .2182 Metetra
.972 .819 .631 r
.71508 .2182 .71614 .21361 .70726 .20382 .70611 .20573 Metetra
.922 .975 .715 r
.70611 .20573 .70726 .20382 .69861 .20742 .69741 .20767 Metetra
.49 .163 .339 r
.69741 .20767 .69861 .20742 .69024 .22757 .68928 .23785 Metetra
.955 .746 .582 r
.68928 .23785 .69024 .22757 .68041 .19868 .67912 .19632 Metetra
0 .105 .637 r
.67912 .19632 .68041 .19868 .67025 .15974 .669 .15896 Metetra
.236 .435 .853 r
.669 .15896 .67025 .15974 .66057 .14506 .65917 .13786 Metetra
.945 .63 .191 r
.65917 .13786 .66057 .14506 .65072 .12864 .64921 .11626 Metetra
.981 .69 .366 r
.64921 .11626 .65072 .12864 .6408 .11611 .63947 .11221 Metetra
.787 .441 0 r
.63947 .11221 .6408 .11611 .63061 .09665 .62921 .08843 Metetra
.99 .726 .405 r
.82647 .30739 .82902 .33852 .82066 .30651 .81921 .29893 Metetra
.971 .661 .286 r
.81921 .29893 .82066 .30651 .81304 .29209 .81181 .28924 Metetra
.774 .39 0 r
.81181 .28924 .81304 .29209 .80555 .28263 .80413 .27541 Metetra
.972 .66 .311 r
.80413 .27541 .80555 .28263 .79801 .27416 .79672 .2701 Metetra
.943 .583 .207 r
.79672 .2701 .79801 .27416 .79037 .26567 .78922 .26506 Metetra
.674 .22 .167 r
.78922 .26506 .79037 .26567 .78256 .25561 .78218 .27442 Metetra
.997 .779 .433 r
.78218 .27442 .78256 .25561 .7748 .24945 .77535 .29293 Metetra
.994 .756 .454 r
.77535 .29293 .7748 .24945 .7674 .25575 .76761 .29193 Metetra
.992 .755 .472 r
.76761 .29193 .7674 .25575 .75944 .25081 .75916 .27491 Metetra
.996 .768 .463 r
.75916 .27491 .75944 .25081 .75138 .24669 .75127 .27649 Metetra
.994 .761 .468 r
.75127 .27649 .75138 .24669 .74333 .2463 .74294 .26946 Metetra
.99 .76 .494 r
.74294 .26946 .74333 .2463 .73453 .22776 .73404 .24871 Metetra
.993 .766 .489 r
.73404 .24871 .73453 .22776 .7257 .21133 .7253 .23607 Metetra
.99 .759 .492 r
.7253 .23607 .7257 .21133 .71681 .19635 .71614 .21361 Metetra
.994 .773 .495 r
.71614 .21361 .71681 .19635 .70801 .18847 .70726 .20382 Metetra
.998 .784 .476 r
.70726 .20382 .70801 .18847 .69975 .20461 .69861 .20742 Metetra
.671 .764 .28 r
.69861 .20742 .69975 .20461 .69103 .21118 .69024 .22757 Metetra
.983 .761 .525 r
.69024 .22757 .69103 .21118 .68149 .1927 .68041 .19868 Metetra
.923 .739 .635 r
.68041 .19868 .68149 .1927 .67144 .15778 .67025 .15974 Metetra
.898 .835 .775 r
.67025 .15974 .67144 .15778 .66177 .14344 .66057 .14506 Metetra
.864 .818 .802 r
.66057 .14506 .66177 .14344 .65199 .13013 .65072 .12864 Metetra
0 0 .493 r
.65072 .12864 .65199 .13013 .64228 .1274 .6408 .11611 Metetra
.976 .683 .301 r
.6408 .11611 .64228 .1274 .63206 .10696 .63061 .09665 Metetra
.986 .752 .499 r
.82902 .33852 .82884 .31106 .82142 .29891 .82066 .30651 Metetra
.981 .786 .569 r
.82066 .30651 .82142 .29891 .81392 .28678 .81304 .29209 Metetra
.983 .813 .597 r
.81304 .29209 .81392 .28678 .8064 .27632 .80555 .28263 Metetra
.988 .808 .572 r
.80555 .28263 .8064 .27632 .79869 .26379 .79801 .27416 Metetra
.993 .787 .524 r
.79801 .27416 .79869 .26379 .79099 .2535 .79037 .26567 Metetra
.992 .78 .516 r
.79037 .26567 .79099 .2535 .78294 .23696 .78256 .25561 Metetra
.995 .771 .483 r
.78256 .25561 .78294 .23696 .77516 .2295 .7748 .24945 Metetra
.997 .774 .459 r
.7748 .24945 .77516 .2295 .76777 .23544 .7674 .25575 Metetra
.995 .769 .478 r
.7674 .25575 .76777 .23544 .75986 .23086 .75944 .25081 Metetra
.995 .77 .478 r
.75944 .25081 .75986 .23086 .75207 .23339 .75138 .24669 Metetra
.998 .786 .489 r
.75138 .24669 .75207 .23339 .7439 .22884 .74333 .2463 Metetra
.989 .766 .507 r
.74333 .2463 .7439 .22884 .73518 .21191 .73453 .22776 Metetra
.99 .77 .51 r
.73453 .22776 .73518 .21191 .72639 .19588 .7257 .21133 Metetra
.991 .771 .509 r
.7257 .21133 .72639 .19588 .71765 .18495 .71681 .19635 Metetra
.994 .788 .517 r
.71681 .19635 .71765 .18495 .70887 .17686 .70801 .18847 Metetra
.997 .803 .447 r
.70801 .18847 .70887 .17686 .70004 .17191 .69975 .20461 Metetra
.996 .763 .452 r
.69975 .20461 .70004 .17191 .69158 .18632 .69103 .21118 Metetra
.991 .761 .487 r
.69103 .21118 .69158 .18632 .68234 .17786 .68149 .1927 Metetra
.977 .757 .54 r
.68149 .1927 .68234 .17786 .67277 .16204 .67144 .15778 Metetra
.906 .543 .087 r
.67144 .15778 .67277 .16204 .66292 .13919 .66177 .14344 Metetra
.969 .826 .648 r
.66177 .14344 .66292 .13919 .65313 .12515 .65199 .13013 Metetra
.994 .853 .591 r
.65199 .13013 .65313 .12515 .64337 .11928 .64228 .1274 Metetra
.978 .785 .576 r
.64228 .1274 .64337 .11928 .63316 .09834 .63206 .10696 Metetra
.969 .809 .628 r
.82884 .31106 .82973 .3066 .82238 .2958 .82142 .29891 Metetra
.949 .82 .682 r
.82142 .29891 .82238 .2958 .81499 .28611 .81392 .28678 Metetra
.765 .825 .899 r
.81392 .28678 .81499 .28611 .80756 .27739 .8064 .27632 Metetra
0 .233 .75 r
.8064 .27632 .80756 .27739 .80004 .26906 .79869 .26379 Metetra
.948 .612 .202 r
.79869 .26379 .80004 .26906 .79254 .26363 .79099 .2535 Metetra
.973 .679 .289 r
.79099 .2535 .79254 .26363 .78581 .27978 .78294 .23696 Metetra
.99 .73 .414 r
.78294 .23696 .78581 .27978 .77934 .30654 .77516 .2295 Metetra
.99 .735 .431 r
.77516 .2295 .77934 .30654 .77211 .3186 .76777 .23544 Metetra
.991 .736 .426 r
.76777 .23544 .77211 .3186 .76494 .33654 .75986 .23086 Metetra
.991 .737 .431 r
.75986 .23086 .76494 .33654 .75997 .42053 .75207 .23339 Metetra
.992 .74 .432 r
.75207 .23339 .75997 .42053 .7509 .39656 .7439 .22884 Metetra
.992 .74 .429 r
.7439 .22884 .7509 .39656 .74145 .36367 .73518 .21191 Metetra
.992 .74 .428 r
.73518 .21191 .74145 .36367 .73447 .40948 .72639 .19588 Metetra
.992 .74 .431 r
.72639 .19588 .73447 .40948 .72462 .37135 .71765 .18495 Metetra
.992 .74 .431 r
.71765 .18495 .72462 .37135 .71448 .32541 .70887 .17686 Metetra
.992 .739 .431 r
.70887 .17686 .71448 .32541 .70727 .38406 .70004 .17191 Metetra
.991 .74 .435 r
.70004 .17191 .70727 .38406 .69792 .37531 .69158 .18632 Metetra
.992 .74 .431 r
.69158 .18632 .69792 .37531 .68842 .36643 .68234 .17786 Metetra
.992 .74 .43 r
.68234 .17786 .68842 .36643 .67738 .30069 .67277 .16204 Metetra
.992 .739 .426 r
.67277 .16204 .67738 .30069 .6649 .17165 .66292 .13919 Metetra
.99 .725 .399 r
.66292 .13919 .6649 .17165 .65468 .13932 .65313 .12515 Metetra
.983 .697 .369 r
.65313 .12515 .65468 .13932 .6446 .11777 .64337 .11928 Metetra
.833 .778 .8 r
.64337 .11928 .6446 .11777 .63455 .1051 .63316 .09834 Metetra
.988 .716 .379 r
.82973 .3066 .83176 .32646 .82377 .30196 .82238 .2958 Metetra
.961 .637 .244 r
.82238 .2958 .82377 .30196 .81632 .291 .81499 .28611 Metetra
.947 .604 .201 r
.81499 .28611 .81632 .291 .80883 .28089 .80756 .27739 Metetra
.911 .533 .102 r
.80756 .27739 .80883 .28089 .80134 .27309 .80004 .26906 Metetra
.941 .579 .198 r
.80004 .26906 .80134 .27309 .79421 .27647 .79254 .26363 Metetra
.973 .69 .43 r
.79254 .26363 .79421 .27647 .78746 .29221 .78581 .27978 Metetra
.963 .681 .453 r
.78581 .27978 .78746 .29221 .78035 .30303 .77934 .30654 Metetra
.924 .881 .461 r
.77934 .30654 .78035 .30303 .77526 .37027 .77211 .3186 Metetra
.988 .729 .436 r
.77211 .3186 .77526 .37027 .76628 .34082 .76494 .33654 Metetra
.778 .52 .546 r
.76494 .33654 .76628 .34082 .75818 .33778 .75997 .42053 Metetra
.992 .748 .454 r
.75997 .42053 .75818 .33778 .7494 .31901 .7509 .39656 Metetra
.991 .748 .459 r
.7509 .39656 .7494 .31901 .73998 .28427 .74145 .36367 Metetra
.995 .754 .424 r
.74145 .36367 .73998 .28427 .73192 .29309 .73447 .40948 Metetra
.991 .746 .453 r
.73447 .40948 .73192 .29309 .72254 .26542 .72462 .37135 Metetra
.991 .746 .457 r
.72462 .37135 .72254 .26542 .71359 .25474 .71448 .32541 Metetra
.995 .756 .417 r
.71448 .32541 .71359 .25474 .70587 .2914 .70727 .38406 Metetra
.993 .749 .447 r
.70727 .38406 .70587 .2914 .6987 .35802 .69792 .37531 Metetra
.994 .775 .494 r
.69792 .37531 .6987 .35802 .68884 .33381 .68842 .36643 Metetra
.978 .742 .51 r
.68842 .36643 .68884 .33381 .6766 .21742 .67738 .30069 Metetra
.982 .736 .487 r
.67738 .30069 .6766 .21742 .66584 .15848 .6649 .17165 Metetra
.977 .761 .546 r
.6649 .17165 .66584 .15848 .65606 .14493 .65468 .13932 Metetra
.91 .579 .103 r
.65468 .13932 .65606 .14493 .64603 .12635 .6446 .11777 Metetra
.971 .662 .288 r
.6446 .11777 .64603 .12635 .63599 .11434 .63455 .1051 Metetra
.937 .641 .178 r
.83176 .32646 .83326 .33488 .82574 .32068 .82377 .30196 Metetra
.987 .714 .375 r
.82377 .30196 .82574 .32068 .81812 .30603 .81632 .291 Metetra
.985 .705 .362 r
.81632 .291 .81812 .30603 .81025 .28776 .80883 .28089 Metetra
.968 .652 .282 r
.80883 .28089 .81025 .28776 .80276 .27995 .80134 .27309 Metetra
.968 .655 .36 r
.80134 .27309 .80276 .27995 .79574 .28604 .79421 .27647 Metetra
.965 .673 .425 r
.79421 .27647 .79574 .28604 .78861 .29247 .78746 .29221 Metetra
.566 .114 .137 r
.78746 .29221 .78861 .29247 .78398 .36538 .78035 .30303 Metetra
.983 .725 .461 r
.78035 .30303 .78398 .36538 .77643 .37019 .77526 .37027 Metetra
.61 .587 .803 r
.77526 .37027 .77643 .37019 .76903 .38279 .76628 .34082 Metetra
.99 .729 .416 r
.76628 .34082 .76903 .38279 .76072 .3751 .75818 .33778 Metetra
.99 .728 .397 r
.75818 .33778 .76072 .3751 .75289 .38471 .7494 .31901 Metetra
.992 .736 .404 r
.7494 .31901 .75289 .38471 .74306 .34012 .73998 .28427 Metetra
.989 .731 .429 r
.73998 .28427 .74306 .34012 .73512 .35425 .73192 .29309 Metetra
.992 .735 .407 r
.73192 .29309 .73512 .35425 .7253 .31464 .72254 .26542 Metetra
.991 .731 .413 r
.72254 .26542 .7253 .31464 .71608 .29692 .71359 .25474 Metetra
.984 .722 .446 r
.71359 .25474 .71608 .29692 .70936 .36991 .70587 .2914 Metetra
.985 .729 .453 r
.70587 .2914 .70936 .36991 .70042 .37491 .6987 .35802 Metetra
.982 .705 .332 r
.6987 .35802 .70042 .37491 .69093 .36591 .68884 .33381 Metetra
.943 .7 .232 r
.68884 .33381 .69093 .36591 .67912 .26906 .6766 .21742 Metetra
.99 .734 .378 r
.6766 .21742 .67912 .26906 .66745 .17401 .66584 .15848 Metetra
.984 .702 .355 r
.66584 .15848 .66745 .17401 .65746 .15194 .65606 .14493 Metetra
.95 .631 .205 r
.65606 .14493 .65746 .15194 .64744 .13411 .64603 .12635 Metetra
.967 .652 .274 r
.64603 .12635 .64744 .13411 .63725 .11434 .63599 .11434 Metetra
0 0 .453 r
.83326 .33488 .83446 .33682 .82675 .31868 .82574 .32068 Metetra
.895 .803 .751 r
.82574 .32068 .82675 .31868 .81889 .29864 .81812 .30603 Metetra
.974 .779 .581 r
.81812 .30603 .81889 .29864 .8113 .28635 .81025 .28776 Metetra
.893 .887 .818 r
.81025 .28776 .8113 .28635 .80382 .27851 .80276 .27995 Metetra
.74 .932 .592 r
.80276 .27995 .80382 .27851 .79698 .28842 .79574 .28604 Metetra
.893 .502 .277 r
.79574 .28604 .79698 .28842 .78963 .28935 .78861 .29247 Metetra
.267 .094 .451 r
.78861 .29247 .78963 .28935 .78463 .35238 .78398 .36538 Metetra
.999 .79 .474 r
.78398 .36538 .78463 .35238 .7766 .34422 .77643 .37019 Metetra
.997 .769 .443 r
.77643 .37019 .7766 .34422 .7682 .32951 .76903 .38279 Metetra
.993 .753 .453 r
.76903 .38279 .7682 .32951 .76033 .33197 .76072 .3751 Metetra
.995 .758 .443 r
.76072 .3751 .76033 .33197 .75223 .33174 .75289 .38471 Metetra
.989 .747 .475 r
.75289 .38471 .75223 .33174 .7435 .31769 .74306 .34012 Metetra
.998 .774 .444 r
.74306 .34012 .7435 .31769 .73502 .3142 .73512 .35425 Metetra
.988 .75 .483 r
.73512 .35425 .73502 .3142 .72579 .29192 .7253 .31464 Metetra
.991 .763 .49 r
.7253 .31464 .72579 .29192 .71701 .28733 .71608 .29692 Metetra
.71608 .29692 .71701 .28733 .70899 .3142 .70936 .36991 Metetra
.994 .755 .446 r
.70936 .36991 .70899 .3142 .70167 .37471 .70042 .37491 Metetra
.549 .811 .994 r
.70042 .37491 .70167 .37471 .69219 .36581 .69093 .36591 Metetra
.596 .47 .679 r
.69093 .36591 .69219 .36581 .68011 .25834 .67912 .26906 Metetra
.891 .68 .61 r
.67912 .26906 .68011 .25834 .66885 .18046 .66745 .17401 Metetra
.928 .606 .146 r
.66745 .17401 .66885 .18046 .65856 .14479 .65746 .15194 Metetra
.979 .794 .586 r
.65746 .15194 .65856 .14479 .64866 .13207 .64744 .13411 Metetra
.879 .799 .767 r
.64744 .13411 .64866 .13207 .63858 .11787 .63725 .11434 Metetra
.792 .449 0 r
.83446 .33682 .83574 .34061 .82791 .31975 .82675 .31868 Metetra
.187 .36 .804 r
.82675 .31868 .82791 .31975 .8203 .30505 .81889 .29864 Metetra
.956 .635 .225 r
.81889 .29864 .8203 .30505 .81278 .29428 .8113 .28635 Metetra
.973 .665 .303 r
.8113 .28635 .81278 .29428 .80526 .28589 .80382 .27851 Metetra
.964 .658 .397 r
.80382 .27851 .80526 .28589 .79818 .28986 .79698 .28842 Metetra
.814 .333 .04 r
.79698 .28842 .79818 .28986 .79108 .29694 .78963 .28935 Metetra
.877 .605 .523 r
.78963 .28935 .79108 .29694 .78795 .40628 .78463 .35238 Metetra
.991 .732 .416 r
.78463 .35238 .78795 .40628 .78184 .44863 .7766 .34422 Metetra
.992 .738 .423 r
.7766 .34422 .78184 .44863 .77209 .40105 .7682 .32951 Metetra
.991 .734 .426 r
.7682 .32951 .77209 .40105 .76339 .38311 .76033 .33197 Metetra
.99 .731 .421 r
.76033 .33197 .76339 .38311 .75538 .38696 .75223 .33174 Metetra
.991 .733 .412 r
.75223 .33174 .75538 .38696 .74533 .33593 .7435 .31769 Metetra
.986 .709 .388 r
.7435 .31769 .74533 .33593 .73659 .32523 .73502 .3142 Metetra
.97 .678 .273 r
.73502 .3142 .73659 .32523 .72678 .28482 .72579 .29192 Metetra
.996 .818 .55 r
.72579 .29192 .72678 .28482 .71808 .2822 .71701 .28733 Metetra
.853 .797 .303 r
.71701 .28733 .71808 .2822 .70982 .30025 .70899 .3142 Metetra
.922 .758 .274 r
.70899 .3142 .70982 .30025 .70292 .3745 .70167 .37471 Metetra
.547 .813 .995 r
.70167 .37471 .70292 .3745 .69345 .36561 .69219 .36581 Metetra
.601 .468 .672 r
.69219 .36581 .69345 .36561 .68163 .26903 .68011 .25834 Metetra
.712 .498 0 r
.68011 .25834 .68163 .26903 .67027 .18804 .66885 .18046 Metetra
.885 .591 .079 r
.66885 .18046 .67027 .18804 .66003 .15488 .65856 .14479 Metetra
.976 .676 .31 r
.65856 .14479 .66003 .15488 .65017 .14423 .64866 .13207 Metetra
.98 .688 .327 r
.64866 .13207 .65017 .14423 .63996 .12338 .63858 .11787 Metetra
.988 .722 .371 r
.83574 .34061 .83807 .36632 .83018 .34456 .82791 .31975 Metetra
.989 .721 .381 r
.82791 .31975 .83018 .34456 .82244 .32743 .8203 .30505 Metetra
.988 .718 .384 r
.8203 .30505 .82244 .32743 .8148 .3144 .81278 .29428 Metetra
.987 .715 .384 r
.81278 .29428 .8148 .3144 .80653 .28917 .80526 .28589 Metetra
.93 .561 .288 r
.80526 .28589 .80653 .28917 .7989 .28021 .79818 .28986 Metetra
1 .806 .474 r
.79818 .28986 .7989 .28021 .79112 .27011 .79108 .29694 Metetra
.915 .724 .228 r
.79108 .29694 .79112 .27011 .7835 .26662 .78795 .40628 Metetra
.994 .749 .428 r
.78795 .40628 .7835 .26662 .77616 .27341 .78184 .44863 Metetra
.992 .745 .448 r
.78184 .44863 .77616 .27341 .76838 .27237 .77209 .40105 Metetra
.992 .747 .445 r
.77209 .40105 .76838 .27237 .76072 .27808 .76339 .38311 Metetra
.993 .749 .44 r
.76339 .38311 .76072 .27808 .75291 .28387 .75538 .38696 Metetra
.991 .745 .458 r
.75538 .38696 .75291 .28387 .74359 .25054 .74533 .33593 Metetra
.993 .749 .447 r
.74533 .33593 .74359 .25054 .73454 .22702 .73659 .32523 Metetra
.991 .746 .455 r
.73659 .32523 .73454 .22702 .72539 .20322 .72678 .28482 Metetra
.993 .75 .444 r
.72678 .28482 .72539 .20322 .71671 .19785 .71808 .2822 Metetra
.994 .752 .436 r
.71808 .2822 .71671 .19785 .70851 .21351 .70982 .30025 Metetra
.995 .754 .412 r
.70982 .30025 .70851 .21351 .70221 .30432 .70292 .3745 Metetra
.993 .751 .449 r
.70292 .3745 .70221 .30432 .69192 .26085 .69345 .36561 Metetra
.988 .742 .469 r
.69345 .36561 .69192 .26085 .68084 .18795 .68163 .26903 Metetra
.987 .742 .473 r
.68163 .26903 .68084 .18795 .67084 .15918 .67027 .18804 Metetra
.988 .754 .492 r
.67027 .18804 .67084 .15918 .661 .14217 .66003 .15488 Metetra
.994 .784 .514 r
.66003 .15488 .661 .14217 .65151 .14794 .65017 .14423 Metetra
.802 .441 0 r
.65017 .14423 .65151 .14794 .64113 .11839 .63996 .12338 Metetra
.991 .752 .467 r
.83807 .36632 .8371 .32293 .8296 .30836 .83018 .34456 Metetra
.992 .755 .469 r
.83018 .34456 .8296 .30836 .82196 .29274 .82244 .32743 Metetra
.993 .756 .467 r
.82244 .32743 .82196 .29274 .81442 .28098 .8148 .3144 Metetra
.99 .753 .48 r
.8148 .3144 .81442 .28098 .80689 .27141 .80653 .28917 Metetra
.994 .77 .488 r
.80653 .28917 .80689 .27141 .79919 .26036 .7989 .28021 Metetra
.994 .767 .485 r
.7989 .28021 .79919 .26036 .79115 .24353 .79112 .27011 Metetra
.995 .764 .464 r
.79112 .27011 .79115 .24353 .78339 .2355 .7835 .26662 Metetra
.996 .763 .447 r
.7835 .26662 .78339 .2355 .77574 .23335 .77616 .27341 Metetra
.995 .757 .452 r
.77616 .27341 .77574 .23335 .76787 .22847 .76838 .27237 Metetra
.995 .757 .445 r
.76838 .27237 .76787 .22847 .75999 .22669 .76072 .27808 Metetra
.995 .755 .443 r
.76072 .27808 .75999 .22669 .75225 .23248 .75291 .28387 Metetra
.99 .749 .469 r
.75291 .28387 .75225 .23248 .74327 .20682 .74359 .25054 Metetra
.992 .752 .468 r
.74359 .25054 .74327 .20682 .73469 .19591 .73454 .22702 Metetra
.991 .756 .48 r
.73454 .22702 .73469 .19591 .72591 .18229 .72539 .20322 Metetra
.995 .77 .476 r
.72539 .20322 .72591 .18229 .71718 .17397 .71671 .19785 Metetra
.997 .773 .441 r
.71671 .19785 .71718 .17397 .70846 .1707 .70851 .21351 Metetra
.986 .761 .365 r
.70851 .21351 .70846 .1707 .70152 .23581 .70221 .30432 Metetra
.99 .747 .464 r
.70221 .30432 .70152 .23581 .69225 .22677 .69192 .26085 Metetra
.977 .739 .511 r
.69192 .26085 .69225 .22677 .68245 .20245 .68084 .18795 Metetra
.975 .695 .297 r
.68084 .18795 .68245 .20245 .67191 .15192 .67084 .15918 Metetra
.98 .795 .581 r
.67084 .15918 .67191 .15192 .66197 .12957 .661 .14217 Metetra
.999 .797 .479 r
.661 .14217 .66197 .12957 .6532 .16783 .65151 .14794 Metetra
.984 .711 .338 r
.65151 .14794 .6532 .16783 .64247 .12215 .64113 .11839 Metetra
.882 .801 .765 r
.8371 .32293 .83812 .32114 .8307 .30827 .8296 .30836 Metetra
.604 .677 .892 r
.8296 .30836 .8307 .30827 .82313 .29398 .82196 .29274 Metetra
0 .121 .66 r
.82196 .29274 .82313 .29398 .81564 .2831 .81442 .28098 Metetra
.748 .313 0 r
.81442 .28098 .81564 .2831 .80816 .27479 .80689 .27141 Metetra
.876 .496 .021 r
.80689 .27141 .80816 .27479 .80116 .27997 .79919 .26036 Metetra
.986 .714 .361 r
.79919 .26036 .80116 .27997 .79439 .29395 .79115 .24353 Metetra
.991 .732 .414 r
.79115 .24353 .79439 .29395 .79294 .44241 .78339 .2355 Metetra
.992 .74 .43 r
.78339 .2355 .79294 .44241 .78538 .4481 .77574 .23335 Metetra
.992 .74 .43 r
.77574 .23335 .78538 .4481 .77716 .44035 .76787 .22847 Metetra
.992 .74 .43 r
.76787 .22847 .77716 .44035 .76881 .43248 .75999 .22669 Metetra
.992 .74 .431 r
.75999 .22669 .76881 .43248 .76034 .42449 .75225 .23248 Metetra
.992 .74 .425 r
.75225 .23248 .76034 .42449 .75174 .41638 .74327 .20682 Metetra
.992 .74 .428 r
.74327 .20682 .75174 .41638 .743 .40815 .73469 .19591 Metetra
.992 .74 .428 r
.73469 .19591 .743 .40815 .73413 .39978 .72591 .18229 Metetra
.992 .74 .429 r
.72591 .18229 .73413 .39978 .72512 .39129 .71718 .17397 Metetra
.992 .74 .43 r
.71718 .17397 .72512 .39129 .71597 .38266 .70846 .1707 Metetra
.99 .738 .441 r
.70846 .1707 .71597 .38266 .70668 .3739 .70152 .23581 Metetra
.992 .738 .426 r
.70152 .23581 .70668 .3739 .69723 .36499 .69225 .22677 Metetra
.992 .739 .422 r
.69225 .22677 .69723 .36499 .68763 .35594 .68245 .20245 Metetra
.993 .74 .417 r
.68245 .20245 .68763 .35594 .67476 .21813 .67191 .15192 Metetra
.991 .735 .411 r
.67191 .15192 .67476 .21813 .66392 .16015 .66197 .12957 Metetra
.98 .712 .446 r
.66197 .12957 .66392 .16015 .65433 .16154 .6532 .16783 Metetra
.917 .729 .633 r
.6532 .16783 .65433 .16154 .64367 .11849 .64247 .12215 Metetra
.992 .736 .417 r
.83812 .32114 .84273 .3938 .83359 .34585 .8307 .30827 Metetra
.99 .729 .399 r
.8307 .30827 .83359 .34585 .82568 .32489 .82313 .29398 Metetra
.99 .725 .397 r
.82313 .29398 .82568 .32489 .81825 .31623 .81564 .2831 Metetra
.99 .726 .403 r
.81564 .2831 .81825 .31623 .81075 .30801 .80816 .27479 Metetra
.988 .724 .419 r
.80816 .27479 .81075 .30801 .80376 .31399 .80116 .27997 Metetra
.987 .723 .429 r
.80116 .27997 .80376 .31399 .79848 .36406 .79439 .29395 Metetra
.972 .716 .488 r
.79439 .29395 .79848 .36406 .79466 .45556 .79294 .44241 Metetra
.98 .694 .397 r
.79294 .44241 .79466 .45556 .78656 .44792 .78538 .4481 Metetra
.547 .813 .995 r
.78538 .4481 .78656 .44792 .77835 .44017 .77716 .44035 Metetra
.547 .813 .995 r
.77716 .44035 .77835 .44017 .77001 .4323 .76881 .43248 Metetra
.547 .813 .995 r
.76881 .43248 .77001 .4323 .76154 .42431 .76034 .42449 Metetra
.547 .813 .995 r
.76034 .42449 .76154 .42431 .75295 .41619 .75174 .41638 Metetra
.547 .813 .995 r
.75174 .41638 .75295 .41619 .74422 .40796 .743 .40815 Metetra
.547 .813 .995 r
.743 .40815 .74422 .40796 .73536 .39959 .73413 .39978 Metetra
.547 .813 .995 r
.73413 .39978 .73536 .39959 .72635 .39081 .72512 .39129 Metetra
.676 .866 .971 r
.72512 .39129 .72635 .39081 .71722 .38246 .71597 .38266 Metetra
.547 .813 .995 r
.71597 .38266 .71722 .38246 .70018 .10234 .70668 .3739 Metetra
.993 .745 .437 r
.70668 .3739 .70018 .10234 .69849 .36479 .69723 .36499 Metetra
.547 .813 .995 r
.69723 .36499 .69849 .36479 .6889 .35573 .68763 .35594 Metetra
.597 .453 .656 r
.68763 .35594 .6889 .35573 .67915 .34653 .67476 .21813 Metetra
.993 .74 .411 r
.67476 .21813 .67915 .34653 .66663 .22343 .66392 .16015 Metetra
.99 .732 .422 r
.66392 .16015 .66663 .22343 .65671 .21313 .65433 .16154 Metetra
.991 .733 .389 r
.65433 .16154 .65671 .21313 .64555 .14887 .64367 .11849 Metetra
.988 .746 .477 r
.84273 .3938 .84124 .34002 .83404 .33199 .83359 .34585 Metetra
.985 .765 .526 r
.83359 .34585 .83404 .33199 .82598 .30735 .82568 .32489 Metetra
.994 .77 .487 r
.82568 .32489 .82598 .30735 .81851 .29707 .81825 .31623 Metetra
.994 .768 .482 r
.81825 .31623 .81851 .29707 .81105 .28921 .81075 .30801 Metetra
.998 .775 .456 r
.81075 .30801 .81105 .28921 .80408 .29498 .80376 .31399 Metetra
.971 .767 .336 r
.80376 .31399 .80408 .29498 .79617 .28168 .79848 .36406 Metetra
.993 .753 .394 r
.79848 .36406 .79617 .28168 .7894 .29851 .79466 .45556 Metetra
.993 .746 .439 r
.79466 .45556 .7894 .29851 .78173 .29671 .78656 .44792 Metetra
.993 .746 .439 r
.78656 .44792 .78173 .29671 .77365 .28791 .77835 .44017 Metetra
.993 .746 .439 r
.77835 .44017 .77365 .28791 .76546 .27912 .77001 .4323 Metetra
.993 .746 .439 r
.77001 .4323 .76546 .27912 .75758 .28199 .76154 .42431 Metetra
.993 .747 .44 r
.76154 .42431 .75758 .28199 .74872 .26114 .75295 .41619 Metetra
.993 .746 .439 r
.75295 .41619 .74872 .26114 .74016 .25195 .74422 .40796 Metetra
.993 .746 .439 r
.74422 .40796 .74016 .25195 .73147 .24256 .73536 .39959 Metetra
.993 .746 .439 r
.73536 .39959 .73147 .24256 .72264 .23309 .72635 .39081 Metetra
.993 .746 .439 r
.72635 .39081 .72264 .23309 .71368 .22347 .71722 .38246 Metetra
.979 .731 .488 r
.71722 .38246 .71368 .22347 .70918 .37349 .70018 .10234 Metetra
.986 .733 .46 r
.70018 .10234 .70918 .37349 .69975 .36458 .69849 .36479 Metetra
.547 .813 .995 r
.69849 .36479 .69975 .36458 .68595 .19345 .6889 .35573 Metetra
.993 .746 .439 r
.6889 .35573 .68595 .19345 .67589 .16201 .67915 .34653 Metetra
.989 .741 .457 r
.67915 .34653 .67589 .16201 .66634 .15589 .66663 .22343 Metetra
.993 .751 .449 r
.66663 .22343 .66634 .15589 .65634 .13719 .65671 .21313 Metetra
.989 .745 .467 r
.65671 .21313 .65634 .13719 .64602 .10937 .64555 .14887 Metetra
.989 .809 .569 r
.84124 .34002 .84205 .33378 .83443 .31662 .83404 .33199 Metetra
.983 .761 .524 r
.83404 .33199 .83443 .31662 .82684 .30179 .82598 .30735 Metetra
.983 .81 .592 r
.82598 .30735 .82684 .30179 .81907 .28462 .81851 .29707 Metetra
.994 .781 .505 r
.81851 .29707 .81907 .28462 .81157 .27541 .81105 .28921 Metetra
.999 .786 .464 r
.81105 .28921 .81157 .27541 .80434 .27481 .80408 .29498 Metetra
.993 .765 .488 r
.80408 .29498 .80434 .27481 .79743 .28445 .79617 .28168 Metetra
.875 .529 .392 r
.79617 .28168 .79743 .28445 .79272 .35104 .7894 .29851 Metetra
.99 .731 .418 r
.7894 .29851 .79272 .35104 .78576 .36829 .78173 .29671 Metetra
.991 .735 .418 r
.78173 .29671 .78576 .36829 .77612 .32125 .77365 .28791 Metetra
.99 .725 .401 r
.77365 .28791 .77612 .32125 .7679 .3126 .76546 .27912 Metetra
.989 .724 .415 r
.76546 .27912 .7679 .3126 .75995 .31429 .75758 .28199 Metetra
.99 .725 .384 r
.75758 .28199 .75995 .31429 .75019 .2691 .74872 .26114 Metetra
.971 .659 .289 r
.74872 .26114 .75019 .2691 .74206 .27244 .74016 .25195 Metetra
.987 .713 .379 r
.74016 .25195 .74206 .27244 .73292 .24998 .73147 .24256 Metetra
.968 .65 .276 r
.73147 .24256 .73292 .24998 .72399 .23719 .72264 .23309 Metetra
.922 .552 .13 r
.72264 .23309 .72399 .23719 .71719 .29898 .71368 .22347 Metetra
.975 .718 .479 r
.71368 .22347 .71719 .29898 .71043 .37329 .70918 .37349 Metetra
.547 .813 .995 r
.70918 .37349 .71043 .37329 .70101 .36437 .69975 .36458 Metetra
.596 .444 .646 r
.69975 .36458 .70101 .36437 .68842 .24009 .68595 .19345 Metetra
.991 .731 .392 r
.68595 .19345 .68842 .24009 .68089 .31315 .67589 .16201 Metetra
.992 .739 .426 r
.67589 .16201 .68089 .31315 .66773 .1619 .66634 .15589 Metetra
.931 .6 .151 r
.66634 .15589 .66773 .1619 .65788 .15 .65634 .13719 Metetra
.971 .685 .28 r
.65634 .13719 .65788 .15 .64742 .11565 .64602 .10937 Metetra
.647 .681 .867 r
.84205 .33378 .84314 .33355 .8351 .30743 .83443 .31662 Metetra
.985 .781 .548 r
.83443 .31662 .8351 .30743 .82762 .29446 .82684 .30179 Metetra
.976 .783 .578 r
.82684 .30179 .82762 .29446 .81979 .27586 .81907 .28462 Metetra
.992 .793 .537 r
.81907 .28462 .81979 .27586 .81221 .26457 .81157 .27541 Metetra
.998 .794 .494 r
.81157 .27541 .81221 .26457 .80519 .26804 .80434 .27481 Metetra
.994 .832 .471 r
.80434 .27481 .80519 .26804 .79795 .26959 .79743 .28445 Metetra
.886 .723 .211 r
.79743 .28445 .79795 .26959 .79177 .29986 .79272 .35104 Metetra
.995 .756 .432 r
.79272 .35104 .79177 .29986 .78384 .29136 .78576 .36829 Metetra
.99 .746 .462 r
.78576 .36829 .78384 .29136 .7755 .27519 .77612 .32125 Metetra
.994 .754 .454 r
.77612 .32125 .7755 .27519 .76711 .26035 .7679 .3126 Metetra
.994 .754 .444 r
.7679 .3126 .76711 .26035 .75918 .26086 .75995 .31429 Metetra
.989 .747 .472 r
.75995 .31429 .75918 .26086 .75024 .23673 .75019 .2691 Metetra
.996 .762 .45 r
.75019 .2691 .75024 .23673 .74165 .2253 .74206 .27244 Metetra
.992 .752 .463 r
.74206 .27244 .74165 .2253 .73266 .20555 .73292 .24998 Metetra
.993 .755 .457 r
.73292 .24998 .73266 .20555 .72392 .19687 .72399 .23719 Metetra
.992 .763 .39 r
.72399 .23719 .72392 .19687 .71528 .19572 .71719 .29898 Metetra
.994 .752 .413 r
.71719 .29898 .71528 .19572 .70716 .21756 .71043 .37329 Metetra
.993 .746 .439 r
.71043 .37329 .70716 .21756 .69743 .18967 .70101 .36437 Metetra
.989 .741 .458 r
.70101 .36437 .69743 .18967 .68778 .16844 .68842 .24009 Metetra
.994 .756 .406 r
.68842 .24009 .68778 .16844 .6777 .13431 .68089 .31315 Metetra
.988 .74 .461 r
.68089 .31315 .6777 .13431 .6681 .12392 .66773 .1619 Metetra
.994 .757 .461 r
.66773 .1619 .6681 .12392 .65864 .12682 .65788 .15 Metetra
.986 .756 .503 r
.65788 .15 .65864 .12682 .64853 .10784 .64742 .11565 Metetra
.986 .718 .348 r
.84314 .33355 .84538 .3568 .83706 .32515 .8351 .30743 Metetra
.986 .71 .36 r
.8351 .30743 .83706 .32515 .82889 .29777 .82762 .29446 Metetra
.715 .37 0 r
.82762 .29446 .82889 .29777 .82115 .281 .81979 .27586 Metetra
.939 .6 .172 r
.81979 .27586 .82115 .281 .81366 .27169 .81221 .26457 Metetra
.97 .657 .359 r
.81221 .26457 .81366 .27169 .80603 .26141 .80519 .26804 Metetra
1 .827 .521 r
.80519 .26804 .80603 .26141 .79795 .24279 .79795 .26959 Metetra
.995 .768 .409 r
.79795 .26959 .79795 .24279 .79046 .24049 .79177 .29986 Metetra
.993 .752 .448 r
.79177 .29986 .79046 .24049 .78304 .24264 .78384 .29136 Metetra
.993 .752 .457 r
.78384 .29136 .78304 .24264 .7755 .24542 .7755 .27519 Metetra
.993 .759 .471 r
.7755 .27519 .7755 .24542 .7678 .24766 .76711 .26035 Metetra
.998 .789 .484 r
.76711 .26035 .7678 .24766 .75966 .24181 .75918 .26086 Metetra
.988 .761 .506 r
.75918 .26086 .75966 .24181 .75127 .23237 .75024 .23673 Metetra
.974 .826 .633 r
.75024 .23673 .75127 .23237 .74251 .21578 .74165 .2253 Metetra
.982 .778 .555 r
.74165 .2253 .74251 .21578 .7335 .19451 .73266 .20555 Metetra
.994 .789 .518 r
.73266 .20555 .7335 .19451 .72502 .19327 .72392 .19687 Metetra
.988 .887 .623 r
.72392 .19687 .72502 .19327 .71723 .2195 .71528 .19572 Metetra
.982 .71 .431 r
.71528 .19572 .71723 .2195 .70986 .26772 .70716 .21756 Metetra
.991 .732 .396 r
.70716 .21756 .70986 .26772 .70041 .25215 .69743 .18967 Metetra
.991 .734 .407 r
.69743 .18967 .70041 .25215 .6892 .17502 .68778 .16844 Metetra
.848 .551 .015 r
.68778 .16844 .6892 .17502 .67921 .14484 .6777 .13431 Metetra
.977 .678 .32 r
.6777 .13431 .67921 .14484 .66968 .13787 .6681 .12392 Metetra
.981 .693 .384 r
.6681 .12392 .66968 .13787 .66027 .14358 .65864 .12682 Metetra
.984 .704 .343 r
.65864 .12682 .66027 .14358 .65003 .11902 .64853 .10784 Metetra
.989 .75 .477 r
.84538 .3568 .84457 .3175 .83677 .29587 .83706 .32515 Metetra
.989 .753 .486 r
.83706 .32515 .83677 .29587 .82939 .28481 .82889 .29777 Metetra
.988 .771 .522 r
.82889 .29777 .82939 .28481 .82205 .27632 .82115 .281 Metetra
.981 .822 .612 r
.82115 .281 .82205 .27632 .81451 .26549 .81366 .27169 Metetra
.986 .806 .578 r
.81366 .27169 .81451 .26549 .80681 .25324 .80603 .26141 Metetra
.978 .779 .569 r
.80603 .26141 .80681 .25324 .79874 .23464 .79795 .24279 Metetra
.998 .808 .52 r
.79795 .24279 .79874 .23464 .79124 .23163 .79046 .24049 Metetra
1 .808 .497 r
.79046 .24049 .79124 .23163 .78366 .22958 .78304 .24264 Metetra
.999 .788 .475 r
.78304 .24264 .78366 .22958 .77609 .23094 .7755 .24542 Metetra
.998 .784 .473 r
.7755 .24542 .77609 .23094 .76867 .23965 .7678 .24766 Metetra
.995 .806 .537 r
.7678 .24766 .76867 .23965 .76121 .25175 .75966 .24181 Metetra
.977 .678 .317 r
.75966 .24181 .76121 .25175 .75186 .21558 .75127 .23237 Metetra
.991 .769 .502 r
.75127 .23237 .75186 .21558 .74298 .19485 .74251 .21578 Metetra
.99 .762 .495 r
.74251 .21578 .74298 .19485 .73427 .18173 .7335 .19451 Metetra
.998 .789 .489 r
.7335 .19451 .73427 .18173 .72554 .172 .72502 .19327 Metetra
.996 .777 .418 r
.72502 .19327 .72554 .172 .71707 .1746 .71723 .2195 Metetra
.995 .761 .407 r
.71723 .2195 .71707 .1746 .70876 .18842 .70986 .26772 Metetra
.993 .749 .447 r
.70986 .26772 .70876 .18842 .69996 .19191 .70041 .25215 Metetra
.986 .742 .48 r
.70041 .25215 .69996 .19191 .69013 .16317 .6892 .17502 Metetra
.977 .764 .55 r
.6892 .17502 .69013 .16317 .68058 .14949 .67921 .14484 Metetra
.942 .583 .2 r
.67921 .14484 .68058 .14949 .67085 .13407 .66968 .13787 Metetra
.98 .903 .571 r
.66968 .13787 .67085 .13407 .66148 .14084 .66027 .14358 Metetra
.895 .777 .724 r
.66027 .14358 .66148 .14084 .65127 .11724 .65003 .11902 Metetra
.981 .767 .541 r
.84457 .3175 .8451 .30589 .83777 .29376 .83677 .29587 Metetra
.923 .839 .744 r
.83677 .29587 .83777 .29376 .83049 .28447 .82939 .28481 Metetra
.658 .826 .964 r
.82939 .28481 .83049 .28447 .82316 .27608 .82205 .27632 Metetra
.633 .771 .946 r
.82205 .27632 .82316 .27608 .8155 .26258 .81451 .26549 Metetra
.946 .827 .695 r
.81451 .26549 .8155 .26258 .80797 .25393 .80681 .25324 Metetra
.318 .475 .859 r
.80681 .25324 .80797 .25393 .80023 .2429 .79874 .23464 Metetra
.975 .668 .332 r
.79874 .23464 .80023 .2429 .79258 .2363 .79124 .23163 Metetra
.954 .606 .262 r
.79124 .23163 .79258 .2363 .78533 .24223 .78366 .22958 Metetra
.981 .694 .381 r
.78366 .22958 .78533 .24223 .7781 .25222 .77609 .23094 Metetra
.985 .712 .414 r
.77609 .23094 .7781 .25222 .77054 .25788 .76867 .23965 Metetra
.982 .705 .417 r
.76867 .23965 .77054 .25788 .76229 .24898 .76121 .25175 Metetra
.844 .701 .705 r
.76121 .25175 .76229 .24898 .75353 .22904 .75186 .21558 Metetra
.977 .693 .307 r
.75186 .21558 .75353 .22904 .74448 .20347 .74298 .19485 Metetra
.969 .663 .276 r
.74298 .19485 .74448 .20347 .73561 .1859 .73427 .18173 Metetra
.923 .557 .133 r
.73427 .18173 .73561 .1859 .72681 .1739 .72554 .172 Metetra
.855 .406 .129 r
.72554 .172 .72681 .1739 .71834 .1764 .71707 .1746 Metetra
.824 .429 .302 r
.71707 .1746 .71834 .1764 .71007 .19121 .70876 .18842 Metetra
.906 .505 .223 r
.70876 .18842 .71007 .19121 .70058 .17015 .69996 .19191 Metetra
.988 .759 .501 r
.69996 .19191 .70058 .17015 .6907 .13836 .69013 .16317 Metetra
.994 .764 .477 r
.69013 .16317 .6907 .13836 .68099 .11701 .68058 .14949 Metetra
.993 .759 .468 r
.68058 .14949 .68099 .11701 .67138 .10436 .67085 .13407 Metetra
.996 .766 .449 r
.67085 .13407 .67138 .10436 .66174 .09656 .66148 .14084 Metetra
.992 .753 .463 r
.66148 .14084 .66174 .09656 .65185 .08485 .65127 .11724 Metetra
.976 .805 .607 r
.8451 .30589 .84595 .30075 .83876 .29116 .83777 .29376 Metetra
.951 .849 .706 r
.83777 .29376 .83876 .29116 .83145 .28118 .83049 .28447 Metetra
.97 .845 .663 r
.83049 .28447 .83145 .28118 .8239 .26777 .82316 .27608 Metetra
.986 .787 .554 r
.82316 .27608 .8239 .26777 .81609 .25053 .8155 .26258 Metetra
.994 .782 .508 r
.8155 .26258 .81609 .25053 .80848 .23989 .80797 .25393 Metetra
.993 .775 .503 r
.80797 .25393 .80848 .23989 .80035 .21926 .80023 .2429 Metetra
.995 .765 .468 r
.80023 .2429 .80035 .21926 .79285 .21527 .79258 .2363 Metetra
.997 .772 .451 r
.79258 .2363 .79285 .21527 .78566 .22186 .78533 .24223 Metetra
.998 .774 .445 r
.78533 .24223 .78566 .22186 .778 .22034 .7781 .25222 Metetra
.996 .762 .445 r
.7781 .25222 .778 .22034 .77017 .21762 .77054 .25788 Metetra
.994 .756 .455 r
.77054 .25788 .77017 .21762 .76215 .21358 .76229 .24898 Metetra
.992 .755 .469 r
.76229 .24898 .76215 .21358 .75353 .19618 .75353 .22904 Metetra
.991 .755 .477 r
.75353 .22904 .75353 .19618 .74491 .18173 .74448 .20347 Metetra
.992 .763 .488 r
.74448 .20347 .74491 .18173 .73624 .16911 .73561 .1859 Metetra
.994 .772 .494 r
.73561 .1859 .73624 .16911 .72754 .15912 .72681 .1739 Metetra
.998 .785 .473 r
.72681 .1739 .72754 .15912 .71883 .15309 .71834 .1764 Metetra
.997 .773 .439 r
.71834 .1764 .71883 .15309 .71012 .15152 .71007 .19121 Metetra
.992 .754 .465 r
.71007 .19121 .71012 .15152 .70104 .14296 .70058 .17015 Metetra
.989 .755 .491 r
.70058 .17015 .70104 .14296 .6918 .13342 .6907 .13836 Metetra
.956 .791 .638 r
.6907 .13836 .6918 .13342 .68216 .11415 .68099 .11701 Metetra
.947 .848 .711 r
.68099 .11701 .68216 .11415 .67263 .10411 .67138 .10436 Metetra
.547 .838 .998 r
.67138 .10436 .67263 .10411 .66305 .09873 .66174 .09656 Metetra
.734 .287 0 r
.66174 .09656 .66305 .09873 .65304 .08111 .65185 .08485 Metetra
.651 .207 0 r
.84595 .30075 .84714 .30255 .83982 .29033 .83876 .29116 Metetra
.803 .843 .881 r
.83876 .29116 .83982 .29033 .83241 .27778 .83145 .28118 Metetra
.952 .814 .671 r
.83145 .28118 .83241 .27778 .82499 .26709 .8239 .26777 Metetra
.741 .732 .843 r
.8239 .26777 .82499 .26709 .8174 .25462 .81609 .25053 Metetra
.913 .552 .104 r
.81609 .25053 .8174 .25462 .80972 .24224 .80848 .23989 Metetra
0 0 .492 r
.80848 .23989 .80972 .24224 .80153 .22021 .80035 .21926 Metetra
.555 0 0 r
.80035 .21926 .80153 .22021 .79402 .21603 .79285 .21527 Metetra
.697 .211 .089 r
.79285 .21527 .79402 .21603 .78655 .21544 .78566 .22186 Metetra
.998 .826 .54 r
.78566 .22186 .78655 .21544 .77911 .21905 .778 .22034 Metetra
.884 .973 .835 r
.778 .22034 .77911 .21905 .77157 .22356 .77017 .21762 Metetra
.963 .632 .279 r
.77017 .21762 .77157 .22356 .76381 .22623 .76215 .21358 Metetra
.978 .691 .31 r
.76215 .21358 .76381 .22623 .75503 .20488 .75353 .19618 Metetra
.968 .662 .268 r
.75353 .19618 .75503 .20488 .74636 .1892 .74491 .18173 Metetra
.963 .648 .252 r
.74491 .18173 .74636 .1892 .73743 .16883 .73624 .16911 Metetra
.615 .809 .975 r
.73624 .16911 .73743 .16883 .72874 .15902 .72754 .15912 Metetra
.427 .798 .994 r
.72754 .15912 .72874 .15902 .72024 .15943 .71883 .15309 Metetra
.965 .637 .304 r
.71883 .15309 .72024 .15943 .71183 .16794 .71012 .15152 Metetra
.985 .704 .365 r
.71012 .15152 .71183 .16794 .70288 .1641 .70104 .14296 Metetra
.987 .713 .378 r
.70104 .14296 .70288 .1641 .69368 .15694 .6918 .13342 Metetra
.987 .716 .367 r
.6918 .13342 .69368 .15694 .68362 .12232 .68216 .11415 Metetra
.97 .657 .285 r
.68216 .11415 .68362 .12232 .67396 .1073 .67263 .10411 Metetra
.906 .502 .112 r
.67263 .10411 .67396 .1073 .66478 .11907 .66305 .09873 Metetra
.986 .711 .36 r
.66305 .09873 .66478 .11907 .65449 .0895 .65304 .08111 Metetra
.89 .53 .053 r
.84714 .30255 .84844 .30651 .84099 .29146 .83982 .29033 Metetra
0 .211 .734 r
.83982 .29033 .84099 .29146 .83357 .27887 .83241 .27778 Metetra
0 .178 .7 r
.83241 .27778 .83357 .27887 .82623 .26971 .82499 .26709 Metetra
.758 .36 0 r
.82499 .26709 .82623 .26971 .8188 .26065 .8174 .25462 Metetra
.948 .622 .2 r
.8174 .25462 .8188 .26065 .81118 .2496 .80972 .24224 Metetra
.929 .623 .155 r
.80972 .24224 .81118 .2496 .80336 .236 .80153 .22021 Metetra
.985 .705 .375 r
.80153 .22021 .80336 .236 .79641 .24543 .79402 .21603 Metetra
.989 .722 .405 r
.79402 .21603 .79641 .24543 .78918 .25131 .78655 .21544 Metetra
.989 .725 .414 r
.78655 .21544 .78918 .25131 .78182 .25758 .77911 .21905 Metetra
.989 .726 .416 r
.77911 .21905 .78182 .25758 .77408 .25809 .77157 .22356 Metetra
.989 .724 .412 r
.77157 .22356 .77408 .25809 .7661 .25557 .76381 .22623 Metetra
.989 .723 .375 r
.76381 .22623 .7661 .25557 .75773 .2463 .75503 .20488 Metetra
.99 .729 .397 r
.75503 .20488 .75773 .2463 .74915 .23438 .74636 .1892 Metetra
.991 .73 .396 r
.74636 .1892 .74915 .23438 .74008 .21161 .73743 .16883 Metetra
.99 .729 .404 r
.73743 .16883 .74008 .21161 .73153 .20746 .72874 .15902 Metetra
.99 .729 .415 r
.72874 .15902 .73153 .20746 .72328 .21729 .72024 .15943 Metetra
.99 .73 .422 r
.72024 .15943 .72328 .21729 .71683 .29279 .71183 .16794 Metetra
.992 .737 .422 r
.71183 .16794 .71683 .29279 .70524 .20299 .70288 .1641 Metetra
.99 .726 .404 r
.70288 .1641 .70524 .20299 .69533 .17185 .69368 .15694 Metetra
.969 .691 .274 r
.69368 .15694 .69533 .17185 .68505 .12957 .68362 .12232 Metetra
.957 .638 .229 r
.68362 .12232 .68505 .12957 .67544 .1164 .67396 .1073 Metetra
.968 .662 .388 r
.67396 .1073 .67544 .1164 .66578 .10756 .66478 .11907 Metetra
.978 .767 .551 r
.66478 .11907 .66578 .10756 .65572 .08792 .65449 .0895 Metetra
.988 .776 .529 r
.84844 .30651 .84899 .29534 .84176 .28447 .84099 .29146 Metetra
.984 .794 .569 r
.84099 .29146 .84176 .28447 .83415 .26755 .83357 .27887 Metetra
.994 .783 .513 r
.83357 .27887 .83415 .26755 .82651 .25168 .82623 .26971 Metetra
.994 .769 .483 r
.82623 .26971 .82651 .25168 .81907 .24191 .8188 .26065 Metetra
.994 .768 .485 r
.8188 .26065 .81907 .24191 .81161 .23371 .81118 .2496 Metetra
.992 .77 .499 r
.81118 .2496 .81161 .23371 .80381 .22027 .80336 .236 Metetra
.998 .782 .448 r
.80336 .236 .80381 .22027 .79655 .2215 .79641 .24543 Metetra
.997 .768 .448 r
.79641 .24543 .79655 .2215 .78932 .22664 .78918 .25131 Metetra
.997 .768 .447 r
.78918 .25131 .78932 .22664 .7816 .22331 .78182 .25758 Metetra
.995 .76 .448 r
.78182 .25758 .7816 .22331 .77368 .2177 .77408 .25809 Metetra
.995 .757 .448 r
.77408 .25809 .77368 .2177 .76526 .20226 .7661 .25557 Metetra
.994 .753 .448 r
.7661 .25557 .76526 .20226 .75719 .19899 .75773 .2463 Metetra
.994 .754 .453 r
.75773 .2463 .75719 .19899 .7485 .18235 .74915 .23438 Metetra
.992 .751 .457 r
.74915 .23438 .7485 .18235 .73986 .16985 .74008 .21161 Metetra
.995 .757 .449 r
.74008 .21161 .73986 .16985 .73118 .15989 .73153 .20746 Metetra
.995 .757 .437 r
.73153 .20746 .73118 .15989 .72265 .15884 .72328 .21729 Metetra
.993 .757 .392 r
.72328 .21729 .72265 .15884 .71399 .1584 .71683 .29279 Metetra
.99 .742 .456 r
.71683 .29279 .71399 .1584 .70493 .14988 .70524 .20299 Metetra
.992 .75 .461 r
.70524 .20299 .70493 .14988 .69542 .13006 .69533 .17185 Metetra
.989 .749 .476 r
.69533 .17185 .69542 .13006 .68593 .11559 .68505 .12957 Metetra
.993 .779 .508 r
.68505 .12957 .68593 .11559 .67608 .09182 .67544 .1164 Metetra
.995 .766 .47 r
.67544 .1164 .67608 .09182 .66653 .08571 .66578 .10756 Metetra
.992 .764 .488 r
.66578 .10756 .66653 .08571 .65662 .07084 .65572 .08792 Metetra
.985 .707 .357 r
.84899 .29534 .85091 .31171 .8431 .28918 .84176 .28447 Metetra
.878 .541 .039 r
.84176 .28447 .8431 .28918 .83573 .27723 .83415 .26755 Metetra
.969 .672 .271 r
.83415 .26755 .83573 .27723 .82834 .26675 .82651 .25168 Metetra
.984 .703 .354 r
.82651 .25168 .82834 .26675 .82072 .25337 .81907 .24191 Metetra
.981 .69 .336 r
.81907 .24191 .82072 .25337 .81316 .24316 .81161 .23371 Metetra
.972 .673 .284 r
.81161 .23371 .81316 .24316 .80538 .23015 .80381 .22027 Metetra
.978 .68 .365 r
.80381 .22027 .80538 .23015 .79791 .22665 .79655 .2215 Metetra
.955 .622 .338 r
.79655 .2215 .79791 .22665 .79041 .2252 .78932 .22664 Metetra
.906 .959 .815 r
.78932 .22664 .79041 .2252 .78283 .22494 .7816 .22331 Metetra
.743 .252 0 r
.7816 .22331 .78283 .22494 .77503 .22231 .77368 .2177 Metetra
.898 .55 .072 r
.77368 .2177 .77503 .22231 .76696 .2161 .76526 .20226 Metetra
.983 .697 .368 r
.76526 .20226 .76696 .2161 .75853 .2034 .75719 .19899 Metetra
.88 .529 .035 r
.75719 .19899 .75853 .2034 .75019 .19635 .7485 .18235 Metetra
.982 .697 .339 r
.7485 .18235 .75019 .19635 .74139 .17973 .73986 .16985 Metetra
.976 .675 .311 r
.73986 .16985 .74139 .17973 .73297 .17752 .73118 .15989 Metetra
.985 .706 .385 r
.73118 .15989 .73297 .17752 .72404 .16424 .72265 .15884 Metetra
.958 .617 .289 r
.72265 .15884 .72404 .16424 .71602 .18481 .71399 .1584 Metetra
.988 .719 .388 r
.71399 .1584 .71602 .18481 .70669 .16785 .70493 .14988 Metetra
.984 .707 .342 r
.70493 .14988 .70669 .16785 .69688 .13801 .69542 .13006 Metetra
.963 .65 .251 r
.69542 .13006 .69688 .13801 .68724 .11802 .68593 .11559 Metetra
0 0 .47 r
.68593 .11559 .68724 .11802 .67764 .10421 .67608 .09182 Metetra
.981 .688 .348 r
.67608 .09182 .67764 .10421 .6683 .10727 .66653 .08571 Metetra
.987 .713 .368 r
.66653 .08571 .6683 .10727 .65818 .0841 .65662 .07084 Metetra
.974 .768 .565 r
.85091 .31171 .85156 .3026 .84433 .29169 .8431 .28918 Metetra
.744 .342 0 r
.8431 .28918 .84433 .29169 .83713 .28323 .83573 .27723 Metetra
.953 .626 .217 r
.83573 .27723 .83713 .28323 .82961 .26989 .82834 .26675 Metetra
.809 .43 0 r
.82834 .26675 .82961 .26989 .82216 .26009 .82072 .25337 Metetra
.961 .641 .245 r
.82072 .25337 .82216 .26009 .81424 .24181 .81316 .24316 Metetra
.857 .822 .813 r
.81316 .24316 .81424 .24181 .80604 .21927 .80538 .23015 Metetra
.997 .791 .5 r
.80538 .23015 .80604 .21927 .79854 .2146 .79791 .22665 Metetra
.998 .789 .488 r
.79791 .22665 .79854 .2146 .79119 .2162 .79041 .2252 Metetra
.999 .805 .503 r
.79041 .2252 .79119 .2162 .78369 .2173 .78283 .22494 Metetra
.998 .813 .527 r
.78283 .22494 .78369 .2173 .77602 .21752 .77503 .22231 Metetra
.99 .838 .598 r
.77503 .22231 .77602 .21752 .76839 .2225 .76696 .2161 Metetra
.952 .627 .213 r
.76696 .2161 .76839 .2225 .75969 .20254 .75853 .2034 Metetra
.802 .917 .916 r
.75853 .2034 .75969 .20254 .75109 .188 .75019 .19635 Metetra
.984 .787 .56 r
.75019 .19635 .75109 .188 .74251 .17722 .74139 .17973 Metetra
.969 .923 .694 r
.74139 .17973 .74251 .17722 .73384 .16758 .73297 .17752 Metetra
.991 .788 .535 r
.73297 .17752 .73384 .16758 .72509 .15908 .72404 .16424 Metetra
.919 .835 .38 r
.72404 .16424 .72509 .15908 .71657 .16269 .71602 .18481 Metetra
.993 .764 .484 r
.71602 .18481 .71657 .16269 .70733 .1475 .70669 .16785 Metetra
.987 .759 .505 r
.70669 .16785 .70733 .1475 .69801 .13401 .69688 .13801 Metetra
.947 .799 .665 r
.69688 .13801 .69801 .13401 .6885 .11853 .68724 .11802 Metetra
.208 .523 .918 r
.68724 .11802 .6885 .11853 .67917 .115 .67764 .10421 Metetra
.977 .678 .367 r
.67764 .10421 .67917 .115 .66962 .10954 .6683 .10727 Metetra
0 0 .493 r
.6683 .10727 .66962 .10954 .65947 .08517 .65818 .0841 Metetra
.793 .824 .876 r
.85156 .3026 .85263 .30179 .84537 .29028 .84433 .29169 Metetra
.892 .877 .814 r
.84433 .29169 .84537 .29028 .838 .27801 .83713 .28323 Metetra
.975 .803 .608 r
.83713 .28323 .838 .27801 .83056 .26631 .82961 .26989 Metetra
.97 .834 .653 r
.82961 .26989 .83056 .26631 .82323 .25874 .82216 .26009 Metetra
.825 .761 .792 r
.82216 .26009 .82323 .25874 .81559 .24659 .81424 .24181 Metetra
.816 .495 0 r
.81424 .24181 .81559 .24659 .80776 .2324 .80604 .21927 Metetra
.983 .696 .36 r
.80604 .21927 .80776 .2324 .80021 .22661 .79854 .2146 Metetra
.981 .691 .376 r
.79854 .2146 .80021 .22661 .79313 .23479 .79119 .2162 Metetra
.986 .709 .393 r
.79119 .2162 .79313 .23479 .7859 .24287 .78369 .2173 Metetra
.988 .718 .401 r
.78369 .2173 .7859 .24287 .77819 .24289 .77602 .21752 Metetra
.987 .717 .408 r
.77602 .21752 .77819 .24289 .77011 .23659 .76839 .2225 Metetra
.978 .695 .311 r
.76839 .2225 .77011 .23659 .76175 .22608 .75969 .20254 Metetra
.988 .717 .372 r
.75969 .20254 .76175 .22608 .75291 .20554 .75109 .188 Metetra
.985 .707 .361 r
.75109 .188 .75291 .20554 .74406 .18738 .74251 .17722 Metetra
.977 .677 .315 r
.74251 .17722 .74406 .18738 .73538 .17738 .73384 .16758 Metetra
.976 .675 .316 r
.73384 .16758 .73538 .17738 .72709 .18354 .72509 .15908 Metetra
.987 .715 .403 r
.72509 .15908 .72709 .18354 .71899 .20121 .71657 .16269 Metetra
.99 .727 .394 r
.71657 .16269 .71899 .20121 .70967 .18485 .70733 .1475 Metetra
.99 .726 .394 r
.70733 .1475 .70967 .18485 .69981 .15406 .69801 .13401 Metetra
.986 .711 .36 r
.69801 .13401 .69981 .15406 .68976 .1189 .6885 .11853 Metetra
0 .419 .723 r
.6885 .11853 .68976 .1189 .68018 .10537 .67917 .115 Metetra
.997 .802 .52 r
.67917 .115 .68018 .10537 .67088 .10953 .66962 .10954 Metetra
.563 .621 .868 r
.66962 .10954 .67088 .10953 .66091 .09276 .65947 .08517 Metetra
.892 .529 .056 r
.85263 .30179 .85393 .30569 .84669 .29438 .84537 .29028 Metetra
.895 .538 .064 r
.84537 .29028 .84669 .29438 .83934 .28271 .838 .27801 Metetra
.923 .576 .128 r
.838 .27801 .83934 .28271 .83177 .26809 .83056 .26631 Metetra
.719 .253 0 r
.83056 .26631 .83177 .26809 .82388 .24841 .82323 .25874 Metetra
.991 .783 .527 r
.82323 .25874 .82388 .24841 .81617 .23435 .81559 .24659 Metetra
.991 .776 .518 r
.81559 .24659 .81617 .23435 .80785 .20855 .80776 .2324 Metetra
.995 .765 .464 r
.80776 .2324 .80785 .20855 .80016 .19889 .80021 .22661 Metetra
.996 .765 .44 r
.80021 .22661 .80016 .19889 .79234 .18871 .79313 .23479 Metetra
.995 .756 .435 r
.79313 .23479 .79234 .18871 .78499 .19223 .7859 .24287 Metetra
.995 .754 .441 r
.7859 .24287 .78499 .19223 .77733 .19171 .77819 .24289 Metetra
.994 .753 .445 r
.77819 .24289 .77733 .19171 .76957 .19187 .77011 .23659 Metetra
.994 .754 .451 r
.77011 .23659 .76957 .19187 .76148 .18703 .76175 .22608 Metetra
.993 .754 .463 r
.76175 .22608 .76148 .18703 .75309 .17728 .75291 .20554 Metetra
.993 .759 .473 r
.75291 .20554 .75309 .17728 .74428 .15926 .74406 .18738 Metetra
.995 .762 .464 r
.74406 .18738 .74428 .15926 .73584 .15508 .73538 .17738 Metetra
.997 .772 .45 r
.73538 .17738 .73584 .15508 .72749 .15804 .72709 .18354 Metetra
.997 .771 .431 r
.72709 .18354 .72749 .15804 .71914 .16646 .71899 .20121 Metetra
.993 .757 .463 r
.71899 .20121 .71914 .16646 .71008 .15723 .70967 .18485 Metetra
.99 .756 .487 r
.70967 .18485 .71008 .15723 .70084 .14639 .69981 .15406 Metetra
.953 .756 .601 r
.69981 .15406 .70084 .14639 .69133 .13094 .68976 .1189 Metetra
.978 .686 .318 r
.68976 .1189 .69133 .13094 .68167 .1148 .68018 .10537 Metetra
.974 .668 .362 r
.68018 .10537 .68167 .1148 .67229 .11546 .67088 .10953 Metetra
.934 .6 .159 r
.67088 .10953 .67229 .11546 .66206 .08715 .66091 .09276 Metetra
.918 .837 .749 r
.85393 .30569 .85493 .30365 .84752 .28872 .84669 .29438 Metetra
.981 .805 .591 r
.84669 .29438 .84752 .28872 .84022 .27772 .83934 .28271 Metetra
.969 .8 .617 r
.83934 .28271 .84022 .27772 .83289 .26799 .83177 .26809 Metetra
.612 .643 .856 r
.83177 .26809 .83289 .26799 .82538 .25634 .82388 .24841 Metetra
.962 .653 .244 r
.82388 .24841 .82538 .25634 .81806 .25098 .81617 .23435 Metetra
.978 .702 .307 r
.81617 .23435 .81806 .25098 .81083 .24998 .80785 .20855 Metetra
.99 .729 .401 r
.80785 .20855 .81083 .24998 .80364 .25275 .80016 .19889 Metetra
.991 .732 .406 r
.80016 .19889 .80364 .25275 .79665 .2633 .79234 .18871 Metetra
.991 .734 .419 r
.79234 .18871 .79665 .2633 .78894 .2601 .78499 .19223 Metetra
.991 .733 .416 r
.78499 .19223 .78894 .2601 .78133 .2624 .77733 .19171 Metetra
.991 .733 .417 r
.77733 .19171 .78133 .2624 .77407 .27731 .76957 .19187 Metetra
.991 .735 .416 r
.76957 .19187 .77407 .27731 .76496 .24805 .76148 .18703 Metetra
.991 .733 .409 r
.76148 .18703 .76496 .24805 .75633 .23358 .75309 .17728 Metetra
.991 .732 .401 r
.75309 .17728 .75633 .23358 .74737 .21305 .74428 .15926 Metetra
.991 .731 .41 r
.74428 .15926 .74737 .21305 .73868 .20331 .73584 .15508 Metetra
.99 .729 .414 r
.73584 .15508 .73868 .20331 .73032 .20743 .72749 .15804 Metetra
.99 .728 .418 r
.72749 .15804 .73032 .20743 .72233 .22899 .71914 .16646 Metetra
.991 .732 .409 r
.71914 .16646 .72233 .22899 .71282 .20713 .71008 .15723 Metetra
.991 .73 .404 r
.71008 .15723 .71282 .20713 .70287 .17369 .70084 .14639 Metetra
.988 .719 .378 r
.70084 .14639 .70287 .17369 .69322 .15418 .69133 .13094 Metetra
.987 .715 .368 r
.69133 .13094 .69322 .15418 .68313 .12262 .68167 .1148 Metetra
.97 .653 .332 r
.68167 .1148 .68313 .12262 .67371 .12182 .67229 .11546 Metetra
.884 .571 .064 r
.67229 .11546 .67371 .12182 .66336 .08833 .66206 .08715 Metetra
.812 .451 0 r
.85493 .30365 .85622 .30717 .84886 .29326 .84752 .28872 Metetra
.922 .572 .125 r
.84752 .28872 .84886 .29326 .84153 .28174 .84022 .27772 Metetra
.914 .551 .106 r
.84022 .27772 .84153 .28174 .8338 .26364 .83289 .26799 Metetra
.973 .817 .628 r
.83289 .26799 .8338 .26364 .8264 .25409 .82538 .25634 Metetra
.958 .898 .723 r
.82538 .25634 .8264 .25409 .81935 .25443 .81806 .25098 Metetra
.934 .556 .214 r
.81806 .25098 .81935 .25443 .81203 .25119 .81083 .24998 Metetra
.782 .291 .045 r
.81083 .24998 .81203 .25119 .80596 .2796 .80364 .25275 Metetra
.986 .718 .416 r
.80364 .25275 .80596 .2796 .79791 .26563 .79665 .2633 Metetra
.874 .438 .053 r
.79665 .2633 .79791 .26563 .7903 .26451 .78894 .2601 Metetra
.949 .597 .291 r
.78894 .2601 .7903 .26451 .78295 .27337 .78133 .2624 Metetra
.971 .679 .411 r
.78133 .2624 .78295 .27337 .77478 .26509 .77407 .27731 Metetra
.978 .762 .545 r
.77407 .27731 .77478 .26509 .76655 .25822 .76496 .24805 Metetra
.973 .674 .288 r
.76496 .24805 .76655 .25822 .75778 .24025 .75633 .23358 Metetra
.926 .608 .144 r
.75633 .23358 .75778 .24025 .74889 .22183 .74737 .21305 Metetra
.972 .664 .293 r
.74737 .21305 .74889 .22183 .74008 .20857 .73868 .20331 Metetra
.955 .614 .318 r
.73868 .20331 .74008 .20857 .73185 .21681 .73032 .20743 Metetra
.959 .66 .421 r
.73032 .20743 .73185 .21681 .72371 .23339 .72233 .22899 Metetra
.825 .483 0 r
.72233 .22899 .72371 .23339 .71443 .21926 .71282 .20713 Metetra
.955 .67 .229 r
.71282 .20713 .71443 .21926 .70451 .18723 .70287 .17369 Metetra
.978 .691 .309 r
.70287 .17369 .70451 .18723 .69517 .1795 .69322 .15418 Metetra
.985 .717 .346 r
.69322 .15418 .69517 .1795 .6846 .13047 .68313 .12262 Metetra
.97 .653 .324 r
.68313 .12262 .6846 .13047 .67493 .11961 .67371 .12182 Metetra
.833 .717 .736 r
.67371 .12182 .67493 .11961 .66487 .09886 .66336 .08833 Metetra
.987 .717 .368 r
.85622 .30717 .85849 .32988 .8511 .31586 .84886 .29326 Metetra
.988 .717 .373 r
.84886 .29326 .8511 .31586 .84381 .30529 .84153 .28174 Metetra
.987 .717 .361 r
.84153 .28174 .84381 .30529 .83653 .297 .8338 .26364 Metetra
.99 .725 .393 r
.8338 .26364 .83653 .297 .82915 .28854 .8264 .25409 Metetra
.989 .725 .407 r
.8264 .25409 .82915 .28854 .82179 .28263 .81935 .25443 Metetra
.989 .721 .397 r
.81935 .25443 .82179 .28263 .81437 .27795 .81203 .25119 Metetra
.982 .713 .44 r
.81203 .25119 .81437 .27795 .80732 .2842 .80596 .2796 Metetra
.904 .555 .084 r
.80596 .2796 .80732 .2842 .80004 .28819 .79791 .26563 Metetra
.987 .715 .393 r
.79791 .26563 .80004 .28819 .79188 .27447 .7903 .26451 Metetra
.974 .676 .39 r
.7903 .26451 .79188 .27447 .78402 .27055 .78295 .27337 Metetra
.963 .867 .697 r
.78295 .27337 .78402 .27055 .77584 .26173 .77478 .26509 Metetra
.977 .865 .66 r
.77478 .26509 .77584 .26173 .76756 .25341 .76655 .25822 Metetra
.962 .798 .633 r
.76655 .25822 .76756 .25341 .7587 .2326 .75778 .24025 Metetra
.98 .787 .574 r
.75778 .24025 .7587 .2326 .75005 .22037 .74889 .22183 Metetra
.867 .841 .818 r
.74889 .22183 .75005 .22037 .74133 .20967 .74008 .20857 Metetra
.753 .289 .147 r
.74008 .20857 .74133 .20967 .73256 .20107 .73185 .21681 Metetra
.997 .787 .433 r
.73185 .21681 .73256 .20107 .72446 .21807 .72371 .23339 Metetra
.993 .775 .501 r
.72371 .23339 .72446 .21807 .71487 .1928 .71443 .21926 Metetra
.989 .756 .489 r
.71443 .21926 .71487 .1928 .70547 .17727 .70451 .18723 Metetra
.996 .797 .522 r
.70451 .18723 .70547 .17727 .69604 .16555 .69517 .1795 Metetra
.965 .745 .555 r
.69517 .1795 .69604 .16555 .68608 .13894 .6846 .13047 Metetra
.969 .657 .28 r
.6846 .13047 .68608 .13894 .67648 .13099 .67493 .11961 Metetra
.971 .677 .279 r
.67493 .11961 .67648 .13099 .66653 .11505 .66487 .09886 Metetra
.969 .67 .272 r
.85849 .32988 .86008 .33927 .85197 .31095 .8511 .31586 Metetra
.98 .815 .606 r
.8511 .31586 .85197 .31095 .84441 .29464 .84381 .30529 Metetra
.995 .787 .513 r
.84381 .30529 .84441 .29464 .83662 .27537 .83653 .297 Metetra
.995 .766 .471 r
.83653 .297 .83662 .27537 .82903 .26187 .82915 .28854 Metetra
.995 .762 .459 r
.82915 .28854 .82903 .26187 .82155 .25275 .82179 .28263 Metetra
.995 .761 .454 r
.82179 .28263 .82155 .25275 .8137 .23743 .81437 .27795 Metetra
.995 .757 .436 r
.81437 .27795 .8137 .23743 .80633 .23509 .80732 .2842 Metetra
.995 .755 .436 r
.80732 .2842 .80633 .23509 .79939 .24571 .80004 .28819 Metetra
.994 .754 .453 r
.80004 .28819 .79939 .24571 .79209 .25109 .79188 .27447 Metetra
.996 .767 .461 r
.79188 .27447 .79209 .25109 .78437 .24985 .78402 .27055 Metetra
.995 .768 .474 r
.78402 .27055 .78437 .24985 .77648 .24762 .77584 .26173 Metetra
.996 .779 .494 r
.77584 .26173 .77648 .24762 .76781 .22861 .76756 .25341 Metetra
.992 .76 .481 r
.76756 .25341 .76781 .22861 .7589 .20532 .7587 .2326 Metetra
.994 .761 .467 r
.7587 .2326 .7589 .20532 .75008 .1872 .75005 .22037 Metetra
.994 .759 .458 r
.75005 .22037 .75008 .1872 .74143 .17724 .74133 .20967 Metetra
.995 .76 .457 r
.74133 .20967 .74143 .17724 .73363 .19647 .73256 .20107 Metetra
.925 .854 .414 r
.73256 .20107 .73363 .19647 .72569 .21776 .72446 .21807 Metetra
.644 .65 .841 r
.72446 .21807 .72569 .21776 .71625 .19713 .71487 .1928 Metetra
.888 .527 .049 r
.71487 .1928 .71625 .19713 .70637 .16544 .70547 .17727 Metetra
.994 .786 .515 r
.70547 .17727 .70637 .16544 .69692 .15187 .69604 .16555 Metetra
.985 .768 .529 r
.69604 .16555 .69692 .15187 .68715 .13145 .68608 .13894 Metetra
.995 .813 .551 r
.68608 .13894 .68715 .13145 .67801 .14135 .67648 .13099 Metetra
.972 .672 .285 r
.67648 .13099 .67801 .14135 .66785 .11668 .66653 .11505 Metetra
.991 .752 .472 r
.86008 .33927 .85934 .30311 .85188 .28696 .85197 .31095 Metetra
.993 .76 .477 r
.85197 .31095 .85188 .28696 .84448 .27338 .84441 .29464 Metetra
.991 .761 .488 r
.84441 .29464 .84448 .27338 .83715 .26301 .83662 .27537 Metetra
.991 .776 .514 r
.83662 .27537 .83715 .26301 .82978 .25379 .82903 .26187 Metetra
.993 .798 .541 r
.82903 .26187 .82978 .25379 .82229 .24399 .82155 .25275 Metetra
.986 .784 .55 r
.82155 .25275 .82229 .24399 .81384 .21525 .8137 .23743 Metetra
.996 .768 .459 r
.8137 .23743 .81384 .21525 .80632 .20884 .80633 .23509 Metetra
.997 .767 .435 r
.80633 .23509 .80632 .20884 .79929 .21636 .79939 .24571 Metetra
.996 .763 .441 r
.79939 .24571 .79929 .21636 .79218 .22528 .79209 .25109 Metetra
.996 .765 .454 r
.79209 .25109 .79218 .22528 .78454 .22512 .78437 .24985 Metetra
.996 .766 .456 r
.78437 .24985 .78454 .22512 .77687 .22751 .77648 .24762 Metetra
.992 .764 .49 r
.77648 .24762 .77687 .22751 .76825 .20877 .76781 .22861 Metetra
.99 .762 .497 r
.76781 .22861 .76825 .20877 .75936 .18559 .7589 .20532 Metetra
.992 .765 .49 r
.7589 .20532 .75936 .18559 .75072 .17147 .75008 .1872 Metetra
.995 .776 .49 r
.75008 .1872 .75072 .17147 .7421 .16147 .74143 .17724 Metetra
.995 .787 .424 r
.74143 .17724 .7421 .16147 .73376 .16362 .73363 .19647 Metetra
.996 .765 .424 r
.73363 .19647 .73376 .16362 .72584 .18374 .72569 .21776 Metetra
.993 .756 .466 r
.72569 .21776 .72584 .18374 .71718 .18678 .71625 .19713 Metetra
.972 .764 .563 r
.71625 .19713 .71718 .18678 .70752 .16197 .70637 .16544 Metetra
.959 .836 .678 r
.70637 .16544 .70752 .16197 .69781 .13903 .69692 .15187 Metetra
.989 .775 .524 r
.69692 .15187 .69781 .13903 .68814 .12135 .68715 .13145 Metetra
.998 .812 .467 r
.68715 .13145 .68814 .12135 .6797 .1578 .67801 .14135 Metetra
.98 .699 .316 r
.67801 .14135 .6797 .1578 .66894 .1087 .66785 .11668 Metetra
.985 .71 .347 r
.85934 .30311 .86142 .32201 .85369 .30064 .85188 .28696 Metetra
.981 .697 .325 r
.85188 .28696 .85369 .30064 .84637 .28894 .84448 .27338 Metetra
.984 .704 .349 r
.84448 .27338 .84637 .28894 .83899 .27777 .83715 .26301 Metetra
.984 .701 .349 r
.83715 .26301 .83899 .27777 .8316 .26839 .82978 .25379 Metetra
.983 .7 .346 r
.82978 .25379 .8316 .26839 .82471 .27157 .82229 .24399 Metetra
.986 .72 .35 r
.82229 .24399 .82471 .27157 .81757 .27233 .81384 .21525 Metetra
.991 .732 .408 r
.81384 .21525 .81757 .27233 .81239 .31986 .80632 .20884 Metetra
.991 .736 .421 r
.80632 .20884 .81239 .31986 .80428 .30511 .79929 .21636 Metetra
.991 .735 .421 r
.79929 .21636 .80428 .30511 .79669 .30481 .79218 .22528 Metetra
.991 .734 .416 r
.79218 .22528 .79669 .30481 .78809 .28314 .78454 .22512 Metetra
.99 .731 .414 r
.78454 .22512 .78809 .28314 .78262 .34243 .77687 .22751 Metetra
.992 .737 .412 r
.77687 .22751 .78262 .34243 .77408 .32913 .76825 .20877 Metetra
.992 .738 .411 r
.76825 .20877 .77408 .32913 .76567 .32235 .75936 .18559 Metetra
.992 .738 .415 r
.75936 .18559 .76567 .32235 .75547 .26976 .75072 .17147 Metetra
.992 .736 .413 r
.75072 .17147 .75547 .26976 .7455 .2244 .7421 .16147 Metetra
.991 .731 .414 r
.7421 .16147 .7455 .2244 .73713 .22753 .73376 .16362 Metetra
.99 .73 .424 r
.73376 .16362 .73713 .22753 .73307 .36963 .72584 .18374 Metetra
.992 .738 .421 r
.72584 .18374 .73307 .36963 .7238 .36065 .71718 .18678 Metetra
.992 .739 .415 r
.71718 .18678 .7238 .36065 .70949 .18647 .70752 .16197 Metetra
.986 .716 .356 r
.70752 .16197 .70949 .18647 .69982 .16567 .69781 .13903 Metetra
.988 .718 .371 r
.69781 .13903 .69982 .16567 .68996 .14219 .68814 .12135 Metetra
.975 .698 .44 r
.68814 .12135 .68996 .14219 .68033 .1325 .6797 .1578 Metetra
.983 .749 .505 r
.6797 .1578 .68033 .1325 .67046 .11904 .66894 .1087 Metetra
.981 .705 .321 r
.86142 .32201 .86342 .33931 .85612 .32654 .85369 .30064 Metetra
.988 .72 .377 r
.85369 .30064 .85612 .32654 .84872 .31363 .84637 .28894 Metetra
.988 .719 .376 r
.84637 .28894 .84872 .31363 .84121 .30019 .83899 .27777 Metetra
.988 .716 .375 r
.83899 .27777 .84121 .30019 .83386 .2919 .8316 .26839 Metetra
.987 .716 .401 r
.8316 .26839 .83386 .2919 .82685 .29312 .82471 .27157 Metetra
.987 .714 .394 r
.82471 .27157 .82685 .29312 .82045 .31034 .81757 .27233 Metetra
.982 .718 .451 r
.81757 .27233 .82045 .31034 .81595 .37386 .81239 .31986 Metetra
.991 .731 .4 r
.81239 .31986 .81595 .37386 .80691 .33861 .80428 .30511 Metetra
.989 .723 .403 r
.80428 .30511 .80691 .33861 .79989 .35254 .79669 .30481 Metetra
.991 .73 .39 r
.79669 .30481 .79989 .35254 .79196 .34834 .78809 .28314 Metetra
.986 .726 .445 r
.78809 .28314 .79196 .34834 .78401 .34706 .78262 .34243 Metetra
.91 .556 .096 r
.78262 .34243 .78401 .34706 .77485 .31759 .77408 .32913 Metetra
.997 .789 .505 r
.77408 .32913 .77485 .31759 .76411 .24839 .76567 .32235 Metetra
.991 .745 .458 r
.76567 .32235 .76411 .24839 .75728 .28603 .75547 .26976 Metetra
.953 .683 .234 r
.75547 .26976 .75728 .28603 .74846 .27384 .7455 .2244 Metetra
.99 .728 .411 r
.7455 .2244 .74846 .27384 .74072 .29733 .73713 .22753 Metetra
.976 .716 .473 r
.73713 .22753 .74072 .29733 .73433 .36942 .73307 .36963 Metetra
.547 .813 .995 r
.73307 .36963 .73433 .36942 .72507 .36044 .7238 .36065 Metetra
.596 .444 .645 r
.7238 .36065 .72507 .36044 .71107 .19723 .70949 .18647 Metetra
.967 .671 .264 r
.70949 .18647 .71107 .19723 .70493 .30098 .69982 .16567 Metetra
.992 .738 .412 r
.69982 .16567 .70493 .30098 .69215 .17659 .68996 .14219 Metetra
.989 .723 .392 r
.68996 .14219 .69215 .17659 .68246 .16585 .68033 .1325 Metetra
.989 .723 .386 r
.68033 .1325 .68246 .16585 .67187 .1243 .67046 .11904 Metetra
.815 .437 0 r
.86342 .33931 .8647 .3425 .85648 .31166 .85612 .32654 Metetra
.993 .772 .498 r
.85612 .32654 .85648 .31166 .84859 .28856 .84872 .31363 Metetra
.994 .761 .47 r
.84872 .31363 .84859 .28856 .84123 .27746 .84121 .30019 Metetra
.995 .765 .467 r
.84121 .30019 .84123 .27746 .83394 .26977 .83386 .2919 Metetra
.997 .768 .452 r
.83386 .2919 .83394 .26977 .82711 .27405 .82685 .29312 Metetra
.996 .776 .42 r
.82685 .29312 .82711 .27405 .82068 .28998 .82045 .31034 Metetra
.948 .75 .288 r
.82045 .31034 .82068 .28998 .81708 .37277 .81595 .37386 Metetra
.734 .639 .753 r
.81595 .37386 .81708 .37277 .80698 .31307 .80691 .33861 Metetra
.997 .768 .429 r
.80691 .33861 .80698 .31307 .79923 .30892 .79989 .35254 Metetra
.995 .755 .443 r
.79989 .35254 .79923 .30892 .79223 .32594 .79196 .34834 Metetra
.997 .769 .457 r
.79196 .34834 .79223 .32594 .78754 .40478 .78401 .34706 Metetra
.991 .732 .39 r
.78401 .34706 .78754 .40478 .77761 .35761 .77485 .31759 Metetra
.98 .723 .324 r
.77485 .31759 .77761 .35761 .76809 .32188 .76411 .24839 Metetra
.989 .73 .432 r
.76411 .24839 .76809 .32188 .75821 .27805 .75728 .28603 Metetra
.99 .799 .553 r
.75728 .28603 .75821 .27805 .74826 .23332 .74846 .27384 Metetra
.996 .76 .42 r
.74846 .27384 .74826 .23332 .74183 .29329 .74072 .29733 Metetra
.063 0 .347 r
.74072 .29733 .74183 .29329 .7356 .36922 .73433 .36942 Metetra
.547 .813 .995 r
.73433 .36942 .7356 .36922 .72589 .34562 .72507 .36044 Metetra
.865 .647 .605 r
.72507 .36044 .72589 .34562 .71272 .21047 .71107 .19723 Metetra
.897 .627 .52 r
.71107 .19723 .71272 .21047 .70273 .17916 .70493 .30098 Metetra
.988 .74 .461 r
.70493 .30098 .70273 .17916 .6929 .15727 .69215 .17659 Metetra
.995 .771 .48 r
.69215 .17659 .6929 .15727 .68332 .14942 .68246 .16585 Metetra
.978 .754 .53 r
.68246 .16585 .68332 .14942 .67306 .12056 .67187 .1243 Metetra
0 0 .391 r
.8647 .3425 .86602 .34636 .85809 .32137 .85648 .31166 Metetra
.949 .656 .209 r
.85648 .31166 .85809 .32137 .85093 .31272 .84859 .28856 Metetra
.988 .718 .374 r
.84859 .28856 .85093 .31272 .8436 .30274 .84123 .27746 Metetra
.988 .719 .383 r
.84123 .27746 .8436 .30274 .83599 .28887 .83394 .26977 Metetra
.985 .71 .397 r
.83394 .26977 .83599 .28887 .82901 .29024 .82711 .27405 Metetra
.979 .7 .419 r
.82711 .27405 .82901 .29024 .82137 .27974 .82068 .28998 Metetra
0 0 .097 r
.82068 .28998 .82137 .27974 .81557 .31276 .81708 .37277 Metetra
.989 .744 .47 r
.81708 .37277 .81557 .31276 .8104 .36454 .80698 .31307 Metetra
.991 .73 .406 r
.80698 .31307 .8104 .36454 .80139 .33188 .79923 .30892 Metetra
.984 .711 .42 r
.79923 .30892 .80139 .33188 .79412 .34277 .79223 .32594 Metetra
.935 .665 .503 r
.79223 .32594 .79412 .34277 .78612 .33944 .78754 .40478 Metetra
.991 .746 .459 r
.78754 .40478 .78612 .33944 .77777 .33027 .77761 .35761 Metetra
.988 .753 .491 r
.77761 .35761 .77777 .33027 .76767 .27857 .76809 .32188 Metetra
.989 .748 .473 r
.76809 .32188 .76767 .27857 .75818 .24361 .75821 .27805 Metetra
.988 .749 .485 r
.75821 .27805 .75818 .24361 .7496 .23634 .74826 .23332 Metetra
.773 .49 .507 r
.74826 .23332 .7496 .23634 .74126 .24025 .74183 .29329 Metetra
.991 .757 .38 r
.74183 .29329 .74126 .24025 .73686 .36901 .7356 .36922 Metetra
.62 .653 .861 r
.7356 .36922 .73686 .36901 .72623 .31609 .72589 .34562 Metetra
.948 .711 .547 r
.72589 .34562 .72623 .31609 .71405 .21277 .71272 .21047 Metetra
0 .057 .616 r
.71272 .21047 .71405 .21277 .7042 .18649 .70273 .17916 Metetra
.935 .62 .166 r
.70273 .17916 .7042 .18649 .694 .1509 .6929 .15727 Metetra
.993 .824 .569 r
.6929 .15727 .694 .1509 .68435 .13991 .68332 .14942 Metetra
.975 .771 .567 r
.68332 .14942 .68435 .13991 .67442 .12338 .67306 .12056 Metetra
.858 .554 .026 r
.86602 .34636 .86747 .35263 .85944 .32584 .85809 .32137 Metetra
.931 .577 .152 r
.85809 .32137 .85944 .32584 .85181 .30793 .85093 .31272 Metetra
.982 .82 .607 r
.85093 .31272 .85181 .30793 .84385 .28475 .8436 .30274 Metetra
.993 .767 .487 r
.8436 .30274 .84385 .28475 .83653 .27634 .83599 .28887 Metetra
.999 .788 .472 r
.83599 .28887 .83653 .27634 .8301 .28888 .82901 .29024 Metetra
.874 .858 .822 r
.82901 .29024 .8301 .28888 .82275 .28459 .82137 .27974 Metetra
.889 .587 .47 r
.82137 .27974 .82275 .28459 .81874 .35718 .81557 .31276 Metetra
.983 .72 .449 r
.81557 .31276 .81874 .35718 .81159 .36456 .8104 .36454 Metetra
.593 .563 .789 r
.8104 .36454 .81159 .36456 .80139 .30417 .80139 .33188 Metetra
.996 .766 .433 r
.80139 .33188 .80139 .30417 .79553 .34765 .79412 .34277 Metetra
.951 .601 .24 r
.79412 .34277 .79553 .34765 .78752 .34396 .78612 .33944 Metetra
.929 .569 .148 r
.78612 .33944 .78752 .34396 .77689 .27697 .77777 .33027 Metetra
.989 .746 .469 r
.77777 .33027 .77689 .27697 .76801 .25535 .76767 .27857 Metetra
.987 .755 .499 r
.76767 .27857 .76801 .25535 .75868 .22422 .75818 .24361 Metetra
.996 .771 .473 r
.75818 .24361 .75868 .22422 .74977 .20667 .7496 .23634 Metetra
.996 .764 .443 r
.7496 .23634 .74977 .20667 .74101 .19686 .74126 .24025 Metetra
.963 .746 .302 r
.74126 .24025 .74101 .19686 .73399 .24359 .73686 .36901 Metetra
.992 .744 .443 r
.73686 .36901 .73399 .24359 .72421 .21234 .72623 .31609 Metetra
.989 .741 .461 r
.72623 .31609 .72421 .21234 .71398 .16891 .71405 .21277 Metetra
.993 .752 .459 r
.71405 .21277 .71398 .16891 .70509 .17348 .7042 .18649 Metetra
.976 .759 .545 r
.7042 .18649 .70509 .17348 .69526 .15071 .694 .1509 Metetra
.558 .788 .985 r
.694 .1509 .69526 .15071 .68599 .1536 .68435 .13991 Metetra
.979 .69 .316 r
.68435 .13991 .68599 .1536 .67581 .12792 .67442 .12338 Metetra
.982 .76 .526 r
.86747 .35263 .86783 .33812 .86004 .31562 .85944 .32584 Metetra
.985 .776 .54 r
.85944 .32584 .86004 .31562 .8523 .2952 .85181 .30793 Metetra
.983 .766 .53 r
.85181 .30793 .8523 .2952 .84501 .28539 .84385 .28475 Metetra
0 .404 .846 r
.84385 .28475 .84501 .28539 .83731 .26908 .83653 .27634 Metetra
.987 .823 .435 r
.83653 .27634 .83731 .26908 .82982 .25875 .8301 .28888 Metetra
.995 .76 .45 r
.8301 .28888 .82982 .25875 .82215 .24667 .82275 .28459 Metetra
.982 .755 .348 r
.82275 .28459 .82215 .24667 .81532 .25524 .81874 .35718 Metetra
.994 .748 .426 r
.81874 .35718 .81532 .25524 .80783 .25223 .81159 .36456 Metetra
.991 .744 .448 r
.81159 .36456 .80783 .25223 .80095 .26631 .80139 .30417 Metetra
.992 .761 .392 r
.80139 .30417 .80095 .26631 .79323 .26392 .79553 .34765 Metetra
.994 .749 .432 r
.79553 .34765 .79323 .26392 .78601 .2771 .78752 .34396 Metetra
.989 .744 .467 r
.78752 .34396 .78601 .2771 .77675 .24292 .77689 .27697 Metetra
.993 .755 .465 r
.77689 .27697 .77675 .24292 .76816 .22764 .76801 .25535 Metetra
.99 .755 .484 r
.76801 .25535 .76816 .22764 .75967 .21808 .75868 .22422 Metetra
.975 .797 .598 r
.75868 .22422 .75967 .21808 .75101 .20743 .74977 .20667 Metetra
0 .341 .8 r
.74977 .20667 .75101 .20743 .74219 .19549 .74101 .19686 Metetra
.342 .091 .381 r
.74101 .19686 .74219 .19549 .73523 .24356 .73399 .24359 Metetra
.589 .582 .813 r
.73399 .24359 .73523 .24356 .72615 .234 .72421 .21234 Metetra
.974 .706 .296 r
.72421 .21234 .72615 .234 .71607 .19629 .71398 .16891 Metetra
.987 .716 .4 r
.71398 .16891 .71607 .19629 .70547 .14298 .70509 .17348 Metetra
.993 .758 .47 r
.70509 .17348 .70547 .14298 .6958 .12437 .69526 .15071 Metetra
.997 .768 .448 r
.69526 .15071 .6958 .12437 .68683 .13719 .68599 .1536 Metetra
.989 .767 .51 r
.68599 .1536 .68683 .13719 .67685 .11793 .67581 .12792 Metetra
.978 .769 .553 r
.86783 .33812 .86842 .32822 .86045 .30173 .86004 .31562 Metetra
.987 .767 .518 r
.86004 .31562 .86045 .30173 .85298 .28642 .8523 .2952 Metetra
.993 .793 .532 r
.8523 .2952 .85298 .28642 .84559 .27419 .84501 .28539 Metetra
.989 .776 .527 r
.84501 .28539 .84559 .27419 .83783 .25623 .83731 .26908 Metetra
.994 .779 .501 r
.83731 .26908 .83783 .25623 .83019 .24253 .82982 .25875 Metetra
.994 .771 .489 r
.82982 .25875 .83019 .24253 .82224 .22388 .82215 .24667 Metetra
.997 .769 .436 r
.82215 .24667 .82224 .22388 .81487 .21983 .81532 .25524 Metetra
.995 .758 .445 r
.81532 .25524 .81487 .21983 .80762 .2211 .80783 .25223 Metetra
.996 .763 .426 r
.80783 .25223 .80762 .2211 .80039 .22591 .80095 .26631 Metetra
.995 .756 .441 r
.80095 .26631 .80039 .22591 .79311 .23268 .79323 .26392 Metetra
.996 .763 .428 r
.79323 .26392 .79311 .23268 .78572 .24062 .78601 .2771 Metetra
.99 .751 .473 r
.78601 .2771 .78572 .24062 .77719 .22362 .77675 .24292 Metetra
.993 .767 .485 r
.77675 .24292 .77719 .22362 .76824 .19843 .76816 .22764 Metetra
.995 .761 .458 r
.76816 .22764 .76824 .19843 .75949 .18062 .75967 .21808 Metetra
.994 .757 .451 r
.75967 .21808 .75949 .18062 .75091 .17055 .75101 .20743 Metetra
.994 .757 .453 r
.75101 .20743 .75091 .17055 .74299 .18316 .74219 .19549 Metetra
.927 .765 .286 r
.74219 .19549 .74299 .18316 .73617 .23433 .73523 .24356 Metetra
.995 .798 .53 r
.73523 .24356 .73617 .23433 .72783 .24728 .72615 .234 Metetra
.951 .671 .222 r
.72615 .234 .72783 .24728 .71707 .18794 .71607 .19629 Metetra
.928 .726 .608 r
.71607 .19629 .71707 .18794 .70684 .14703 .70547 .14298 Metetra
.839 .478 0 r
.70547 .14298 .70684 .14703 .69733 .13388 .6958 .12437 Metetra
.969 .663 .386 r
.6958 .12437 .69733 .13388 .68824 .1421 .68683 .13719 Metetra
.886 .54 .05 r
.68683 .13719 .68824 .1421 .67805 .11472 .67685 .11793 Metetra
.987 .758 .506 r
.86842 .32822 .86857 .30976 .86112 .29322 .86045 .30173 Metetra
.985 .784 .551 r
.86045 .30173 .86112 .29322 .8538 .28035 .85298 .28642 Metetra
.983 .802 .582 r
.85298 .28642 .8538 .28035 .84646 .269 .84559 .27419 Metetra
.964 .789 .618 r
.84559 .27419 .84646 .269 .83911 .25922 .83783 .25623 Metetra
.775 .393 0 r
.83783 .25623 .83911 .25922 .83207 .25803 .83019 .24253 Metetra
.98 .699 .317 r
.83019 .24253 .83207 .25803 .82595 .2789 .82224 .22388 Metetra
.991 .731 .406 r
.82224 .22388 .82595 .2789 .81943 .29474 .81487 .21983 Metetra
.991 .733 .413 r
.81487 .21983 .81943 .29474 .81213 .29661 .80762 .2211 Metetra
.991 .733 .415 r
.80762 .2211 .81213 .29661 .80437 .29069 .80039 .22591 Metetra
.991 .732 .415 r
.80039 .22591 .80437 .29069 .79745 .30771 .79311 .23268 Metetra
.991 .733 .416 r
.79311 .23268 .79745 .30771 .7897 .30873 .78572 .24062 Metetra
.991 .733 .401 r
.78572 .24062 .7897 .30873 .78067 .28107 .77719 .22362 Metetra
.991 .732 .391 r
.77719 .22362 .78067 .28107 .77219 .26956 .76824 .19843 Metetra
.991 .733 .401 r
.76824 .19843 .77219 .26956 .7631 .245 .75949 .18062 Metetra
.991 .732 .404 r
.75949 .18062 .7631 .245 .75432 .23118 .75091 .17055 Metetra
.99 .73 .417 r
.75091 .17055 .75432 .23118 .74571 .22583 .74299 .18316 Metetra
.983 .719 .444 r
.74299 .18316 .74571 .22583 .73854 .26779 .73617 .23433 Metetra
.987 .72 .413 r
.73617 .23433 .73854 .26779 .72907 .24664 .72783 .24728 Metetra
.651 .544 .72 r
.72783 .24728 .72907 .24664 .71839 .18978 .71707 .18794 Metetra
.178 .26 .711 r
.71707 .18794 .71839 .18978 .70847 .1594 .70684 .14703 Metetra
.978 .685 .315 r
.70684 .14703 .70847 .1594 .69852 .13127 .69733 .13388 Metetra
.902 .936 .567 r
.69733 .13388 .69852 .13127 .68907 .12524 .68824 .1421 Metetra
.988 .765 .51 r
.68824 .1421 .68907 .12524 .67916 .10756 .67805 .11472 Metetra
.984 .709 .34 r
.86857 .30976 .87067 .32846 .86325 .31259 .86112 .29322 Metetra
.986 .711 .354 r
.86112 .29322 .86325 .31259 .85555 .29268 .8538 .28035 Metetra
.979 .69 .319 r
.8538 .28035 .85555 .29268 .84809 .27899 .84646 .269 Metetra
.975 .677 .302 r
.84646 .269 .84809 .27899 .84078 .27022 .83911 .25922 Metetra
.98 .686 .354 r
.83911 .25922 .84078 .27022 .83423 .27918 .83207 .25803 Metetra
.982 .708 .427 r
.83207 .25803 .83423 .27918 .82733 .28375 .82595 .2789 Metetra
.932 .607 .398 r
.82595 .2789 .82733 .28375 .82066 .29619 .81943 .29474 Metetra
.811 .329 .049 r
.81943 .29474 .82066 .29619 .81262 .28117 .81213 .29661 Metetra
.997 .777 .48 r
.81213 .29661 .81262 .28117 .80454 .26738 .80437 .29069 Metetra
.996 .771 .421 r
.80437 .29069 .80454 .26738 .79677 .26338 .79745 .30771 Metetra
.995 .756 .436 r
.79745 .30771 .79677 .26338 .78903 .26303 .7897 .30873 Metetra
.992 .751 .458 r
.7897 .30873 .78903 .26303 .78029 .24137 .78067 .28107 Metetra
.994 .756 .45 r
.78067 .28107 .78029 .24137 .77196 .23219 .77219 .26956 Metetra
.993 .754 .463 r
.77219 .26956 .77196 .23219 .76302 .21017 .7631 .245 Metetra
.994 .757 .456 r
.7631 .245 .76302 .21017 .75432 .19758 .75432 .23118 Metetra
.995 .76 .448 r
.75432 .23118 .75432 .19758 .74598 .19841 .74571 .22583 Metetra
.99 .768 .386 r
.74571 .22583 .74598 .19841 .7385 .22927 .73854 .26779 Metetra
.993 .755 .459 r
.73854 .26779 .7385 .22927 .72929 .21443 .72907 .24664 Metetra
.984 .746 .495 r
.72907 .24664 .72929 .21443 .71926 .17731 .71839 .18978 Metetra
.98 .765 .541 r
.71839 .18978 .71926 .17731 .70982 .1624 .70847 .1594 Metetra
0 0 .419 r
.70847 .1594 .70982 .1624 .70023 .14666 .69852 .13127 Metetra
.983 .697 .355 r
.69852 .13127 .70023 .14666 .69069 .13807 .68907 .12524 Metetra
.976 .685 .302 r
.68907 .12524 .69069 .13807 .68038 .10514 .67916 .10756 Metetra
.935 .8 .687 r
.87067 .32846 .87162 .32535 .86394 .30432 .86325 .31259 Metetra
.977 .776 .566 r
.86325 .31259 .86394 .30432 .85641 .28757 .85555 .29268 Metetra
.975 .804 .609 r
.85555 .29268 .85641 .28757 .84905 .27562 .84809 .27899 Metetra
.972 .846 .658 r
.84809 .27899 .84905 .27562 .84178 .26739 .84078 .27022 Metetra
.902 .899 .486 r
.84078 .27022 .84178 .26739 .83487 .2686 .83423 .27918 Metetra
.999 .799 .467 r
.83423 .27918 .83487 .2686 .82791 .27136 .82733 .28375 Metetra
.996 .793 .433 r
.82733 .28375 .82791 .27136 .82168 .29295 .82066 .29619 Metetra
.946 .815 .684 r
.82066 .29619 .82168 .29295 .81397 .28508 .81262 .28117 Metetra
.867 .502 .007 r
.81262 .28117 .81397 .28508 .80624 .27936 .80454 .26738 Metetra
.981 .688 .346 r
.80454 .26738 .80624 .27936 .79832 .27199 .79677 .26338 Metetra
.974 .666 .335 r
.79677 .26338 .79832 .27199 .79068 .2742 .78903 .26303 Metetra
.965 .673 .255 r
.78903 .26303 .79068 .2742 .78185 .25013 .78029 .24137 Metetra
.971 .663 .287 r
.78029 .24137 .78185 .25013 .77345 .23947 .77196 .23219 Metetra
.927 .615 .147 r
.77196 .23219 .77345 .23947 .76477 .22447 .76302 .21017 Metetra
.981 .695 .33 r
.76302 .21017 .76477 .22447 .75604 .21099 .75432 .19758 Metetra
.982 .692 .368 r
.75432 .19758 .75604 .21099 .74758 .20868 .74598 .19841 Metetra
.954 .66 .44 r
.74598 .19841 .74758 .20868 .74126 .27383 .7385 .22927 Metetra
.99 .727 .391 r
.7385 .22927 .74126 .27383 .73045 .2116 .72929 .21443 Metetra
.85 .711 .708 r
.72929 .21443 .73045 .2116 .72022 .16782 .71926 .17731 Metetra
.991 .791 .54 r
.71926 .17731 .72022 .16782 .71061 .14668 .70982 .1624 Metetra
.994 .774 .498 r
.70982 .1624 .71061 .14668 .70066 .11737 .70023 .14666 Metetra
.995 .762 .456 r
.70023 .14666 .70066 .11737 .69131 .11348 .69069 .13807 Metetra
.989 .757 .49 r
.69069 .13807 .69131 .11348 .68124 .08856 .68038 .10514 Metetra
.932 .774 .662 r
.87162 .32535 .87253 .32147 .86509 .30498 .86394 .30432 Metetra
.313 .484 .868 r
.86394 .30432 .86509 .30498 .85775 .29171 .85641 .28757 Metetra
.894 .536 .061 r
.85641 .28757 .85775 .29171 .85031 .27828 .84905 .27562 Metetra
.841 .427 0 r
.84905 .27562 .85031 .27828 .84286 .26619 .84178 .26739 Metetra
.821 .998 .777 r
.84178 .26739 .84286 .26619 .83568 .26159 .83487 .2686 Metetra
1 .825 .5 r
.83487 .2686 .83568 .26159 .82948 .28019 .82791 .27136 Metetra
.957 .66 .429 r
.82791 .27136 .82948 .28019 .8232 .30053 .82168 .29295 Metetra
.968 .652 .274 r
.82168 .29295 .8232 .30053 .81481 .27773 .81397 .28508 Metetra
.997 .812 .537 r
.81397 .28508 .81481 .27773 .80704 .27072 .80624 .27936 Metetra
.996 .801 .527 r
.80624 .27936 .80704 .27072 .7994 .26938 .79832 .27199 Metetra
.964 .937 .635 r
.79832 .27199 .7994 .26938 .79135 .26144 .79068 .2742 Metetra
.985 .768 .529 r
.79068 .2742 .79135 .26144 .78304 .24989 .78185 .25013 Metetra
.606 .791 .969 r
.78185 .25013 .78304 .24989 .77466 .23939 .77345 .23947 Metetra
.572 .705 .932 r
.77345 .23947 .77466 .23939 .76578 .21909 .76477 .22447 Metetra
.98 .814 .605 r
.76477 .22447 .76578 .21909 .7571 .2067 .75604 .21099 Metetra
.993 .867 .596 r
.75604 .21099 .7571 .2067 .74857 .20207 .74758 .20868 Metetra
0 0 .105 r
.74758 .20868 .74857 .20207 .74107 .23163 .74126 .27383 Metetra
.986 .745 .482 r
.74126 .27383 .74107 .23163 .73206 .22244 .73045 .2116 Metetra
.903 .626 .123 r
.73045 .2116 .73206 .22244 .72188 .1808 .72022 .16782 Metetra
.973 .684 .288 r
.72022 .16782 .72188 .1808 .71232 .16131 .71061 .14668 Metetra
.97 .688 .276 r
.71061 .14668 .71232 .16131 .70268 .14349 .70066 .11737 Metetra
.988 .715 .385 r
.70066 .11737 .70268 .14349 .6931 .13266 .69131 .11348 Metetra
.982 .705 .326 r
.69131 .11348 .6931 .13266 .68316 .11336 .68124 .08856 Metetra
.795 .445 0 r
.87253 .32147 .87384 .3252 .86605 .30183 .86509 .30498 Metetra
.949 .818 .681 r
.86509 .30498 .86605 .30183 .85848 .28396 .85775 .29171 Metetra
.987 .791 .555 r
.85775 .29171 .85848 .28396 .85121 .27357 .85031 .27828 Metetra
.976 .814 .616 r
.85031 .27828 .85121 .27357 .84395 .26515 .84286 .26619 Metetra
.85 .952 .881 r
.84286 .26619 .84395 .26515 .83714 .26806 .83568 .26159 Metetra
.946 .636 .418 r
.83568 .26159 .83714 .26806 .83034 .274 .82948 .28019 Metetra
.933 .812 .354 r
.82948 .28019 .83034 .274 .82409 .29446 .8232 .30053 Metetra
.961 .777 .609 r
.8232 .30053 .82409 .29446 .81652 .28944 .81481 .27773 Metetra
.98 .686 .331 r
.81481 .27773 .81652 .28944 .80882 .28418 .80704 .27072 Metetra
.982 .694 .362 r
.80704 .27072 .80882 .28418 .80091 .27677 .7994 .26938 Metetra
.966 .648 .268 r
.7994 .26938 .80091 .27677 .79299 .27201 .79135 .26144 Metetra
.975 .676 .299 r
.79135 .26144 .79299 .27201 .78412 .24679 .78304 .24989 Metetra
.962 .852 .686 r
.78304 .24989 .78412 .24679 .77568 .23464 .77466 .23939 Metetra
.956 .792 .638 r
.77466 .23939 .77568 .23464 .76683 .21449 .76578 .21909 Metetra
.977 .825 .625 r
.76578 .21909 .76683 .21449 .75802 .19838 .7571 .2067 Metetra
.998 .809 .523 r
.7571 .2067 .75802 .19838 .74932 .18843 .74857 .20207 Metetra
.982 .789 .381 r
.74857 .20207 .74932 .18843 .74144 .206 .74107 .23163 Metetra
.995 .764 .461 r
.74107 .23163 .74144 .206 .73205 .18408 .73206 .22244 Metetra
.99 .75 .473 r
.73206 .22244 .73205 .18408 .72235 .15597 .72188 .1808 Metetra
.993 .762 .474 r
.72188 .1808 .72235 .15597 .7131 .1455 .71232 .16131 Metetra
.993 .772 .5 r
.71232 .16131 .7131 .1455 .70329 .12059 .70268 .14349 Metetra
.995 .767 .468 r
.70268 .14349 .70329 .12059 .69371 .10823 .6931 .13266 Metetra
.994 .763 .475 r
.6931 .13266 .69371 .10823 .68379 .08806 .68316 .11336 Metetra
.989 .76 .498 r
.87384 .3252 .87395 .3064 .86667 .29223 .86605 .30183 Metetra
.985 .777 .544 r
.86605 .30183 .86667 .29223 .85936 .27917 .85848 .28396 Metetra
.981 .819 .607 r
.85848 .28396 .85936 .27917 .85207 .26812 .85121 .27357 Metetra
.989 .82 .581 r
.85121 .27357 .85207 .26812 .84457 .25482 .84395 .26515 Metetra
.999 .799 .473 r
.84395 .26515 .84457 .25482 .83697 .24088 .83714 .26806 Metetra
.996 .764 .435 r
.83714 .26806 .83697 .24088 .82893 .21971 .83034 .274 Metetra
.995 .754 .416 r
.83034 .274 .82893 .21971 .82178 .21953 .82409 .29446 Metetra
.994 .749 .431 r
.82409 .29446 .82178 .21953 .81464 .2219 .81652 .28944 Metetra
.994 .75 .433 r
.81652 .28944 .81464 .2219 .80703 .21688 .80882 .28418 Metetra
.994 .75 .434 r
.80882 .28418 .80703 .21688 .79938 .21356 .80091 .27677 Metetra
.994 .751 .433 r
.80091 .27677 .79938 .21356 .79156 .20909 .79299 .27201 Metetra
.993 .749 .445 r
.79299 .27201 .79156 .20909 .78321 .19493 .78412 .24679 Metetra
.994 .752 .442 r
.78412 .24679 .78321 .19493 .77483 .18232 .77568 .23464 Metetra
.993 .751 .447 r
.77568 .23464 .77483 .18232 .76628 .16851 .76683 .21449 Metetra
.994 .753 .447 r
.76683 .21449 .76628 .16851 .75776 .15834 .75802 .19838 Metetra
.995 .756 .446 r
.75802 .19838 .75776 .15834 .7491 .14795 .74932 .18843 Metetra
.995 .759 .421 r
.74932 .18843 .7491 .14795 .74095 .15575 .74144 .206 Metetra
.993 .752 .449 r
.74144 .206 .74095 .15575 .73196 .14371 .73205 .18408 Metetra
.993 .753 .46 r
.73205 .18408 .73196 .14371 .72243 .11915 .72235 .15597 Metetra
.995 .757 .449 r
.72235 .15597 .72243 .11915 .71304 .10221 .7131 .1455 Metetra
.993 .753 .455 r
.7131 .1455 .71304 .10221 .70369 .09108 .70329 .12059 Metetra
.995 .761 .458 r
.70329 .12059 .70369 .09108 .69426 .08196 .69371 .10823 Metetra
.994 .761 .472 r
.69371 .10823 .69426 .08196 .68442 .06361 .68379 .08806 Metetra
.992 .775 .511 r
.87395 .3064 .8744 .29395 .86728 .28255 .86667 .29223 Metetra
.991 .784 .53 r
.86667 .29223 .86728 .28255 .85984 .26676 .85936 .27917 Metetra
.994 .779 .503 r
.85936 .27917 .85984 .26676 .85259 .25604 .85207 .26812 Metetra
.992 .778 .511 r
.85207 .26812 .85259 .25604 .84484 .23737 .84457 .25482 Metetra
.994 .768 .486 r
.84457 .25482 .84484 .23737 .83729 .22409 .83697 .24088 Metetra
.99 .764 .501 r
.83697 .24088 .83729 .22409 .82957 .20906 .82893 .21971 Metetra
.999 .795 .483 r
.82893 .21971 .82957 .20906 .82208 .20104 .82178 .21953 Metetra
.998 .774 .451 r
.82178 .21953 .82208 .20104 .81534 .21174 .81464 .2219 Metetra
.998 .795 .503 r
.81464 .2219 .81534 .21174 .80801 .2126 .80703 .21688 Metetra
.993 .859 .595 r
.80703 .21688 .80801 .2126 .80049 .21197 .79938 .21356 Metetra
.919 .944 .8 r
.79938 .21356 .80049 .21197 .7929 .2127 .79156 .20909 Metetra
.843 .469 0 r
.79156 .20909 .7929 .2127 .78455 .19824 .78321 .19493 Metetra
.841 .454 0 r
.78321 .19493 .78455 .19824 .77606 .18303 .77483 .18232 Metetra
.127 .439 .876 r
.77483 .18232 .77606 .18303 .76741 .16646 .76628 .16851 Metetra
.928 .874 .763 r
.76628 .16851 .76741 .16646 .75884 .15457 .75776 .15834 Metetra
.974 .844 .651 r
.75776 .15834 .75884 .15457 .7502 .14442 .7491 .14795 Metetra
.959 .904 .531 r
.7491 .14795 .7502 .14442 .74243 .16283 .74095 .15575 Metetra
.957 .634 .229 r
.74095 .15575 .74243 .16283 .73355 .15434 .73196 .14371 Metetra
.958 .664 .234 r
.73196 .14371 .73355 .15434 .72439 .14128 .72243 .11915 Metetra
.986 .711 .353 r
.72243 .11915 .72439 .14128 .71478 .11811 .71304 .10221 Metetra
.983 .698 .342 r
.71304 .10221 .71478 .11811 .70538 .10536 .70369 .09108 Metetra
.981 .693 .339 r
.70369 .09108 .70538 .10536 .69616 .10436 .69426 .08196 Metetra
.985 .711 .352 r
.69426 .08196 .69616 .10436 .68612 .07928 .68442 .06361 Metetra
0 .076 .624 r
.8744 .29395 .87559 .2953 .86814 .27766 .86728 .28255 Metetra
.967 .797 .62 r
.86728 .28255 .86814 .27766 .86093 .26606 .85984 .26676 Metetra
.771 .827 .896 r
.85984 .26676 .86093 .26606 .8535 .25174 .85259 .25604 Metetra
.951 .788 .645 r
.85259 .25604 .8535 .25174 .84602 .23814 .84484 .23737 Metetra
.122 .414 .861 r
.84484 .23737 .84602 .23814 .83949 .24582 .83729 .22409 Metetra
.986 .713 .354 r
.83729 .22409 .83949 .24582 .83313 .25977 .82957 .20906 Metetra
.991 .73 .398 r
.82957 .20906 .83313 .25977 .82668 .27494 .82208 .20104 Metetra
.991 .732 .415 r
.82208 .20104 .82668 .27494 .81917 .27019 .81534 .21174 Metetra
.991 .731 .407 r
.81534 .21174 .81917 .27019 .81136 .26149 .80801 .2126 Metetra
.99 .728 .403 r
.80801 .2126 .81136 .26149 .8036 .2564 .80049 .21197 Metetra
.99 .727 .403 r
.80049 .21197 .8036 .2564 .79559 .24829 .7929 .2127 Metetra
.989 .724 .381 r
.7929 .2127 .79559 .24829 .78729 .23596 .78455 .19824 Metetra
.989 .725 .382 r
.78455 .19824 .78729 .23596 .77899 .22631 .77606 .18303 Metetra
.99 .727 .386 r
.77606 .18303 .77899 .22631 .77043 .21311 .76741 .16646 Metetra
.99 .728 .392 r
.76741 .16646 .77043 .21311 .76172 .19908 .75884 .15457 Metetra
.99 .727 .393 r
.75884 .15457 .76172 .19908 .75334 .19725 .7502 .14442 Metetra
.989 .727 .417 r
.7502 .14442 .75334 .19725 .74491 .19858 .74243 .16283 Metetra
.989 .723 .388 r
.74243 .16283 .74491 .19858 .736 .1902 .73355 .15434 Metetra
.989 .723 .383 r
.73355 .15434 .736 .1902 .7265 .16788 .72439 .14128 Metetra
.986 .717 .354 r
.72439 .14128 .7265 .16788 .71708 .15153 .71478 .11811 Metetra
.989 .722 .381 r
.71478 .11811 .71708 .15153 .70712 .12151 .70538 .10536 Metetra
.983 .698 .368 r
.70538 .10536 .70712 .12151 .69759 .10995 .69616 .10436 Metetra
.866 .54 .025 r
.69616 .10436 .69759 .10995 .68763 .08795 .68612 .07928 Metetra
.755 .411 0 r
.87559 .2953 .87689 .29894 .86972 .28649 .86814 .27766 Metetra
.968 .664 .268 r
.86814 .27766 .86972 .28649 .86274 .27935 .86093 .26606 Metetra
.978 .692 .31 r
.86093 .26606 .86274 .27935 .85532 .26525 .8535 .25174 Metetra
.979 .693 .315 r
.8535 .25174 .85532 .26525 .84834 .26179 .84602 .23814 Metetra
.987 .714 .403 r
.84602 .23814 .84834 .26179 .84124 .2581 .83949 .24582 Metetra
.976 .687 .407 r
.83949 .24582 .84124 .2581 .83462 .26669 .83313 .25977 Metetra
.955 .645 .402 r
.83313 .25977 .83462 .26669 .82799 .27786 .82668 .27494 Metetra
.895 .487 .079 r
.82668 .27494 .82799 .27786 .82024 .26785 .81917 .27019 Metetra
.948 .874 .73 r
.81917 .27019 .82024 .26785 .81243 .2589 .81136 .26149 Metetra
.969 .898 .697 r
.81136 .26149 .81243 .2589 .80464 .25294 .8036 .2564 Metetra
.977 .857 .656 r
.8036 .2564 .80464 .25294 .79677 .24774 .79559 .24829 Metetra
.719 .808 .92 r
.79559 .24829 .79677 .24774 .78838 .23313 .78729 .23596 Metetra
.959 .863 .7 r
.78729 .23596 .78838 .23313 .77989 .21859 .77899 .22631 Metetra
.989 .799 .556 r
.77899 .22631 .77989 .21859 .77145 .20814 .77043 .21311 Metetra
.977 .816 .617 r
.77043 .21311 .77145 .20814 .76282 .19583 .76172 .19908 Metetra
.984 .9 .639 r
.76172 .19908 .76282 .19583 .75437 .1917 .75334 .19725 Metetra
.998 .851 .539 r
.75334 .19725 .75437 .1917 .74602 .19468 .74491 .19858 Metetra
.981 .855 .641 r
.74491 .19858 .74602 .19468 .73725 .19 .736 .1902 Metetra
.619 .662 .87 r
.736 .1902 .73725 .19 .72748 .15917 .7265 .16788 Metetra
.988 .792 .551 r
.7265 .16788 .72748 .15917 .71821 .14745 .71708 .15153 Metetra
.919 .762 .671 r
.71708 .15153 .71821 .14745 .70854 .12659 .70712 .12151 Metetra
.931 .577 .149 r
.70712 .12151 .70854 .12659 .69879 .10738 .69759 .10995 Metetra
.901 .794 .733 r
.69759 .10995 .69879 .10738 .68862 .07688 .68763 .08795 Metetra
.993 .776 .502 r
.87689 .29894 .8773 .28593 .86987 .26824 .86972 .28649 Metetra
.996 .77 .469 r
.86972 .28649 .86987 .26824 .86264 .25582 .86274 .27935 Metetra
.994 .761 .469 r
.86274 .27935 .86264 .25582 .85562 .24899 .85532 .26525 Metetra
.997 .775 .467 r
.85532 .26525 .85562 .24899 .84847 .24167 .84834 .26179 Metetra
.997 .769 .458 r
.84834 .26179 .84847 .24167 .84164 .24296 .84124 .2581 Metetra
.998 .783 .438 r
.84124 .2581 .84164 .24296 .83474 .24504 .83462 .26669 Metetra
.997 .771 .427 r
.83462 .26669 .83474 .24504 .82857 .26532 .82799 .27786 Metetra
.995 .781 .5 r
.82799 .27786 .82857 .26532 .82111 .26136 .82024 .26785 Metetra
.992 .813 .562 r
.82024 .26785 .82111 .26136 .81323 .25038 .81243 .2589 Metetra
.997 .803 .521 r
.81243 .2589 .81323 .25038 .80556 .24673 .80464 .25294 Metetra
.996 .825 .553 r
.80464 .25294 .80556 .24673 .79761 .23946 .79677 .24774 Metetra
.988 .792 .551 r
.79677 .24774 .79761 .23946 .78945 .22984 .78838 .23313 Metetra
.951 .825 .683 r
.78838 .23313 .78945 .22984 .78098 .21561 .77989 .21859 Metetra
.96 .856 .693 r
.77989 .21859 .78098 .21561 .77241 .20162 .77145 .20814 Metetra
.988 .809 .574 r
.77145 .20814 .77241 .20162 .76375 .18814 .76282 .19583 Metetra
.998 .815 .527 r
.76282 .19583 .76375 .18814 .75549 .18875 .75437 .1917 Metetra
.969 .928 .614 r
.75437 .1917 .75549 .18875 .74719 .19256 .74602 .19468 Metetra
.949 .93 .748 r
.74602 .19468 .74719 .19256 .73813 .17903 .73725 .19 Metetra
.977 .766 .552 r
.73725 .19 .73813 .17903 .7287 .15803 .72748 .15917 Metetra
.834 .87 .871 r
.72748 .15917 .7287 .15803 .71902 .13289 .71821 .14745 Metetra
.991 .772 .51 r
.71821 .14745 .71902 .13289 .7093 .10949 .70854 .12659 Metetra
.993 .77 .495 r
.70854 .12659 .7093 .10949 .69965 .09257 .69879 .10738 Metetra
.985 .765 .522 r
.69879 .10738 .69965 .09257 .68973 .07067 .68862 .07688 Metetra
.962 .668 .247 r
.8773 .28593 .87897 .29606 .87128 .27377 .86987 .26824 Metetra
.931 .598 .151 r
.86987 .26824 .87128 .27377 .86412 .26258 .86264 .25582 Metetra
.964 .643 .261 r
.86264 .25582 .86412 .26258 .85671 .24835 .85562 .24899 Metetra
.756 .888 .937 r
.85562 .24899 .85671 .24835 .84994 .24827 .84847 .24167 Metetra
.968 .647 .322 r
.84847 .24167 .84994 .24827 .84315 .25033 .84164 .24296 Metetra
.971 .656 .336 r
.84164 .24296 .84315 .25033 .83695 .26704 .83474 .24504 Metetra
.983 .709 .422 r
.83474 .24504 .83695 .26704 .83067 .28516 .82857 .26532 Metetra
.986 .71 .372 r
.82857 .26532 .83067 .28516 .82216 .25867 .82111 .26136 Metetra
.95 .849 .708 r
.82111 .26136 .82216 .25867 .81448 .25206 .81323 .25038 Metetra
.782 .292 0 r
.81323 .25038 .81448 .25206 .80676 .24708 .80556 .24673 Metetra
.12 .562 .92 r
.80556 .24673 .80676 .24708 .7988 .2392 .79761 .23946 Metetra
.611 .809 .976 r
.79761 .23946 .7988 .2392 .79075 .23223 .78945 .22984 Metetra
.666 .262 0 r
.78945 .22984 .79075 .23223 .78239 .22046 .78098 .21561 Metetra
.909 .558 .094 r
.78098 .21561 .78239 .22046 .77369 .20313 .77241 .20162 Metetra
0 .024 .576 r
.77241 .20162 .77369 .20313 .765 .1886 .76375 .18814 Metetra
.428 0 0 r
.76375 .18814 .765 .1886 .75669 .18769 .75549 .18875 Metetra
.645 .944 .711 r
.75549 .18875 .75669 .18769 .74841 .19187 .74719 .19256 Metetra
.745 .817 .908 r
.74719 .19256 .74841 .19187 .73934 .17782 .73813 .17903 Metetra
.801 .762 .817 r
.73813 .17903 .73934 .17782 .72977 .15235 .7287 .15803 Metetra
.958 .782 .622 r
.7287 .15803 .72977 .15235 .72019 .12981 .71902 .13289 Metetra
.914 .786 .706 r
.71902 .13289 .72019 .12981 .71054 .1085 .7093 .10949 Metetra
.789 .801 .862 r
.7093 .10949 .71054 .1085 .70083 .08926 .69965 .09257 Metetra
.928 .798 .696 r
.69965 .09257 .70083 .08926 .69111 .07415 .68973 .07067 Metetra
.814 .725 .767 r
.87897 .29606 .88 .2946 .87257 .2769 .87128 .27377 Metetra
.831 .445 0 r
.87128 .27377 .87257 .2769 .86541 .2658 .86412 .26258 Metetra
.781 .41 0 r
.86412 .26258 .86541 .2658 .85831 .25737 .85671 .24835 Metetra
.976 .673 .34 r
.85671 .24835 .85831 .25737 .85129 .25246 .84994 .24827 Metetra
.948 .592 .277 r
.84994 .24827 .85129 .25246 .84445 .25334 .84315 .25033 Metetra
.886 .541 .388 r
.84315 .25033 .84445 .25334 .83797 .26416 .83695 .26704 Metetra
.83695 .26704 .83797 .26416 .83123 .2724 .83067 .28516 Metetra
.983 .765 .532 r
.83067 .28516 .83123 .2724 .82299 .25118 .82216 .25867 Metetra
.996 .809 .536 r
.82216 .25867 .82299 .25118 .81536 .24534 .81448 .25206 Metetra
.997 .819 .542 r
.81448 .25206 .81536 .24534 .80767 .24075 .80676 .24708 Metetra
.994 .818 .561 r
.80676 .24708 .80767 .24075 .7997 .23246 .7988 .2392 Metetra
.995 .817 .55 r
.7988 .2392 .7997 .23246 .79147 .22065 .79075 .23223 Metetra
.994 .784 .51 r
.79075 .23223 .79147 .22065 .78277 .19999 .78239 .22046 Metetra
.994 .765 .48 r
.78239 .22046 .78277 .19999 .7744 .19018 .77369 .20313 Metetra
.993 .779 .507 r
.77369 .20313 .7744 .19018 .76579 .17719 .765 .1886 Metetra
.999 .795 .483 r
.765 .1886 .76579 .17719 .75759 .17858 .75669 .18769 Metetra
1 .813 .481 r
.75669 .18769 .75759 .17858 .74974 .19428 .74841 .19187 Metetra
.692 .277 0 r
.74841 .19187 .74974 .19428 .74079 .18369 .73934 .17782 Metetra
.865 .546 .027 r
.73934 .17782 .74079 .18369 .73115 .15603 .72977 .15235 Metetra
.728 .383 0 r
.72977 .15235 .73115 .15603 .72141 .12861 .72019 .12981 Metetra
.799 .763 .82 r
.72019 .12981 .72141 .12861 .7118 .10822 .71054 .1085 Metetra
.631 .707 .9 r
.71054 .1085 .7118 .10822 .70269 .10962 .70083 .08926 Metetra
.985 .707 .349 r
.70083 .08926 .70269 .10962 .69262 .08245 .69111 .07415 Metetra
.643 .673 .864 r
.88 .2946 .88111 .29439 .87381 .27914 .87257 .2769 Metetra
.694 .28 0 r
.87257 .2769 .87381 .27914 .86667 .2682 .86541 .2658 Metetra
.8 .374 0 r
.86541 .2658 .86667 .2682 .85933 .25533 .85831 .25737 Metetra
.953 .912 .738 r
.85831 .25737 .85933 .25533 .85191 .24234 .85129 .25246 Metetra
1 .798 .479 r
.85129 .25246 .85191 .24234 .84466 .23452 .84445 .25334 Metetra
.997 .775 .428 r
.84445 .25334 .84466 .23452 .83713 .22308 .83797 .26416 Metetra
.995 .756 .424 r
.83797 .26416 .83713 .22308 .83025 .22707 .83123 .2724 Metetra
.993 .752 .449 r
.83123 .2724 .83025 .22707 .8232 .23058 .82299 .25118 Metetra
.996 .769 .461 r
.82299 .25118 .8232 .23058 .81583 .22955 .81536 .24534 Metetra
.997 .777 .471 r
.81536 .24534 .81583 .22955 .80827 .2274 .80767 .24075 Metetra
.996 .781 .49 r
.80767 .24075 .80827 .2274 .80039 .22072 .7997 .23246 Metetra
.994 .783 .509 r
.7997 .23246 .80039 .22072 .79217 .20859 .79147 .22065 Metetra
.988 .774 .525 r
.79147 .22065 .79217 .20859 .78367 .19239 .78277 .19999 Metetra
.994 .806 .546 r
.78277 .19999 .78367 .19239 .77489 .1719 .7744 .19018 Metetra
.995 .77 .479 r
.7744 .19018 .77489 .1719 .76629 .15839 .76579 .17719 Metetra
.998 .775 .452 r
.76579 .17719 .76629 .15839 .75769 .14823 .75759 .17858 Metetra
.996 .765 .421 r
.75759 .17858 .75769 .14823 .74958 .15495 .74974 .19428 Metetra
.995 .756 .444 r
.74974 .19428 .74958 .15495 .7409 .15046 .74079 .18369 Metetra
.993 .755 .466 r
.74079 .18369 .7409 .15046 .73176 .13674 .73115 .15603 Metetra
.99 .762 .497 r
.73115 .15603 .73176 .13674 .72209 .11013 .72141 .12861 Metetra
.993 .767 .49 r
.72141 .12861 .72209 .11013 .71274 .0974 .7118 .10822 Metetra
1 .802 .482 r
.7118 .10822 .71274 .0974 .70349 .09314 .70269 .10962 Metetra
.989 .766 .508 r
.70269 .10962 .70349 .09314 .69361 .07181 .69262 .08245 Metetra
.747 .752 .856 r
.88111 .29439 .88218 .29373 .87468 .27447 .87381 .27914 Metetra
.98 .818 .611 r
.87381 .27914 .87468 .27447 .86727 .2583 .86667 .2682 Metetra
.992 .784 .526 r
.86667 .2682 .86727 .2583 .86002 .24662 .85933 .25533 Metetra
.99 .789 .539 r
.85933 .25533 .86002 .24662 .85276 .2366 .85191 .24234 Metetra
.992 .819 .57 r
.85191 .24234 .85276 .2366 .84538 .22604 .84466 .23452 Metetra
.992 .793 .537 r
.84466 .23452 .84538 .22604 .83762 .20953 .83713 .22308 Metetra
.999 .786 .454 r
.83713 .22308 .83762 .20953 .8302 .20182 .83025 .22707 Metetra
.997 .765 .437 r
.83025 .22707 .8302 .20182 .82337 .20897 .8232 .23058 Metetra
.997 .769 .45 r
.8232 .23058 .82337 .20897 .81605 .20856 .81583 .22955 Metetra
.997 .769 .453 r
.81583 .22955 .81605 .20856 .80865 .20935 .80827 .2274 Metetra
.997 .772 .468 r
.80827 .2274 .80865 .20935 .80098 .20658 .80039 .22072 Metetra
.995 .777 .494 r
.80039 .22072 .80098 .20658 .79281 .19544 .79217 .20859 Metetra
.992 .776 .508 r
.79217 .20859 .79281 .19544 .78433 .17923 .78367 .19239 Metetra
.989 .772 .517 r
.78367 .19239 .78433 .17923 .77593 .16765 .77489 .1719 Metetra
.972 .824 .639 r
.77489 .1719 .77593 .16765 .7674 .15559 .76629 .15839 Metetra
.958 .864 .704 r
.76629 .15839 .7674 .15559 .75896 .14926 .75769 .14823 Metetra
.735 .247 .083 r
.75769 .14823 .75896 .14926 .75072 .15242 .74958 .15495 Metetra
.966 .915 .707 r
.74958 .15495 .75072 .15242 .74235 .15647 .7409 .15046 Metetra
.938 .603 .169 r
.7409 .15046 .74235 .15647 .73313 .14015 .73176 .13674 Metetra
0 0 .316 r
.73176 .13674 .73313 .14015 .72362 .11857 .72209 .11013 Metetra
.964 .651 .254 r
.72209 .11013 .72362 .11857 .71422 .10443 .71274 .0974 Metetra
.965 .637 .278 r
.71274 .0974 .71422 .10443 .70489 .09706 .70349 .09314 Metetra
.788 .434 0 r
.70349 .09314 .70489 .09706 .69513 .08043 .69361 .07181 Metetra
.991 .763 .49 r
.88218 .29373 .88229 .27544 .87519 .26315 .87468 .27447 Metetra
.99 .776 .521 r
.87468 .27447 .87519 .26315 .86812 .25313 .86727 .2583 Metetra
.982 .812 .599 r
.86727 .2583 .86812 .25313 .86106 .24487 .86002 .24662 Metetra
.912 .861 .778 r
.86002 .24662 .86106 .24487 .85399 .23845 .85276 .2366 Metetra
.612 .177 0 r
.85276 .2366 .85399 .23845 .84745 .24442 .84538 .22604 Metetra
.983 .706 .333 r
.84538 .22604 .84745 .24442 .84091 .25312 .83762 .20953 Metetra
.99 .727 .391 r
.83762 .20953 .84091 .25312 .83466 .27065 .8302 .20182 Metetra
.991 .731 .409 r
.8302 .20182 .83466 .27065 .82673 .25597 .82337 .20897 Metetra
.99 .728 .4 r
.82337 .20897 .82673 .25597 .81907 .24886 .81605 .20856 Metetra
.99 .725 .398 r
.81605 .20856 .81907 .24886 .8114 .24423 .80865 .20935 Metetra
.989 .723 .391 r
.80865 .20935 .8114 .24423 .80356 .23853 .80098 .20658 Metetra
.989 .721 .377 r
.80098 .20658 .80356 .23853 .79542 .22878 .79281 .19544 Metetra
.988 .722 .372 r
.79281 .19544 .79542 .22878 .78722 .22008 .78433 .17923 Metetra
.99 .726 .385 r
.78433 .17923 .78722 .22008 .77879 .20883 .77593 .16765 Metetra
.99 .726 .385 r
.77593 .16765 .77879 .20883 .77004 .19222 .7674 .15559 Metetra
.989 .723 .388 r
.7674 .15559 .77004 .19222 .76112 .17408 .75896 .14926 Metetra
.987 .713 .39 r
.75896 .14926 .76112 .17408 .75309 .18366 .75072 .15242 Metetra
.988 .719 .396 r
.75072 .15242 .75309 .18366 .74434 .17763 .74235 .15647 Metetra
.985 .709 .347 r
.74235 .15647 .74434 .17763 .73501 .1586 .73313 .14015 Metetra
.981 .703 .323 r
.73313 .14015 .73501 .1586 .72575 .14555 .72362 .11857 Metetra
.987 .716 .366 r
.72362 .11857 .72575 .14555 .71611 .12435 .71422 .10443 Metetra
.985 .706 .361 r
.71422 .10443 .71611 .12435 .70622 .09909 .70489 .09706 Metetra
0 0 .443 r
.70489 .09706 .70622 .09909 .69617 .07158 .69513 .08043 Metetra
.899 .549 .073 r
.88229 .27544 .88365 .27992 .87578 .25348 .87519 .26315 Metetra
.994 .788 .519 r
.87519 .26315 .87578 .25348 .86872 .24332 .86812 .25313 Metetra
.996 .79 .512 r
.86812 .25313 .86872 .24332 .86159 .23338 .86106 .24487 Metetra
.997 .786 .493 r
.86106 .24487 .86159 .23338 .85461 .22832 .85399 .23845 Metetra
.998 .801 .456 r
.85399 .23845 .85461 .22832 .84833 .23914 .84745 .24442 Metetra
.983 .85 .467 r
.84745 .24442 .84833 .23914 .84125 .23651 .84091 .25312 Metetra
.994 .779 .409 r
.84091 .25312 .84125 .23651 .83502 .25395 .83466 .27065 Metetra
.994 .77 .487 r
.83466 .27065 .83502 .25395 .82714 .2397 .82673 .25597 Metetra
.997 .775 .474 r
.82673 .25597 .82714 .2397 .81948 .23217 .81907 .24886 Metetra
.997 .775 .467 r
.81907 .24886 .81948 .23217 .81158 .22169 .8114 .24423 Metetra
.996 .767 .456 r
.8114 .24423 .81158 .22169 .80382 .21714 .80356 .23853 Metetra
.996 .767 .465 r
.80356 .23853 .80382 .21714 .79528 .19704 .79542 .22878 Metetra
.995 .759 .448 r
.79542 .22878 .79528 .19704 .78707 .18701 .78722 .22008 Metetra
.995 .758 .449 r
.78722 .22008 .78707 .18701 .77876 .17749 .77879 .20883 Metetra
.994 .758 .457 r
.77879 .20883 .77876 .17749 .77022 .16534 .77004 .19222 Metetra
.994 .76 .465 r
.77004 .19222 .77022 .16534 .762 .16462 .76112 .17408 Metetra
.996 .812 .454 r
.76112 .17408 .762 .16462 .75376 .16783 .75309 .18366 Metetra
.997 .779 .475 r
.75309 .18366 .75376 .16783 .74512 .16404 .74434 .17763 Metetra
.992 .775 .51 r
.74434 .17763 .74512 .16404 .73557 .13779 .73501 .1586 Metetra
.995 .768 .471 r
.73501 .1586 .73557 .13779 .72627 .12261 .72575 .14555 Metetra
.993 .763 .477 r
.72575 .14555 .72627 .12261 .71643 .09397 .71611 .12435 Metetra
.993 .757 .466 r
.71611 .12435 .71643 .09397 .70697 .08109 .70622 .09909 Metetra
.99 .764 .5 r
.70622 .09909 .70697 .08109 .69705 .05728 .69617 .07158 Metetra
.77 .475 0 r
.88365 .27992 .88507 .28536 .87767 .26759 .87578 .25348 Metetra
.981 .696 .329 r
.87578 .25348 .87767 .26759 .8706 .25735 .86872 .24332 Metetra
.981 .696 .329 r
.86872 .24332 .8706 .25735 .86357 .24965 .86159 .23338 Metetra
.984 .703 .357 r
.86159 .23338 .86357 .24965 .85674 .24766 .85461 .22832 Metetra
.984 .707 .403 r
.85461 .22832 .85674 .24766 .84975 .24451 .84833 .23914 Metetra
.958 .618 .259 r
.84833 .23914 .84975 .24451 .84369 .26259 .84125 .23651 Metetra
.986 .714 .415 r
.84125 .23651 .84369 .26259 .83694 .26957 .83502 .25395 Metetra
.981 .698 .324 r
.83502 .25395 .83694 .26957 .82893 .25261 .82714 .2397 Metetra
.98 .69 .331 r
.82714 .2397 .82893 .25261 .82123 .24453 .81948 .23217 Metetra
.978 .686 .315 r
.81948 .23217 .82123 .24453 .81344 .23684 .81158 .22169 Metetra
.983 .698 .353 r
.81158 .22169 .81344 .23684 .80589 .23698 .80382 .21714 Metetra
.982 .707 .33 r
.80382 .21714 .80589 .23698 .79738 .21816 .79528 .19704 Metetra
.986 .71 .359 r
.79528 .19704 .79738 .21816 .78917 .20863 .78707 .18701 Metetra
.986 .711 .361 r
.78707 .18701 .78917 .20863 .78062 .19368 .77876 .17749 Metetra
.982 .699 .335 r
.77876 .17749 .78062 .19368 .77216 .18363 .77022 .16534 Metetra
.985 .704 .372 r
.77022 .16534 .77216 .18363 .7635 .17191 .762 .16462 Metetra
.968 .646 .328 r
.762 .16462 .7635 .17191 .75542 .17926 .75376 .16783 Metetra
.978 .68 .333 r
.75376 .16783 .75542 .17926 .74656 .16941 .74512 .16404 Metetra
.827 .507 0 r
.74512 .16404 .74656 .16941 .73715 .14731 .73557 .13779 Metetra
.966 .66 .258 r
.73557 .13779 .73715 .14731 .72766 .12647 .72627 .12261 Metetra
0 0 .264 r
.72627 .12261 .72766 .12647 .71834 .11418 .71643 .09397 Metetra
.985 .707 .35 r
.71643 .09397 .71834 .11418 .70848 .08901 .70697 .08109 Metetra
.933 .622 .161 r
.70697 .08109 .70848 .08901 .69873 .07128 .69705 .05728 Metetra
.944 .791 .661 r
.88507 .28536 .88598 .2816 .8788 .26788 .87767 .26759 Metetra
.353 .623 .954 r
.87767 .26759 .8788 .26788 .87154 .25404 .8706 .25735 Metetra
.976 .854 .654 r
.8706 .25735 .87154 .25404 .86449 .24561 .86357 .24965 Metetra
.995 .865 .587 r
.86357 .24965 .86449 .24561 .85762 .24247 .85674 .24766 Metetra
.997 .839 .56 r
.85674 .24766 .85762 .24247 .85062 .23898 .84975 .24451 Metetra
.925 .817 .355 r
.84975 .24451 .85062 .23898 .84406 .2467 .84369 .26259 Metetra
.998 .78 .439 r
.84369 .26259 .84406 .2467 .83807 .26863 .83694 .26957 Metetra
.783 .766 .837 r
.83694 .26957 .83807 .26863 .83018 .25436 .82893 .25261 Metetra
.68 .209 0 r
.82893 .25261 .83018 .25436 .82241 .24437 .82123 .24453 Metetra
.534 .808 .996 r
.82123 .24453 .82241 .24437 .81446 .23288 .81344 .23684 Metetra
.993 .88 .582 r
.81344 .23684 .81446 .23288 .80663 .2267 .80589 .23698 Metetra
.988 .78 .536 r
.80589 .23698 .80663 .2267 .79835 .21269 .79738 .21816 Metetra
.989 .824 .586 r
.79738 .21816 .79835 .21269 .78994 .19795 .78917 .20863 Metetra
.992 .784 .523 r
.78917 .20863 .78994 .19795 .78112 .1758 .78062 .19368 Metetra
.996 .772 .474 r
.78062 .19368 .78112 .1758 .77248 .16067 .77216 .18363 Metetra
.995 .765 .463 r
.77216 .18363 .77248 .16067 .76396 .15141 .7635 .17191 Metetra
.997 .774 .437 r
.7635 .17191 .76396 .15141 .75598 .16061 .75542 .17926 Metetra
.996 .772 .471 r
.75542 .17926 .75598 .16061 .74769 .16595 .74656 .16941 Metetra
.93 .793 .687 r
.74656 .16941 .74769 .16595 .73823 .14232 .73715 .14731 Metetra
.962 .798 .632 r
.73715 .14731 .73823 .14232 .7291 .13171 .72766 .12647 Metetra
.928 .579 .143 r
.72766 .12647 .7291 .13171 .71952 .11124 .71834 .11418 Metetra
.903 .778 .713 r
.71834 .11418 .71952 .11124 .70995 .09518 .70848 .08901 Metetra
.926 .594 .138 r
.70848 .08901 .70995 .09518 .6998 .06354 .69873 .07128 Metetra
.973 .682 .288 r
.88598 .2816 .88773 .29313 .88021 .27318 .8788 .26788 Metetra
.913 .578 .109 r
.8788 .26788 .88021 .27318 .87295 .25928 .87154 .25404 Metetra
.943 .602 .185 r
.87154 .25404 .87295 .25928 .86569 .24685 .86449 .24561 Metetra
.689 .162 0 r
.86449 .24561 .86569 .24685 .85856 .23862 .85762 .24247 Metetra
.992 .865 .606 r
.85762 .24247 .85856 .23862 .85239 .2514 .85062 .23898 Metetra
.98 .689 .384 r
.85062 .23898 .85239 .2514 .84593 .26086 .84406 .2467 Metetra
.974 .69 .424 r
.84406 .2467 .84593 .26086 .83889 .26153 .83807 .26863 Metetra
.986 .797 .566 r
.83807 .26863 .83889 .26153 .83125 .2521 .83018 .25436 Metetra
.94 .865 .738 r
.83018 .25436 .83125 .2521 .82346 .24158 .82241 .24437 Metetra
.951 .847 .703 r
.82241 .24437 .82346 .24158 .81553 .23025 .81446 .23288 Metetra
.967 .892 .699 r
.81446 .23288 .81553 .23025 .80769 .22341 .80663 .2267 Metetra
.954 .828 .68 r
.80663 .2267 .80769 .22341 .79943 .20975 .79835 .21269 Metetra
.943 .827 .701 r
.79835 .21269 .79943 .20975 .79105 .19556 .78994 .19795 Metetra
.886 .775 .734 r
.78994 .19795 .79105 .19556 .78244 .17832 .78112 .1758 Metetra
.67 .274 0 r
.78112 .1758 .78244 .17832 .77374 .16144 .77248 .16067 Metetra
0 .327 .786 r
.77248 .16067 .77374 .16144 .7652 .15165 .76396 .15141 Metetra
.507 .003 0 r
.76396 .15141 .7652 .15165 .75723 .1607 .75598 .16061 Metetra
.333 0 0 r
.75598 .16061 .75723 .1607 .74855 .1549 .74769 .16595 Metetra
.986 .775 .537 r
.74769 .16595 .74855 .1549 .7392 .13368 .73823 .14232 Metetra
.995 .802 .534 r
.73823 .14232 .7392 .13368 .72987 .11653 .7291 .13171 Metetra
.992 .772 .503 r
.7291 .13171 .72987 .11653 .72053 .10303 .71952 .11124 Metetra
.989 .796 .554 r
.71952 .11124 .72053 .10303 .71103 .08871 .70995 .09518 Metetra
.954 .768 .613 r
.70995 .09518 .71103 .08871 .70138 .07401 .6998 .06354 Metetra
0 0 .563 r
.88773 .29313 .88897 .29532 .88158 .27767 .88021 .27318 Metetra
.882 .535 .041 r
.88021 .27318 .88158 .27767 .87413 .26025 .87295 .25928 Metetra
0 .31 .802 r
.87295 .25928 .87413 .26025 .86692 .24872 .86569 .24685 Metetra
.7 .244 0 r
.86569 .24685 .86692 .24872 .85971 .23891 .85856 .23862 Metetra
.592 .169 .207 r
.85856 .23862 .85971 .23891 .8527 .23473 .85239 .2514 Metetra
.997 .778 .429 r
.85239 .2514 .8527 .23473 .84505 .21998 .84593 .26086 Metetra
.995 .755 .429 r
.84593 .26086 .84505 .21998 .838 .21928 .83889 .26153 Metetra
.995 .754 .438 r
.83889 .26153 .838 .21928 .83073 .21645 .83125 .2521 Metetra
.995 .756 .444 r
.83125 .2521 .83073 .21645 .82351 .21718 .82346 .24158 Metetra
.995 .763 .459 r
.82346 .24158 .82351 .21718 .81587 .21156 .81553 .23025 Metetra
.997 .771 .464 r
.81553 .23025 .81587 .21156 .80791 .20137 .80769 .22341 Metetra
.995 .765 .467 r
.80769 .22341 .80791 .20137 .79969 .18773 .79943 .20975 Metetra
.995 .765 .468 r
.79943 .20975 .79969 .18773 .79153 .17808 .79105 .19556 Metetra
.994 .768 .487 r
.79105 .19556 .79153 .17808 .78287 .15898 .78244 .17832 Metetra
.994 .767 .48 r
.78244 .17832 .78287 .15898 .77446 .14895 .77374 .16144 Metetra
.996 .784 .497 r
.77374 .16144 .77446 .14895 .76608 .14262 .7652 .15165 Metetra
.996 .815 .456 r
.7652 .15165 .76608 .14262 .75816 .1523 .75723 .1607 Metetra
.998 .809 .522 r
.75723 .1607 .75816 .1523 .74923 .13899 .74855 .1549 Metetra
.992 .77 .5 r
.74855 .1549 .74923 .13899 .73987 .11667 .7392 .13368 Metetra
.994 .771 .488 r
.7392 .13368 .73987 .11667 .73078 .10611 .72987 .11653 Metetra
.994 .79 .522 r
.72987 .11653 .73078 .10611 .72128 .08682 .72053 .10303 Metetra
.995 .774 .487 r
.72053 .10303 .72128 .08682 .71205 .08003 .71103 .08871 Metetra
.992 .797 .544 r
.71103 .08871 .71205 .08003 .70231 .06172 .70138 .07401 Metetra
.993 .763 .48 r
.88897 .29532 .88898 .2755 .88151 .25604 .88158 .27767 Metetra
.993 .761 .474 r
.88158 .27767 .88151 .25604 .87411 .23894 .87413 .26025 Metetra
.995 .764 .465 r
.87413 .26025 .87411 .23894 .86703 .22945 .86692 .24872 Metetra
.996 .767 .467 r
.86692 .24872 .86703 .22945 .85988 .22022 .85971 .23891 Metetra
.997 .771 .458 r
.85971 .23891 .85988 .22022 .85267 .21167 .8527 .23473 Metetra
.994 .762 .466 r
.8527 .23473 .85267 .21167 .84531 .20216 .84505 .21998 Metetra
.997 .774 .452 r
.84505 .21998 .84531 .20216 .8381 .19757 .838 .21928 Metetra
.997 .768 .449 r
.838 .21928 .8381 .19757 .83107 .1992 .83073 .21645 Metetra
.998 .776 .451 r
.83073 .21645 .83107 .1992 .8242 .20684 .82351 .21718 Metetra
.998 .794 .499 r
.82351 .21718 .8242 .20684 .81665 .2028 .81587 .21156 Metetra
.995 .797 .529 r
.81587 .21156 .81665 .2028 .80891 .19718 .80791 .20137 Metetra
.971 .822 .639 r
.80791 .20137 .80891 .19718 .80076 .18488 .79969 .18773 Metetra
.961 .863 .696 r
.79969 .18773 .80076 .18488 .79241 .17044 .79153 .17808 Metetra
.982 .788 .569 r
.79153 .17808 .79241 .17044 .78403 .15776 .78287 .15898 Metetra
.857 .884 .857 r
.78287 .15898 .78403 .15776 .77552 .14484 .77446 .14895 Metetra
.988 .858 .618 r
.77446 .14895 .77552 .14484 .76714 .13824 .76608 .14262 Metetra
.966 .877 .486 r
.76608 .14262 .76714 .13824 .75896 .1406 .75816 .1523 Metetra
.995 .784 .51 r
.75816 .1523 .75896 .1406 .75033 .13494 .74923 .13899 Metetra
.943 .792 .664 r
.74923 .13899 .75033 .13494 .74128 .12114 .73987 .11667 Metetra
.916 .551 .112 r
.73987 .11667 .74128 .12114 .732 .10464 .73078 .10611 Metetra
.839 .794 .808 r
.73078 .10611 .732 .10464 .7227 .09138 .72128 .08682 Metetra
.933 .567 .167 r
.72128 .08682 .7227 .09138 .71345 .08413 .71205 .08003 Metetra
.839 .477 0 r
.71205 .08003 .71345 .08413 .7036 .06184 .70231 .06172 Metetra
.458 .544 .857 r
.88898 .2755 .89012 .27594 .8831 .26439 .88151 .25604 Metetra
.948 .644 .203 r
.88151 .25604 .8831 .26439 .87598 .25265 .87411 .23894 Metetra
.981 .694 .326 r
.87411 .23894 .87598 .25265 .86902 .24557 .86703 .22945 Metetra
.983 .701 .341 r
.86703 .22945 .86902 .24557 .8619 .23702 .85988 .22022 Metetra
.984 .703 .346 r
.85988 .22022 .8619 .23702 .85492 .23324 .85267 .21167 Metetra
.986 .712 .359 r
.85267 .21167 .85492 .23324 .84872 .24711 .84531 .20216 Metetra
.99 .727 .392 r
.84531 .20216 .84872 .24711 .84209 .25525 .8381 .19757 Metetra
.991 .729 .401 r
.8381 .19757 .84209 .25525 .83457 .24755 .83107 .1992 Metetra
.99 .727 .404 r
.83107 .1992 .83457 .24755 .82681 .23733 .8242 .20684 Metetra
.988 .72 .382 r
.8242 .20684 .82681 .23733 .81912 .23072 .81665 .2028 Metetra
.988 .718 .377 r
.81665 .2028 .81912 .23072 .8114 .22602 .80891 .19718 Metetra
.988 .718 .368 r
.80891 .19718 .8114 .22602 .80314 .21197 .80076 .18488 Metetra
.987 .717 .361 r
.80076 .18488 .80314 .21197 .79486 .19959 .79241 .17044 Metetra
.988 .718 .368 r
.79241 .17044 .79486 .19959 .78646 .18719 .78403 .15776 Metetra
.988 .718 .368 r
.78403 .15776 .78646 .18719 .77792 .17424 .77552 .14484 Metetra
.988 .718 .377 r
.77552 .14484 .77792 .17424 .76938 .16415 .76714 .13824 Metetra
.987 .714 .386 r
.76714 .13824 .76938 .16415 .7609 .15913 .75896 .1406 Metetra
.985 .704 .358 r
.75896 .1406 .7609 .15913 .75252 .16077 .75033 .13494 Metetra
.987 .714 .36 r
.75033 .13494 .75252 .16077 .74315 .13885 .74128 .12114 Metetra
.982 .701 .328 r
.74128 .12114 .74315 .13885 .73438 .13794 .732 .10464 Metetra
.988 .72 .373 r
.732 .10464 .73438 .13794 .7246 .11094 .7227 .09138 Metetra
.985 .705 .357 r
.7227 .09138 .7246 .11094 .71497 .09195 .71345 .08413 Metetra
.935 .622 .166 r
.71345 .08413 .71497 .09195 .70525 .07419 .7036 .06184 Metetra
.919 .577 .12 r
.89012 .27594 .89152 .28092 .88427 .26531 .8831 .26439 Metetra
0 .326 .812 r
.8831 .26439 .88427 .26531 .87706 .25181 .87598 .25265 Metetra
.813 .903 .904 r
.87598 .25265 .87706 .25181 .87 .24268 .86902 .24557 Metetra
.966 .858 .682 r
.86902 .24557 .87 .24268 .86297 .23584 .8619 .23702 Metetra
.875 .964 .852 r
.8619 .23702 .86297 .23584 .85632 .23824 .85492 .23324 Metetra
.94 .612 .383 r
.85492 .23324 .85632 .23824 .85004 .25038 .84872 .24711 Metetra
.92 .552 .308 r
.84872 .24711 .85004 .25038 .84376 .26537 .84209 .25525 Metetra
.975 .674 .302 r
.84209 .25525 .84376 .26537 .83568 .24617 .83457 .24755 Metetra
.877 .871 .828 r
.83457 .24755 .83568 .24617 .82798 .23699 .82681 .23733 Metetra
.613 .868 .991 r
.82681 .23733 .82798 .23699 .82018 .22789 .81912 .23072 Metetra
.976 .896 .676 r
.81912 .23072 .82018 .22789 .81245 .22278 .8114 .22602 Metetra
.953 .828 .683 r
.8114 .22602 .81245 .22278 .80424 .20947 .80314 .21197 Metetra
.939 .848 .726 r
.80314 .21197 .80424 .20947 .79607 .19947 .79486 .19959 Metetra
.566 .743 .959 r
.79486 .19959 .79607 .19947 .78756 .18431 .78646 .18719 Metetra
.949 .843 .704 r
.78646 .18719 .78756 .18431 .77914 .17393 .77792 .17424 Metetra
.623 .817 .975 r
.77792 .17424 .77914 .17393 .77042 .15903 .76938 .16415 Metetra
.995 .845 .578 r
.76938 .16415 .77042 .15903 .76235 .16444 .7609 .15913 Metetra
.954 .608 .28 r
.7609 .15913 .76235 .16444 .75377 .1607 .75252 .16077 Metetra
.585 .646 .877 r
.75252 .16077 .75377 .1607 .74449 .14099 .74315 .13885 Metetra
.852 .394 .042 r
.74315 .13885 .74449 .14099 .73557 .13564 .73438 .13794 Metetra
.865 .756 .741 r
.73438 .13794 .73557 .13564 .72568 .10486 .7246 .11094 Metetra
.977 .801 .599 r
.7246 .11094 .72568 .10486 .7161 .08696 .71497 .09195 Metetra
.972 .812 .626 r
.71497 .09195 .7161 .08696 .70652 .07342 .70525 .07419 Metetra
.924 .603 .137 r
.89152 .28092 .89299 .28724 .88588 .27415 .88427 .26531 Metetra
.962 .658 .243 r
.88427 .26531 .88588 .27415 .87885 .26396 .87706 .25181 Metetra
.978 .687 .315 r
.87706 .25181 .87885 .26396 .87182 .25553 .87 .24268 Metetra
.98 .691 .33 r
.87 .24268 .87182 .25553 .86479 .24864 .86297 .23584 Metetra
.982 .692 .365 r
.86297 .23584 .86479 .24864 .85786 .24582 .85632 .23824 Metetra
.964 .654 .386 r
.85632 .23824 .85786 .24582 .85096 .24548 .85004 .25038 Metetra
.931 .835 .387 r
.85004 .25038 .85096 .24548 .8446 .25862 .84376 .26537 Metetra
.976 .787 .584 r
.84376 .26537 .8446 .25862 .83678 .2447 .83568 .24617 Metetra
.893 .886 .818 r
.83568 .24617 .83678 .2447 .82915 .23658 .82798 .23699 Metetra
.674 .841 .964 r
.82798 .23699 .82915 .23658 .82137 .22775 .82018 .22789 Metetra
.439 .817 .991 r
.82018 .22789 .82137 .22775 .81351 .21961 .81245 .22278 Metetra
.954 .834 .686 r
.81245 .22278 .81351 .21961 .80547 .20998 .80424 .20947 Metetra
.123 .508 .909 r
.80424 .20947 .80547 .20998 .79727 .1993 .79607 .19947 Metetra
.604 .719 .926 r
.79607 .19947 .79727 .1993 .78868 .18196 .78756 .18431 Metetra
.943 .871 .737 r
.78756 .18431 .78868 .18196 .7798 .15996 .77914 .17393 Metetra
.994 .777 .498 r
.77914 .17393 .7798 .15996 .77145 .15402 .77042 .15903 Metetra
.99 .866 .516 r
.77042 .15903 .77145 .15402 .76339 .15919 .76235 .16444 Metetra
.997 .847 .569 r
.76235 .16444 .76339 .15919 .75469 .15152 .75377 .1607 Metetra
.987 .785 .548 r
.75377 .1607 .75469 .15152 .74547 .13308 .74449 .14099 Metetra
.998 .814 .526 r
.74449 .14099 .74547 .13308 .73647 .12463 .73557 .13564 Metetra
.979 .767 .548 r
.73557 .13564 .73647 .12463 .72671 .09738 .72568 .10486 Metetra
.985 .797 .569 r
.72568 .10486 .72671 .09738 .71746 .0894 .7161 .08696 Metetra
.715 .29 0 r
.7161 .08696 .71746 .0894 .70758 .06587 .70652 .07342 Metetra
.853 .492 0 r
.89299 .28724 .89433 .29111 .88711 .27606 .88588 .27415 Metetra
.628 .196 0 r
.88588 .27415 .88711 .27606 .88009 .26594 .87885 .26396 Metetra
.717 .27 0 r
.87885 .26396 .88009 .26594 .87318 .2595 .87182 .25553 Metetra
.921 .552 .127 r
.87182 .25553 .87318 .2595 .86602 .25021 .86479 .24864 Metetra
.776 .281 0 r
.86479 .24864 .86602 .25021 .85885 .24252 .85786 .24582 Metetra
.988 .896 .608 r
.85786 .24582 .85885 .24252 .85217 .2465 .85096 .24548 Metetra
.746 .337 .275 r
.85096 .24548 .85217 .2465 .8456 .25512 .8446 .25862 Metetra
.958 .822 .667 r
.8446 .25862 .8456 .25512 .83794 .24424 .83678 .2447 Metetra
.688 .864 .965 r
.83678 .2447 .83794 .24424 .83019 .23357 .82915 .23658 Metetra
.968 .862 .681 r
.82915 .23658 .83019 .23357 .82253 .22718 .82137 .22775 Metetra
.723 .88 .954 r
.82137 .22775 .82253 .22718 .8149 .2238 .81351 .21961 Metetra
.91 .542 .096 r
.81351 .21961 .8149 .2238 .8065 .20589 .80547 .20998 Metetra
.979 .838 .634 r
.80547 .20998 .8065 .20589 .79807 .18968 .79727 .1993 Metetra
.989 .785 .537 r
.79727 .1993 .79807 .18968 .78989 .1816 .78868 .18196 Metetra
.66 .677 .855 r
.78868 .18196 .78989 .1816 .78116 .16334 .7798 .15996 Metetra
.903 .505 .09 r
.7798 .15996 .78116 .16334 .77259 .15156 .77145 .15402 Metetra
.923 .946 .602 r
.77145 .15402 .77259 .15156 .76424 .14874 .76339 .15919 Metetra
.998 .795 .505 r
.76339 .15919 .76424 .14874 .75594 .15138 .75469 .15152 Metetra
.592 .686 .907 r
.75469 .15152 .75594 .15138 .74671 .1327 .74547 .13308 Metetra
.624 .859 .987 r
.74547 .13308 .74671 .1327 .73756 .11931 .73647 .12463 Metetra
.951 .778 .632 r
.73647 .12463 .73756 .11931 .72785 .09328 .72671 .09738 Metetra
.986 .859 .629 r
.72671 .09738 .72785 .09328 .71852 .08232 .71746 .0894 Metetra
.975 .787 .587 r
.71746 .0894 .71852 .08232 .70895 .06856 .70758 .06587 Metetra
.969 .802 .621 r
.89433 .29111 .89518 .28641 .88802 .27213 .88711 .27606 Metetra
.977 .831 .633 r
.88711 .27606 .88802 .27213 .88101 .26218 .88009 .26594 Metetra
.986 .853 .624 r
.88009 .26594 .88101 .26218 .8739 .25174 .87318 .2595 Metetra
.994 .801 .536 r
.87318 .2595 .8739 .25174 .86673 .24209 .86602 .25021 Metetra
.996 .801 .525 r
.86602 .25021 .86673 .24209 .85974 .23746 .85885 .24252 Metetra
.994 .855 .51 r
.85885 .24252 .85974 .23746 .85305 .24104 .85217 .2465 Metetra
.983 .847 .464 r
.85217 .2465 .85305 .24104 .8466 .25168 .8456 .25512 Metetra
.968 .84 .662 r
.8456 .25512 .8466 .25168 .83885 .23876 .83794 .24424 Metetra
.987 .818 .587 r
.83794 .24424 .83885 .23876 .83119 .22968 .83019 .23357 Metetra
.987 .858 .624 r
.83019 .23357 .83119 .22968 .82346 .2215 .82253 .22718 Metetra
.998 .836 .551 r
.82253 .22718 .82346 .2215 .81562 .21324 .8149 .2238 Metetra
.99 .78 .529 r
.8149 .2238 .81562 .21324 .80748 .20092 .8065 .20589 Metetra
.972 .808 .619 r
.8065 .20589 .80748 .20092 .79915 .18662 .79807 .18968 Metetra
.972 .871 .678 r
.79807 .18968 .79915 .18662 .79076 .17322 .78989 .1816 Metetra
.986 .788 .555 r
.78989 .1816 .79076 .17322 .78217 .15795 .78116 .16334 Metetra
.986 .821 .595 r
.78116 .16334 .78217 .15795 .77367 .14759 .77259 .15156 Metetra
.992 .876 .606 r
.77259 .15156 .77367 .14759 .7655 .14927 .76424 .14874 Metetra
.525 0 0 r
.76424 .14874 .7655 .14927 .75708 .14839 .75594 .15138 Metetra
.931 .812 .707 r
.75594 .15138 .75708 .14839 .74767 .12417 .74671 .1327 Metetra
.993 .798 .541 r
.74671 .1327 .74767 .12417 .73854 .11098 .73756 .11931 Metetra
.976 .778 .571 r
.73756 .11931 .73854 .11098 .72916 .09431 .72785 .09328 Metetra
0 .201 .698 r
.72785 .09328 .72916 .09431 .71994 .08673 .71852 .08232 Metetra
.894 .528 .06 r
.71852 .08232 .71994 .08673 .71028 .0697 .70895 .06856 Metetra
.658 .283 0 r
.89518 .28641 .89645 .28903 .88948 .27821 .88802 .27213 Metetra
.947 .618 .196 r
.88802 .27213 .88948 .27821 .8824 .26682 .88101 .26218 Metetra
.916 .565 .112 r
.88101 .26218 .8824 .26682 .87532 .25711 .8739 .25174 Metetra
.938 .598 .168 r
.8739 .25174 .87532 .25711 .86823 .24881 .86673 .24209 Metetra
.965 .641 .268 r
.86673 .24209 .86823 .24881 .86103 .24019 .85974 .23746 Metetra
.911 .514 .225 r
.85974 .23746 .86103 .24019 .85357 .22842 .85305 .24104 Metetra
.996 .79 .427 r
.85305 .24104 .85357 .22842 .8464 .22429 .8466 .25168 Metetra
.995 .76 .453 r
.8466 .25168 .8464 .22429 .83944 .2269 .83885 .23876 Metetra
.997 .785 .496 r
.83885 .23876 .83944 .2269 .83186 .21902 .83119 .22968 Metetra
.997 .79 .502 r
.83119 .22968 .83186 .21902 .82429 .21381 .82346 .2215 Metetra
.996 .807 .535 r
.82346 .2215 .82429 .21381 .81671 .21089 .81562 .21324 Metetra
.934 .849 .736 r
.81562 .21324 .81671 .21089 .80843 .19502 .80748 .20092 Metetra
.983 .808 .589 r
.80748 .20092 .80843 .19502 .80001 .17838 .79915 .18662 Metetra
.992 .796 .544 r
.79915 .18662 .80001 .17838 .79169 .16645 .79076 .17322 Metetra
.986 .801 .573 r
.79076 .17322 .79169 .16645 .78325 .15445 .78217 .15795 Metetra
.973 .852 .662 r
.78217 .15795 .78325 .15445 .77471 .14265 .77367 .14759 Metetra
.996 .863 .544 r
.77367 .14759 .77471 .14265 .76654 .14383 .7655 .14927 Metetra
.998 .85 .548 r
.7655 .14927 .76654 .14383 .75816 .14365 .75708 .14839 Metetra
.95 .786 .643 r
.75708 .14839 .75816 .14365 .74887 .12255 .74767 .12417 Metetra
.884 .859 .811 r
.74767 .12417 .74887 .12255 .73951 .10229 .73854 .11098 Metetra
.99 .793 .547 r
.73854 .11098 .73951 .10229 .73024 .08846 .72916 .09431 Metetra
.995 .833 .571 r
.72916 .09431 .73024 .08846 .72107 .08186 .71994 .08673 Metetra
.973 .816 .627 r
.71994 .08673 .72107 .08186 .71128 .06033 .71028 .0697 Metetra
.994 .789 .522 r
.89645 .28903 .89704 .27976 .88985 .26463 .88948 .27821 Metetra
.995 .776 .49 r
.88948 .27821 .88985 .26463 .88284 .25438 .8824 .26682 Metetra
.996 .78 .492 r
.8824 .26682 .88284 .25438 .87579 .2447 .87532 .25711 Metetra
.997 .782 .489 r
.87532 .25711 .87579 .2447 .86832 .22892 .86823 .24881 Metetra
.996 .767 .461 r
.86823 .24881 .86832 .22892 .86136 .22451 .86103 .24019 Metetra
.995 .772 .481 r
.86103 .24019 .86136 .22451 .85352 .20489 .85357 .22842 Metetra
.996 .765 .446 r
.85357 .22842 .85352 .20489 .84614 .19594 .8464 .22429 Metetra
.996 .762 .43 r
.8464 .22429 .84614 .19594 .83966 .20726 .83944 .2269 Metetra
.996 .769 .46 r
.83944 .2269 .83966 .20726 .8324 .20567 .83186 .21902 Metetra
.998 .783 .476 r
.83186 .21902 .8324 .20567 .82493 .20197 .82429 .21381 Metetra
.999 .79 .478 r
.82429 .21381 .82493 .20197 .81738 .19934 .81671 .21089 Metetra
.992 .78 .515 r
.81671 .21089 .81738 .19934 .80916 .18435 .80843 .19502 Metetra
.991 .782 .524 r
.80843 .19502 .80916 .18435 .80076 .16764 .80001 .17838 Metetra
.995 .788 .512 r
.80001 .17838 .80076 .16764 .79239 .15427 .79169 .16645 Metetra
.996 .783 .501 r
.79169 .16645 .79239 .15427 .78396 .14173 .78325 .15445 Metetra
.996 .782 .497 r
.78325 .15445 .78396 .14173 .7755 .13165 .77471 .14265 Metetra
.999 .799 .473 r
.77471 .14265 .7755 .13165 .7675 .13652 .76654 .14383 Metetra
1 .826 .511 r
.76654 .14383 .7675 .13652 .76013 .16286 .75816 .14365 Metetra
.98 .702 .32 r
.75816 .14365 .76013 .16286 .75055 .13418 .74887 .12255 Metetra
.966 .671 .259 r
.74887 .12255 .75055 .13418 .7409 .1061 .73951 .10229 Metetra
.861 .483 0 r
.73951 .10229 .7409 .1061 .73166 .09287 .73024 .08846 Metetra
.929 .558 .155 r
.73024 .08846 .73166 .09287 .72244 .08459 .72107 .08186 Metetra
0 0 .364 r
.72107 .08186 .72244 .08459 .71273 .06547 .71128 .06033 Metetra
.86 .516 .005 r
.89704 .27976 .89842 .28423 .89135 .27143 .88985 .26463 Metetra
.954 .632 .216 r
.88985 .26463 .89135 .27143 .88391 .25329 .88284 .25438 Metetra
.847 .864 .855 r
.88284 .25438 .88391 .25329 .87684 .24309 .87579 .2447 Metetra
.866 .797 .781 r
.87579 .2447 .87684 .24309 .86982 .23566 .86832 .22892 Metetra
.965 .641 .27 r
.86832 .22892 .86982 .23566 .86341 .24159 .86136 .22451 Metetra
.978 .699 .307 r
.86136 .22451 .86341 .24159 .85648 .23988 .85352 .20489 Metetra
.989 .722 .376 r
.85352 .20489 .85648 .23988 .84969 .24334 .84614 .19594 Metetra
.99 .726 .404 r
.84614 .19594 .84969 .24334 .84187 .22847 .83966 .20726 Metetra
.986 .71 .371 r
.83966 .20726 .84187 .22847 .83438 .22223 .8324 .20567 Metetra
.984 .701 .355 r
.8324 .20567 .83438 .22223 .82702 .22101 .82493 .20197 Metetra
.985 .706 .364 r
.82493 .20197 .82702 .22101 .8194 .21724 .81738 .19934 Metetra
.982 .702 .328 r
.81738 .19934 .8194 .21724 .81129 .20503 .80916 .18435 Metetra
.983 .707 .335 r
.80916 .18435 .81129 .20503 .80315 .19479 .80076 .16764 Metetra
.987 .716 .359 r
.80076 .16764 .80315 .19479 .79449 .17484 .79239 .15427 Metetra
.984 .707 .345 r
.79239 .15427 .79449 .17484 .78592 .15959 .78396 .14173 Metetra
.983 .702 .341 r
.78396 .14173 .78592 .15959 .77735 .14699 .7755 .13165 Metetra
.982 .695 .372 r
.7755 .13165 .77735 .14699 .76922 .14869 .7675 .13652 Metetra
.967 .674 .419 r
.7675 .13652 .76922 .14869 .76103 .15312 .76013 .16286 Metetra
.978 .771 .558 r
.76013 .16286 .76103 .15312 .75182 .13426 .75055 .13418 Metetra
.556 .583 .836 r
.75055 .13418 .75182 .13426 .74254 .11673 .7409 .1061 Metetra
.97 .669 .278 r
.7409 .1061 .74254 .11673 .73304 .09614 .73166 .09287 Metetra
.879 .473 .03 r
.73166 .09287 .73304 .09614 .72372 .08464 .72244 .08459 Metetra
.525 .653 .916 r
.72244 .08459 .72372 .08464 .714 .06477 .71273 .06547 Metetra
.979 .809 .604 r
.89842 .28423 .89925 .27921 .89218 .26613 .89135 .27143 Metetra
.967 .789 .612 r
.89135 .27143 .89218 .26613 .88497 .25201 .88391 .25329 Metetra
.869 .859 .828 r
.88391 .25329 .88497 .25201 .87789 .24155 .87684 .24309 Metetra
.91 .9 .803 r
.87684 .24309 .87789 .24155 .87094 .23511 .86982 .23566 Metetra
.86982 .23566 .87094 .23511 .86429 .23645 .86341 .24159 Metetra
.998 .845 .549 r
.86341 .24159 .86429 .23645 .85754 .23795 .85648 .23988 Metetra
.899 .965 .643 r
.85648 .23988 .85754 .23795 .85096 .24535 .84969 .24334 Metetra
0 0 .471 r
.84969 .24334 .85096 .24535 .84286 .22453 .84187 .22847 Metetra
.988 .856 .618 r
.84187 .22847 .84286 .22453 .8352 .21472 .83438 .22223 Metetra
1 .818 .507 r
.83438 .22223 .8352 .21472 .82774 .21117 .82702 .22101 Metetra
.999 .799 .494 r
.82702 .22101 .82774 .21117 .81976 .19898 .8194 .21724 Metetra
.996 .77 .472 r
.8194 .21724 .81976 .19898 .81179 .18928 .81129 .20503 Metetra
.996 .775 .477 r
.81129 .20503 .81179 .18928 .80359 .1771 .80315 .19479 Metetra
.993 .767 .487 r
.80315 .19479 .80359 .1771 .79544 .16853 .79449 .17484 Metetra
.984 .804 .582 r
.79449 .17484 .79544 .16853 .78681 .15152 .78592 .15959 Metetra
.993 .8 .543 r
.78592 .15959 .78681 .15152 .7785 .14493 .77735 .14699 Metetra
.927 .97 .688 r
.77735 .14699 .7785 .14493 .77016 .141 .76922 .14869 Metetra
.998 .825 .484 r
.76922 .14869 .77016 .141 .76159 .13491 .76103 .15312 Metetra
.994 .768 .483 r
.76103 .15312 .76159 .13491 .75264 .12221 .75182 .13426 Metetra
.993 .781 .514 r
.75182 .13426 .75264 .12221 .74347 .10682 .74254 .11673 Metetra
.988 .783 .54 r
.74254 .11673 .74347 .10682 .73435 .09689 .73304 .09614 Metetra
0 .374 .83 r
.73304 .09614 .73435 .09689 .725 .08435 .72372 .08464 Metetra
.632 .704 .898 r
.72372 .08464 .725 .08435 .71543 .06939 .714 .06477 Metetra
.586 .702 .923 r
.89925 .27921 .90036 .27915 .89352 .26989 .89218 .26613 Metetra
.826 .466 0 r
.89218 .26613 .89352 .26989 .88661 .26107 .88497 .25201 Metetra
.967 .663 .266 r
.88497 .25201 .88661 .26107 .87957 .25141 .87789 .24155 Metetra
.975 .673 .302 r
.87789 .24155 .87957 .25141 .87262 .24509 .87094 .23511 Metetra
.978 .677 .344 r
.87094 .23511 .87262 .24509 .8657 .24134 .86429 .23645 Metetra
.955 .608 .279 r
.86429 .23645 .8657 .24134 .85932 .24993 .85754 .23795 Metetra
.979 .686 .376 r
.85754 .23795 .85932 .24993 .85335 .2693 .85096 .24535 Metetra
.983 .711 .334 r
.85096 .24535 .85335 .2693 .84503 .24457 .84286 .22453 Metetra
.985 .707 .348 r
.84286 .22453 .84503 .24457 .83732 .23386 .8352 .21472 Metetra
.985 .706 .361 r
.8352 .21472 .83732 .23386 .8298 .22937 .82774 .21117 Metetra
.983 .703 .336 r
.82774 .21117 .8298 .22937 .82222 .22608 .81976 .19898 Metetra
.987 .716 .364 r
.81976 .19898 .82222 .22608 .81393 .21003 .81179 .18928 Metetra
.984 .708 .345 r
.81179 .18928 .81393 .21003 .80594 .20288 .80359 .1771 Metetra
.987 .714 .364 r
.80359 .1771 .80594 .20288 .79732 .18399 .79544 .16853 Metetra
.977 .693 .306 r
.79544 .16853 .79732 .18399 .78877 .16899 .78681 .15152 Metetra
.983 .701 .348 r
.78681 .15152 .78877 .16899 .78016 .1553 .7785 .14493 Metetra
.976 .672 .317 r
.7785 .14493 .78016 .1553 .77198 .15571 .77016 .141 Metetra
.981 .692 .337 r
.77016 .141 .77198 .15571 .76395 .16396 .76159 .13491 Metetra
.987 .716 .363 r
.76159 .13491 .76395 .16396 .75448 .1379 .75264 .12221 Metetra
.979 .693 .314 r
.75264 .12221 .75448 .1379 .74555 .1298 .74347 .10682 Metetra
.985 .71 .356 r
.74347 .10682 .74555 .1298 .73603 .10886 .73435 .09689 Metetra
.974 .677 .295 r
.73435 .09689 .73603 .10886 .72651 .09142 .725 .08435 Metetra
.945 .619 .19 r
.725 .08435 .72651 .09142 .71671 .06902 .71543 .06939 Metetra
.982 .699 .332 r
.90036 .27915 .90239 .29486 .89535 .28225 .89352 .26989 Metetra
.978 .687 .313 r
.89352 .26989 .89535 .28225 .88834 .27176 .88661 .26107 Metetra
.974 .677 .293 r
.88661 .26107 .88834 .27176 .88133 .2628 .87957 .25141 Metetra
.978 .683 .317 r
.87957 .25141 .88133 .2628 .87403 .25012 .87262 .24509 Metetra
.951 .604 .226 r
.87262 .24509 .87403 .25012 .86697 .24341 .8657 .24134 Metetra
.869 .467 .268 r
.8657 .24134 .86697 .24341 .8602 .24453 .85932 .24993 Metetra
.901 .805 .327 r
.85932 .24993 .8602 .24453 .85423 .2635 .85335 .2693 Metetra
.957 .774 .614 r
.85335 .2693 .85423 .2635 .84649 .25028 .84503 .24457 Metetra
.938 .601 .169 r
.84503 .24457 .84649 .25028 .83886 .24106 .83732 .23386 Metetra
.966 .644 .274 r
.83732 .23386 .83886 .24106 .83122 .23405 .8298 .22937 Metetra
.945 .588 .212 r
.8298 .22937 .83122 .23405 .82352 .22817 .82222 .22608 Metetra
0 0 .465 r
.82222 .22608 .82352 .22817 .81513 .20981 .81393 .21003 Metetra
.546 .833 .998 r
.81393 .21003 .81513 .20981 .8072 .2037 .80594 .20288 Metetra
.221 .43 .853 r
.80594 .20288 .8072 .2037 .79873 .18819 .79732 .18399 Metetra
.863 .501 .001 r
.79732 .18399 .79873 .18819 .79038 .17794 .78877 .16899 Metetra
.962 .653 .244 r
.78877 .16899 .79038 .17794 .78178 .16469 .78016 .1553 Metetra
.974 .665 .327 r
.78016 .1553 .78178 .16469 .77345 .16119 .77198 .15571 Metetra
.952 .611 .327 r
.77198 .15571 .77345 .16119 .76533 .16709 .76395 .16396 Metetra
0 0 .387 r
.76395 .16396 .76533 .16709 .75583 .14029 .75448 .1379 Metetra
.803 .356 0 r
.75448 .1379 .75583 .14029 .74682 .12972 .74555 .1298 Metetra
.58 .659 .891 r
.74555 .1298 .74682 .12972 .73734 .10965 .73603 .10886 Metetra
.147 .425 .865 r
.73603 .10886 .73734 .10965 .728 .09745 .72651 .09142 Metetra
.891 .564 .068 r
.72651 .09142 .728 .09745 .71799 .06856 .71671 .06902 Metetra
.994 .78 .507 r
.90239 .29486 .90286 .28357 .89607 .27516 .89535 .28225 Metetra
.992 .802 .549 r
.89535 .28225 .89607 .27516 .8892 .26677 .88834 .27176 Metetra
.989 .825 .59 r
.88834 .27176 .8892 .26677 .88221 .258 .88133 .2628 Metetra
.978 .814 .61 r
.88133 .2628 .88221 .258 .87515 .24958 .87403 .25012 Metetra
.72 .894 .959 r
.87403 .25012 .87515 .24958 .86846 .24975 .86697 .24341 Metetra
.966 .638 .304 r
.86697 .24341 .86846 .24975 .86097 .23687 .8602 .24453 Metetra
.959 .805 .367 r
.8602 .24453 .86097 .23687 .85501 .25576 .85423 .2635 Metetra
.99 .796 .548 r
.85423 .2635 .85501 .25576 .84693 .23545 .84649 .25028 Metetra
.997 .777 .478 r
.84649 .25028 .84693 .23545 .83947 .22938 .83886 .24106 Metetra
.998 .788 .489 r
.83886 .24106 .83947 .22938 .83174 .21995 .83122 .23405 Metetra
.998 .781 .473 r
.83122 .23405 .83174 .21995 .82417 .21632 .82352 .22817 Metetra
.991 .777 .517 r
.82352 .22817 .82417 .21632 .81562 .19395 .81513 .20981 Metetra
.998 .777 .467 r
.81513 .20981 .81562 .19395 .80726 .17762 .8072 .2037 Metetra
.995 .761 .457 r
.8072 .2037 .80726 .17762 .79875 .16042 .79873 .18819 Metetra
.996 .761 .447 r
.79873 .18819 .79875 .16042 .79037 .14845 .79038 .17794 Metetra
.995 .759 .448 r
.79038 .17794 .79037 .14845 .78178 .13444 .78178 .16469 Metetra
.996 .761 .436 r
.78178 .16469 .78178 .13444 .77369 .13577 .77345 .16119 Metetra
.996 .767 .428 r
.77345 .16119 .77369 .13577 .76555 .13988 .76533 .16709 Metetra
.993 .757 .467 r
.76533 .16709 .76555 .13988 .75635 .12004 .75583 .14029 Metetra
.996 .769 .462 r
.75583 .14029 .75635 .12004 .74741 .11056 .74682 .12972 Metetra
.994 .767 .48 r
.74682 .12972 .74741 .11056 .738 .09159 .73734 .10965 Metetra
.996 .772 .472 r
.73734 .10965 .738 .09159 .72873 .08046 .728 .09745 Metetra
.99 .765 .501 r
.728 .09745 .72873 .08046 .71929 .06871 .71799 .06856 Metetra
.985 .709 .35 r
.90286 .28357 .90515 .30366 .89809 .29074 .89607 .27516 Metetra
.982 .699 .334 r
.89607 .27516 .89809 .29074 .89091 .27703 .8892 .26677 Metetra
.973 .674 .291 r
.8892 .26677 .89091 .27703 .88381 .26625 .88221 .258 Metetra
.966 .656 .264 r
.88221 .258 .88381 .26625 .8767 .25684 .87515 .24958 Metetra
.97 .651 .31 r
.87515 .24958 .8767 .25684 .86953 .24816 .86846 .24975 Metetra
.883 .834 .793 r
.86846 .24975 .86953 .24816 .8622 .23823 .86097 .23687 Metetra
.772 .406 .364 r
.86097 .23687 .8622 .23823 .85499 .23236 .85501 .25576 Metetra
.994 .76 .469 r
.85501 .25576 .85499 .23236 .84763 .22588 .84693 .23545 Metetra
.998 .797 .502 r
.84693 .23545 .84763 .22588 .8407 .23022 .83947 .22938 Metetra
0 .305 .781 r
.83947 .22938 .8407 .23022 .8338 .23798 .83174 .21995 Metetra
.984 .703 .356 r
.83174 .21995 .8338 .23798 .82664 .2433 .82417 .21632 Metetra
.984 .714 .339 r
.82417 .21632 .82664 .2433 .81741 .20661 .81562 .19395 Metetra
.972 .681 .282 r
.81562 .19395 .81741 .20661 .8091 .19171 .80726 .17762 Metetra
.974 .687 .293 r
.80726 .17762 .8091 .19171 .80031 .16825 .79875 .16042 Metetra
.958 .64 .23 r
.79875 .16042 .80031 .16825 .79189 .15537 .79037 .14845 Metetra
.944 .619 .186 r
.79037 .14845 .79189 .15537 .78344 .1448 .78178 .13444 Metetra
.976 .673 .338 r
.78178 .13444 .78344 .1448 .77559 .15216 .77369 .13577 Metetra
.983 .697 .369 r
.77369 .13577 .77559 .15216 .7692 .20217 .76555 .13988 Metetra
.99 .729 .381 r
.76555 .13988 .7692 .20217 .75884 .15294 .75635 .12004 Metetra
.988 .719 .371 r
.75635 .12004 .75884 .15294 .74885 .11523 .74741 .11056 Metetra
.857 .508 0 r
.74741 .11056 .74885 .11523 .73938 .09456 .738 .09159 Metetra
.824 .411 0 r
.738 .09159 .73938 .09456 .73043 .09285 .72873 .08046 Metetra
.975 .679 .3 r
.72873 .08046 .73043 .09285 .72069 .07191 .71929 .06871 Metetra
.995 .775 .494 r
.90515 .30366 .90551 .29046 .89858 .27957 .89809 .29074 Metetra
.993 .78 .51 r
.89809 .29074 .89858 .27957 .89146 .26673 .89091 .27703 Metetra
.995 .786 .509 r
.89091 .27703 .89146 .26673 .88448 .2578 .88381 .26625 Metetra
.995 .797 .525 r
.88381 .26625 .88448 .2578 .87743 .2492 .8767 .25684 Metetra
.995 .803 .533 r
.8767 .25684 .87743 .2492 .87015 .23805 .86953 .24816 Metetra
.996 .789 .509 r
.86953 .24816 .87015 .23805 .86273 .22608 .8622 .23823 Metetra
.998 .785 .481 r
.8622 .23823 .86273 .22608 .85537 .21697 .85499 .23236 Metetra
.997 .776 .468 r
.85499 .23236 .85537 .21697 .84818 .21341 .84763 .22588 Metetra
.998 .79 .448 r
.84763 .22588 .84818 .21341 .84111 .21432 .8407 .23022 Metetra
.997 .78 .43 r
.8407 .23022 .84111 .21432 .83352 .2073 .8338 .23798 Metetra
.996 .761 .422 r
.8338 .23798 .83352 .2073 .82602 .20458 .82664 .2433 Metetra
.992 .75 .459 r
.82664 .2433 .82602 .20458 .81789 .19076 .81741 .20661 Metetra
.995 .772 .484 r
.81741 .20661 .81789 .19076 .80963 .17636 .8091 .19171 Metetra
.991 .767 .502 r
.8091 .19171 .80963 .17636 .80132 .16325 .80031 .16825 Metetra
.982 .822 .608 r
.80031 .16825 .80132 .16325 .79286 .14935 .79189 .15537 Metetra
.991 .819 .573 r
.79189 .15537 .79286 .14935 .7845 .14041 .78344 .1448 Metetra
.976 .879 .505 r
.78344 .1448 .7845 .14041 .77638 .14071 .77559 .15216 Metetra
.886 .741 .233 r
.77559 .15216 .77638 .14071 .76885 .16027 .7692 .20217 Metetra
.991 .748 .463 r
.7692 .20217 .76885 .16027 .75965 .14078 .75884 .15294 Metetra
.976 .759 .546 r
.75884 .15294 .75965 .14078 .75011 .11488 .74885 .11523 Metetra
.653 .702 .882 r
.74885 .11523 .75011 .11488 .74081 .09898 .73938 .09456 Metetra
.939 .568 .208 r
.73938 .09456 .74081 .09898 .73194 .0995 .73043 .09285 Metetra
.915 .59 .116 r
.73043 .09285 .73194 .0995 .72207 .07472 .72069 .07191 Metetra
.976 .826 .628 r
.90551 .29046 .90639 .2864 .89942 .27444 .89858 .27957 Metetra
.98 .81 .6 r
.89858 .27957 .89942 .27444 .89243 .26378 .89146 .26673 Metetra
.967 .856 .679 r
.89146 .26673 .89243 .26378 .88534 .25274 .88448 .2578 Metetra
.99 .826 .586 r
.88448 .2578 .88534 .25274 .87843 .24639 .87743 .2492 Metetra
.954 .844 .695 r
.87743 .2492 .87843 .24639 .87142 .24032 .87015 .23805 Metetra
.664 .254 0 r
.87015 .23805 .87142 .24032 .86469 .24129 .86273 .22608 Metetra
.981 .696 .328 r
.86273 .22608 .86469 .24129 .85847 .25456 .85537 .21697 Metetra
.989 .723 .382 r
.85537 .21697 .85847 .25456 .85108 .24735 .84818 .21341 Metetra
.989 .72 .385 r
.84818 .21341 .85108 .24735 .84347 .23813 .84111 .21432 Metetra
.986 .712 .361 r
.84111 .21432 .84347 .23813 .83588 .23145 .83352 .2073 Metetra
.987 .712 .37 r
.83352 .2073 .83588 .23145 .82852 .23188 .82602 .20458 Metetra
.986 .715 .355 r
.82602 .20458 .82852 .23188 .82023 .21521 .81789 .19076 Metetra
.985 .712 .348 r
.81789 .19076 .82023 .21521 .81194 .20061 .80963 .17636 Metetra
.985 .712 .35 r
.80963 .17636 .81194 .20061 .80365 .18847 .80132 .16325 Metetra
.985 .713 .35 r
.80132 .16325 .80365 .18847 .79516 .17427 .79286 .14935 Metetra
.986 .712 .359 r
.79286 .14935 .79516 .17427 .78658 .16077 .7845 .14041 Metetra
.985 .706 .368 r
.7845 .14041 .78658 .16077 .77833 .15817 .77638 .14071 Metetra
.98 .696 .402 r
.77638 .14071 .77833 .15817 .77039 .16747 .76885 .16027 Metetra
.928 .609 .148 r
.76885 .16027 .77039 .16747 .76086 .13918 .75965 .14078 Metetra
.82 .742 .778 r
.75965 .14078 .76086 .13918 .75186 .12807 .75011 .11488 Metetra
.974 .682 .29 r
.75011 .11488 .75186 .12807 .74211 .09944 .74081 .09898 Metetra
.399 0 0 r
.74081 .09898 .74211 .09944 .73295 .09131 .73194 .0995 Metetra
.979 .783 .569 r
.73194 .0995 .73295 .09131 .72318 .06869 .72207 .07472 Metetra
.909 .565 .096 r
.90639 .2864 .9078 .29132 .90054 .27429 .89942 .27444 Metetra
.595 .753 .954 r
.89942 .27444 .90054 .27429 .89356 .26364 .89243 .26378 Metetra
.597 .75 .95 r
.89243 .26378 .89356 .26364 .88661 .25501 .88534 .25274 Metetra
.813 .372 0 r
.88534 .25274 .88661 .25501 .87958 .24646 .87843 .24639 Metetra
.342 .726 .985 r
.87843 .24639 .87958 .24646 .87309 .24989 .87142 .24032 Metetra
.976 .672 .335 r
.87142 .24032 .87309 .24989 .86611 .24611 .86469 .24129 Metetra
.939 .605 .37 r
.86469 .24129 .86611 .24611 .8594 .24963 .85847 .25456 Metetra
.992 .836 .585 r
.85847 .25456 .8594 .24963 .85195 .24124 .85108 .24735 Metetra
.993 .817 .564 r
.85108 .24735 .85195 .24124 .84442 .23321 .84347 .23813 Metetra
.993 .839 .584 r
.84347 .23813 .84442 .23321 .83689 .22742 .83588 .23145 Metetra
.993 .88 .571 r
.83588 .23145 .83689 .22742 .8294 .22494 .82852 .23188 Metetra
.984 .796 .572 r
.82852 .23188 .8294 .22494 .821 .20566 .82023 .21521 Metetra
.993 .789 .528 r
.82023 .21521 .821 .20566 .813 .19711 .81194 .20061 Metetra
.967 .841 .665 r
.81194 .20061 .813 .19711 .80469 .18418 .80365 .18847 Metetra
.972 .824 .637 r
.80365 .18847 .80469 .18418 .79626 .17115 .79516 .17427 Metetra
.955 .841 .69 r
.79516 .17427 .79626 .17115 .78746 .15197 .78658 .16077 Metetra
1 .809 .499 r
.78658 .16077 .78746 .15197 .77936 .15262 .77833 .15817 Metetra
.981 .855 .472 r
.77833 .15817 .77936 .15262 .77145 .16229 .77039 .16747 Metetra
.946 .773 .636 r
.77039 .16747 .77145 .16229 .76196 .13466 .76086 .13918 Metetra
.983 .839 .621 r
.76086 .13918 .76196 .13466 .75282 .11934 .75186 .12807 Metetra
.976 .774 .568 r
.75186 .12807 .75282 .11934 .74331 .09724 .74211 .09944 Metetra
.944 .908 .754 r
.74211 .09944 .74331 .09724 .73421 .09022 .73295 .09131 Metetra
.779 .752 .828 r
.73295 .09131 .73421 .09022 .72438 .06585 .72318 .06869 Metetra
.31 .475 .862 r
.9078 .29132 .90897 .29202 .90162 .27357 .90054 .27429 Metetra
.776 .83 .894 r
.90054 .27429 .90162 .27357 .89468 .26335 .89356 .26364 Metetra
.638 .818 .969 r
.89356 .26364 .89468 .26335 .88763 .25274 .88661 .25501 Metetra
.949 .874 .727 r
.88661 .25501 .88763 .25274 .88071 .24617 .87958 .24646 Metetra
.87958 .24646 .88071 .24617 .87405 .24604 .87309 .24989 Metetra
.992 .867 .604 r
.87309 .24989 .87405 .24604 .86699 .24078 .86611 .24611 Metetra
.995 .85 .505 r
.86611 .24611 .86699 .24078 .86083 .25458 .8594 .24963 Metetra
.933 .582 .156 r
.8594 .24963 .86083 .25458 .85324 .24327 .85195 .24124 Metetra
.735 .28 0 r
.85195 .24124 .85324 .24327 .84577 .23653 .84442 .23321 Metetra
.899 .502 .078 r
.84442 .23321 .84577 .23653 .83814 .2285 .83689 .22742 Metetra
.634 .082 0 r
.83689 .22742 .83814 .2285 .83089 .23098 .8294 .22494 Metetra
.896 .571 .078 r
.8294 .22494 .83089 .23098 .82234 .20839 .821 .20566 Metetra
.828 .407 0 r
.821 .20566 .82234 .20839 .81432 .1993 .813 .19711 Metetra
.636 .217 0 r
.813 .19711 .81432 .1993 .80605 .18735 .80469 .18418 Metetra
.805 .412 0 r
.80469 .18418 .80605 .18735 .7976 .17357 .79626 .17115 Metetra
0 0 .436 r
.79626 .17115 .7976 .17357 .78897 .15835 .78746 .15197 Metetra
.962 .628 .288 r
.78746 .15197 .78897 .15835 .78085 .15856 .77936 .15262 Metetra
.954 .62 .338 r
.77936 .15262 .78085 .15856 .77293 .1677 .77145 .16229 Metetra
.799 .486 0 r
.77145 .16229 .77293 .1677 .76335 .13795 .76196 .13466 Metetra
.789 .403 0 r
.76196 .13466 .76335 .13795 .75425 .12379 .75282 .11934 Metetra
.802 .461 0 r
.75282 .11934 .75425 .12379 .74479 .10274 .74331 .09724 Metetra
.945 .595 .196 r
.74331 .09724 .74479 .10274 .73542 .088 .73421 .09022 Metetra
.874 .777 .751 r
.73421 .09022 .73542 .088 .72581 .06996 .72438 .06585 Metetra
.874 .775 .749 r
.90897 .29202 .90998 .29007 .90323 .28178 .90162 .27357 Metetra
.962 .652 .245 r
.90162 .27357 .90323 .28178 .89622 .2705 .89468 .26335 Metetra
.954 .635 .216 r
.89468 .26335 .89622 .2705 .88894 .25567 .88763 .25274 Metetra
.871 .465 .013 r
.88763 .25274 .88894 .25567 .88206 .2498 .88071 .24617 Metetra
.935 .558 .209 r
.88071 .24617 .88206 .2498 .87509 .24393 .87405 .24604 Metetra
.955 .914 .733 r
.87405 .24604 .87509 .24393 .86814 .24045 .86699 .24078 Metetra
.363 0 .118 r
.86699 .24078 .86814 .24045 .86199 .25428 .86083 .25458 Metetra
.648 .785 .947 r
.86083 .25458 .86199 .25428 .85453 .24538 .85324 .24327 Metetra
.78 .324 0 r
.85324 .24327 .85453 .24538 .84702 .23762 .84577 .23653 Metetra
0 .102 .6 r
.84577 .23653 .84702 .23762 .83953 .23256 .83814 .2285 Metetra
.941 .574 .253 r
.83814 .2285 .83953 .23256 .83226 .23431 .83089 .23098 Metetra
0 0 .315 r
.83089 .23098 .83226 .23431 .82407 .21939 .82234 .20839 Metetra
.974 .674 .295 r
.82234 .20839 .82407 .21939 .81621 .214 .81432 .1993 Metetra
.978 .691 .313 r
.81432 .1993 .81621 .214 .80776 .19809 .80605 .18735 Metetra
.968 .668 .268 r
.80605 .18735 .80776 .19809 .79921 .18241 .7976 .17357 Metetra
.957 .647 .227 r
.7976 .17357 .79921 .18241 .79044 .16379 .78897 .15835 Metetra
.955 .608 .263 r
.78897 .15835 .79044 .16379 .78236 .16502 .78085 .15856 Metetra
.959 .629 .34 r
.78085 .15856 .78236 .16502 .77519 .19302 .77293 .1677 Metetra
.98 .709 .319 r
.77293 .1677 .77519 .19302 .76594 .1727 .76335 .13795 Metetra
.988 .719 .364 r
.76335 .13795 .76594 .1727 .75607 .13846 .75425 .12379 Metetra
.972 .685 .283 r
.75425 .12379 .75607 .13846 .74623 .10735 .74479 .10274 Metetra
.889 .528 .05 r
.74479 .10274 .74623 .10735 .73699 .096 .73542 .088 Metetra
.945 .629 .19 r
.73542 .088 .73699 .096 .72712 .07042 .72581 .06996 Metetra
.899 .526 .069 r
.90998 .29007 .91133 .29387 .90448 .28375 .90323 .28178 Metetra
0 0 .388 r
.90323 .28178 .90448 .28375 .89764 .27536 .89622 .2705 Metetra
.88 .539 .04 r
.89622 .2705 .89764 .27536 .8907 .26672 .88894 .25567 Metetra
.977 .68 .312 r
.88894 .25567 .8907 .26672 .88366 .25789 .88206 .2498 Metetra
.968 .655 .276 r
.88206 .2498 .88366 .25789 .87607 .24072 .87509 .24393 Metetra
.986 .887 .635 r
.87509 .24393 .87607 .24072 .86943 .24277 .86814 .24045 Metetra
.865 .492 .338 r
.86814 .24045 .86943 .24277 .86331 .25701 .86199 .25428 Metetra
.819 .404 0 r
.86199 .25428 .86331 .25701 .85528 .23701 .85453 .24538 Metetra
.997 .803 .519 r
.85453 .24538 .85528 .23701 .848 .2335 .84702 .23762 Metetra
.992 .86 .603 r
.84702 .23762 .848 .2335 .84064 .23059 .83953 .23256 Metetra
.921 .971 .682 r
.83953 .23256 .84064 .23059 .83292 .22292 .83226 .23431 Metetra
.994 .782 .51 r
.83226 .23431 .83292 .22292 .82475 .208 .82407 .21939 Metetra
.999 .791 .485 r
.82407 .21939 .82475 .208 .81655 .19471 .81621 .214 Metetra
.995 .767 .471 r
.81621 .214 .81655 .19471 .80805 .1769 .80776 .19809 Metetra
.995 .765 .465 r
.80776 .19809 .80805 .1769 .79935 .15703 .79921 .18241 Metetra
.995 .761 .459 r
.79921 .18241 .79935 .15703 .79081 .14306 .79044 .16379 Metetra
.997 .771 .438 r
.79044 .16379 .79081 .14306 .78249 .13732 .78236 .16502 Metetra
.992 .765 .389 r
.78236 .16502 .78249 .13732 .77472 .1491 .77519 .19302 Metetra
.994 .752 .438 r
.77519 .19302 .77472 .1491 .76556 .12939 .76594 .1727 Metetra
.993 .75 .448 r
.76594 .1727 .76556 .12939 .75631 .11046 .75607 .13846 Metetra
.993 .756 .467 r
.75607 .13846 .75631 .11046 .74692 .0905 .74623 .10735 Metetra
.997 .775 .472 r
.74623 .10735 .74692 .0905 .73793 .08599 .73699 .096 Metetra
.984 .778 .546 r
.73699 .096 .73793 .08599 .72843 .07071 .72712 .07042 Metetra
.886 .52 .044 r
.91133 .29387 .91269 .29781 .90571 .28553 .90448 .28375 Metetra
.648 .192 0 r
.90448 .28375 .90571 .28553 .89871 .27419 .89764 .27536 Metetra
.864 .885 .85 r
.89764 .27536 .89871 .27419 .89162 .26267 .8907 .26672 Metetra
.983 .84 .621 r
.8907 .26672 .89162 .26267 .88446 .2515 .88366 .25789 Metetra
.979 .792 .582 r
.88366 .25789 .88446 .2515 .87715 .23926 .87607 .24072 Metetra
.85 .987 .714 r
.87607 .24072 .87715 .23926 .86974 .22673 .86943 .24277 Metetra
.993 .778 .405 r
.86943 .24277 .86974 .22673 .86292 .22716 .86331 .25701 Metetra
.994 .756 .453 r
.86331 .25701 .86292 .22716 .85571 .22226 .85528 .23701 Metetra
.998 .78 .461 r
.85528 .23701 .85571 .22226 .84849 .21948 .848 .2335 Metetra
.998 .782 .462 r
.848 .2335 .84849 .21948 .84084 .21033 .84064 .23059 Metetra
.997 .768 .453 r
.84064 .23059 .84084 .21033 .83343 .20838 .83292 .22292 Metetra
.995 .775 .489 r
.83292 .22292 .83343 .20838 .82533 .19443 .82475 .208 Metetra
.996 .778 .491 r
.82475 .208 .82533 .19443 .81705 .17901 .81655 .19471 Metetra
.994 .771 .488 r
.81655 .19471 .81705 .17901 .80871 .16425 .80805 .1769 Metetra
.992 .775 .511 r
.80805 .1769 .80871 .16425 .80044 .15379 .79935 .15703 Metetra
.957 .837 .684 r
.79935 .15703 .80044 .15379 .79204 .1428 .79081 .14306 Metetra
.521 .858 .995 r
.79081 .14306 .79204 .1428 .78368 .13606 .78249 .13732 Metetra
.78249 .13732 .78368 .13606 .77591 .14721 .77472 .1491 Metetra
.873 .799 .774 r
.77472 .1491 .77591 .14721 .76675 .12738 .76556 .12939 Metetra
.885 .809 .768 r
.76556 .12939 .76675 .12738 .75734 .10381 .75631 .11046 Metetra
.98 .797 .585 r
.75631 .11046 .75734 .10381 .74812 .08836 .74692 .0905 Metetra
.948 .94 .746 r
.74692 .0905 .74812 .08836 .73911 .08281 .73793 .08599 Metetra
.953 .84 .695 r
.73793 .08599 .73911 .08281 .72962 .06739 .72843 .07071 Metetra
.975 .818 .624 r
.91269 .29781 .91356 .29351 .90662 .28157 .90571 .28553 Metetra
.975 .827 .634 r
.90571 .28553 .90662 .28157 .8995 .26809 .89871 .27419 Metetra
.989 .808 .57 r
.89871 .27419 .8995 .26809 .89242 .25659 .89162 .26267 Metetra
.989 .809 .569 r
.89162 .26267 .89242 .25659 .8854 .24773 .88446 .2515 Metetra
.97 .827 .646 r
.88446 .2515 .8854 .24773 .87823 .23787 .87715 .23926 Metetra
.867 .836 .814 r
.87715 .23926 .87823 .23787 .8708 .22476 .86974 .22673 Metetra
.939 .964 .695 r
.86974 .22673 .8708 .22476 .86355 .21673 .86292 .22716 Metetra
.999 .794 .487 r
.86292 .22716 .86355 .21673 .85636 .21196 .85571 .22226 Metetra
.999 .796 .481 r
.85571 .22226 .85636 .21196 .84933 .21247 .84849 .21948 Metetra
.995 .81 .544 r
.84849 .21948 .84933 .21247 .84186 .20671 .84084 .21033 Metetra
.991 .885 .606 r
.84084 .21033 .84186 .20671 .83447 .20504 .83343 .20838 Metetra
.958 .831 .676 r
.83343 .20838 .83447 .20504 .82635 .19037 .82533 .19443 Metetra
.966 .819 .647 r
.82533 .19443 .82635 .19037 .81816 .17644 .81705 .17901 Metetra
.933 .833 .724 r
.81705 .17901 .81816 .17644 .8099 .1635 .80871 .16425 Metetra
.769 .864 .919 r
.80871 .16425 .8099 .1635 .80159 .15184 .80044 .15379 Metetra
.921 .875 .775 r
.80044 .15379 .80159 .15184 .79325 .14219 .79204 .1428 Metetra
.711 .916 .965 r
.79204 .1428 .79325 .14219 .78502 .13807 .78368 .13606 Metetra
.846 .432 .253 r
.78368 .13606 .78502 .13807 .77738 .15238 .77591 .14721 Metetra
.866 .527 .017 r
.77591 .14721 .77738 .15238 .76869 .14477 .76675 .12738 Metetra
.975 .694 .294 r
.76675 .12738 .76869 .14477 .75903 .11495 .75734 .10381 Metetra
.968 .668 .265 r
.75734 .10381 .75903 .11495 .74987 .10117 .74812 .08836 Metetra
.978 .682 .321 r
.74812 .08836 .74987 .10117 .74098 .09922 .73911 .08281 Metetra
.978 .693 .312 r
.73911 .08281 .74098 .09922 .73121 .07612 .72962 .06739 Metetra
.991 .799 .55 r
.91356 .29351 .91426 .28635 .90726 .27331 .90662 .28157 Metetra
.991 .791 .538 r
.90662 .28157 .90726 .27331 .90045 .26483 .8995 .26809 Metetra
.964 .835 .668 r
.8995 .26809 .90045 .26483 .89353 .25601 .89242 .25659 Metetra
.743 .857 .933 r
.89242 .25659 .89353 .25601 .88654 .24758 .8854 .24773 Metetra
.582 .771 .969 r
.8854 .24773 .88654 .24758 .87971 .24374 .87823 .23787 Metetra
.925 .593 .136 r
.87823 .23787 .87971 .24374 .87345 .2524 .8708 .22476 Metetra
.987 .716 .362 r
.8708 .22476 .87345 .2524 .86673 .2549 .86355 .21673 Metetra
.989 .722 .377 r
.86355 .21673 .86673 .2549 .8593 .2459 .85636 .21196 Metetra
.988 .72 .381 r
.85636 .21196 .8593 .2459 .85175 .23688 .84933 .21247 Metetra
.986 .712 .361 r
.84933 .21247 .85175 .23688 .8444 .23377 .84186 .20671 Metetra
.987 .715 .372 r
.84186 .20671 .8444 .23377 .8369 .23025 .83447 .20504 Metetra
.985 .712 .345 r
.83447 .20504 .8369 .23025 .82901 .22098 .82635 .19037 Metetra
.987 .717 .356 r
.82635 .19037 .82901 .22098 .82084 .20822 .81816 .17644 Metetra
.987 .718 .36 r
.81816 .17644 .82084 .20822 .81256 .19533 .8099 .1635 Metetra
.987 .718 .362 r
.8099 .1635 .81256 .19533 .80384 .17482 .80159 .15184 Metetra
.985 .709 .35 r
.80159 .15184 .80384 .17482 .79523 .15933 .79325 .14219 Metetra
.983 .698 .346 r
.79325 .14219 .79523 .15933 .78678 .15041 .78502 .13807 Metetra
.976 .679 .383 r
.78502 .13807 .78678 .15041 .77885 .15751 .77738 .15238 Metetra
.937 .582 .17 r
.77738 .15238 .77885 .15751 .76972 .13853 .76869 .14477 Metetra
.957 .772 .612 r
.76869 .14477 .76972 .13853 .7606 .1226 .75903 .11495 Metetra
.951 .629 .207 r
.75903 .11495 .7606 .1226 .75132 .1057 .74987 .10117 Metetra
.939 .57 .204 r
.74987 .10117 .75132 .1057 .74213 .09502 .74098 .09922 Metetra
.948 .797 .66 r
.74098 .09922 .74213 .09502 .73245 .07424 .73121 .07612 Metetra
0 0 .362 r
.91426 .28635 .91552 .28862 .90872 .27889 .90726 .27331 Metetra
.942 .604 .18 r
.90726 .27331 .90872 .27889 .90162 .26532 .90045 .26483 Metetra
.147 .519 .916 r
.90045 .26483 .90162 .26532 .89454 .25368 .89353 .25601 Metetra
.952 .875 .722 r
.89353 .25601 .89454 .25368 .88755 .24494 .88654 .24758 Metetra
.976 .904 .675 r
.88654 .24758 .88755 .24494 .88113 .2483 .87971 .24374 Metetra
.945 .6 .332 r
.87971 .24374 .88113 .2483 .87362 .23374 .87345 .2524 Metetra
.997 .772 .433 r
.87345 .2524 .87362 .23374 .8675 .24716 .86673 .2549 Metetra
.996 .805 .531 r
.86673 .2549 .8675 .24716 .86007 .23793 .8593 .2459 Metetra
.996 .804 .528 r
.8593 .2459 .86007 .23793 .85247 .22756 .85175 .23688 Metetra
1 .802 .491 r
.85175 .23688 .85247 .22756 .84522 .22603 .8444 .23377 Metetra
1 .814 .51 r
.8444 .23377 .84522 .22603 .83799 .22774 .8369 .23025 Metetra
.955 .876 .719 r
.8369 .23025 .83799 .22774 .82957 .2072 .82901 .22098 Metetra
.996 .778 .487 r
.82901 .22098 .82957 .2072 .82157 .19743 .82084 .20822 Metetra
.995 .787 .509 r
.82084 .20822 .82157 .19743 .81344 .18744 .81256 .19533 Metetra
.983 .787 .563 r
.81256 .19533 .81344 .18744 .80507 .17475 .80384 .17482 Metetra
.565 .701 .932 r
.80384 .17482 .80507 .17475 .79635 .15643 .79523 .15933 Metetra
.967 .877 .693 r
.79523 .15933 .79635 .15643 .78793 .14803 .78678 .15041 Metetra
.877 .935 .559 r
.78678 .15041 .78793 .14803 .78066 .17112 .77885 .15751 Metetra
.97 .68 .276 r
.77885 .15751 .78066 .17112 .77092 .13662 .76972 .13853 Metetra
.894 .836 .781 r
.76972 .13853 .77092 .13662 .76235 .13513 .7606 .1226 Metetra
.97 .676 .274 r
.7606 .1226 .76235 .13513 .75218 .09424 .75132 .1057 Metetra
.997 .79 .499 r
.75132 .1057 .75218 .09424 .74282 .07806 .74213 .09502 Metetra
.994 .77 .486 r
.74213 .09502 .74282 .07806 .73346 .06552 .73245 .07424 Metetra
.994 .803 .541 r
.91552 .28862 .91622 .28147 .90935 .27027 .90872 .27889 Metetra
.992 .789 .533 r
.90872 .27889 .90935 .27027 .90255 .26176 .90162 .26532 Metetra
.968 .831 .653 r
.90162 .26532 .90255 .26176 .89561 .25233 .89454 .25368 Metetra
.885 .886 .827 r
.89454 .25368 .89561 .25233 .88862 .24353 .88755 .24494 Metetra
.796 .971 .67 r
.88755 .24494 .88862 .24353 .8816 .2358 .88113 .2483 Metetra
.994 .777 .499 r
.88113 .2483 .8816 .2358 .87463 .23084 .87362 .23374 Metetra
.782 .819 .343 r
.87362 .23374 .87463 .23084 .86832 .24037 .8675 .24716 Metetra
.995 .811 .547 r
.8675 .24716 .86832 .24037 .86073 .22798 .86007 .23793 Metetra
.996 .791 .509 r
.86007 .23793 .86073 .22798 .85356 .22549 .85247 .22756 Metetra
.952 .952 .714 r
.85247 .22756 .85356 .22549 .84603 .2183 .84522 .22603 Metetra
.999 .819 .485 r
.84522 .22603 .84603 .2183 .83859 .21522 .83799 .22774 Metetra
.991 .774 .512 r
.83799 .22774 .83859 .21522 .8305 .20109 .82957 .2072 Metetra
.993 .819 .565 r
.82957 .2072 .8305 .20109 .82254 .19207 .82157 .19743 Metetra
.991 .828 .585 r
.82157 .19743 .82254 .19207 .8143 .17928 .81344 .18744 Metetra
.994 .8 .538 r
.81344 .18744 .8143 .17928 .80594 .16643 .80507 .17475 Metetra
.988 .79 .551 r
.80507 .17475 .80594 .16643 .79713 .14569 .79635 .15643 Metetra
.998 .793 .497 r
.79635 .15643 .79713 .14569 .78909 .1458 .78793 .14803 Metetra
.78793 .14803 .78909 .1458 .78093 .14654 .78066 .17112 Metetra
.991 .756 .478 r
.78066 .17112 .78093 .14654 .77215 .13567 .77092 .13662 Metetra
.751 .992 .879 r
.77092 .13662 .77215 .13567 .76284 .11417 .76235 .13513 Metetra
.987 .755 .496 r
.76235 .13513 .76284 .11417 .75344 .09363 .75218 .09424 Metetra
.717 .785 .905 r
.75218 .09424 .75344 .09363 .74413 .07849 .74282 .07806 Metetra
.221 .56 .936 r
.74282 .07806 .74413 .07849 .73462 .0614 .73346 .06552 Metetra
.955 .641 .219 r
.91622 .28147 .91781 .28916 .91069 .27387 .90935 .27027 Metetra
.886 .507 .041 r
.90935 .27027 .91069 .27387 .90375 .26271 .90255 .26176 Metetra
0 .252 .751 r
.90255 .26176 .90375 .26271 .89683 .25353 .89561 .25233 Metetra
0 .082 .605 r
.89561 .25233 .89683 .25353 .88986 .24513 .88862 .24353 Metetra
.62 .145 0 r
.88862 .24353 .88986 .24513 .88343 .2479 .8816 .2358 Metetra
.978 .684 .32 r
.8816 .2358 .88343 .2479 .87705 .25387 .87463 .23084 Metetra
.986 .71 .388 r
.87463 .23084 .87705 .25387 .87017 .25287 .86832 .24037 Metetra
.973 .681 .289 r
.86832 .24037 .87017 .25287 .86261 .2412 .86073 .22798 Metetra
.98 .688 .336 r
.86073 .22798 .86261 .2412 .85523 .23482 .85356 .22549 Metetra
.97 .663 .281 r
.85356 .22549 .85523 .23482 .84778 .22929 .84603 .2183 Metetra
.977 .677 .319 r
.84603 .2183 .84778 .22929 .84037 .22674 .83859 .21522 Metetra
.969 .673 .271 r
.83859 .21522 .84037 .22674 .83198 .2067 .8305 .20109 Metetra
.94 .597 .175 r
.8305 .20109 .83198 .2067 .82399 .19691 .82254 .19207 Metetra
.903 .55 .081 r
.82254 .19207 .82399 .19691 .81565 .18184 .8143 .17928 Metetra
.718 .307 0 r
.8143 .17928 .81565 .18184 .80731 .16941 .80594 .16643 Metetra
0 0 .338 r
.80594 .16643 .80731 .16941 .79888 .15724 .79713 .14569 Metetra
.978 .678 .333 r
.79713 .14569 .79888 .15724 .79048 .14897 .78909 .1458 Metetra
.912 .509 .168 r
.78909 .1458 .79048 .14897 .78253 .15478 .78093 .14654 Metetra
.96 .643 .239 r
.78093 .14654 .78253 .15478 .7735 .1376 .77215 .13567 Metetra
0 .041 .61 r
.77215 .13567 .7735 .1376 .76452 .12464 .76284 .11417 Metetra
.956 .656 .226 r
.76284 .11417 .76452 .12464 .7551 .10356 .75344 .09363 Metetra
.962 .656 .246 r
.75344 .09363 .7551 .10356 .74568 .08576 .74413 .07849 Metetra
.937 .614 .168 r
.74413 .07849 .74568 .08576 .73605 .0654 .73462 .0614 Metetra
0 .183 .716 r
.91781 .28916 .91902 .29057 .91231 .28198 .91069 .27387 Metetra
.958 .646 .229 r
.91069 .27387 .91231 .28198 .90553 .27376 .90375 .26271 Metetra
.973 .676 .29 r
.90375 .26271 .90553 .27376 .89849 .26255 .89683 .25353 Metetra
.968 .661 .268 r
.89683 .25353 .89849 .26255 .89147 .25311 .88986 .24513 Metetra
.972 .658 .328 r
.88986 .24513 .89147 .25311 .88459 .24797 .88343 .2479 Metetra
.395 0 0 r
.88343 .2479 .88459 .24797 .87782 .2466 .87705 .25387 Metetra
1 .819 .501 r
.87705 .25387 .87782 .2466 .87174 .26017 .87017 .25287 Metetra
.95 .63 .205 r
.87017 .25287 .87174 .26017 .86494 .26297 .86261 .2412 Metetra
.985 .708 .352 r
.86261 .2412 .86494 .26297 .8578 .26162 .85523 .23482 Metetra
.987 .714 .363 r
.85523 .23482 .8578 .26162 .85063 .26203 .84778 .22929 Metetra
.988 .718 .373 r
.84778 .22929 .85063 .26203 .84261 .24771 .84037 .22674 Metetra
.98 .704 .316 r
.84037 .22674 .84261 .24771 .83464 .23651 .83198 .2067 Metetra
.987 .716 .359 r
.83198 .2067 .83464 .23651 .82614 .2164 .82399 .19691 Metetra
.981 .702 .324 r
.82399 .19691 .82614 .2164 .81742 .19371 .81565 .18184 Metetra
.972 .675 .283 r
.81565 .18184 .81742 .19371 .80875 .17374 .80731 .16941 Metetra
.89 .524 .051 r
.80731 .16941 .80875 .17374 .80017 .15826 .79888 .15724 Metetra
0 .152 .634 r
.79888 .15724 .80017 .15826 .79201 .15545 .79048 .14897 Metetra
.961 .629 .317 r
.79048 .14897 .79201 .15545 .78489 .18149 .78253 .15478 Metetra
.984 .712 .342 r
.78253 .15478 .78489 .18149 .77555 .15715 .7735 .1376 Metetra
.982 .701 .33 r
.7735 .1376 .77555 .15715 .76623 .13587 .76452 .12464 Metetra
.959 .662 .235 r
.76452 .12464 .76623 .13587 .75651 .10705 .7551 .10356 Metetra
.769 .396 0 r
.7551 .10356 .75651 .10705 .74736 .09648 .74568 .08576 Metetra
.958 .658 .232 r
.74568 .08576 .74736 .09648 .7379 .0812 .73605 .0654 Metetra
.955 .633 .221 r
.91902 .29057 .92057 .29747 .91328 .27921 .91231 .28198 Metetra
.967 .865 .686 r
.91231 .28198 .91328 .27921 .90624 .26629 .90553 .27376 Metetra
.993 .8 .541 r
.90553 .27376 .90624 .26629 .89921 .25502 .89849 .26255 Metetra
.995 .803 .533 r
.89849 .26255 .89921 .25502 .89191 .24049 .89147 .25311 Metetra
.998 .784 .471 r
.89147 .25311 .89191 .24049 .88519 .23781 .88459 .24797 Metetra
.999 .797 .473 r
.88459 .24797 .88519 .23781 .87802 .22892 .87782 .2466 Metetra
.993 .774 .403 r
.87782 .2466 .87802 .22892 .8711 .22636 .87174 .26017 Metetra
.995 .757 .417 r
.87174 .26017 .8711 .22636 .86402 .22279 .86494 .26297 Metetra
.995 .754 .419 r
.86494 .26297 .86402 .22279 .8569 .22084 .8578 .26162 Metetra
.995 .754 .417 r
.8578 .26162 .8569 .22084 .84946 .21483 .85063 .26203 Metetra
.994 .751 .427 r
.85063 .26203 .84946 .21483 .84211 .21296 .84261 .24771 Metetra
.995 .756 .434 r
.84261 .24771 .84211 .21296 .83372 .19231 .83464 .23651 Metetra
.994 .751 .434 r
.83464 .23651 .83372 .19231 .82547 .17636 .82614 .2164 Metetra
.994 .752 .44 r
.82614 .2164 .82547 .17636 .81737 .16568 .81742 .19371 Metetra
.995 .758 .453 r
.81742 .19371 .81737 .16568 .80901 .15197 .80875 .17374 Metetra
.996 .765 .46 r
.80875 .17374 .80901 .15197 .80067 .14132 .80017 .15826 Metetra
.998 .777 .45 r
.80017 .15826 .80067 .14132 .79232 .13312 .79201 .15545 Metetra
.99 .769 .384 r
.79201 .15545 .79232 .13312 .78465 .1447 .78489 .18149 Metetra
.994 .754 .444 r
.78489 .18149 .78465 .1447 .77547 .12321 .77555 .15715 Metetra
.995 .755 .445 r
.77555 .15715 .77547 .12321 .76623 .10261 .76623 .13587 Metetra
.994 .754 .453 r
.76623 .13587 .76623 .10261 .75698 .08489 .75651 .10705 Metetra
.997 .767 .452 r
.75651 .10705 .75698 .08489 .74808 .08038 .74736 .09648 Metetra
.996 .775 .479 r
.74736 .09648 .74808 .08038 .7383 .05521 .7379 .0812 Metetra
.992 .771 .502 r
.92057 .29747 .9209 .28425 .91391 .27078 .91328 .27921 Metetra
.992 .791 .532 r
.91328 .27921 .91391 .27078 .90698 .25954 .90624 .26629 Metetra
.992 .804 .554 r
.90624 .26629 .90698 .25954 .89968 .24342 .89921 .25502 Metetra
.994 .779 .504 r
.89921 .25502 .89968 .24342 .89257 .23189 .89191 .24049 Metetra
1 .805 .491 r
.89191 .24049 .89257 .23189 .88531 .21912 .88519 .23781 Metetra
.997 .769 .456 r
.88519 .23781 .88531 .21912 .87768 .20138 .87802 .22892 Metetra
.996 .761 .429 r
.87802 .22892 .87768 .20138 .87042 .19188 .8711 .22636 Metetra
.995 .756 .424 r
.8711 .22636 .87042 .19188 .86435 .20664 .86402 .22279 Metetra
.998 .777 .448 r
.86402 .22279 .86435 .20664 .85734 .20621 .8569 .22084 Metetra
.998 .779 .464 r
.8569 .22084 .85734 .20621 .84994 .20066 .84946 .21483 Metetra
.998 .782 .455 r
.84946 .21483 .84994 .20066 .84248 .19602 .84211 .21296 Metetra
.993 .767 .485 r
.84211 .21296 .84248 .19602 .83436 .18041 .83372 .19231 Metetra
.994 .78 .505 r
.83372 .19231 .83436 .18041 .82639 .16998 .82547 .17636 Metetra
.993 .816 .561 r
.82547 .17636 .82639 .16998 .81812 .15544 .81737 .16568 Metetra
.995 .789 .514 r
.81737 .16568 .81812 .15544 .81003 .14707 .80901 .15197 Metetra
.988 .833 .601 r
.80901 .15197 .81003 .14707 .80172 .13675 .80067 .14132 Metetra
.99 .847 .604 r
.80067 .14132 .80172 .13675 .79351 .1316 .79232 .13312 Metetra
.79232 .13312 .79351 .1316 .78569 .13921 .78465 .1447 Metetra
.969 .796 .615 r
.78465 .1447 .78569 .13921 .77685 .12573 .77547 .12321 Metetra
0 0 .431 r
.77547 .12321 .77685 .12573 .76747 .10178 .76623 .10261 Metetra
.758 .782 .873 r
.76623 .10261 .76747 .10178 .75839 .08824 .75698 .08489 Metetra
.9 .494 .091 r
.75698 .08489 .75839 .08824 .74966 .08816 .74808 .08038 Metetra
.912 .601 .117 r
.74808 .08038 .74966 .08816 .73991 .06408 .7383 .05521 Metetra
.935 .615 .164 r
.9209 .28425 .92244 .29107 .91526 .27429 .91391 .27078 Metetra
.841 .466 0 r
.91391 .27078 .91526 .27429 .90835 .26349 .90698 .25954 Metetra
.795 .447 0 r
.90698 .25954 .90835 .26349 .90142 .25362 .89968 .24342 Metetra
.967 .667 .263 r
.89968 .24342 .90142 .25362 .89445 .24462 .89257 .23189 Metetra
.973 .682 .286 r
.89257 .23189 .89445 .24462 .88763 .23983 .88531 .21912 Metetra
.98 .704 .318 r
.88531 .21912 .88763 .23983 .88106 .24165 .87768 .20138 Metetra
.988 .722 .369 r
.87768 .20138 .88106 .24165 .87489 .25296 .87042 .19188 Metetra
.99 .727 .397 r
.87042 .19188 .87489 .25296 .86734 .24072 .86435 .20664 Metetra
.988 .719 .376 r
.86435 .20664 .86734 .24072 .85994 .23346 .85734 .20621 Metetra
.987 .714 .362 r
.85734 .20621 .85994 .23346 .85271 .23156 .84994 .20066 Metetra
.987 .717 .367 r
.84994 .20066 .85271 .23156 .84567 .23583 .84248 .19602 Metetra
.987 .722 .361 r
.84248 .19602 .84567 .23583 .83694 .2084 .83436 .18041 Metetra
.986 .714 .354 r
.83436 .18041 .83694 .2084 .82892 .19746 .82639 .16998 Metetra
.985 .713 .346 r
.82639 .16998 .82892 .19746 .82083 .18724 .81812 .15544 Metetra
.987 .717 .362 r
.81812 .15544 .82083 .18724 .81253 .17514 .81003 .14707 Metetra
.986 .714 .354 r
.81003 .14707 .81253 .17514 .80382 .15627 .80172 .13675 Metetra
.984 .702 .347 r
.80172 .13675 .80382 .15627 .79568 .15293 .79351 .1316 Metetra
.985 .705 .376 r
.79351 .1316 .79568 .15293 .7873 .14755 .78569 .13921 Metetra
.955 .639 .22 r
.78569 .13921 .7873 .14755 .77917 .15173 .77685 .12573 Metetra
.982 .71 .326 r
.77685 .12573 .77917 .15173 .76991 .13153 .76747 .10178 Metetra
.986 .714 .352 r
.76747 .10178 .76991 .13153 .76031 .10507 .75839 .08824 Metetra
.982 .695 .35 r
.75839 .08824 .76031 .10507 .75104 .09061 .74966 .08816 Metetra
0 0 .504 r
.74966 .08816 .75104 .09061 .74119 .06325 .73991 .06408 Metetra
.862 .785 .774 r
.92244 .29107 .92347 .28943 .91676 .28046 .91526 .27429 Metetra
.938 .609 .17 r
.91526 .27429 .91676 .28046 .91 .27203 .90835 .26349 Metetra
.962 .653 .247 r
.90835 .26349 .91 .27203 .90313 .26331 .90142 .25362 Metetra
.969 .665 .272 r
.90142 .25362 .90313 .26331 .89618 .25468 .89445 .24462 Metetra
.974 .672 .301 r
.89445 .24462 .89618 .25468 .88917 .24656 .88763 .23983 Metetra
.967 .641 .305 r
.88763 .23983 .88917 .24656 .88228 .2425 .88106 .24165 Metetra
.718 .284 .218 r
.88106 .24165 .88228 .2425 .87603 .2521 .87489 .25296 Metetra
.793 .828 .879 r
.87489 .25296 .87603 .2521 .86894 .24854 .86734 .24072 Metetra
.963 .645 .253 r
.86734 .24072 .86894 .24854 .86173 .24478 .85994 .23346 Metetra
.978 .678 .324 r
.85994 .23346 .86173 .24478 .85422 .23737 .85271 .23156 Metetra
.959 .622 .304 r
.85271 .23156 .85422 .23737 .84688 .2357 .84567 .23583 Metetra
.616 .608 .82 r
.84567 .23583 .84688 .2357 .83842 .21375 .83694 .2084 Metetra
.925 .579 .134 r
.83694 .2084 .83842 .21375 .83031 .20078 .82892 .19746 Metetra
.851 .455 0 r
.82892 .19746 .83031 .20078 .82196 .18506 .82083 .18724 Metetra
.929 .862 .753 r
.82083 .18724 .82196 .18506 .81339 .16663 .81253 .17514 Metetra
.988 .789 .548 r
.81253 .17514 .81339 .16663 .80513 .15766 .80382 .15627 Metetra
.698 .172 0 r
.80382 .15627 .80513 .15766 .79687 .15156 .79568 .15293 Metetra
.883 .958 .845 r
.79568 .15293 .79687 .15156 .78936 .1665 .7873 .14755 Metetra
.984 .7 .365 r
.7873 .14755 .78936 .1665 .78062 .1559 .77917 .15173 Metetra
.792 .442 0 r
.77917 .15173 .78062 .1559 .77099 .12633 .76991 .13153 Metetra
.954 .783 .632 r
.76991 .13153 .77099 .12633 .76099 .08902 .76031 .10507 Metetra
.996 .775 .477 r
.76031 .10507 .76099 .08902 .75208 .08363 .75104 .09061 Metetra
.971 .781 .592 r
.75104 .09061 .75208 .08363 .74245 .06213 .74119 .06325 Metetra
.835 .873 .872 r
.92347 .28943 .92454 .28844 .91765 .27633 .91676 .28046 Metetra
.986 .84 .613 r
.91676 .28046 .91765 .27633 .91069 .26441 .91 .27203 Metetra
.996 .803 .528 r
.91 .27203 .91069 .26441 .90364 .25222 .90313 .26331 Metetra
.997 .786 .49 r
.90313 .26331 .90364 .25222 .89689 .24678 .89618 .25468 Metetra
.997 .803 .522 r
.89618 .25468 .89689 .24678 .89019 .2441 .88917 .24656 Metetra
.971 .912 .691 r
.88917 .24656 .89019 .2441 .88348 .243 .88228 .2425 Metetra
.631 .164 .126 r
.88228 .2425 .88348 .243 .87721 .25212 .87603 .2521 Metetra
.232 .716 .93 r
.87603 .2521 .87721 .25212 .86984 .24306 .86894 .24854 Metetra
.998 .839 .548 r
.86894 .24854 .86984 .24306 .86263 .23909 .86173 .24478 Metetra
.995 .828 .563 r
.86173 .24478 .86263 .23909 .8551 .23116 .85422 .23737 Metetra
1 .833 .522 r
.85422 .23737 .8551 .23116 .84746 .2231 .84688 .2357 Metetra
.99 .773 .513 r
.84688 .2357 .84746 .2231 .83942 .20932 .83842 .21375 Metetra
.978 .828 .625 r
.83842 .21375 .83942 .20932 .83147 .1994 .83031 .20078 Metetra
.848 .817 .819 r
.83031 .20078 .83147 .1994 .82305 .18198 .82196 .18506 Metetra
.935 .811 .698 r
.82196 .18506 .82305 .18198 .81468 .16764 .81339 .16663 Metetra
0 .179 .669 r
.81339 .16663 .81468 .16764 .80609 .151 .80513 .15766 Metetra
.998 .824 .538 r
.80513 .15766 .80609 .151 .7977 .14158 .79687 .15156 Metetra
.986 .805 .41 r
.79687 .15156 .7977 .14158 .78978 .1462 .78936 .1665 Metetra
.997 .769 .454 r
.78936 .1665 .78978 .1462 .78133 .14191 .78062 .1559 Metetra
.988 .767 .515 r
.78062 .1559 .78133 .14191 .77217 .12347 .77099 .12633 Metetra
.856 .717 .708 r
.77099 .12633 .77217 .12347 .76225 .08824 .76099 .08902 Metetra
.741 .954 .944 r
.76099 .08902 .76225 .08824 .75335 .08281 .75208 .08363 Metetra
.742 .745 .854 r
.75208 .08363 .75335 .08281 .74375 .06194 .74245 .06213 Metetra
.945 .835 .705 r
.92454 .28844 .92551 .28581 .91871 .27503 .91765 .27633 Metetra
.862 .836 .82 r
.91765 .27633 .91871 .27503 .91164 .2611 .91069 .26441 Metetra
.963 .831 .666 r
.91069 .26441 .91164 .2611 .90497 .25545 .90364 .25222 Metetra
.895 .499 .066 r
.90364 .25222 .90497 .25545 .89786 .24367 .89689 .24678 Metetra
.986 .894 .631 r
.89689 .24678 .89786 .24367 .89115 .24047 .89019 .2441 Metetra
.992 .884 .59 r
.89019 .2441 .89115 .24047 .88435 .23756 .88348 .243 Metetra
.975 .844 .444 r
.88348 .243 .88435 .23756 .87809 .24642 .87721 .25212 Metetra
.993 .822 .568 r
.87721 .25212 .87809 .24642 .87076 .23798 .86984 .24306 Metetra
.997 .845 .56 r
.86984 .24306 .87076 .23798 .86329 .22878 .86263 .23909 Metetra
.998 .793 .495 r
.86263 .23909 .86329 .22878 .85584 .22209 .8551 .23116 Metetra
.998 .799 .508 r
.8551 .23116 .85584 .22209 .84853 .22018 .84746 .2231 Metetra
.949 .837 .699 r
.84746 .2231 .84853 .22018 .84045 .20542 .83942 .20932 Metetra
.981 .848 .636 r
.83942 .20932 .84045 .20542 .83237 .19253 .83147 .1994 Metetra
.985 .798 .572 r
.83147 .1994 .83237 .19253 .82409 .17769 .82305 .18198 Metetra
.974 .825 .635 r
.82305 .18198 .82409 .17769 .81581 .1654 .81468 .16764 Metetra
.91 .824 .749 r
.81468 .16764 .81581 .1654 .80713 .14642 .80609 .151 Metetra
.988 .843 .608 r
.80609 .151 .80713 .14642 .7989 .14021 .7977 .14158 Metetra
.72 .951 .659 r
.7977 .14158 .7989 .14021 .79098 .14468 .78978 .1462 Metetra
.899 .967 .82 r
.78978 .1462 .79098 .14468 .78258 .14134 .78133 .14191 Metetra
.706 .75 .886 r
.78133 .14191 .78258 .14134 .77323 .11799 .77217 .12347 Metetra
.936 .757 .634 r
.77217 .12347 .77323 .11799 .76356 .08899 .76225 .08824 Metetra
0 .224 .63 r
.76225 .08824 .76356 .08899 .75452 .07935 .75335 .08281 Metetra
.941 .81 .687 r
.75335 .08281 .75452 .07935 .74487 .05686 .74375 .06194 Metetra
.669 .785 .936 r
.92551 .28581 .92662 .28548 .91961 .27122 .91871 .27503 Metetra
.965 .816 .647 r
.91871 .27503 .91961 .27122 .91289 .263 .91164 .2611 Metetra
.762 .295 0 r
.91164 .2611 .91289 .263 .90605 .25422 .90497 .25545 Metetra
.853 .841 .832 r
.90497 .25545 .90605 .25422 .89919 .24665 .89786 .24367 Metetra
.899 .493 .091 r
.89786 .24367 .89919 .24665 .89245 .24292 .89115 .24047 Metetra
.87 .437 .034 r
.89115 .24047 .89245 .24292 .8856 .23888 .88435 .23756 Metetra
.796 .359 .207 r
.88435 .23756 .8856 .23888 .87955 .25159 .87809 .24642 Metetra
.932 .584 .154 r
.87809 .24642 .87955 .25159 .87208 .24037 .87076 .23798 Metetra
.76 .329 0 r
.87076 .23798 .87208 .24037 .86468 .23238 .86329 .22878 Metetra
.9 .512 .074 r
.86329 .22878 .86468 .23238 .85714 .22394 .85584 .22209 Metetra
.816 .337 0 r
.85584 .22209 .85714 .22394 .84983 .22194 .84853 .22018 Metetra
0 0 .558 r
.84853 .22018 .84983 .22194 .84155 .20287 .84045 .20542 Metetra
.941 .849 .723 r
.84045 .20542 .84155 .20287 .83346 .18978 .83237 .19253 Metetra
.94 .834 .713 r
.83237 .19253 .83346 .18978 .82467 .16396 .82409 .17769 Metetra
.997 .779 .483 r
.82409 .17769 .82467 .16396 .81641 .1513 .81581 .1654 Metetra
.994 .774 .495 r
.81581 .1654 .81641 .1513 .80809 .13991 .80713 .14642 Metetra
.998 .826 .541 r
.80713 .14642 .80809 .13991 .79972 .13022 .7989 .14021 Metetra
.998 .806 .456 r
.7989 .14021 .79972 .13022 .79204 .13967 .79098 .14468 Metetra
.997 .856 .566 r
.79098 .14468 .79204 .13967 .78338 .12972 .78258 .14134 Metetra
.99 .777 .522 r
.78258 .14134 .78338 .12972 .77421 .11037 .77323 .11799 Metetra
.971 .776 .583 r
.77323 .11799 .77421 .11037 .76483 .08852 .76356 .08899 Metetra
.666 .863 .974 r
.76356 .08899 .76483 .08852 .75568 .07572 .75452 .07935 Metetra
.939 .801 .681 r
.75452 .07935 .75568 .07572 .74634 .06133 .74487 .05686 Metetra
.958 .657 .231 r
.92662 .28548 .92835 .29516 .92167 .28646 .91961 .27122 Metetra
.98 .694 .32 r
.91961 .27122 .92167 .28646 .91478 .27548 .91289 .263 Metetra
.976 .683 .3 r
.91289 .263 .91478 .27548 .90789 .26591 .90605 .25422 Metetra
.975 .68 .299 r
.90605 .25422 .90789 .26591 .90111 .25985 .89919 .24665 Metetra
.98 .688 .327 r
.89919 .24665 .90111 .25985 .89377 .24563 .89245 .24292 Metetra
.877 .456 .036 r
.89245 .24292 .89377 .24563 .88655 .23487 .8856 .23888 Metetra
.903 .844 .389 r
.8856 .23888 .88655 .23487 .87946 .22847 .87955 .25159 Metetra
.996 .763 .447 r
.87955 .25159 .87946 .22847 .87259 .22783 .87208 .24037 Metetra
.998 .784 .478 r
.87208 .24037 .87259 .22783 .86548 .22492 .86468 .23238 Metetra
.997 .809 .53 r
.86468 .23238 .86548 .22492 .85819 .22078 .85714 .22394 Metetra
.985 .902 .629 r
.85714 .22394 .85819 .22078 .85046 .21045 .84983 .22194 Metetra
.992 .778 .515 r
.84983 .22194 .85046 .21045 .84246 .19663 .84155 .20287 Metetra
.989 .811 .571 r
.84155 .20287 .84246 .19663 .8342 .17971 .83346 .18978 Metetra
.983 .773 .543 r
.83346 .18978 .8342 .17971 .82575 .16073 .82467 .16396 Metetra
.962 .846 .68 r
.82467 .16396 .82575 .16073 .8176 .15016 .81641 .1513 Metetra
.838 .871 .867 r
.81641 .1513 .8176 .15016 .80938 .14084 .80809 .13991 Metetra
0 .249 .732 r
.80809 .13991 .80938 .14084 .80125 .13638 .79972 .13022 Metetra
.957 .622 .331 r
.79972 .13022 .80125 .13638 .79377 .15057 .79204 .13967 Metetra
.97 .668 .279 r
.79204 .13967 .79377 .15057 .78474 .13176 .78338 .12972 Metetra
0 0 .545 r
.78338 .12972 .78474 .13176 .77558 .11244 .77421 .11037 Metetra
0 .002 .578 r
.77421 .11037 .77558 .11244 .76634 .09397 .76483 .08852 Metetra
.92 .571 .12 r
.76483 .08852 .76634 .09397 .7574 .08704 .75568 .07572 Metetra
.967 .666 .264 r
.75568 .07572 .7574 .08704 .74783 .06645 .74634 .06133 Metetra
.996 .802 .526 r
.92835 .29516 .929 .28749 .9219 .27144 .92167 .28646 Metetra
.997 .773 .472 r
.92167 .28646 .9219 .27144 .91503 .26056 .91478 .27548 Metetra
.997 .774 .468 r
.91478 .27548 .91503 .26056 .90811 .25015 .90789 .26591 Metetra
.998 .774 .456 r
.90789 .26591 .90811 .25015 .90112 .23999 .90111 .25985 Metetra
.996 .765 .46 r
.90111 .25985 .90112 .23999 .89389 .22734 .89377 .24563 Metetra
.996 .769 .458 r
.89377 .24563 .89389 .22734 .88657 .21439 .88655 .23487 Metetra
.997 .767 .443 r
.88655 .23487 .88657 .21439 .8794 .2059 .87946 .22847 Metetra
.996 .766 .428 r
.87946 .22847 .8794 .2059 .87289 .21136 .87259 .22783 Metetra
.998 .775 .447 r
.87259 .22783 .87289 .21136 .8659 .21031 .86548 .22492 Metetra
.998 .78 .457 r
.86548 .22492 .8659 .21031 .85846 .2029 .85819 .22078 Metetra
.997 .771 .459 r
.85819 .22078 .85846 .2029 .8511 .19913 .85046 .21045 Metetra
.996 .784 .503 r
.85046 .21045 .8511 .19913 .84309 .18483 .84246 .19663 Metetra
.994 .78 .506 r
.84246 .19663 .84309 .18483 .83501 .17112 .8342 .17971 Metetra
.988 .788 .546 r
.8342 .17971 .83501 .17112 .82672 .15507 .82575 .16073 Metetra
.992 .824 .577 r
.82575 .16073 .82672 .15507 .8185 .14297 .8176 .15016 Metetra
.997 .813 .539 r
.8176 .15016 .8185 .14297 .81043 .13651 .80938 .14084 Metetra
.994 .865 .593 r
.80938 .14084 .81043 .13651 .80223 .13009 .80125 .13638 Metetra
.965 .834 .414 r
.80125 .13638 .80223 .13009 .79451 .13819 .79377 .15057 Metetra
.994 .779 .506 r
.79377 .15057 .79451 .13819 .78635 .13973 .78474 .13176 Metetra
.934 .619 .162 r
.78474 .13176 .78635 .13973 .77665 .10708 .77558 .11244 Metetra
.976 .809 .611 r
.77558 .11244 .77665 .10708 .76755 .09193 .76634 .09397 Metetra
.939 .927 .767 r
.76634 .09397 .76755 .09193 .75868 .08628 .7574 .08704 Metetra
.735 .75 .864 r
.7574 .08704 .75868 .08628 .74912 .06593 .74783 .06645 Metetra
.838 .783 .8 r
.929 .28749 .93005 .28617 .92313 .27304 .9219 .27144 Metetra
0 0 .524 r
.9219 .27144 .92313 .27304 .91627 .26207 .91503 .26056 Metetra
0 0 .54 r
.91503 .26056 .91627 .26207 .90946 .25348 .90811 .25015 Metetra
.842 .456 0 r
.90811 .25015 .90946 .25348 .90254 .24454 .90112 .23999 Metetra
.883 .531 .041 r
.90112 .23999 .90254 .24454 .89584 .24097 .89389 .22734 Metetra
.974 .685 .289 r
.89389 .22734 .89584 .24097 .8893 .2421 .88657 .21439 Metetra
.986 .714 .353 r
.88657 .21439 .8893 .2421 .88327 .25457 .8794 .2059 Metetra
.989 .724 .385 r
.8794 .2059 .88327 .25457 .87553 .23809 .87289 .21136 Metetra
.987 .713 .365 r
.87289 .21136 .87553 .23809 .86813 .22972 .8659 .21031 Metetra
.983 .703 .338 r
.8659 .21031 .86813 .22972 .86072 .22306 .85846 .2029 Metetra
.984 .704 .349 r
.85846 .2029 .86072 .22306 .85319 .21643 .8511 .19913 Metetra
.978 .695 .309 r
.8511 .19913 .85319 .21643 .84527 .20404 .84309 .18483 Metetra
.98 .7 .32 r
.84309 .18483 .84527 .20404 .8372 .19079 .83501 .17112 Metetra
.98 .7 .316 r
.83501 .17112 .8372 .19079 .8289 .17492 .82672 .15507 Metetra
.981 .702 .327 r
.82672 .15507 .8289 .17492 .82041 .15736 .8185 .14297 Metetra
.979 .688 .32 r
.8185 .14297 .82041 .15736 .81215 .14694 .81043 .13651 Metetra
.972 .667 .29 r
.81043 .13651 .81215 .14694 .80376 .13622 .80223 .13009 Metetra
.957 .621 .322 r
.80223 .13009 .80376 .13622 .79602 .14371 .79451 .13819 Metetra
.954 .605 .263 r
.79451 .13819 .79602 .14371 .7877 .14148 .78635 .13973 Metetra
.101 .243 .724 r
.78635 .13973 .7877 .14148 .77885 .12995 .77665 .10708 Metetra
.982 .705 .33 r
.77665 .10708 .77885 .12995 .76924 .10215 .76755 .09193 Metetra
.972 .663 .29 r
.76755 .09193 .76924 .10215 .7598 .0817 .75868 .08628 Metetra
.964 .809 .64 r
.75868 .08628 .7598 .0817 .75023 .06058 .74912 .06593 Metetra
.861 .82 .807 r
.93005 .28617 .9311 .28479 .92421 .27195 .92313 .27304 Metetra
.84 .845 .849 r
.92313 .27304 .92421 .27195 .9174 .26183 .91627 .26207 Metetra
.615 .81 .975 r
.91627 .26207 .9174 .26183 .9106 .25323 .90946 .25348 Metetra
.617 .806 .973 r
.90946 .25348 .9106 .25323 .90371 .24471 .90254 .24454 Metetra
.1 .618 .886 r
.90254 .24454 .90371 .24471 .89706 .24193 .89584 .24097 Metetra
.691 .148 0 r
.89584 .24097 .89706 .24193 .89025 .23816 .8893 .2421 Metetra
.901 .846 .39 r
.8893 .2421 .89025 .23816 .88423 .25059 .88327 .25457 Metetra
.961 .81 .649 r
.88327 .25457 .88423 .25059 .87675 .23864 .87553 .23809 Metetra
.037 .466 .88 r
.87553 .23809 .87675 .23864 .86948 .23254 .86813 .22972 Metetra
.853 .434 0 r
.86813 .22972 .86948 .23254 .86194 .22326 .86072 .22306 Metetra
.232 .655 .958 r
.86072 .22306 .86194 .22326 .85465 .22115 .85319 .21643 Metetra
.896 .541 .066 r
.85319 .21643 .85465 .22115 .84649 .20402 .84527 .20404 Metetra
.531 .708 .952 r
.84527 .20404 .84649 .20402 .83859 .19411 .8372 .19079 Metetra
.754 .38 0 r
.8372 .19079 .83859 .19411 .83015 .17525 .8289 .17492 Metetra
.429 .589 .908 r
.8289 .17492 .83015 .17525 .82182 .16094 .82041 .15736 Metetra
.864 .475 0 r
.82041 .15736 .82182 .16094 .8133 .14465 .81215 .14694 Metetra
.941 .878 .744 r
.81215 .14694 .8133 .14465 .80497 .1353 .80376 .13622 Metetra
.80376 .13622 .80497 .1353 .79727 .14328 .79602 .14371 Metetra
.502 .901 .932 r
.79602 .14371 .79727 .14328 .78918 .14619 .7877 .14148 Metetra
.905 .542 .084 r
.7877 .14148 .78918 .14619 .77982 .12197 .77885 .12995 Metetra
.976 .778 .574 r
.77885 .12995 .77982 .12197 .77035 .09762 .76924 .10215 Metetra
.963 .808 .642 r
.76924 .10215 .77035 .09762 .76111 .0818 .7598 .0817 Metetra
.517 .627 .899 r
.7598 .0817 .76111 .0818 .75154 .06059 .75023 .06058 Metetra
0 0 .428 r
.9311 .28479 .93236 .28688 .92524 .27023 .92421 .27195 Metetra
.912 .864 .78 r
.92421 .27195 .92524 .27023 .91854 .26173 .9174 .26183 Metetra
.542 .774 .984 r
.9174 .26183 .91854 .26173 .91174 .25306 .9106 .25323 Metetra
.577 .796 .982 r
.9106 .25323 .91174 .25306 .90488 .24495 .90371 .24471 Metetra
0 .525 .803 r
.90371 .24471 .90488 .24495 .89836 .24422 .89706 .24193 Metetra
.845 .4 0 r
.89706 .24193 .89836 .24422 .89162 .24164 .89025 .23816 Metetra
.916 .558 .341 r
.89025 .23816 .89162 .24164 .88498 .24278 .88423 .25059 Metetra
.994 .8 .536 r
.88423 .25059 .88498 .24278 .87787 .23726 .87675 .23864 Metetra
.896 .936 .833 r
.87675 .23864 .87787 .23726 .87034 .22627 .86948 .23254 Metetra
.995 .818 .555 r
.86948 .23254 .87034 .22627 .86246 .21034 .86194 .22326 Metetra
.999 .786 .457 r
.86194 .22326 .86246 .21034 .85532 .21046 .85465 .22115 Metetra
.993 .783 .516 r
.85465 .22115 .85532 .21046 .84682 .18616 .84649 .20402 Metetra
.997 .771 .457 r
.84649 .20402 .84682 .18616 .83895 .17632 .83859 .19411 Metetra
.995 .768 .474 r
.83859 .19411 .83895 .17632 .83097 .16667 .83015 .17525 Metetra
.994 .796 .533 r
.83015 .17525 .83097 .16667 .82275 .15419 .82182 .16094 Metetra
.987 .803 .57 r
.82182 .16094 .82275 .15419 .81433 .13997 .8133 .14465 Metetra
.99 .842 .602 r
.8133 .14465 .81433 .13997 .80602 .13056 .80497 .1353 Metetra
.973 .869 .482 r
.80497 .1353 .80602 .13056 .79842 .14046 .79727 .14328 Metetra
.955 .936 .608 r
.79727 .14328 .79842 .14046 .78991 .13323 .78918 .14619 Metetra
.991 .774 .511 r
.78918 .14619 .78991 .13323 .78046 .10607 .77982 .12197 Metetra
.993 .769 .492 r
.77982 .12197 .78046 .10607 .77144 .09244 .77035 .09762 Metetra
.981 .82 .609 r
.77035 .09762 .77144 .09244 .76209 .07333 .76111 .0818 Metetra
.987 .79 .552 r
.76111 .0818 .76209 .07333 .75259 .05359 .75154 .06059 Metetra
.917 .8 .716 r
.93236 .28688 .93334 .28434 .92661 .27399 .92524 .27023 Metetra
.888 .512 .045 r
.92524 .27023 .92661 .27399 .91967 .26158 .91854 .26173 Metetra
.569 .786 .981 r
.91854 .26173 .91967 .26158 .91288 .25293 .91174 .25306 Metetra
.544 .789 .989 r
.91174 .25306 .91288 .25293 .90613 .24646 .90488 .24495 Metetra
.787 .288 0 r
.90488 .24495 .90613 .24646 .89951 .24396 .89836 .24422 Metetra
.434 .856 .951 r
.89836 .24422 .89951 .24396 .89288 .24316 .89162 .24164 Metetra
.807 .319 .004 r
.89162 .24164 .89288 .24316 .88665 .25132 .88498 .24278 Metetra
.968 .654 .271 r
.88498 .24278 .88665 .25132 .8792 .23981 .87787 .23726 Metetra
.737 .323 0 r
.87787 .23726 .8792 .23981 .87186 .23211 .87034 .22627 Metetra
.902 .57 .086 r
.87034 .22627 .87186 .23211 .86401 .21687 .86246 .21034 Metetra
.963 .631 .279 r
.86246 .21034 .86401 .21687 .85669 .21346 .85532 .21046 Metetra
0 0 .436 r
.85532 .21046 .85669 .21346 .84857 .19671 .84682 .18616 Metetra
.969 .666 .272 r
.84682 .18616 .84857 .19671 .84048 .18253 .83895 .17632 Metetra
.942 .606 .181 r
.83895 .17632 .84048 .18253 .83231 .16883 .83097 .16667 Metetra
.63 .207 0 r
.83097 .16667 .83231 .16883 .82415 .15748 .82275 .15419 Metetra
.784 .399 0 r
.82275 .15419 .82415 .15748 .81585 .14572 .81433 .13997 Metetra
.937 .593 .166 r
.81433 .13997 .81585 .14572 .80749 .13528 .80602 .13056 Metetra
.941 .587 .313 r
.80602 .13056 .80749 .13528 .79981 .14317 .79842 .14046 Metetra
.835 .403 0 r
.79842 .14046 .79981 .14317 .79184 .14847 .78991 .13323 Metetra
.962 .678 .25 r
.78991 .13323 .79184 .14847 .78238 .12161 .78046 .10607 Metetra
.976 .688 .301 r
.78046 .10607 .78238 .12161 .77271 .09177 .77144 .09244 Metetra
.723 .756 .879 r
.77144 .09244 .77271 .09177 .76344 .07461 .76209 .07333 Metetra
0 .251 .763 r
.76209 .07333 .76344 .07461 .75418 .06122 .75259 .05359 Metetra
.992 .81 .557 r
.93334 .28434 .93408 .27809 .92739 .26822 .92661 .27399 Metetra
.987 .809 .576 r
.92661 .27399 .92739 .26822 .92045 .25558 .91967 .26158 Metetra
.995 .817 .555 r
.91967 .26158 .92045 .25558 .91337 .24181 .91288 .25293 Metetra
.999 .788 .479 r
.91288 .25293 .91337 .24181 .90657 .2342 .90613 .24646 Metetra
.999 .786 .459 r
.90613 .24646 .90657 .2342 .90017 .23516 .89951 .24396 Metetra
1 .805 .476 r
.89951 .24396 .90017 .23516 .89373 .23739 .89288 .24316 Metetra
.981 .84 .447 r
.89288 .24316 .89373 .23739 .88718 .23966 .88665 .25132 Metetra
.997 .784 .492 r
.88665 .25132 .88718 .23966 .87988 .23056 .8792 .23981 Metetra
.998 .798 .502 r
.8792 .23981 .87988 .23056 .8723 .21797 .87186 .23211 Metetra
.996 .775 .485 r
.87186 .23211 .8723 .21797 .86503 .21333 .86401 .21687 Metetra
.99 .884 .616 r
.86401 .21687 .86503 .21333 .85773 .21015 .85669 .21346 Metetra
.948 .817 .682 r
.85669 .21346 .85773 .21015 .84932 .18748 .84857 .19671 Metetra
.994 .792 .523 r
.84857 .19671 .84932 .18748 .84145 .17727 .84048 .18253 Metetra
.984 .819 .598 r
.84048 .18253 .84145 .17727 .83327 .16315 .83231 .16883 Metetra
.991 .822 .578 r
.83231 .16883 .83327 .16315 .82503 .14976 .82415 .15748 Metetra
.995 .805 .537 r
.82415 .15748 .82503 .14976 .81655 .1338 .81585 .14572 Metetra
.998 .787 .487 r
.81585 .14572 .81655 .1338 .80827 .12457 .80749 .13528 Metetra
.995 .802 .435 r
.80749 .13528 .80827 .12457 .80031 .12559 .79981 .14317 Metetra
.996 .777 .426 r
.79981 .14317 .80031 .12559 .79195 .12082 .79184 .14847 Metetra
.994 .757 .455 r
.79184 .14847 .79195 .12082 .78293 .1036 .78238 .12161 Metetra
.992 .763 .489 r
.78238 .12161 .78293 .1036 .77392 .08981 .77271 .09177 Metetra
.893 .831 .778 r
.77271 .09177 .77392 .08981 .76466 .07275 .76344 .07461 Metetra
.905 .869 .793 r
.76344 .07461 .76466 .07275 .75538 .05846 .75418 .06122 Metetra
.852 .472 0 r
.93408 .27809 .93543 .28157 .92885 .27334 .92739 .26822 Metetra
.9 .558 .078 r
.92739 .26822 .92885 .27334 .92213 .26429 .92045 .25558 Metetra
.951 .644 .21 r
.92045 .25558 .92213 .26429 .91527 .25433 .91337 .24181 Metetra
.976 .683 .301 r
.91337 .24181 .91527 .25433 .9083 .24391 .90657 .2342 Metetra
.976 .67 .323 r
.90657 .2342 .9083 .24391 .90132 .23496 .90017 .23516 Metetra
.90017 .23516 .90132 .23496 .89424 .2258 .89373 .23739 Metetra
.998 .791 .445 r
.89373 .23739 .89424 .2258 .88708 .21677 .88718 .23966 Metetra
.996 .763 .441 r
.88718 .23966 .88708 .21677 .8802 .21476 .87988 .23056 Metetra
.997 .773 .47 r
.87988 .23056 .8802 .21476 .87318 .21221 .8723 .21797 Metetra
.999 .834 .544 r
.8723 .21797 .87318 .21221 .86599 .20861 .86503 .21333 Metetra
.997 .855 .565 r
.86503 .21333 .86599 .20861 .85857 .2028 .85773 .21015 Metetra
.978 .783 .574 r
.85773 .21015 .85857 .2028 .85068 .19007 .84932 .18748 Metetra
.768 .346 0 r
.84932 .18748 .85068 .19007 .84252 .17409 .84145 .17727 Metetra
.956 .837 .684 r
.84145 .17727 .84252 .17409 .83415 .15575 .83327 .16315 Metetra
.993 .804 .547 r
.83327 .16315 .83415 .15575 .82598 .14358 .82503 .14976 Metetra
.986 .807 .58 r
.82503 .14976 .82598 .14358 .81767 .13094 .81655 .1338 Metetra
.967 .878 .694 r
.81655 .1338 .81767 .13094 .8097 .12839 .80827 .12457 Metetra
.929 .545 .2 r
.80827 .12457 .8097 .12839 .80172 .12885 .80031 .12559 Metetra
.892 .484 .069 r
.80031 .12559 .80172 .12885 .79311 .1181 .79195 .12082 Metetra
.932 .829 .721 r
.79195 .12082 .79311 .1181 .78409 .10053 .78293 .1036 Metetra
.957 .851 .696 r
.78293 .1036 .78409 .10053 .77512 .08733 .77392 .08981 Metetra
.923 .834 .739 r
.77392 .08981 .77512 .08733 .76583 .06926 .76466 .07275 Metetra
.965 .846 .674 r
.76466 .07275 .76583 .06926 .75657 .05514 .75538 .05846 Metetra
.83 .887 .883 r
.93543 .28157 .9365 .28063 .9296 .2671 .92885 .27334 Metetra
.995 .814 .551 r
.92885 .27334 .9296 .2671 .92237 .24942 .92213 .26429 Metetra
.997 .774 .467 r
.92213 .26429 .92237 .24942 .91546 .23835 .91527 .25433 Metetra
.997 .772 .463 r
.91527 .25433 .91546 .23835 .90852 .22814 .9083 .24391 Metetra
.997 .773 .46 r
.9083 .24391 .90852 .22814 .90145 .21717 .90132 .23496 Metetra
.997 .77 .453 r
.90132 .23496 .90145 .21717 .89414 .20346 .89424 .2258 Metetra
.996 .764 .441 r
.89424 .2258 .89414 .20346 .88711 .19629 .88708 .21677 Metetra
.997 .768 .431 r
.88708 .21677 .88711 .19629 .88071 .20241 .8802 .21476 Metetra
.999 .787 .459 r
.8802 .21476 .88071 .20241 .87379 .20136 .87318 .21221 Metetra
.999 .793 .472 r
.87318 .21221 .87379 .20136 .86668 .19881 .86599 .20861 Metetra
.999 .798 .489 r
.86599 .20861 .86668 .19881 .85925 .19262 .85857 .2028 Metetra
.996 .789 .508 r
.85857 .2028 .85925 .19262 .85131 .17861 .85068 .19007 Metetra
.995 .782 .505 r
.85068 .19007 .85131 .17861 .84317 .16245 .84252 .17409 Metetra
.993 .78 .509 r
.84252 .17409 .84317 .16245 .83505 .14896 .83415 .15575 Metetra
.993 .811 .554 r
.83415 .15575 .83505 .14896 .82688 .13646 .82598 .14358 Metetra
.993 .808 .55 r
.82598 .14358 .82688 .13646 .8187 .12616 .81767 .13094 Metetra
.997 .861 .563 r
.81767 .13094 .8187 .12616 .81051 .11855 .8097 .12839 Metetra
.999 .805 .468 r
.8097 .12839 .81051 .11855 .80285 .12558 .80172 .12885 Metetra
.971 .863 .674 r
.80172 .12885 .80285 .12558 .79443 .11902 .79311 .1181 Metetra
.103 .382 .842 r
.79311 .1181 .79443 .11902 .78528 .09842 .78409 .10053 Metetra
.922 .866 .767 r
.78409 .10053 .78528 .09842 .77636 .08603 .77512 .08733 Metetra
.828 .808 .832 r
.77512 .08733 .77636 .08603 .7674 .07625 .76583 .06926 Metetra
.938 .609 .169 r
.76583 .06926 .7674 .07625 .75796 .05742 .75657 .05514 Metetra
.95 .824 .684 r
.9365 .28063 .93745 .27762 .93075 .2672 .9296 .2671 Metetra
.554 .626 .878 r
.9296 .2671 .93075 .2672 .92391 .25599 .92237 .24942 Metetra
.939 .614 .173 r
.92237 .24942 .92391 .25599 .91709 .2463 .91546 .23835 Metetra
.955 .641 .222 r
.91546 .23835 .91709 .2463 .91031 .23877 .90852 .22814 Metetra
.967 .667 .263 r
.90852 .22814 .91031 .23877 .90385 .23817 .90145 .21717 Metetra
.981 .704 .322 r
.90145 .21717 .90385 .23817 .89728 .2377 .89414 .20346 Metetra
.987 .718 .359 r
.89414 .20346 .89728 .2377 .89079 .24066 .88711 .19629 Metetra
.989 .722 .381 r
.88711 .19629 .89079 .24066 .88369 .23469 .88071 .20241 Metetra
.987 .717 .367 r
.88071 .20241 .88369 .23469 .8764 .22724 .87379 .20136 Metetra
.986 .711 .358 r
.87379 .20136 .8764 .22724 .86897 .21908 .86668 .19881 Metetra
.983 .703 .339 r
.86668 .19881 .86897 .21908 .86143 .21097 .85925 .19262 Metetra
.978 .697 .311 r
.85925 .19262 .86143 .21097 .85363 .20003 .85131 .17861 Metetra
.98 .703 .318 r
.85131 .17861 .85363 .20003 .84572 .18892 .84317 .16245 Metetra
.984 .71 .338 r
.84317 .16245 .84572 .18892 .83748 .17331 .83505 .14896 Metetra
.983 .708 .335 r
.83505 .14896 .83748 .17331 .82917 .15827 .82688 .13646 Metetra
.983 .704 .333 r
.82688 .13646 .82917 .15827 .82077 .1438 .8187 .12616 Metetra
.981 .696 .327 r
.8187 .12616 .82077 .1438 .81247 .13374 .81051 .11855 Metetra
.981 .69 .358 r
.81051 .11855 .81247 .13374 .80472 .13905 .80285 .12558 Metetra
.977 .682 .309 r
.80285 .12558 .80472 .13905 .79646 .13645 .79443 .11902 Metetra
.973 .691 .288 r
.79443 .11902 .79646 .13645 .78741 .11851 .78528 .09842 Metetra
.981 .7 .323 r
.78528 .09842 .78741 .11851 .77792 .09267 .77636 .08603 Metetra
.946 .61 .193 r
.77636 .08603 .77792 .09267 .76869 .07574 .7674 .07625 Metetra
.688 .746 .895 r
.7674 .07625 .76869 .07574 .7592 .05557 .75796 .05742 Metetra
.98 .833 .625 r
.93745 .27762 .93833 .27361 .93118 .25596 .93075 .2672 Metetra
.997 .783 .492 r
.93075 .2672 .93118 .25596 .92426 .24295 .92391 .25599 Metetra
.997 .779 .475 r
.92391 .25599 .92426 .24295 .91756 .23492 .91709 .2463 Metetra
.998 .786 .479 r
.91709 .2463 .91756 .23492 .91115 .23344 .91031 .23877 Metetra
.998 .844 .524 r
.91031 .23877 .91115 .23344 .90479 .23434 .90385 .23817 Metetra
.992 .88 .571 r
.90385 .23817 .90479 .23434 .89847 .2379 .89728 .2377 Metetra
.359 0 0 r
.89728 .2377 .89847 .2379 .89197 .24048 .89079 .24066 Metetra
.51 .832 .999 r
.89079 .24066 .89197 .24048 .8847 .23132 .88369 .23469 Metetra
.982 .868 .647 r
.88369 .23469 .8847 .23132 .87737 .22295 .8764 .22724 Metetra
.989 .847 .607 r
.8764 .22724 .87737 .22295 .87013 .21819 .86897 .21908 Metetra
.807 .907 .91 r
.86897 .21908 .87013 .21819 .86276 .2132 .86143 .21097 Metetra
.679 .249 0 r
.86143 .21097 .86276 .2132 .85483 .19949 .85363 .20003 Metetra
.712 .832 .939 r
.85363 .20003 .85483 .19949 .8469 .18777 .84572 .18892 Metetra
.82 .811 .842 r
.84572 .18892 .8469 .18777 .83857 .17031 .83748 .17331 Metetra
.948 .834 .697 r
.83748 .17331 .83857 .17031 .83043 .15867 .82917 .15827 Metetra
.333 .576 .93 r
.82917 .15827 .83043 .15867 .8221 .14538 .82077 .1438 Metetra
0 0 .464 r
.82077 .1438 .8221 .14538 .81377 .13479 .81247 .13374 Metetra
.721 .211 .01 r
.81247 .13374 .81377 .13479 .80572 .13307 .80472 .13905 Metetra
.999 .841 .533 r
.80472 .13905 .80572 .13307 .79753 .13164 .79646 .13645 Metetra
.973 .815 .625 r
.79646 .13645 .79753 .13164 .78816 .10573 .78741 .11851 Metetra
.99 .773 .513 r
.78741 .11851 .78816 .10573 .77883 .08312 .77792 .09267 Metetra
.994 .792 .526 r
.77792 .09267 .77883 .08312 .76978 .07034 .76869 .07574 Metetra
.975 .807 .612 r
.76869 .07574 .76978 .07034 .7602 .04746 .7592 .05557 Metetra
.911 .599 .115 r
.93833 .27361 .93992 .28076 .93246 .25824 .93118 .25596 Metetra
0 0 .376 r
.93118 .25596 .93246 .25824 .92533 .2418 .92426 .24295 Metetra
.864 .898 .856 r
.92426 .24295 .92533 .2418 .91854 .2321 .91756 .23492 Metetra
.981 .912 .634 r
.91756 .23492 .91854 .2321 .91258 .23779 .91115 .23344 Metetra
.946 .585 .237 r
.91115 .23344 .91258 .23779 .90611 .2369 .90479 .23434 Metetra
.9 .489 .19 r
.90479 .23434 .90611 .2369 .8995 .23538 .89847 .2379 Metetra
.95 .938 .605 r
.89847 .2379 .8995 .23538 .89323 .24186 .89197 .24048 Metetra
0 .004 .534 r
.89197 .24048 .89323 .24186 .88621 .23702 .8847 .23132 Metetra
.938 .597 .17 r
.8847 .23132 .88621 .23702 .87885 .22812 .87737 .22295 Metetra
.943 .592 .192 r
.87737 .22295 .87885 .22812 .8713 .21748 .87013 .21819 Metetra
.743 .948 .946 r
.87013 .21819 .8713 .21748 .8642 .21733 .86276 .2132 Metetra
.851 .487 0 r
.86276 .2132 .8642 .21733 .85616 .20144 .85483 .19949 Metetra
0 0 .401 r
.85483 .19949 .85616 .20144 .84817 .18863 .8469 .18777 Metetra
.18 .419 .855 r
.8469 .18777 .84817 .18863 .84001 .17423 .83857 .17031 Metetra
.865 .489 .001 r
.83857 .17031 .84001 .17423 .83177 .16064 .83043 .15867 Metetra
0 0 .436 r
.83043 .15867 .83177 .16064 .82335 .14535 .8221 .14538 Metetra
.484 .743 .985 r
.8221 .14538 .82335 .14535 .8151 .13619 .81377 .13479 Metetra
.723 .197 0 r
.81377 .13479 .8151 .13619 .80718 .13716 .80572 .13307 Metetra
.93 .549 .177 r
.80572 .13307 .80718 .13716 .79889 .13322 .79753 .13164 Metetra
.023 .231 .736 r
.79753 .13164 .79889 .13322 .78941 .10487 .78816 .10573 Metetra
.746 .733 .84 r
.78816 .10573 .78941 .10487 .78011 .08278 .77883 .08312 Metetra
.633 .797 .961 r
.77883 .08312 .78011 .08278 .77094 .06682 .76978 .07034 Metetra
.936 .801 .685 r
.76978 .07034 .77094 .06682 .7616 .04976 .7602 .04746 Metetra
.93 .773 .664 r
.93992 .28076 .94081 .27699 .93383 .26177 .93246 .25824 Metetra
.725 .377 0 r
.93246 .25824 .93383 .26177 .92677 .24658 .92533 .2418 Metetra
.912 .56 .101 r
.92533 .2418 .92677 .24658 .91988 .23527 .91854 .2321 Metetra
.923 .542 .261 r
.91854 .2321 .91988 .23527 .91321 .22902 .91258 .23779 Metetra
1 .805 .474 r
.91258 .23779 .91321 .22902 .90647 .22317 .90611 .2369 Metetra
.998 .782 .446 r
.90611 .2369 .90647 .22317 .9003 .22884 .8995 .23538 Metetra
.989 .83 .452 r
.8995 .23538 .9003 .22884 .89432 .23998 .89323 .24186 Metetra
.943 .935 .758 r
.89323 .24186 .89432 .23998 .8871 .23161 .88621 .23702 Metetra
.994 .828 .572 r
.88621 .23702 .8871 .23161 .87971 .2219 .87885 .22812 Metetra
.994 .816 .559 r
.87885 .22812 .87971 .2219 .87227 .21293 .8713 .21748 Metetra
.995 .866 .547 r
.8713 .21748 .87227 .21293 .86491 .20764 .8642 .21733 Metetra
.994 .788 .521 r
.8642 .21733 .86491 .20764 .857 .19411 .85616 .20144 Metetra
.994 .805 .545 r
.85616 .20144 .857 .19411 .84938 .18816 .84817 .18863 Metetra
.691 .775 .916 r
.84817 .18863 .84938 .18816 .84119 .17313 .84001 .17423 Metetra
.824 .838 .859 r
.84001 .17423 .84119 .17313 .83294 .15889 .83177 .16064 Metetra
.886 .835 .791 r
.83177 .16064 .83294 .15889 .82456 .14426 .82335 .14535 Metetra
.838 .907 .885 r
.82335 .14535 .82456 .14426 .81621 .13278 .8151 .13619 Metetra
.981 .909 .593 r
.8151 .13619 .81621 .13278 .80815 .13049 .80718 .13716 Metetra
1 .83 .525 r
.80718 .13716 .80815 .13049 .79985 .12584 .79889 .13322 Metetra
.972 .778 .584 r
.79889 .13322 .79985 .12584 .79061 .10262 .78941 .10487 Metetra
.887 .793 .75 r
.78941 .10487 .79061 .10262 .78129 .08008 .78011 .08278 Metetra
.937 .842 .724 r
.78011 .08278 .78129 .08008 .77223 .06656 .77094 .06682 Metetra
.619 .732 .927 r
.77094 .06682 .77223 .06656 .76277 .04609 .7616 .04976 Metetra
.838 .792 .808 r
.94081 .27699 .94186 .27572 .93492 .26102 .93383 .26177 Metetra
.763 .765 .855 r
.93383 .26177 .93492 .26102 .9283 .25272 .92677 .24658 Metetra
.93 .6 .149 r
.92677 .24658 .9283 .25272 .92121 .23818 .91988 .23527 Metetra
.861 .451 0 r
.91988 .23527 .92121 .23818 .91436 .22891 .91321 .22902 Metetra
.468 .806 .999 r
.91321 .22902 .91436 .22891 .90849 .23753 .90647 .22317 Metetra
.982 .692 .358 r
.90647 .22317 .90849 .23753 .90169 .23251 .9003 .22884 Metetra
.924 .565 .328 r
.9003 .22884 .90169 .23251 .89516 .23393 .89432 .23998 Metetra
.996 .821 .552 r
.89432 .23998 .89516 .23393 .88844 .23415 .8871 .23161 Metetra
.763 .341 0 r
.8871 .23161 .88844 .23415 .88111 .22543 .87971 .2219 Metetra
.869 .48 .006 r
.87971 .2219 .88111 .22543 .87364 .21597 .87227 .21293 Metetra
.878 .466 .032 r
.87227 .21293 .87364 .21597 .86649 .21457 .86491 .20764 Metetra
.935 .61 .161 r
.86491 .20764 .86649 .21457 .8582 .19347 .857 .19411 Metetra
.723 .93 .959 r
.857 .19411 .8582 .19347 .85013 .17867 .84938 .18816 Metetra
.994 .791 .52 r
.84938 .18816 .85013 .17867 .84205 .16551 .84119 .17313 Metetra
.993 .802 .545 r
.84119 .17313 .84205 .16551 .83389 .1529 .83294 .15889 Metetra
.988 .813 .58 r
.83294 .15889 .83389 .1529 .82546 .13691 .82456 .14426 Metetra
.996 .81 .541 r
.82456 .14426 .82546 .13691 .81733 .1298 .81621 .13278 Metetra
.979 .916 .648 r
.81621 .13278 .81733 .1298 .8091 .12332 .80815 .13049 Metetra
1 .823 .519 r
.80815 .13049 .8091 .12332 .80146 .13335 .79985 .12584 Metetra
.904 .591 .1 r
.79985 .12584 .80146 .13335 .79192 .10319 .79061 .10262 Metetra
.368 .511 .87 r
.79061 .10262 .79192 .10319 .78285 .08633 .78129 .08008 Metetra
.927 .59 .141 r
.78129 .08008 .78285 .08633 .77392 .07618 .77223 .06656 Metetra
.945 .639 .193 r
.77223 .06656 .77392 .07618 .76453 .05772 .76277 .04609 Metetra
.901 .573 .086 r
.94186 .27572 .94337 .28159 .9365 .26803 .93492 .26102 Metetra
.952 .63 .212 r
.93492 .26102 .9365 .26803 .92957 .25479 .9283 .25272 Metetra
0 0 .489 r
.9283 .25272 .92957 .25479 .9223 .23719 .92121 .23818 Metetra
.832 .876 .876 r
.92121 .23818 .9223 .23719 .91545 .22775 .91436 .22891 Metetra
.91436 .22891 .91545 .22775 .90852 .21837 .90849 .23753 Metetra
.997 .769 .438 r
.90849 .23753 .90852 .21837 .90177 .21374 .90169 .23251 Metetra
.996 .77 .424 r
.90169 .23251 .90177 .21374 .89515 .21316 .89516 .23393 Metetra
.996 .767 .423 r
.89516 .23393 .89515 .21316 .88836 .21157 .88844 .23415 Metetra
.996 .764 .438 r
.88844 .23415 .88836 .21157 .88128 .20675 .88111 .22543 Metetra
.997 .769 .449 r
.88111 .22543 .88128 .20675 .87405 .20115 .87364 .21597 Metetra
.998 .78 .443 r
.87364 .21597 .87405 .20115 .86657 .19313 .86649 .21457 Metetra
.995 .762 .462 r
.86649 .21457 .86657 .19313 .8586 .17775 .8582 .19347 Metetra
.996 .773 .472 r
.8582 .19347 .8586 .17775 .85037 .15907 .85013 .17867 Metetra
.996 .767 .453 r
.85013 .17867 .85037 .15907 .84247 .14895 .84205 .16551 Metetra
.997 .773 .463 r
.84205 .16551 .84247 .14895 .83438 .13733 .83389 .1529 Metetra
.996 .773 .475 r
.83389 .1529 .83438 .13733 .82623 .12673 .82546 .13691 Metetra
.999 .797 .489 r
.82546 .13691 .82623 .12673 .81779 .11233 .81733 .1298 Metetra
.998 .774 .447 r
.81733 .1298 .81779 .11233 .81001 .11525 .8091 .12332 Metetra
.988 .82 .433 r
.8091 .12332 .81001 .11525 .80203 .1172 .80146 .13335 Metetra
.991 .765 .497 r
.80146 .13335 .80203 .1172 .79279 .09326 .79192 .10319 Metetra
.994 .79 .52 r
.79192 .10319 .79279 .09326 .7837 .07555 .78285 .08633 Metetra
.998 .794 .494 r
.78285 .08633 .7837 .07555 .77493 .0689 .77392 .07618 Metetra
.988 .801 .563 r
.77392 .07618 .77493 .0689 .76572 .05448 .76453 .05772 Metetra
.982 .81 .596 r
.94337 .28159 .94418 .27647 .93704 .25847 .9365 .26803 Metetra
.995 .787 .513 r
.9365 .26803 .93704 .25847 .92994 .24229 .92957 .25479 Metetra
.994 .774 .499 r
.92957 .25479 .92994 .24229 .92308 .23107 .9223 .23719 Metetra
.995 .815 .554 r
.9223 .23719 .92308 .23107 .91615 .22007 .91545 .22775 Metetra
.997 .804 .524 r
.91545 .22775 .91615 .22007 .90939 .21334 .90852 .21837 Metetra
.998 .842 .558 r
.90852 .21837 .90939 .21334 .90196 .1969 .90177 .21374 Metetra
.997 .774 .432 r
.90177 .21374 .90196 .1969 .89501 .19023 .89515 .21316 Metetra
.996 .764 .423 r
.89515 .21316 .89501 .19023 .88828 .18911 .88836 .21157 Metetra
.996 .765 .43 r
.88836 .21157 .88828 .18911 .88179 .19422 .88128 .20675 Metetra
.999 .785 .465 r
.88128 .20675 .88179 .19422 .87463 .18964 .87405 .20115 Metetra
.999 .788 .479 r
.87405 .20115 .87463 .18964 .86721 .18237 .86657 .19313 Metetra
.995 .785 .507 r
.86657 .19313 .86721 .18237 .85929 .16756 .8586 .17775 Metetra
.992 .783 .521 r
.8586 .17775 .85929 .16756 .8513 .15339 .85037 .15907 Metetra
.993 .826 .57 r
.85037 .15907 .8513 .15339 .84336 .14206 .84247 .14895 Metetra
.995 .812 .549 r
.84247 .14895 .84336 .14206 .83503 .12516 .83438 .13733 Metetra
.998 .785 .482 r
.83438 .13733 .83503 .12516 .82685 .1134 .82623 .12673 Metetra
.997 .78 .484 r
.82623 .12673 .82685 .1134 .81867 .10428 .81779 .11233 Metetra
.997 .82 .47 r
.81779 .11233 .81867 .10428 .81101 .1093 .81001 .11525 Metetra
.996 .846 .505 r
.81001 .11525 .81101 .1093 .80313 .11295 .80203 .1172 Metetra
.948 .793 .655 r
.80203 .1172 .80313 .11295 .79406 .09292 .79279 .09326 Metetra
.646 .732 .911 r
.79279 .09326 .79406 .09292 .78501 .07606 .7837 .07555 Metetra
0 .439 .818 r
.7837 .07555 .78501 .07606 .77613 .06623 .77493 .0689 Metetra
.943 .856 .725 r
.77493 .0689 .77613 .06623 .76671 .04619 .76572 .05448 Metetra
.655 .679 .861 r
.94418 .27647 .9453 .27621 .93832 .26063 .93704 .25847 Metetra
0 0 .514 r
.93704 .25847 .93832 .26063 .93148 .24854 .92994 .24229 Metetra
.932 .602 .153 r
.92994 .24229 .93148 .24854 .92464 .23772 .92308 .23107 Metetra
.939 .613 .171 r
.92308 .23107 .92464 .23772 .91801 .23158 .91615 .22007 Metetra
.974 .676 .292 r
.91615 .22007 .91801 .23158 .91174 .23319 .90939 .21334 Metetra
.977 .699 .305 r
.90939 .21334 .91174 .23319 .90518 .23174 .90196 .1969 Metetra
.987 .717 .357 r
.90196 .1969 .90518 .23174 .89899 .23852 .89501 .19023 Metetra
.988 .723 .371 r
.89501 .19023 .89899 .23852 .89233 .23947 .88828 .18911 Metetra
.989 .723 .378 r
.88828 .18911 .89233 .23947 .88509 .23204 .88179 .19422 Metetra
.987 .719 .362 r
.88179 .19422 .88509 .23204 .87769 .22351 .87463 .18964 Metetra
.986 .716 .355 r
.87463 .18964 .87769 .22351 .87049 .2208 .86721 .18237 Metetra
.986 .718 .349 r
.86721 .18237 .87049 .2208 .86244 .2042 .85929 .16756 Metetra
.986 .717 .348 r
.85929 .16756 .86244 .2042 .85429 .18752 .8513 .15339 Metetra
.986 .716 .349 r
.8513 .15339 .85429 .18752 .84616 .1731 .84336 .14206 Metetra
.984 .713 .336 r
.84336 .14206 .84616 .1731 .83795 .15914 .83503 .12516 Metetra
.985 .715 .348 r
.83503 .12516 .83795 .15914 .82955 .14363 .82685 .1134 Metetra
.985 .713 .348 r
.82685 .1134 .82955 .14363 .8214 .13575 .81867 .10428 Metetra
.987 .714 .369 r
.81867 .10428 .8214 .13575 .81374 .1412 .81101 .1093 Metetra
.987 .714 .367 r
.81101 .1093 .81374 .1412 .80575 .14305 .80313 .11295 Metetra
.983 .711 .33 r
.80313 .11295 .80575 .14305 .79661 .12209 .79406 .09292 Metetra
.983 .711 .334 r
.79406 .09292 .79661 .12209 .78704 .09353 .78501 .07606 Metetra
.979 .693 .315 r
.78501 .07606 .78704 .09353 .77768 .07218 .77613 .06623 Metetra
.885 .552 .054 r
.77613 .06623 .77768 .07218 .76816 .04977 .76671 .04619 Metetra
.978 .701 .308 r
.9453 .27621 .94775 .29662 .9408 .28167 .93832 .26063 Metetra
.981 .703 .321 r
.93832 .26063 .9408 .28167 .93411 .27208 .93148 .24854 Metetra
.983 .707 .331 r
.93148 .24854 .93411 .27208 .92719 .26022 .92464 .23772 Metetra
.984 .707 .34 r
.92464 .23772 .92719 .26022 .92039 .25157 .91801 .23158 Metetra
.984 .704 .355 r
.91801 .23158 .92039 .25157 .91357 .24417 .91174 .23319 Metetra
.976 .675 .313 r
.91174 .23319 .91357 .24417 .90696 .24188 .90518 .23174 Metetra
.976 .672 .347 r
.90518 .23174 .90696 .24188 .90043 .24293 .89899 .23852 Metetra
.944 .581 .231 r
.89899 .23852 .90043 .24293 .89353 .23939 .89233 .23947 Metetra
.481 .786 .998 r
.89233 .23947 .89353 .23939 .88639 .23371 .88509 .23204 Metetra
.6 .13 0 r
.88509 .23204 .88639 .23371 .87897 .22477 .87769 .22351 Metetra
.673 .138 0 r
.87769 .22351 .87897 .22477 .87217 .22926 .87049 .2208 Metetra
.94 .629 .178 r
.87049 .2208 .87217 .22926 .86373 .2054 .86244 .2042 Metetra
0 .277 .78 r
.86244 .2042 .86373 .2054 .85604 .19747 .85429 .18752 Metetra
.957 .652 .228 r
.85429 .18752 .85604 .19747 .848 .18487 .84616 .1731 Metetra
.966 .668 .257 r
.84616 .1731 .848 .18487 .8393 .16114 .83795 .15914 Metetra
0 0 .496 r
.83795 .15914 .8393 .16114 .83088 .14518 .82955 .14363 Metetra
.6 .106 0 r
.82955 .14363 .83088 .14518 .82276 .13755 .8214 .13575 Metetra
.833 .375 .122 r
.8214 .13575 .82276 .13755 .81459 .13189 .81374 .1412 Metetra
.998 .81 .464 r
.81374 .1412 .81459 .13189 .80679 .13749 .80575 .14305 Metetra
.974 .801 .608 r
.80575 .14305 .80679 .13749 .79794 .12297 .79661 .12209 Metetra
.329 .434 .817 r
.79661 .12209 .79794 .12297 .78861 .0999 .78704 .09353 Metetra
.887 .561 .061 r
.78704 .09353 .78861 .0999 .77962 .08767 .77768 .07218 Metetra
.967 .68 .264 r
.77768 .07218 .77962 .08767 .76996 .06221 .76816 .04977 Metetra
.996 .77 .474 r
.94775 .29662 .9479 .28131 .94162 .27655 .9408 .28167 Metetra
.991 .824 .58 r
.9408 .28167 .94162 .27655 .93488 .266 .93411 .27208 Metetra
.991 .81 .564 r
.93411 .27208 .93488 .266 .92805 .25546 .92719 .26022 Metetra
.991 .834 .587 r
.92719 .26022 .92805 .25546 .92117 .24532 .92039 .25157 Metetra
.997 .82 .541 r
.92039 .25157 .92117 .24532 .91435 .23768 .91357 .24417 Metetra
1 .826 .509 r
.91357 .24417 .91435 .23768 .90772 .23482 .90696 .24188 Metetra
.998 .823 .481 r
.90696 .24188 .90772 .23482 .90151 .24105 .90043 .24293 Metetra
.944 .948 .749 r
.90043 .24293 .90151 .24105 .8948 .24074 .89353 .23939 Metetra
.602 .088 0 r
.89353 .23939 .8948 .24074 .88756 .23295 .88639 .23371 Metetra
.776 .884 .924 r
.88639 .23371 .88756 .23295 .88023 .22549 .87897 .22477 Metetra
.644 .107 0 r
.87897 .22477 .88023 .22549 .8744 .24789 .87217 .22926 Metetra
.97 .691 .275 r
.87217 .22926 .8744 .24789 .86559 .21734 .86373 .2054 Metetra
.973 .674 .287 r
.86373 .2054 .86559 .21734 .8573 .19782 .85604 .19747 Metetra
.324 .597 .944 r
.85604 .19747 .8573 .19782 .84918 .18361 .848 .18487 Metetra
.795 .736 .798 r
.848 .18487 .84918 .18361 .84061 .1624 .8393 .16114 Metetra
0 .231 .75 r
.8393 .16114 .84061 .1624 .83227 .14782 .83088 .14518 Metetra
.818 .385 0 r
.83088 .14518 .83227 .14782 .82401 .1372 .82276 .13755 Metetra
.562 .882 .991 r
.82276 .13755 .82401 .1372 .81583 .13119 .81459 .13189 Metetra
.81459 .13189 .81583 .13119 .8086 .14913 .80679 .13749 Metetra
.965 .665 .254 r
.80679 .13749 .8086 .14913 .79913 .12059 .79794 .12297 Metetra
.89 .789 .743 r
.79794 .12297 .79913 .12059 .78957 .09178 .78861 .0999 Metetra
.997 .807 .53 r
.78861 .0999 .78957 .09178 .78054 .07819 .77962 .08767 Metetra
.986 .782 .544 r
.77962 .08767 .78054 .07819 .77117 .05938 .76996 .06221 Metetra
.857 .434 0 r
.9479 .28131 .94921 .28393 .94249 .27227 .94162 .27655 Metetra
.984 .831 .613 r
.94162 .27655 .94249 .27227 .93581 .2625 .93488 .266 Metetra
.975 .842 .648 r
.93488 .266 .93581 .2625 .92899 .25197 .92805 .25546 Metetra
.976 .845 .648 r
.92805 .25546 .92899 .25197 .92232 .24507 .92117 .24532 Metetra
.598 .83 .988 r
.92117 .24532 .92232 .24507 .91552 .23767 .91435 .23768 Metetra
.221 .719 .912 r
.91435 .23768 .91552 .23767 .90878 .23285 .90772 .23482 Metetra
.814 .921 .533 r
.90772 .23482 .90878 .23285 .90265 .24023 .90151 .24105 Metetra
.69 .981 .855 r
.90151 .24105 .90265 .24023 .89606 .24168 .8948 .24074 Metetra
0 .206 .689 r
.8948 .24074 .89606 .24168 .88928 .24218 .88756 .23295 Metetra
.965 .655 .259 r
.88756 .23295 .88928 .24218 .88186 .23298 .88023 .22549 Metetra
.952 .639 .402 r
.88023 .22549 .88186 .23298 .87533 .24236 .8744 .24789 Metetra
.945 .764 .626 r
.8744 .24789 .87533 .24236 .86628 .20697 .86559 .21734 Metetra
.992 .782 .521 r
.86559 .21734 .86628 .20697 .85833 .19388 .8573 .19782 Metetra
.972 .831 .646 r
.8573 .19782 .85833 .19388 .84995 .17421 .84918 .18361 Metetra
.989 .783 .536 r
.84918 .18361 .84995 .17421 .84159 .15695 .84061 .1624 Metetra
.985 .818 .593 r
.84061 .1624 .84159 .15695 .83324 .14179 .83227 .14782 Metetra
.994 .823 .564 r
.83227 .14782 .83324 .14179 .82488 .12895 .82401 .1372 Metetra
1 .811 .505 r
.82401 .1372 .82488 .12895 .81673 .12287 .81583 .13119 Metetra
.966 .809 .379 r
.81583 .13119 .81673 .12287 .80901 .12971 .8086 .14913 Metetra
.993 .763 .477 r
.8086 .14913 .80901 .12971 .79944 .098 .79913 .12059 Metetra
.994 .76 .466 r
.79913 .12059 .79944 .098 .79034 .07933 .78957 .09178 Metetra
.997 .785 .487 r
.78957 .09178 .79034 .07933 .78163 .07292 .78054 .07819 Metetra
.977 .813 .612 r
.78054 .07819 .78163 .07292 .77232 .05516 .77117 .05938 Metetra
.865 .507 .007 r
.94921 .28393 .95063 .28816 .94391 .27663 .94249 .27227 Metetra
.894 .534 .06 r
.94249 .27227 .94391 .27663 .93695 .26236 .93581 .2625 Metetra
.591 .759 .958 r
.93581 .2625 .93695 .26236 .93015 .25186 .92899 .25197 Metetra
.5 .796 .998 r
.92899 .25197 .93015 .25186 .92325 .24131 .92232 .24507 Metetra
.987 .856 .621 r
.92232 .24507 .92325 .24131 .91637 .23229 .91552 .23767 Metetra
.998 .837 .548 r
.91552 .23767 .91637 .23229 .90849 .20807 .90878 .23285 Metetra
.994 .762 .401 r
.90878 .23285 .90849 .20807 .90223 .21267 .90265 .24023 Metetra
.995 .76 .41 r
.90265 .24023 .90223 .21267 .89489 .20049 .89606 .24168 Metetra
.994 .752 .403 r
.89606 .24168 .89489 .20049 .88787 .19568 .88928 .24218 Metetra
.994 .75 .41 r
.88928 .24218 .88787 .19568 .88067 .18969 .88186 .23298 Metetra
.993 .752 .393 r
.88186 .23298 .88067 .18969 .87389 .1933 .87533 .24236 Metetra
.994 .747 .431 r
.87533 .24236 .87389 .1933 .86616 .18165 .86628 .20697 Metetra
.996 .761 .437 r
.86628 .20697 .86616 .18165 .85782 .16032 .85833 .19388 Metetra
.995 .754 .432 r
.85833 .19388 .85782 .16032 .84996 .15012 .84995 .17421 Metetra
.996 .761 .446 r
.84995 .17421 .84996 .15012 .84166 .13329 .84159 .15695 Metetra
.996 .762 .443 r
.84159 .15695 .84166 .13329 .83344 .12016 .83324 .14179 Metetra
.996 .765 .445 r
.83324 .14179 .83344 .12016 .82547 .11478 .82488 .12895 Metetra
.998 .782 .457 r
.82488 .12895 .82547 .11478 .81768 .11603 .81673 .12287 Metetra
.99 .834 .459 r
.81673 .12287 .81768 .11603 .80928 .10721 .80901 .12971 Metetra
.993 .759 .47 r
.80901 .12971 .80928 .10721 .80079 .09927 .79944 .098 Metetra
0 .251 .763 r
.79944 .098 .80079 .09927 .79209 .08996 .79034 .07933 Metetra
.97 .663 .279 r
.79034 .07933 .79209 .08996 .78314 .07767 .78163 .07292 Metetra
.852 .499 0 r
.78163 .07292 .78314 .07767 .77399 .06417 .77232 .05516 Metetra
.997 .778 .479 r
.95063 .28816 .95094 .27554 .94433 .26529 .94391 .27663 Metetra
.995 .78 .497 r
.94391 .27663 .94433 .26529 .93761 .25463 .93695 .26236 Metetra
.996 .801 .526 r
.93695 .26236 .93761 .25463 .93058 .24027 .93015 .25186 Metetra
.997 .783 .483 r
.93015 .25186 .93058 .24027 .92331 .22319 .92325 .24131 Metetra
.997 .769 .446 r
.92325 .24131 .92331 .22319 .91637 .21294 .91637 .23229 Metetra
.993 .761 .472 r
.91637 .23229 .91637 .21294 .90934 .20254 .90849 .20807 Metetra
.989 .845 .474 r
.90849 .20807 .90934 .20254 .90348 .21364 .90223 .21267 Metetra
0 .312 .802 r
.90223 .21267 .90348 .21364 .89669 .21094 .89489 .20049 Metetra
.972 .668 .288 r
.89489 .20049 .89669 .21094 .88976 .20779 .88787 .19568 Metetra
.974 .677 .296 r
.88787 .19568 .88976 .20779 .88239 .19884 .88067 .18969 Metetra
.973 .661 .321 r
.88067 .18969 .88239 .19884 .87501 .19144 .87389 .1933 Metetra
.914 .868 .78 r
.87389 .1933 .87501 .19144 .86723 .17872 .86616 .18165 Metetra
.919 .792 .705 r
.86616 .18165 .86723 .17872 .8595 .16888 .85782 .16032 Metetra
.957 .642 .228 r
.85782 .16032 .8595 .16888 .85164 .15875 .84996 .15012 Metetra
.941 .63 .181 r
.84996 .15012 .85164 .15875 .84303 .13564 .84166 .13329 Metetra
.645 .232 0 r
.84166 .13329 .84303 .13564 .83491 .12461 .83344 .12016 Metetra
.925 .553 .139 r
.83344 .12016 .83491 .12461 .82661 .11216 .82547 .11478 Metetra
.956 .943 .635 r
.82547 .11478 .82661 .11216 .81874 .11139 .81768 .11603 Metetra
.992 .849 .599 r
.81768 .11603 .81874 .11139 .81066 .10916 .80928 .10721 Metetra
.707 .233 0 r
.80928 .10721 .81066 .10916 .8016 .08833 .80079 .09927 Metetra
.999 .794 .487 r
.80079 .09927 .8016 .08833 .79297 .08004 .79209 .08996 Metetra
.998 .796 .506 r
.79209 .08996 .79297 .08004 .78395 .06561 .78314 .07767 Metetra
.998 .787 .489 r
.78314 .07767 .78395 .06561 .77462 .04706 .77399 .06417 Metetra
.997 .783 .483 r
.95094 .27554 .95134 .26415 .94449 .25006 .94433 .26529 Metetra
.995 .766 .467 r
.93058 .24027 .93065 .22292 .9239 .214 .92331 .22319 Metetra
.997 .794 .505 r
.92331 .22319 .9239 .214 .91661 .19767 .91637 .21294 Metetra
.997 .774 .46 r
.91637 .21294 .91661 .19767 .90965 .18811 .90934 .20254 Metetra
.991 .779 .396 r
.90934 .20254 .90965 .18811 .90287 .18306 .90348 .21364 Metetra
.995 .757 .412 r
.90348 .21364 .90287 .18306 .89606 .17949 .89669 .21094 Metetra
.995 .756 .412 r
.89669 .21094 .89606 .17949 .88931 .17868 .88976 .20779 Metetra
.995 .758 .423 r
.88976 .20779 .88931 .17868 .88306 .18902 .88239 .19884 Metetra
.999 .796 .489 r
.88239 .19884 .88306 .18902 .87601 .18739 .87501 .19144 Metetra
.977 .835 .634 r
.87501 .19144 .87601 .18739 .86796 .16942 .86723 .17872 Metetra
.998 .798 .503 r
.86723 .17872 .86796 .16942 .85956 .14662 .8595 .16888 Metetra
.996 .764 .437 r
.8595 .16888 .85956 .14662 .85143 .13042 .85164 .15875 Metetra
.995 .756 .444 r
.85164 .15875 .85143 .13042 .84303 .11088 .84303 .13564 Metetra
.996 .762 .434 r
.84303 .13564 .84303 .11088 .83503 .1015 .83491 .12461 Metetra
.996 .763 .439 r
.83491 .12461 .83503 .1015 .82695 .09276 .82661 .11216 Metetra
.997 .771 .427 r
.82661 .11216 .82695 .09276 .819 .08972 .81874 .11139 Metetra
.996 .768 .425 r
.81874 .11139 .819 .08972 .81107 .09016 .81066 .10916 Metetra
.996 .766 .465 r
.81066 .10916 .81107 .09016 .80276 .08554 .8016 .08833 Metetra
.968 .894 .698 r
.8016 .08833 .80276 .08554 .79437 .08228 .79297 .08004 Metetra
.602 .186 0 r
.79297 .08004 .79437 .08228 .78525 .06545 .78395 .06561 Metetra
.588 .698 .918 r
.78395 .06561 .78525 .06545 .77589 .04577 .77462 .04706 Metetra
.699 .748 .889 r
.95134 .26415 .95245 .26371 .94546 .24737 .94449 .25006 Metetra
.901 .539 .075 r
.93065 .22292 .93208 .22728 .92533 .21828 .9239 .214 Metetra
.806 .462 0 r
.9239 .214 .92533 .21828 .91833 .20674 .91661 .19767 Metetra
.961 .652 .24 r
.91661 .19767 .91833 .20674 .91129 .1959 .90965 .18811 Metetra
.963 .644 .252 r
.90965 .18811 .91129 .1959 .90415 .18477 .90287 .18306 Metetra
.762 .271 0 r
.90287 .18306 .90415 .18477 .89694 .17403 .89606 .17949 Metetra
.998 .844 .52 r
.89606 .17949 .89694 .17403 .89013 .172 .88931 .17868 Metetra
.976 .825 .416 r
.88931 .17868 .89013 .172 .88391 .1827 .88306 .18902 Metetra
.999 .832 .51 r
.88306 .18902 .88391 .1827 .87667 .17725 .87601 .18739 Metetra
.993 .784 .518 r
.87601 .18739 .87667 .17725 .86898 .16559 .86796 .16942 Metetra
.94 .788 .666 r
.86796 .16942 .86898 .16559 .86004 .13234 .85956 .14662 Metetra
.996 .775 .479 r
.85956 .14662 .86004 .13234 .8522 .12144 .85143 .13042 Metetra
.99 .787 .536 r
.85143 .13042 .8522 .12144 .84419 .1093 .84303 .11088 Metetra
.902 .904 .816 r
.84303 .11088 .84419 .1093 .83608 .0974 .83503 .1015 Metetra
.988 .856 .619 r
.83503 .1015 .83608 .0974 .82806 .08967 .82695 .09276 Metetra
.982 .909 .642 r
.82695 .09276 .82806 .08967 .81978 .0792 .819 .08972 Metetra
.999 .8 .457 r
.819 .08972 .81978 .0792 .81168 .07533 .81107 .09016 Metetra
.998 .781 .449 r
.81107 .09016 .81168 .07533 .80402 .08476 .80276 .08554 Metetra
.708 .972 .927 r
.80276 .08554 .80402 .08476 .79566 .08202 .79437 .08228 Metetra
.619 .732 .927 r
.79437 .08228 .79566 .08202 .78665 .06757 .78525 .06545 Metetra
0 0 .533 r
.78525 .06545 .78665 .06757 .77724 .04663 .77589 .04577 Metetra
0 .203 .728 r
.95245 .26371 .95368 .26516 .94673 .24928 .94546 .24737 Metetra
0 0 .439 r
.94546 .24737 .94673 .24928 .94004 .23863 .93874 .23616 Metetra
.759 .338 0 r
.93874 .23616 .94004 .23863 .9334 .22987 .93208 .22728 Metetra
.773 .357 0 r
.93208 .22728 .9334 .22987 .92725 .23049 .92533 .21828 Metetra
.968 .674 .268 r
.92533 .21828 .92725 .23049 .92125 .23528 .91833 .20674 Metetra
.984 .711 .337 r
.91833 .20674 .92125 .23528 .915 .23795 .91129 .1959 Metetra
.986 .719 .352 r
.91129 .1959 .915 .23795 .90889 .24493 .90415 .18477 Metetra
.988 .724 .362 r
.90415 .18477 .90889 .24493 .90154 .23271 .89694 .17403 Metetra
.988 .724 .369 r
.89694 .17403 .90154 .23271 .89446 .22687 .89013 .172 Metetra
.989 .723 .379 r
.89013 .172 .89446 .22687 .88754 .22575 .88391 .1827 Metetra
.987 .72 .359 r
.88391 .1827 .88754 .22575 .88039 .22264 .87667 .17725 Metetra
.987 .72 .354 r
.87667 .17725 .88039 .22264 .87216 .20174 .86898 .16559 Metetra
.979 .713 .314 r
.86898 .16559 .87216 .20174 .86422 .18792 .86004 .13234 Metetra
.988 .723 .36 r
.86004 .13234 .86422 .18792 .85616 .17382 .8522 .12144 Metetra
.987 .722 .357 r
.8522 .12144 .85616 .17382 .84789 .15764 .84419 .1093 Metetra
.987 .721 .356 r
.84419 .1093 .84789 .15764 .83956 .1423 .83608 .0974 Metetra
.987 .72 .358 r
.83608 .0974 .83956 .1423 .83126 .12983 .82806 .08967 Metetra
.986 .718 .351 r
.82806 .08967 .83126 .12983 .8229 .11842 .81978 .0792 Metetra
.987 .717 .358 r
.81978 .0792 .8229 .11842 .81447 .10835 .81168 .07533 Metetra
.987 .713 .371 r
.81168 .07533 .81447 .10835 .80642 .10947 .80402 .08476 Metetra
.984 .706 .345 r
.80402 .08476 .80642 .10947 .79739 .09199 .79566 .08202 Metetra
.957 .649 .226 r
.79566 .08202 .79739 .09199 .78828 .07525 .78665 .06757 Metetra
.917 .599 .123 r
.78665 .06757 .78828 .07525 .77895 .05621 .77724 .04663 Metetra
.967 .681 .265 r
.95368 .26516 .95576 .27954 .94898 .26631 .94673 .24928 Metetra
.977 .694 .304 r
.94673 .24928 .94898 .26631 .94202 .25149 .94004 .23863 Metetra
.973 .68 .287 r
.94004 .23863 .94202 .25149 .93529 .24155 .9334 .22987 Metetra
.978 .68 .324 r
.9334 .22987 .93529 .24155 .92869 .23495 .92725 .23049 Metetra
.947 .591 .277 r
.92725 .23049 .92869 .23495 .92213 .23049 .92125 .23528 Metetra
.991 .859 .504 r
.92125 .23528 .92213 .23049 .91575 .23078 .915 .23795 Metetra
.988 .821 .436 r
.915 .23795 .91575 .23078 .90939 .23315 .90889 .24493 Metetra
.997 .783 .486 r
.90889 .24493 .90939 .23315 .90261 .23037 .90154 .23271 Metetra
.963 .911 .715 r
.90154 .23271 .90261 .23037 .89535 .22123 .89446 .22687 Metetra
.999 .843 .519 r
.89446 .22687 .89535 .22123 .88805 .21318 .88754 .22575 Metetra
.999 .786 .453 r
.88754 .22575 .88805 .21318 .88073 .20658 .88039 .22264 Metetra
.995 .769 .479 r
.88039 .22264 .88073 .20658 .87278 .19047 .87216 .20174 Metetra
.997 .785 .495 r
.87216 .20174 .87278 .19047 .86497 .17885 .86422 .18792 Metetra
.996 .794 .519 r
.86422 .18792 .86497 .17885 .85669 .16017 .85616 .17382 Metetra
.996 .777 .482 r
.85616 .17382 .85669 .16017 .84861 .14707 .84789 .15764 Metetra
.996 .787 .506 r
.84789 .15764 .84861 .14707 .84051 .13605 .83956 .1423 Metetra
.993 .818 .564 r
.83956 .1423 .84051 .13605 .83219 .12274 .83126 .12983 Metetra
.996 .813 .542 r
.83126 .12983 .83219 .12274 .82365 .10724 .8229 .11842 Metetra
.999 .791 .485 r
.8229 .11842 .82365 .10724 .81569 .10687 .81447 .10835 Metetra
.834 .994 .751 r
.81447 .10835 .81569 .10687 .80777 .11065 .80642 .10947 Metetra
0 .278 .781 r
.80642 .10947 .80777 .11065 .79845 .08627 .79739 .09199 Metetra
.985 .816 .592 r
.79739 .09199 .79845 .08627 .78952 .07355 .78828 .07525 Metetra
.865 .815 .798 r
.78828 .07525 .78952 .07355 .77992 .04787 .77895 .05621 Metetra
.972 .821 .634 r
.95576 .27954 .95664 .27555 .94994 .26339 .94898 .26631 Metetra
.944 .819 .691 r
.94898 .26631 .94994 .26339 .94324 .25254 .94202 .25149 Metetra
0 .226 .736 r
.94202 .25149 .94324 .25254 .93681 .24712 .93529 .24155 Metetra
.94 .598 .176 r
.93529 .24155 .93681 .24712 .93038 .24336 .92869 .23495 Metetra
.966 .651 .264 r
.92869 .23495 .93038 .24336 .92377 .23806 .92213 .23049 Metetra
.968 .646 .287 r
.92213 .23049 .92377 .23806 .91731 .23696 .91575 .23078 Metetra
.962 .627 .283 r
.91575 .23078 .91731 .23696 .91096 .23956 .90939 .23315 Metetra
.958 .623 .241 r
.90939 .23315 .91096 .23956 .90384 .23098 .90261 .23037 Metetra
.048 .455 .879 r
.90261 .23037 .90384 .23098 .89661 .22222 .89535 .22123 Metetra
0 .186 .675 r
.89535 .22123 .89661 .22222 .88939 .21524 .88805 .21318 Metetra
.751 .289 0 r
.88805 .21318 .88939 .21524 .88249 .21629 .88073 .20658 Metetra
.949 .644 .205 r
.88073 .20658 .88249 .21629 .87417 .19333 .87278 .19047 Metetra
.763 .357 0 r
.87278 .19047 .87417 .19333 .86641 .18254 .86497 .17885 Metetra
.724 .374 0 r
.86497 .17885 .86641 .18254 .85861 .1731 .85669 .16017 Metetra
.968 .673 .268 r
.85669 .16017 .85861 .1731 .85025 .15464 .84861 .14707 Metetra
.947 .624 .196 r
.84861 .14707 .85025 .15464 .84195 .13965 .84051 .13605 Metetra
.817 .435 0 r
.84051 .13605 .84195 .13965 .83372 .12816 .83219 .12274 Metetra
.89 .546 .058 r
.83219 .12274 .83372 .12816 .82547 .11876 .82365 .10724 Metetra
.975 .671 .31 r
.82365 .10724 .82547 .11876 .81693 .10583 .81569 .10687 Metetra
.596 .92 .688 r
.81569 .10687 .81693 .10583 .80913 .11199 .80777 .11065 Metetra
.084 .293 .775 r
.80777 .11065 .80913 .11199 .79982 .08777 .79845 .08627 Metetra
0 .037 .577 r
.79845 .08627 .79982 .08777 .79079 .07262 .78952 .07355 Metetra
.746 .717 .825 r
.78952 .07355 .79079 .07262 .78154 .05514 .77992 .04787 Metetra
.875 .526 .028 r
.95664 .27555 .95809 .28018 .9514 .26828 .94994 .26339 Metetra
.899 .55 .074 r
.94994 .26339 .9514 .26828 .94484 .25956 .94324 .25254 Metetra
.957 .632 .231 r
.94324 .25254 .94484 .25956 .93814 .24988 .93681 .24712 Metetra
.875 .455 .028 r
.93681 .24712 .93814 .24988 .93156 .24348 .93038 .24336 Metetra
.261 .693 .964 r
.93038 .24336 .93156 .24348 .92493 .23778 .92377 .23806 Metetra
.363 .831 .885 r
.92377 .23806 .92493 .23778 .91852 .23735 .91731 .23696 Metetra
.473 0 0 r
.91731 .23696 .91852 .23735 .91233 .24238 .91096 .23956 Metetra
.81 .396 0 r
.91096 .23956 .91233 .24238 .9049 .22847 .90384 .23098 Metetra
.96 .882 .711 r
.90384 .23098 .9049 .22847 .89765 .21918 .89661 .22222 Metetra
.979 .882 .664 r
.89661 .22222 .89765 .21918 .89054 .21412 .88939 .21524 Metetra
.757 .99 .778 r
.88939 .21524 .89054 .21412 .88347 .21187 .88249 .21629 Metetra
.951 .788 .645 r
.88249 .21629 .88347 .21187 .87506 .18709 .87417 .19333 Metetra
.995 .819 .556 r
.87417 .19333 .87506 .18709 .86683 .16729 .86641 .18254 Metetra
.998 .777 .457 r
.86641 .18254 .86683 .16729 .85903 .15727 .85861 .1731 Metetra
.996 .771 .474 r
.85861 .1731 .85903 .15727 .85063 .13772 .85025 .15464 Metetra
.997 .771 .461 r
.85025 .15464 .85063 .13772 .84259 .12731 .84195 .13965 Metetra
.998 .785 .479 r
.84195 .13965 .84259 .12731 .83443 .11665 .83372 .12816 Metetra
.999 .79 .48 r
.83372 .12816 .83443 .11665 .82614 .10609 .82547 .11876 Metetra
.998 .783 .481 r
.82547 .11876 .82614 .10609 .81802 .10156 .81693 .10583 Metetra
.97 .882 .503 r
.81693 .10583 .81802 .10156 .81001 .10275 .80913 .11199 Metetra
.987 .783 .542 r
.80913 .11199 .81001 .10275 .80107 .08666 .79982 .08777 Metetra
.816 .837 .866 r
.79982 .08777 .80107 .08666 .79201 .07033 .79079 .07262 Metetra
.914 .836 .755 r
.79079 .07262 .79201 .07033 .78277 .05286 .78154 .05514 Metetra
.947 .635 .197 r
.95809 .28018 .95977 .28836 .95309 .27647 .9514 .26828 Metetra
.957 .642 .226 r
.9514 .26828 .95309 .27647 .94654 .26799 .94484 .25956 Metetra
.956 .643 .223 r
.94484 .25956 .94654 .26799 .93984 .25838 .93814 .24988 Metetra
.963 .65 .25 r
.93814 .24988 .93984 .25838 .93311 .24963 .93156 .24348 Metetra
.949 .613 .204 r
.93156 .24348 .93311 .24963 .92634 .24152 .92493 .23778 Metetra
.929 .548 .178 r
.92493 .23778 .92634 .24152 .91932 .23109 .91852 .23735 Metetra
.99 .833 .458 r
.91852 .23735 .91932 .23109 .91187 .21485 .91233 .24238 Metetra
.995 .758 .43 r
.91233 .24238 .91187 .21485 .90511 .21165 .9049 .22847 Metetra
.997 .772 .449 r
.9049 .22847 .90511 .21165 .89819 .20761 .89765 .21918 Metetra
.999 .789 .464 r
.89765 .21918 .89819 .20761 .89153 .21005 .89054 .21412 Metetra
.994 .875 .576 r
.89054 .21412 .89153 .21005 .88457 .20946 .88347 .21187 Metetra
.879 .762 .729 r
.88347 .21187 .88457 .20946 .87633 .18773 .87506 .18709 Metetra
.341 .497 .869 r
.87506 .18709 .87633 .18773 .86814 .1685 .86683 .16729 Metetra
0 .12 .638 r
.86683 .16729 .86814 .1685 .86026 .15699 .85903 .15727 Metetra
.643 .692 .881 r
.85903 .15727 .86026 .15699 .85234 .1466 .85063 .13772 Metetra
.957 .643 .228 r
.85063 .13772 .85234 .1466 .84414 .13295 .84259 .12731 Metetra
.923 .577 .129 r
.84259 .12731 .84414 .13295 .83596 .12195 .83443 .11665 Metetra
.917 .564 .113 r
.83443 .11665 .83596 .12195 .82781 .11416 .82614 .10609 Metetra
.962 .639 .252 r
.82614 .10609 .82781 .11416 .81927 .10081 .81802 .10156 Metetra
.546 .925 .802 r
.81802 .10156 .81927 .10081 .81108 .09781 .81001 .10275 Metetra
.981 .823 .613 r
.81001 .10275 .81108 .09781 .80234 .08577 .80107 .08666 Metetra
.774 .81 .881 r
.80107 .08666 .80234 .08577 .79357 .07614 .79201 .07033 Metetra
.892 .552 .063 r
.79201 .07033 .79357 .07614 .78436 .05931 .78277 .05286 Metetra
.952 .841 .698 r
.95977 .28836 .96073 .28564 .95366 .26772 .95309 .27647 Metetra
.998 .797 .501 r
.95309 .27647 .95366 .26772 .94682 .25444 .94654 .26799 Metetra
.998 .778 .464 r
.94654 .26799 .94682 .25444 .9402 .24576 .93984 .25838 Metetra
.998 .781 .467 r
.93984 .25838 .9402 .24576 .93332 .23426 .93311 .24963 Metetra
.998 .774 .451 r
.93311 .24963 .93332 .23426 .9262 .22035 .92634 .24152 Metetra
.996 .764 .437 r
.92634 .24152 .9262 .22035 .91852 .19853 .91932 .23109 Metetra
.995 .754 .426 r
.91932 .23109 .91852 .19853 .9118 .19378 .91187 .21485 Metetra
.996 .766 .423 r
.91187 .21485 .9118 .19378 .90527 .19411 .90511 .21165 Metetra
.997 .772 .433 r
.90511 .21165 .90527 .19411 .89872 .19602 .89819 .20761 Metetra
.997 .791 .435 r
.89819 .20761 .89872 .19602 .89169 .19161 .89153 .21005 Metetra
.996 .771 .423 r
.89153 .21005 .89169 .19161 .88485 .19265 .88457 .20946 Metetra
.995 .767 .475 r
.88457 .20946 .88485 .19265 .8769 .17582 .87633 .18773 Metetra
.994 .778 .502 r
.87633 .18773 .8769 .17582 .86862 .15451 .86814 .1685 Metetra
.998 .779 .467 r
.86814 .1685 .86862 .15451 .86093 .14591 .86026 .15699 Metetra
.998 .79 .485 r
.86026 .15699 .86093 .14591 .85295 .13405 .85234 .1466 Metetra
.997 .782 .482 r
.85234 .1466 .85295 .13405 .84492 .12342 .84414 .13295 Metetra
.998 .797 .503 r
.84414 .13295 .84492 .12342 .83678 .11289 .83596 .12195 Metetra
.999 .804 .498 r
.83596 .12195 .83678 .11289 .82862 .10452 .82781 .11416 Metetra
.997 .795 .509 r
.82781 .11416 .82862 .10452 .82044 .09831 .81927 .10081 Metetra
.965 .937 .69 r
.81927 .10081 .82044 .09831 .81249 .10027 .81108 .09781 Metetra
.704 .276 0 r
.81108 .09781 .81249 .10027 .80382 .08965 .80234 .08577 Metetra
.877 .489 .023 r
.80234 .08577 .80382 .08965 .79533 .08653 .79357 .07614 Metetra
.953 .648 .217 r
.79357 .07614 .79533 .08653 .78574 .0608 .78436 .05931 Metetra
.956 .798 .645 r
.96073 .28564 .96161 .28162 .95494 .26975 .95366 .26772 Metetra
0 0 .48 r
.95366 .26772 .95494 .26975 .9482 .25791 .94682 .25444 Metetra
.858 .473 0 r
.94682 .25444 .9482 .25791 .94158 .2492 .9402 .24576 Metetra
.812 .434 0 r
.9402 .24576 .94158 .2492 .93501 .24265 .93332 .23426 Metetra
.942 .631 .184 r
.93332 .23426 .93501 .24265 .9287 .24174 .9262 .22035 Metetra
.972 .696 .286 r
.9262 .22035 .9287 .24174 .92263 .24646 .91852 .19853 Metetra
.987 .721 .359 r
.91852 .19853 .92263 .24646 .91737 .26661 .9118 .19378 Metetra
.989 .726 .37 r
.9118 .19378 .91737 .26661 .90954 .24594 .90527 .19411 Metetra
.988 .722 .367 r
.90527 .19411 .90954 .24594 .90313 .25089 .89872 .19602 Metetra
.988 .723 .362 r
.89872 .19602 .90313 .25089 .89594 .24462 .89169 .19161 Metetra
.988 .722 .367 r
.89169 .19161 .89594 .24462 .89031 .26801 .88485 .19265 Metetra
.988 .726 .359 r
.88485 .19265 .89031 .26801 .88186 .2433 .8769 .17582 Metetra
.987 .724 .353 r
.8769 .17582 .88186 .2433 .87269 .20682 .86862 .15451 Metetra
.987 .722 .357 r
.86862 .15451 .87269 .20682 .86528 .20453 .86093 .14591 Metetra
.987 .723 .357 r
.86093 .14591 .86528 .20453 .85631 .17478 .85295 .13405 Metetra
.986 .717 .348 r
.85295 .13405 .85631 .17478 .8477 .15335 .84492 .12342 Metetra
.984 .71 .337 r
.84492 .12342 .8477 .15335 .83948 .14184 .83678 .11289 Metetra
.984 .71 .339 r
.83678 .11289 .83948 .14184 .83113 .12994 .82862 .10452 Metetra
.983 .706 .337 r
.82862 .10452 .83113 .12994 .82285 .12218 .82044 .09831 Metetra
.984 .704 .349 r
.82044 .09831 .82285 .12218 .81586 .14536 .81249 .10027 Metetra
.986 .718 .351 r
.81249 .10027 .81586 .14536 .8061 .11153 .80382 .08965 Metetra
.982 .7 .336 r
.80382 .08965 .8061 .11153 .79683 .0907 .79533 .08653 Metetra
.685 .361 0 r
.79533 .08653 .79683 .0907 .78716 .06302 .78574 .0608 Metetra
.936 .617 .167 r
.96161 .28162 .96324 .28884 .95652 .27621 .95494 .26975 Metetra
.926 .599 .141 r
.95494 .26975 .95652 .27621 .94989 .26608 .9482 .25791 Metetra
.956 .641 .223 r
.9482 .25791 .94989 .26608 .9432 .2562 .94158 .2492 Metetra
.953 .628 .217 r
.94158 .2492 .9432 .2562 .9365 .24758 .93501 .24265 Metetra
.948 .594 .22 r
.93501 .24265 .9365 .24758 .9304 .25004 .9287 .24174 Metetra
.971 .656 .32 r
.9287 .24174 .9304 .25004 .92382 .24643 .92263 .24646 Metetra
.531 .169 .299 r
.92263 .24646 .92382 .24643 .91711 .24243 .91737 .26661 Metetra
.995 .759 .447 r
.91737 .26661 .91711 .24243 .91058 .24314 .90954 .24594 Metetra
.932 .919 .541 r
.90954 .24594 .91058 .24314 .90382 .24199 .90313 .25089 Metetra
1 .803 .491 r
.90313 .25089 .90382 .24199 .89715 .2443 .89594 .24462 Metetra
.461 .117 .295 r
.89594 .24462 .89715 .2443 .89027 .24528 .89031 .26801 Metetra
.995 .76 .457 r
.89031 .26801 .89027 .24528 .88155 .21523 .88186 .2433 Metetra
.993 .753 .458 r
.88186 .2433 .88155 .21523 .87327 .19462 .87269 .20682 Metetra
.998 .789 .451 r
.87269 .20682 .87327 .19462 .86493 .17433 .86528 .20453 Metetra
.994 .754 .444 r
.86528 .20453 .86493 .17433 .85708 .16537 .85631 .17478 Metetra
.99 .784 .533 r
.85631 .17478 .85708 .16537 .84884 .15096 .8477 .15335 Metetra
.944 .875 .737 r
.8477 .15335 .84884 .15096 .84066 .13993 .83948 .14184 Metetra
.917 .879 .782 r
.83948 .14184 .84066 .13993 .83229 .12728 .83113 .12994 Metetra
.967 .901 .704 r
.83113 .12994 .83229 .12728 .82337 .10585 .82285 .12218 Metetra
.981 .775 .364 r
.82285 .12218 .82337 .10585 .8155 .10932 .81586 .14536 Metetra
.994 .751 .437 r
.81586 .14536 .8155 .10932 .80656 .09244 .8061 .11153 Metetra
.996 .767 .461 r
.8061 .11153 .80656 .09244 .79737 .07285 .79683 .0907 Metetra
.994 .765 .477 r
.79683 .0907 .79737 .07285 .78816 .05535 .78716 .06302 Metetra
.92 .838 .748 r
.96324 .28884 .96424 .28677 .95771 .27687 .95652 .27621 Metetra
.102 .45 .883 r
.95652 .27621 .95771 .27687 .95121 .26859 .94989 .26608 Metetra
.73 .316 0 r
.94989 .26608 .95121 .26859 .94454 .25904 .9432 .2562 Metetra
.806 .398 0 r
.9432 .2562 .94454 .25904 .93773 .2486 .9365 .24758 Metetra
.72 .193 0 r
.9365 .24758 .93773 .2486 .93132 .24581 .9304 .25004 Metetra
.996 .863 .574 r
.9304 .25004 .93132 .24581 .92561 .25609 .92382 .24643 Metetra
.97 .661 .278 r
.92382 .24643 .92561 .25609 .91883 .25096 .91711 .24243 Metetra
.97 .654 .295 r
.91711 .24243 .91883 .25096 .91171 .24185 .91058 .24314 Metetra
.856 .997 .807 r
.91058 .24314 .91171 .24185 .90454 .23346 .90382 .24199 Metetra
.997 .81 .454 r
.90382 .24199 .90454 .23346 .89753 .22967 .89715 .2443 Metetra
.997 .78 .428 r
.89715 .2443 .89753 .22967 .89157 .24639 .89027 .24528 Metetra
.325 .401 .787 r
.89027 .24528 .89157 .24639 .88251 .21027 .88155 .21523 Metetra
.967 .799 .622 r
.88155 .21523 .88251 .21027 .8746 .19617 .87327 .19462 Metetra
0 .201 .726 r
.87327 .19462 .8746 .19617 .8665 .18026 .86493 .17433 Metetra
.934 .591 .156 r
.86493 .17433 .8665 .18026 .85915 .18088 .85708 .16537 Metetra
.971 .683 .279 r
.85708 .16537 .85915 .18088 .85023 .15324 .84884 .15096 Metetra
.684 .25 0 r
.84884 .15096 .85023 .15324 .84188 .13877 .84066 .13993 Metetra
.836 .863 .865 r
.84066 .13993 .84188 .13877 .83355 .12684 .83229 .12728 Metetra
.672 .702 .869 r
.83229 .12728 .83355 .12684 .82491 .11105 .82337 .10585 Metetra
.948 .591 .252 r
.82337 .10585 .82491 .11105 .81692 .11182 .8155 .10932 Metetra
0 0 .379 r
.8155 .10932 .81692 .11182 .80814 .09841 .80656 .09244 Metetra
.879 .546 .043 r
.80656 .09244 .80814 .09841 .79902 .08051 .79737 .07285 Metetra
.927 .605 .144 r
.79737 .07285 .79902 .08051 .78964 .05902 .78816 .05535 Metetra
.79 .395 0 r
.96424 .28677 .96559 .28974 .95887 .27688 .95771 .27687 Metetra
.48 .746 .987 r
.95771 .27687 .95887 .27688 .95228 .26723 .95121 .26859 Metetra
.883 .879 .826 r
.95121 .26859 .95228 .26723 .94564 .25803 .94454 .25904 Metetra
.831 .86 .867 r
.94454 .25904 .94564 .25803 .93896 .24951 .93773 .2486 Metetra
.535 0 0 r
.93773 .2486 .93896 .24951 .93298 .25355 .93132 .24581 Metetra
.968 .65 .348 r
.93132 .24581 .93298 .25355 .92665 .25373 .92561 .25609 Metetra
.967 .915 .705 r
.92561 .25609 .92665 .25373 .92058 .26003 .91883 .25096 Metetra
.959 .648 .235 r
.91883 .25096 .92058 .26003 .91444 .26735 .91171 .24185 Metetra
.982 .707 .331 r
.91171 .24185 .91444 .26735 .90741 .26156 .90454 .23346 Metetra
.984 .71 .344 r
.90454 .23346 .90741 .26156 .90073 .2639 .89753 .22967 Metetra
.987 .715 .379 r
.89753 .22967 .90073 .2639 .89401 .26759 .89157 .24639 Metetra
.957 .685 .242 r
.89157 .24639 .89401 .26759 .88486 .23015 .88251 .21027 Metetra
.977 .696 .302 r
.88251 .21027 .88486 .23015 .87632 .20472 .8746 .19617 Metetra
.938 .626 .175 r
.8746 .19617 .87632 .20472 .86806 .18615 .8665 .18026 Metetra
.955 .61 .249 r
.8665 .18026 .86806 .18615 .85973 .16768 .85915 .18088 Metetra
.99 .769 .507 r
.85915 .18088 .85973 .16768 .85179 .15903 .85023 .15324 Metetra
.903 .563 .085 r
.85023 .15324 .85179 .15903 .84343 .14414 .84188 .13877 Metetra
.909 .559 .095 r
.84188 .13877 .84343 .14414 .83502 .13078 .83355 .12684 Metetra
.808 .439 0 r
.83355 .12684 .83502 .13078 .82676 .1228 .82491 .11105 Metetra
.975 .671 .311 r
.82491 .11105 .82676 .1228 .81871 .12219 .81692 .11182 Metetra
.958 .651 .232 r
.81692 .11182 .81871 .12219 .80975 .10515 .80814 .09841 Metetra
.909 .58 .101 r
.80814 .09841 .80975 .10515 .80073 .0893 .79902 .08051 Metetra
.927 .616 .148 r
.79902 .08051 .80073 .0893 .79124 .06535 .78964 .05902 Metetra
.917 .591 .12 r
.96559 .28974 .96716 .29613 .96007 .27759 .95887 .27688 Metetra
.041 .415 .862 r
.95887 .27688 .96007 .27759 .95357 .2692 .95228 .26723 Metetra
.634 .197 0 r
.95228 .26723 .95357 .2692 .9469 .25946 .94564 .25803 Metetra
0 0 .513 r
.94564 .25803 .9469 .25946 .94028 .25182 .93896 .24951 Metetra
.887 .463 .171 r
.93896 .24951 .94028 .25182 .93447 .25834 .93298 .25355 Metetra
.947 .59 .225 r
.93298 .25355 .93447 .25834 .92806 .25728 .92665 .25373 Metetra
.929 .552 .262 r
.92665 .25373 .92806 .25728 .92177 .25982 .92058 .26003 Metetra
.251 0 0 r
.92058 .26003 .92177 .25982 .9146 .24984 .91444 .26735 Metetra
.997 .771 .436 r
.91444 .26735 .9146 .24984 .90795 .2501 .90741 .26156 Metetra
.997 .792 .434 r
.90741 .26156 .90795 .2501 .90157 .25705 .90073 .2639 Metetra
.994 .829 .464 r
.90073 .2639 .90157 .25705 .89501 .26339 .89401 .26759 Metetra
.899 .731 .665 r
.89401 .26759 .89501 .26339 .8851 .21227 .88486 .23015 Metetra
.994 .764 .475 r
.88486 .23015 .8851 .21227 .87695 .19352 .87632 .20472 Metetra
.995 .782 .505 r
.87632 .20472 .87695 .19352 .86886 .17767 .86806 .18615 Metetra
.991 .792 .538 r
.86806 .18615 .86886 .17767 .86072 .16259 .85973 .16768 Metetra
.995 .841 .578 r
.85973 .16768 .86072 .16259 .85262 .15046 .85179 .15903 Metetra
.995 .798 .526 r
.85179 .15903 .85262 .15046 .84435 .13704 .84343 .14414 Metetra
.995 .81 .546 r
.84343 .14414 .84435 .13704 .83592 .12296 .83502 .13078 Metetra
.999 .814 .514 r
.83502 .13078 .83592 .12296 .82767 .11478 .82676 .1228 Metetra
.999 .819 .481 r
.82676 .1228 .82767 .11478 .81967 .11484 .81871 .12219 Metetra
.992 .804 .553 r
.81871 .12219 .81967 .11484 .81091 .10183 .80975 .10515 Metetra
.958 .842 .685 r
.80975 .10515 .81091 .10183 .8019 .08597 .80073 .0893 Metetra
.929 .798 .694 r
.80073 .0893 .8019 .08597 .79246 .0629 .79124 .06535 Metetra
.994 .774 .497 r
.96716 .29613 .96748 .28389 .96077 .27092 .96007 .27759 Metetra
.998 .813 .531 r
.96007 .27759 .96077 .27092 .95319 .24589 .95357 .2692 Metetra
.996 .761 .428 r
.95357 .2692 .95319 .24589 .94634 .23291 .9469 .25946 Metetra
.995 .758 .418 r
.9469 .25946 .94634 .23291 .93965 .22358 .94028 .25182 Metetra
.993 .757 .391 r
.94028 .25182 .93965 .22358 .9331 .21788 .93447 .25834 Metetra
.993 .751 .397 r
.93447 .25834 .9331 .21788 .92702 .2214 .92806 .25728 Metetra
.993 .753 .395 r
.92806 .25728 .92702 .2214 .91915 .19736 .92177 .25982 Metetra
.993 .745 .397 r
.92177 .25982 .91915 .19736 .91346 .21077 .9146 .24984 Metetra
.993 .752 .396 r
.9146 .24984 .91346 .21077 .90693 .21227 .90795 .2501 Metetra
.992 .752 .389 r
.90795 .2501 .90693 .21227 .9004 .21593 .90157 .25705 Metetra
.992 .751 .389 r
.90157 .25705 .9004 .21593 .89312 .2087 .89501 .26339 Metetra
.993 .744 .431 r
.89501 .26339 .89312 .2087 .88502 .18864 .8851 .21227 Metetra
.996 .76 .443 r
.8851 .21227 .88502 .18864 .87681 .16831 .87695 .19352 Metetra
.996 .76 .434 r
.87695 .19352 .87681 .16831 .86955 .16725 .86886 .17767 Metetra
.996 .788 .503 r
.86886 .17767 .86955 .16725 .86142 .15193 .86072 .16259 Metetra
.998 .791 .492 r
.86072 .16259 .86142 .15193 .85304 .13407 .85262 .15046 Metetra
.997 .773 .457 r
.85262 .15046 .85304 .13407 .84494 .12349 .84435 .13704 Metetra
.998 .78 .474 r
.84435 .13704 .84494 .12349 .8367 .11258 .83592 .12296 Metetra
.999 .796 .483 r
.83592 .12296 .8367 .11258 .82903 .11625 .82767 .11478 Metetra
.752 .234 0 r
.82767 .11478 .82903 .11625 .82015 .0973 .81967 .11484 Metetra
.997 .772 .452 r
.81967 .11484 .82015 .0973 .81149 .08574 .81091 .10183 Metetra
.997 .774 .464 r
.81091 .10183 .81149 .08574 .80252 .07007 .8019 .08597 Metetra
.995 .771 .478 r
.8019 .08597 .80252 .07007 .79252 .03369 .79246 .0629 Metetra
.982 .818 .604 r
.96748 .28389 .96831 .27921 .96159 .26595 .96077 .27092 Metetra
.949 .771 .628 r
.96077 .27092 .96159 .26595 .95505 .25653 .95319 .24589 Metetra
.957 .658 .23 r
.95319 .24589 .95505 .25653 .94853 .24859 .94634 .23291 Metetra
.975 .688 .296 r
.94634 .23291 .94853 .24859 .94173 .23781 .93965 .22358 Metetra
.976 .685 .302 r
.93965 .22358 .94173 .23781 .93496 .22877 .9331 .21788 Metetra
.977 .674 .326 r
.9331 .21788 .93496 .22877 .9272 .20512 .92702 .2214 Metetra
.993 .765 .481 r
.92702 .2214 .9272 .20512 .91951 .18386 .91915 .19736 Metetra
.986 .779 .38 r
.91915 .19736 .91951 .18386 .91371 .19489 .91346 .21077 Metetra
.996 .776 .419 r
.91346 .21077 .91371 .19489 .90724 .19704 .90693 .21227 Metetra
.995 .778 .415 r
.90693 .21227 .90724 .19704 .90017 .19107 .9004 .21593 Metetra
.996 .761 .42 r
.9004 .21593 .90017 .19107 .89301 .1852 .89312 .2087 Metetra
.996 .76 .445 r
.89312 .2087 .89301 .1852 .88523 .17045 .88502 .18864 Metetra
.996 .766 .463 r
.88502 .18864 .88523 .17045 .87747 .15785 .87681 .16831 Metetra
.998 .798 .455 r
.87681 .16831 .87747 .15785 .86987 .15 .86955 .16725 Metetra
.997 .77 .457 r
.86955 .16725 .86987 .15 .86191 .13746 .86142 .15193 Metetra
.996 .774 .477 r
.86142 .15193 .86191 .13746 .854 .12814 .85304 .13407 Metetra
.995 .826 .561 r
.85304 .13407 .854 .12814 .84594 .11822 .84494 .12349 Metetra
.993 .834 .582 r
.84494 .12349 .84594 .11822 .83787 .11038 .8367 .11258 Metetra
.896 .959 .623 r
.8367 .11258 .83787 .11038 .82969 .10312 .82903 .11625 Metetra
.996 .778 .488 r
.82903 .11625 .82969 .10312 .82129 .09395 .82015 .0973 Metetra
.973 .864 .67 r
.82015 .0973 .82129 .09395 .81253 .07993 .81149 .08574 Metetra
.988 .819 .584 r
.81149 .08574 .81253 .07993 .8036 .06481 .80252 .07007 Metetra
.935 .758 .638 r
.80252 .07007 .8036 .06481 .79433 .04489 .79252 .03369 Metetra
0 .25 .763 r
.96831 .27921 .96954 .2804 .96301 .26987 .96159 .26595 Metetra
.87 .499 .012 r
.96159 .26595 .96301 .26987 .95635 .25869 .95505 .25653 Metetra
.72 .28 0 r
.95505 .25653 .95635 .25869 .94972 .24903 .94853 .24859 Metetra
.271 .562 .933 r
.94853 .24859 .94972 .24903 .9433 .24396 .94173 .23781 Metetra
.934 .6 .159 r
.94173 .23781 .9433 .24396 .93678 .2388 .93496 .22877 Metetra
.918 .624 .14 r
.93496 .22877 .93678 .2388 .9312 .25026 .9272 .20512 Metetra
.983 .718 .334 r
.9272 .20512 .9312 .25026 .92512 .2557 .91951 .18386 Metetra
.989 .725 .373 r
.91951 .18386 .92512 .2557 .91802 .24628 .91371 .19489 Metetra
.988 .721 .364 r
.91371 .19489 .91802 .24628 .91131 .24503 .90724 .19704 Metetra
.987 .72 .354 r
.90724 .19704 .91131 .24503 .90528 .25746 .90017 .19107 Metetra
.988 .724 .36 r
.90017 .19107 .90528 .25746 .89976 .28122 .89301 .1852 Metetra
.988 .727 .361 r
.89301 .1852 .89976 .28122 .89086 .24828 .88523 .17045 Metetra
.987 .725 .358 r
.88523 .17045 .89086 .24828 .88144 .20695 .87747 .15785 Metetra
.986 .72 .352 r
.87747 .15785 .88144 .20695 .87307 .18589 .86987 .15 Metetra
.984 .714 .337 r
.86987 .15 .87307 .18589 .86454 .16338 .86191 .13746 Metetra
.982 .705 .328 r
.86191 .13746 .86454 .16338 .85658 .15329 .854 .12814 Metetra
.981 .704 .325 r
.854 .12814 .85658 .15329 .84835 .14039 .84594 .11822 Metetra
.981 .7 .323 r
.84594 .11822 .84835 .14039 .84008 .12892 .83787 .11038 Metetra
.979 .693 .313 r
.83787 .11038 .84008 .12892 .83189 .12163 .82969 .10312 Metetra
.978 .692 .308 r
.82969 .10312 .83189 .12163 .82373 .11803 .82129 .09395 Metetra
.979 .701 .314 r
.82129 .09395 .82373 .11803 .81468 .09801 .81253 .07993 Metetra
.974 .689 .29 r
.81253 .07993 .81468 .09801 .80536 .07465 .8036 .06481 Metetra
.94 .634 .182 r
.8036 .06481 .80536 .07465 .79615 .05633 .79433 .04489 Metetra
.957 .651 .227 r
.96954 .2804 .97133 .28989 .96446 .2743 .96301 .26987 Metetra
.872 .516 .02 r
.96301 .26987 .96446 .2743 .95778 .26274 .95635 .25869 Metetra
.874 .505 .018 r
.95635 .25869 .95778 .26274 .95119 .25362 .94972 .24903 Metetra
.927 .566 .143 r
.94972 .24903 .95119 .25362 .94457 .24549 .9433 .24396 Metetra
.668 .17 0 r
.9433 .24396 .94457 .24549 .93833 .24461 .93678 .2388 Metetra
.955 .622 .343 r
.93678 .2388 .93833 .24461 .93218 .24689 .9312 .25026 Metetra
.95 .894 .502 r
.9312 .25026 .93218 .24689 .92635 .25616 .92512 .2557 Metetra
.181 .544 .928 r
.92512 .2557 .92635 .25616 .92061 .26896 .91802 .24628 Metetra
.983 .704 .339 r
.91802 .24628 .92061 .26896 .91337 .25916 .91131 .24503 Metetra
.98 .686 .363 r
.91131 .24503 .91337 .25916 .90756 .27529 .90528 .25746 Metetra
.981 .694 .391 r
.90528 .25746 .90756 .27529 .90324 .31994 .89976 .28122 Metetra
.978 .711 .31 r
.89976 .28122 .90324 .31994 .89259 .2568 .89086 .24828 Metetra
.765 .501 0 r
.89086 .24828 .89259 .2568 .88473 .24367 .88144 .20695 Metetra
.981 .713 .325 r
.88144 .20695 .88473 .24367 .87538 .20518 .87307 .18589 Metetra
.968 .688 .271 r
.87307 .18589 .87538 .20518 .86677 .18134 .86454 .16338 Metetra
.977 .691 .302 r
.86454 .16338 .86677 .18134 .85786 .15348 .85658 .15329 Metetra
.41 .657 .96 r
.85658 .15329 .85786 .15348 .84976 .14299 .84835 .14039 Metetra
.728 .306 0 r
.84835 .14039 .84976 .14299 .84138 .12922 .84008 .12892 Metetra
.145 .597 .929 r
.84008 .12892 .84138 .12922 .83302 .11837 .83189 .12163 Metetra
.983 .905 .635 r
.83189 .12163 .83302 .11837 .82468 .11043 .82373 .11803 Metetra
.989 .797 .556 r
.82373 .11803 .82468 .11043 .81572 .09209 .81468 .09801 Metetra
.975 .797 .601 r
.81468 .09801 .81572 .09209 .80684 .07831 .80536 .07465 Metetra
.748 .381 0 r
.80536 .07465 .80684 .07831 .79755 .05787 .79615 .05633 Metetra
.847 .512 0 r
.97133 .28989 .97282 .29494 .96591 .2788 .96446 .2743 Metetra
.871 .517 .019 r
.96446 .2743 .96591 .2788 .95931 .26822 .95778 .26274 Metetra
.922 .579 .126 r
.95778 .26274 .95931 .26822 .95272 .25918 .95119 .25362 Metetra
.929 .586 .144 r
.95119 .25362 .95272 .25918 .9461 .25091 .94457 .24549 Metetra
.952 .605 .229 r
.94457 .24549 .9461 .25091 .94032 .25726 .93833 .24461 Metetra
.978 .681 .326 r
.93833 .24461 .94032 .25726 .93476 .26891 .93218 .24689 Metetra
.985 .704 .362 r
.93218 .24689 .93476 .26891 .92863 .27357 .92635 .25616 Metetra
.983 .696 .367 r
.92635 .25616 .92863 .27357 .92051 .2474 .92061 .26896 Metetra
.996 .764 .431 r
.92061 .26896 .92051 .2474 .9139 .24766 .91337 .25916 Metetra
.977 .785 .367 r
.91337 .25916 .9139 .24766 .90789 .26003 .90756 .27529 Metetra
.919 .737 .247 r
.90756 .27529 .90789 .26003 .90217 .27995 .90324 .31994 Metetra
.99 .744 .457 r
.90324 .31994 .90217 .27995 .89292 .24055 .89259 .2568 Metetra
.997 .773 .456 r
.89259 .2568 .89292 .24055 .88379 .20432 .88473 .24367 Metetra
.994 .749 .435 r
.88473 .24367 .88379 .20432 .87577 .18919 .87538 .20518 Metetra
.994 .768 .48 r
.87538 .20518 .87577 .18919 .86793 .17938 .86677 .18134 Metetra
.839 .738 .752 r
.86677 .18134 .86793 .17938 .85949 .16035 .85786 .15348 Metetra
.938 .606 .169 r
.85786 .15348 .85949 .16035 .85114 .14494 .84976 .14299 Metetra
0 0 .472 r
.84976 .14299 .85114 .14494 .84291 .13407 .84138 .12922 Metetra
.899 .537 .071 r
.84138 .12922 .84291 .13407 .83458 .12379 .83302 .11837 Metetra
.927 .572 .141 r
.83302 .11837 .83458 .12379 .8266 .12333 .82468 .11043 Metetra
.959 .664 .236 r
.82468 .11043 .8266 .12333 .81779 .10836 .81572 .09209 Metetra
.972 .683 .282 r
.81572 .09209 .81779 .10836 .80871 .0903 .80684 .07831 Metetra
.952 .655 .216 r
.80684 .07831 .80871 .0903 .79918 .06483 .79755 .05787 Metetra
.817 .779 .817 r
.97282 .29494 .97389 .2938 .96658 .27164 .96591 .2788 Metetra
.996 .805 .53 r
.96591 .2788 .96658 .27164 .95995 .2605 .95931 .26822 Metetra
.998 .804 .514 r
.95931 .26822 .95995 .2605 .95328 .24999 .95272 .25918 Metetra
.999 .796 .491 r
.95272 .25918 .95328 .24999 .94678 .24328 .9461 .25091 Metetra
.988 .814 .427 r
.9461 .25091 .94678 .24328 .94088 .24738 .94032 .25726 Metetra
.981 .794 .385 r
.94032 .25726 .94088 .24738 .93474 .24959 .93476 .26891 Metetra
.994 .768 .401 r
.93476 .26891 .93474 .24959 .92901 .26015 .92863 .27357 Metetra
.991 .768 .503 r
.92863 .27357 .92901 .26015 .92194 .25111 .92051 .2474 Metetra
.926 .54 .174 r
.92051 .2474 .92194 .25111 .91478 .24198 .9139 .24766 Metetra
.948 .827 .387 r
.9139 .24766 .91478 .24198 .90809 .24259 .90789 .26003 Metetra
.982 .768 .36 r
.90789 .26003 .90809 .24259 .90339 .2795 .90217 .27995 Metetra
.655 .584 .763 r
.90217 .27995 .90339 .2795 .89271 .21506 .89292 .24055 Metetra
.993 .754 .461 r
.89292 .24055 .89271 .21506 .88533 .20944 .88379 .20432 Metetra
.871 .524 .022 r
.88379 .20432 .88533 .20944 .87734 .19484 .87577 .18919 Metetra
.923 .575 .127 r
.87577 .18919 .87734 .19484 .86888 .17346 .86793 .17938 Metetra
.982 .804 .589 r
.86793 .17938 .86888 .17346 .86049 .15513 .85949 .16035 Metetra
.985 .82 .599 r
.85949 .16035 .86049 .15513 .85239 .14429 .85114 .14494 Metetra
.733 .861 .941 r
.85114 .14494 .85239 .14429 .84414 .13287 .84291 .13407 Metetra
.849 .902 .872 r
.84291 .13407 .84414 .13287 .83577 .12157 .83458 .12379 Metetra
.94 .963 .69 r
.83458 .12379 .83577 .12157 .82738 .11224 .8266 .12333 Metetra
.998 .789 .494 r
.8266 .12333 .82738 .11224 .8185 .09557 .81779 .10836 Metetra
.997 .781 .487 r
.81779 .10836 .8185 .09557 .80974 .08392 .80871 .0903 Metetra
.975 .792 .594 r
.80871 .0903 .80974 .08392 .80023 .05831 .79918 .06483 Metetra
.023 .212 .719 r
.97389 .2938 .97516 .29554 .96804 .27609 .96658 .27164 Metetra
.873 .517 .021 r
.96658 .27164 .96804 .27609 .96134 .26389 .95995 .2605 Metetra
.817 .434 0 r
.95995 .2605 .96134 .26389 .95473 .25421 .95328 .24999 Metetra
.907 .538 .089 r
.95328 .24999 .95473 .25421 .94818 .2467 .94678 .24328 Metetra
.928 .544 .229 r
.94678 .24328 .94818 .2467 .94228 .25084 .94088 .24738 Metetra
.926 .539 .198 r
.94088 .24738 .94228 .25084 .93592 .24943 .93474 .24959 Metetra
.383 0 .03 r
.93474 .24959 .93592 .24943 .93047 .26428 .92901 .26015 Metetra
.884 .511 .037 r
.92901 .26015 .93047 .26428 .92317 .25136 .92194 .25111 Metetra
.309 .643 .967 r
.92194 .25111 .92317 .25136 .91574 .23757 .91478 .24198 Metetra
.992 .871 .533 r
.91478 .24198 .91574 .23757 .90899 .23689 .90809 .24259 Metetra
.90809 .24259 .90899 .23689 .90222 .2379 .90339 .2795 Metetra
.99 .743 .454 r
.90339 .2795 .90222 .2379 .89357 .2084 .89271 .21506 Metetra
1 .825 .52 r
.89271 .21506 .89357 .2084 .88567 .19329 .88533 .20944 Metetra
.997 .772 .459 r
.88533 .20944 .88567 .19329 .87749 .17472 .87734 .19484 Metetra
.996 .764 .455 r
.87734 .19484 .87749 .17472 .86956 .16265 .86888 .17346 Metetra
.995 .784 .506 r
.86888 .17346 .86956 .16265 .8614 .14833 .86049 .15513 Metetra
.997 .817 .541 r
.86049 .15513 .8614 .14833 .85314 .13406 .85239 .14429 Metetra
.999 .794 .492 r
.85239 .14429 .85314 .13406 .84486 .12168 .84414 .13287 Metetra
.999 .79 .483 r
.84414 .13287 .84486 .12168 .83671 .1142 .83577 .12157 Metetra
.999 .817 .525 r
.83577 .12157 .83671 .1142 .82827 .10358 .82738 .11224 Metetra
.995 .798 .528 r
.82738 .11224 .82827 .10358 .8194 .08672 .8185 .09557 Metetra
.999 .804 .51 r
.8185 .09557 .8194 .08672 .81057 .07298 .80974 .08392 Metetra
.991 .779 .52 r
.80974 .08392 .81057 .07298 .80151 .05723 .80023 .05831 Metetra
.991 .779 .521 r
.97516 .29554 .97564 .28567 .96887 .27132 .96804 .27609 Metetra
.985 .821 .597 r
.96804 .27609 .96887 .27132 .96278 .26805 .96134 .26389 Metetra
.876 .51 .024 r
.96134 .26389 .96278 .26805 .95613 .25769 .95473 .25421 Metetra
.869 .48 .005 r
.95473 .25421 .95613 .25769 .9495 .24889 .94818 .2467 Metetra
.879 .448 .16 r
.94818 .2467 .9495 .24889 .94285 .24121 .94228 .25084 Metetra
.999 .799 .456 r
.94228 .25084 .94285 .24121 .93603 .23228 .93592 .24943 Metetra
.986 .769 .371 r
.93592 .24943 .93603 .23228 .92929 .22603 .93047 .26428 Metetra
.994 .751 .409 r
.93047 .26428 .92929 .22603 .92276 .22496 .92317 .25136 Metetra
.995 .758 .426 r
.92317 .25136 .92276 .22496 .91644 .22897 .91574 .23757 Metetra
.999 .809 .465 r
.91574 .23757 .91644 .22897 .91091 .24861 .90899 .23689 Metetra
.976 .673 .311 r
.90899 .23689 .91091 .24861 .90359 .24025 .90222 .2379 Metetra
0 .113 .65 r
.90222 .2379 .90359 .24025 .89452 .20325 .89357 .2084 Metetra
.984 .818 .599 r
.89357 .2084 .89452 .20325 .8862 .18037 .88567 .19329 Metetra
.996 .777 .487 r
.88567 .19329 .8862 .18037 .87809 .16297 .87749 .17472 Metetra
.998 .786 .479 r
.87749 .17472 .87809 .16297 .86974 .14263 .86956 .16265 Metetra
.997 .766 .442 r
.86956 .16265 .86974 .14263 .86183 .1324 .8614 .14833 Metetra
.997 .774 .458 r
.8614 .14833 .86183 .1324 .85365 .11919 .85314 .13406 Metetra
.998 .777 .459 r
.85314 .13406 .85365 .11919 .84574 .11354 .84486 .12168 Metetra
1 .812 .504 r
.84486 .12168 .84574 .11354 .83758 .10572 .83671 .1142 Metetra
.999 .806 .511 r
.83671 .1142 .83758 .10572 .82962 .10448 .82827 .10358 Metetra
.097 .39 .848 r
.82827 .10358 .82962 .10448 .82062 .08458 .8194 .08672 Metetra
.924 .869 .766 r
.8194 .08672 .82062 .08458 .812 .0755 .81057 .07298 Metetra
.618 .218 0 r
.81057 .07298 .812 .0755 .80282 .05677 .80151 .05723 Metetra
.989 .802 .56 r
.97564 .28567 .97634 .27928 .96967 .26602 .96887 .27132 Metetra
.999 .84 .53 r
.96887 .27132 .96967 .26602 .96309 .25542 .96278 .26805 Metetra
.998 .78 .467 r
.96278 .26805 .96309 .25542 .95646 .24507 .95613 .25769 Metetra
.998 .781 .462 r
.95613 .25769 .95646 .24507 .94979 .23544 .9495 .24889 Metetra
.998 .779 .453 r
.9495 .24889 .94979 .23544 .94282 .22247 .94285 .24121 Metetra
.997 .767 .434 r
.94285 .24121 .94282 .22247 .9354 .20369 .93603 .23228 Metetra
.995 .757 .409 r
.93603 .23228 .9354 .20369 .92802 .18668 .92929 .22603 Metetra
.993 .751 .393 r
.92929 .22603 .92802 .18668 .92189 .19127 .92276 .22496 Metetra
.992 .753 .39 r
.92276 .22496 .92189 .19127 .91555 .19434 .91644 .22897 Metetra
.988 .752 .366 r
.91644 .22897 .91555 .19434 .90875 .19166 .91091 .24861 Metetra
.993 .746 .393 r
.91091 .24861 .90875 .19166 .9016 .18514 .90359 .24025 Metetra
.993 .745 .417 r
.90359 .24025 .9016 .18514 .89394 .17162 .89452 .20325 Metetra
.995 .754 .429 r
.89452 .20325 .89394 .17162 .88622 .15872 .8862 .18037 Metetra
.996 .763 .442 r
.8862 .18037 .88622 .15872 .87826 .1434 .87809 .16297 Metetra
.996 .764 .454 r
.87809 .16297 .87826 .1434 .87032 .13022 .86974 .14263 Metetra
.999 .785 .469 r
.86974 .14263 .87032 .13022 .86218 .11517 .86183 .1324 Metetra
.997 .771 .45 r
.86183 .1324 .86218 .11517 .8544 .10906 .85365 .11919 Metetra
.999 .799 .473 r
.85365 .11919 .8544 .10906 .84643 .1019 .84574 .11354 Metetra
.999 .791 .468 r
.84574 .11354 .84643 .1019 .83842 .09644 .83758 .10572 Metetra
.999 .808 .465 r
.83758 .10572 .83842 .09644 .83054 .09649 .82962 .10448 Metetra
.991 .796 .547 r
.82962 .10448 .83054 .09649 .82198 .08562 .82062 .08458 Metetra
0 .183 .667 r
.82062 .08458 .82198 .08562 .81333 .07548 .812 .0755 Metetra
.542 .67 .921 r
.812 .0755 .81333 .07548 .8039 .05121 .80282 .05677 Metetra
.963 .829 .663 r
.97634 .27928 .97726 .27595 .97071 .26436 .96967 .26602 Metetra
.907 .865 .787 r
.96967 .26602 .97071 .26436 .96408 .25284 .96309 .25542 Metetra
.957 .861 .704 r
.96309 .25542 .96408 .25284 .95764 .24521 .95646 .24507 Metetra
.421 .686 .973 r
.95646 .24507 .95764 .24521 .95118 .23874 .94979 .23544 Metetra
.758 .383 0 r
.94979 .23544 .95118 .23874 .94473 .23369 .94282 .22247 Metetra
.944 .649 .197 r
.94282 .22247 .94473 .23369 .93916 .24398 .9354 .20369 Metetra
.983 .715 .331 r
.9354 .20369 .93916 .24398 .93253 .23955 .92802 .18668 Metetra
.988 .721 .363 r
.92802 .18668 .93253 .23955 .92573 .23388 .92189 .19127 Metetra
.987 .718 .358 r
.92189 .19127 .92573 .23388 .91881 .22793 .91555 .19434 Metetra
.985 .713 .345 r
.91555 .19434 .91881 .22793 .91254 .2347 .90875 .19166 Metetra
.985 .717 .347 r
.90875 .19166 .91254 .2347 .90671 .2511 .9016 .18514 Metetra
.986 .722 .35 r
.9016 .18514 .90671 .2511 .89774 .21594 .89394 .17162 Metetra
.984 .717 .34 r
.89394 .17162 .89774 .21594 .88971 .19826 .88622 .15872 Metetra
.983 .714 .333 r
.88622 .15872 .88971 .19826 .88153 .17954 .87826 .1434 Metetra
.983 .712 .332 r
.87826 .1434 .88153 .17954 .87346 .16459 .87032 .13022 Metetra
.982 .711 .327 r
.87032 .13022 .87346 .16459 .8654 .15167 .86218 .11517 Metetra
.985 .713 .342 r
.86218 .11517 .8654 .15167 .85679 .13036 .8544 .10906 Metetra
.98 .698 .318 r
.8544 .10906 .85679 .13036 .8487 .1211 .84643 .1019 Metetra
.979 .694 .316 r
.84643 .1019 .8487 .1211 .84033 .10871 .83842 .09644 Metetra
.975 .672 .305 r
.83842 .09644 .84033 .10871 .83224 .10477 .83054 .09649 Metetra
.949 .627 .201 r
.83054 .09649 .83224 .10477 .8235 .0899 .82198 .08562 Metetra
.884 .506 .037 r
.82198 .08562 .8235 .0899 .81457 .0738 .81333 .07548 Metetra
.839 .771 .786 r
.81333 .07548 .81457 .0738 .80531 .05309 .8039 .05121 Metetra
.927 .603 .143 r
.97726 .27595 .97888 .28274 .97226 .27013 .97071 .26436 Metetra
.909 .574 .1 r
.97071 .26436 .97226 .27013 .96576 .26052 .96408 .25284 Metetra
.952 .632 .212 r
.96408 .25284 .96576 .26052 .95924 .25173 .95764 .24521 Metetra
.946 .615 .194 r
.95764 .24521 .95924 .25173 .95264 .24298 .95118 .23874 Metetra
.918 .547 .117 r
.95118 .23874 .95264 .24298 .94629 .23954 .94473 .23369 Metetra
.957 .622 .332 r
.94473 .23369 .94629 .23954 .94063 .24826 .93916 .24398 Metetra
.921 .549 .128 r
.93916 .24398 .94063 .24826 .93402 .24406 .93253 .23955 Metetra
.92 .553 .121 r
.93253 .23955 .93402 .24406 .92755 .24367 .92573 .23388 Metetra
.965 .656 .258 r
.92573 .23388 .92755 .24367 .92109 .24528 .91881 .22793 Metetra
.982 .694 .347 r
.91881 .22793 .92109 .24528 .91377 .23459 .91254 .2347 Metetra
.469 .065 .192 r
.91254 .2347 .91377 .23459 .90862 .26243 .90671 .2511 Metetra
.886 .606 .091 r
.90671 .2511 .90862 .26243 .89894 .21522 .89774 .21594 Metetra
.743 .76 .866 r
.89774 .21594 .89894 .21522 .89118 .20217 .88971 .19826 Metetra
.734 .387 0 r
.88971 .19826 .89118 .20217 .88315 .18603 .88153 .17954 Metetra
.91 .579 .103 r
.88153 .17954 .88315 .18603 .87509 .1713 .87346 .16459 Metetra
.924 .593 .134 r
.87346 .16459 .87509 .1713 .86735 .16427 .8654 .15167 Metetra
.95 .656 .211 r
.8654 .15167 .86735 .16427 .85921 .15222 .85679 .13036 Metetra
.979 .698 .313 r
.85679 .13036 .85921 .15222 .85052 .13144 .8487 .1211 Metetra
.957 .649 .228 r
.8487 .1211 .85052 .13144 .84189 .11401 .84033 .10871 Metetra
.937 .578 .175 r
.84033 .10871 .84189 .11401 .8338 .10975 .83224 .10477 Metetra
.872 .518 .021 r
.83224 .10477 .8338 .10975 .82487 .09105 .8235 .0899 Metetra
0 .272 .777 r
.8235 .0899 .82487 .09105 .816 .07596 .81457 .0738 Metetra
0 0 .554 r
.81457 .0738 .816 .07596 .80654 .05087 .80531 .05309 Metetra
.948 .838 .701 r
.97888 .28274 .97984 .28006 .97251 .2569 .97226 .27013 Metetra
.998 .778 .459 r
.97226 .27013 .97251 .2569 .96602 .24715 .96576 .26052 Metetra
.998 .778 .456 r
.96576 .26052 .96602 .24715 .95939 .23646 .95924 .25173 Metetra
.997 .773 .446 r
.95924 .25173 .95939 .23646 .953 .23069 .95264 .24298 Metetra
.998 .784 .444 r
.95264 .24298 .953 .23069 .94748 .23951 .94629 .23954 Metetra
.409 0 0 r
.94629 .23954 .94748 .23951 .94135 .24089 .94063 .24826 Metetra
1 .815 .495 r
.94063 .24826 .94135 .24089 .93554 .24911 .93402 .24406 Metetra
.947 .591 .216 r
.93402 .24406 .93554 .24911 .92994 .26264 .92755 .24367 Metetra
.982 .697 .335 r
.92755 .24367 .92994 .26264 .92261 .25016 .92109 .24528 Metetra
.895 .539 .064 r
.92109 .24528 .92261 .25016 .91626 .25553 .91377 .23459 Metetra
.982 .699 .393 r
.91377 .23459 .91626 .25553 .91198 .29817 .90862 .26243 Metetra
.967 .702 .273 r
.90862 .26243 .91198 .29817 .90061 .22238 .89894 .21522 Metetra
.929 .603 .147 r
.89894 .21522 .90061 .22238 .89357 .22208 .89118 .20217 Metetra
.973 .692 .288 r
.89118 .20217 .89357 .22208 .88504 .19719 .88315 .18603 Metetra
.955 .654 .224 r
.88315 .18603 .88504 .19719 .87638 .17155 .87509 .1713 Metetra
.189 .627 .944 r
.87509 .1713 .87638 .17155 .86869 .16552 .86735 .16427 Metetra
0 .162 .686 r
.86735 .16427 .86869 .16552 .86033 .14891 .85921 .15222 Metetra
.939 .809 .689 r
.85921 .15222 .86033 .14891 .85197 .13463 .85052 .13144 Metetra
.682 .312 0 r
.85052 .13144 .85197 .13463 .84397 .12952 .84189 .11401 Metetra
.976 .683 .304 r
.84189 .11401 .84397 .12952 .83502 .10806 .8338 .10975 Metetra
.866 .816 .798 r
.8338 .10975 .83502 .10806 .82647 .09693 .82487 .09105 Metetra
.899 .557 .076 r
.82487 .09105 .82647 .09693 .81711 .07135 .816 .07596 Metetra
.956 .796 .643 r
.816 .07596 .81711 .07135 .80789 .05112 .80654 .05087 Metetra
.808 .723 .771 r
.97984 .28006 .9809 .27865 .97462 .27081 .97251 .2569 Metetra
.97 .679 .275 r
.97251 .2569 .97462 .27081 .96809 .26057 .96602 .24715 Metetra
.968 .676 .267 r
.96602 .24715 .96809 .26057 .96157 .25162 .95939 .23646 Metetra
.976 .686 .3 r
.95939 .23646 .96157 .25162 .955 .24307 .953 .23069 Metetra
.979 .681 .348 r
.953 .23069 .955 .24307 .94841 .23562 .94748 .23951 Metetra
.986 .882 .536 r
.94748 .23951 .94841 .23562 .94294 .24706 .94135 .24089 Metetra
.96 .626 .316 r
.94135 .24089 .94294 .24706 .93652 .2454 .93554 .24911 Metetra
.839 .816 .333 r
.93554 .24911 .93652 .2454 .92946 .23543 .92994 .26264 Metetra
.995 .757 .42 r
.92994 .26264 .92946 .23543 .92246 .22777 .92261 .25016 Metetra
.993 .763 .393 r
.92261 .25016 .92246 .22777 .91553 .22307 .91626 .25553 Metetra
.975 .746 .323 r
.91626 .25553 .91553 .22307 .90896 .22622 .91198 .29817 Metetra
.992 .74 .427 r
.91198 .29817 .90896 .22622 .90075 .20345 .90061 .22238 Metetra
.995 .77 .413 r
.90061 .22238 .90075 .20345 .89304 .19073 .89357 .22208 Metetra
.995 .753 .43 r
.89357 .22208 .89304 .19073 .88499 .17392 .88504 .19719 Metetra
.995 .759 .449 r
.88504 .19719 .88499 .17392 .87692 .1584 .87638 .17155 Metetra
.998 .784 .45 r
.87638 .17155 .87692 .1584 .8691 .14939 .86869 .16552 Metetra
.997 .772 .46 r
.86869 .16552 .8691 .14939 .86101 .13747 .86033 .14891 Metetra
.998 .787 .487 r
.86033 .14891 .86101 .13747 .85284 .12642 .85197 .13463 Metetra
1 .814 .492 r
.85197 .13463 .85284 .12642 .84445 .11318 .84397 .12952 Metetra
.996 .77 .469 r
.84397 .12952 .84445 .11318 .83653 .11212 .83502 .10806 Metetra
.864 .482 0 r
.83502 .10806 .83653 .11212 .82779 .09697 .82647 .09693 Metetra
.553 .607 .861 r
.82647 .09693 .82779 .09697 .81838 .07033 .81711 .07135 Metetra
.78 .777 .851 r
.81711 .07135 .81838 .07033 .8091 .04839 .80789 .05112 Metetra
.998 .781 .458 r
.9809 .27865 .98119 .26637 .97432 .24977 .97462 .27081 Metetra
.996 .762 .428 r
.97462 .27081 .97432 .24977 .96735 .2326 .96809 .26057 Metetra
.995 .756 .412 r
.96809 .26057 .96735 .2326 .96068 .22087 .96157 .25162 Metetra
.994 .754 .408 r
.96157 .25162 .96068 .22087 .95436 .21562 .955 .24307 Metetra
.995 .757 .41 r
.955 .24307 .95436 .21562 .94891 .22522 .94841 .23562 Metetra
.981 .79 .381 r
.94841 .23562 .94891 .22522 .94338 .23537 .94294 .24706 Metetra
.998 .788 .44 r
.94294 .24706 .94338 .23537 .93729 .23866 .93652 .2454 Metetra
.997 .814 .534 r
.93652 .2454 .93729 .23866 .93035 .23022 .92946 .23543 Metetra
.997 .837 .562 r
.92946 .23543 .93035 .23022 .92337 .22275 .92246 .22777 Metetra
.998 .848 .551 r
.92246 .22777 .92337 .22275 .91661 .22061 .91553 .22307 Metetra
.927 .942 .592 r
.91553 .22307 .91661 .22061 .90951 .21466 .90896 .22622 Metetra
.992 .776 .508 r
.90896 .22622 .90951 .21466 .9017 .19848 .90075 .20345 Metetra
.988 .829 .595 r
.90075 .20345 .9017 .19848 .89376 .18145 .89304 .19073 Metetra
.995 .791 .517 r
.89304 .19073 .89376 .18145 .88564 .16303 .88499 .17392 Metetra
.997 .786 .495 r
.88499 .17392 .88564 .16303 .87782 .15175 .87692 .1584 Metetra
.998 .822 .534 r
.87692 .1584 .87782 .15175 .86994 .14133 .8691 .14939 Metetra
.998 .806 .519 r
.8691 .14939 .86994 .14133 .86184 .12906 .86101 .13747 Metetra
.999 .805 .511 r
.86101 .13747 .86184 .12906 .85346 .11334 .85284 .12642 Metetra
.998 .782 .47 r
.85284 .12642 .85346 .11334 .84532 .10472 .84445 .11318 Metetra
.998 .815 .471 r
.84445 .11318 .84532 .10472 .83708 .09672 .83653 .11212 Metetra
.998 .775 .461 r
.83653 .11212 .83708 .09672 .82793 .07254 .82779 .09697 Metetra
.995 .759 .445 r
.82779 .09697 .82793 .07254 .81944 .06466 .81838 .07033 Metetra
.977 .804 .603 r
.81838 .07033 .81944 .06466 .81033 .04631 .8091 .04839 Metetra
.904 .591 .101 r
.98119 .26637 .98285 .2737 .97621 .26033 .97432 .24977 Metetra
.942 .644 .189 r
.97432 .24977 .97621 .26033 .96894 .23882 .96735 .2326 Metetra
.916 .586 .117 r
.96735 .2326 .96894 .23882 .96207 .22422 .96068 .22087 Metetra
.884 .488 .04 r
.96068 .22087 .96207 .22422 .95536 .21299 .95436 .21562 Metetra
.802 .848 .391 r
.95436 .21562 .95536 .21299 .9489 .20692 .94891 .22522 Metetra
.989 .767 .381 r
.94891 .22522 .9489 .20692 .94212 .1974 .94338 .23537 Metetra
.992 .75 .385 r
.94338 .23537 .94212 .1974 .93621 .20269 .93729 .23866 Metetra
.994 .752 .402 r
.93729 .23866 .93621 .20269 .92992 .20407 .93035 .23022 Metetra
.995 .758 .412 r
.93035 .23022 .92992 .20407 .9235 .20503 .92337 .22275 Metetra
.996 .771 .418 r
.92337 .22275 .9235 .20503 .91625 .19446 .91661 .22061 Metetra
.995 .759 .41 r
.91661 .22061 .91625 .19446 .90947 .19321 .90951 .21466 Metetra
.996 .763 .438 r
.90951 .21466 .90947 .19321 .90146 .17305 .9017 .19848 Metetra
.996 .759 .429 r
.9017 .19848 .90146 .17305 .89339 .15337 .89376 .18145 Metetra
.995 .756 .426 r
.89376 .18145 .89339 .15337 .88596 .14655 .88564 .16303 Metetra
.997 .773 .446 r
.88564 .16303 .88596 .14655 .87803 .13278 .87782 .15175 Metetra
.997 .768 .435 r
.87782 .15175 .87803 .13278 .87007 .12028 .86994 .14133 Metetra
.996 .765 .432 r
.86994 .14133 .87007 .12028 .86224 .11249 .86184 .12906 Metetra
.997 .772 .455 r
.86184 .12906 .86224 .11249 .85403 .09961 .85346 .11334 Metetra
.998 .782 .453 r
.85346 .11334 .85403 .09961 .84607 .09393 .84532 .10472 Metetra
.999 .795 .473 r
.84532 .10472 .84607 .09393 .83771 .083 .83708 .09672 Metetra
.995 .774 .49 r
.83708 .09672 .83771 .083 .82923 .07238 .82793 .07254 Metetra
.475 .808 .999 r
.82793 .07254 .82923 .07238 .82057 .06059 .81944 .06466 Metetra
.968 .827 .651 r
.81944 .06466 .82057 .06059 .81151 .04291 .81033 .04631 Metetra
.996 .791 .513 r
.98285 .2737 .98339 .26499 .97642 .24667 .97621 .26033 Metetra
.994 .769 .488 r
.97621 .26033 .97642 .24667 .96953 .23052 .96894 .23882 Metetra
.994 .792 .523 r
.96894 .23882 .96953 .23052 .9629 .21919 .96207 .22422 Metetra
.99 .824 .582 r
.96207 .22422 .9629 .21919 .95639 .21096 .95536 .21299 Metetra
.953 .918 .739 r
.95536 .21299 .95639 .21096 .9499 .20422 .9489 .20692 Metetra
.965 .87 .694 r
.9489 .20692 .9499 .20422 .94263 .18679 .94212 .1974 Metetra
.992 .793 .414 r
.94212 .1974 .94263 .18679 .93608 .18193 .93621 .20269 Metetra
.994 .765 .402 r
.93621 .20269 .93608 .18193 .93006 .18701 .92992 .20407 Metetra
.995 .772 .411 r
.92992 .20407 .93006 .18701 .92388 .19148 .9235 .20503 Metetra
.998 .779 .459 r
.9235 .20503 .92388 .19148 .91699 .18647 .91625 .19446 Metetra
.999 .814 .471 r
.91625 .19446 .91699 .18647 .90998 .18105 .90947 .19321 Metetra
.995 .777 .495 r
.90947 .19321 .90998 .18105 .90233 .16681 .90146 .17305 Metetra
.982 .799 .581 r
.90146 .17305 .90233 .16681 .89434 .14837 .89339 .15337 Metetra
.997 .846 .566 r
.89339 .15337 .89434 .14837 .88652 .13426 .88596 .14655 Metetra
.998 .783 .477 r
.88596 .14655 .88652 .13426 .87853 .11911 .87803 .13278 Metetra
.998 .779 .463 r
.87803 .13278 .87853 .11911 .87067 .10808 .87007 .12028 Metetra
.999 .787 .46 r
.87007 .12028 .87067 .10808 .86312 .10488 .86224 .11249 Metetra
.997 .808 .53 r
.86224 .11249 .86312 .10488 .85509 .0953 .85403 .09961 Metetra
.994 .868 .589 r
.85403 .09961 .85509 .0953 .84712 .08924 .84607 .09393 Metetra
.991 .845 .6 r
.84607 .09393 .84712 .08924 .83904 .08351 .83771 .083 Metetra
.122 .517 .912 r
.83771 .083 .83904 .08351 .8306 .07347 .82923 .07238 Metetra
0 .225 .728 r
.82923 .07238 .8306 .07347 .82191 .06088 .82057 .06059 Metetra
.413 .605 .926 r
.82057 .06059 .82191 .06088 .81255 .03673 .81151 .04291 Metetra
0 0 .491 r
.98339 .26499 .98472 .26754 .97779 .24978 .97642 .24667 Metetra
0 0 .303 r
.97642 .24667 .97779 .24978 .97135 .24023 .96953 .23052 Metetra
.953 .648 .216 r
.96953 .23052 .97135 .24023 .96489 .23133 .9629 .21919 Metetra
.968 .671 .266 r
.9629 .21919 .96489 .23133 .95842 .2237 .95639 .21096 Metetra
.971 .675 .278 r
.95639 .21096 .95842 .2237 .95268 .22842 .9499 .20422 Metetra
.975 .699 .295 r
.9499 .20422 .95268 .22842 .94736 .24142 .94263 .18679 Metetra
.986 .72 .35 r
.94263 .18679 .94736 .24142 .94087 .23801 .93608 .18193 Metetra
.987 .721 .36 r
.93608 .18193 .94087 .23801 .93383 .22776 .93006 .18701 Metetra
.986 .716 .355 r
.93006 .18701 .93383 .22776 .92683 .21948 .92388 .19148 Metetra
.983 .707 .331 r
.92388 .19148 .92683 .21948 .92008 .21689 .91699 .18647 Metetra
.983 .709 .334 r
.91699 .18647 .92008 .21689 .9142 .23075 .90998 .18105 Metetra
.984 .717 .338 r
.90998 .18105 .9142 .23075 .90542 .1981 .90233 .16681 Metetra
.979 .707 .312 r
.90233 .16681 .90542 .1981 .89763 .18349 .89434 .14837 Metetra
.982 .711 .325 r
.89434 .14837 .89763 .18349 .88984 .17057 .88652 .13426 Metetra
.982 .711 .325 r
.88652 .13426 .88984 .17057 .88189 .15665 .87853 .11911 Metetra
.983 .712 .332 r
.87853 .11911 .88189 .15665 .87381 .14211 .87067 .10808 Metetra
.984 .711 .34 r
.87067 .10808 .87381 .14211 .86578 .1307 .86312 .10488 Metetra
.98 .703 .318 r
.86312 .10488 .86578 .1307 .85757 .11797 .85509 .0953 Metetra
.98 .699 .319 r
.85509 .0953 .85757 .11797 .84923 .10502 .84712 .08924 Metetra
.975 .683 .298 r
.84712 .08924 .84923 .10502 .84108 .09812 .83904 .08351 Metetra
.971 .676 .277 r
.83904 .08351 .84108 .09812 .83252 .08574 .8306 .07347 Metetra
.963 .662 .247 r
.8306 .07347 .83252 .08574 .82365 .06946 .82191 .06088 Metetra
.905 .597 .105 r
.82191 .06088 .82365 .06946 .8144 .04786 .81255 .03673 Metetra
0 g
.25 Mabswid
.01949 .16878 m
.81218 0 L
s
.81218 0 m
.82554 .28775 L
s
.82554 .28775 m
0 .42921 L
s
0 .42921 m
.01949 .16878 L
s
.98247 .23563 m
.81218 0 L
s
.81218 0 m
.82554 .28775 L
s
.82554 .28775 m
1 .48484 L
s
1 .48484 m
.98247 .23563 L
s
.01949 .16878 m
0 .42921 L
s
.01949 .16878 m
.02577 .16744 L
s
gsave
.00693 .17146 -72.8125 -10.9853 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01571 .21927 m
.022 .21799 L
s
gsave
.00314 .22185 -80.625 -11.0567 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.01187 .27054 m
.01817 .26931 L
s
gsave
-0.00072 .27302 -80.625 -11.1292 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.00798 .32261 m
.01429 .32142 L
s
gsave
-0.00464 .32499 -80.625 -11.2029 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.00402 .37549 m
.01034 .37436 L
s
gsave
-0.00861 .37777 -80.625 -11.2779 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
0 .42921 m
.00633 .42813 L
s
gsave
-0.01265 .43138 -88.4375 -11.3542 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.01855 .18133 m
.02232 .18054 L
s
.01761 .19393 m
.02138 .19314 L
s
.01666 .20658 m
.02043 .2058 L
s
.01476 .23202 m
.01853 .23125 L
s
.0138 .24481 m
.01758 .24405 L
s
.01284 .25765 m
.01662 .2569 L
s
.01091 .28349 m
.01469 .28275 L
s
.00993 .29648 m
.01372 .29575 L
s
.00896 .30952 m
.01274 .3088 L
s
.00699 .33576 m
.01078 .33505 L
s
.00601 .34895 m
.00979 .34825 L
s
.00502 .3622 m
.0088 .36151 L
s
.00302 .38884 m
.00681 .38817 L
s
.00202 .40225 m
.00581 .40158 L
s
.00101 .4157 m
.00481 .41504 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{620, 362.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009/0001JR000`400?l00000o`00003oo`3ooooo
0?ooofh0oooo003o0?ooool0ooooKP3oool00?l0ooooZ@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0;@0oooo003o0?ooojT0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`2d0?ooo`00o`3ooonY0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0]03o
ool00?l0ooooY03oool400000080oooo00<000000?ooo`3oool00P3oool600000080oooo00@00000
0?ooo`3oool0oooo1P0000030?ooo`@00000103oool4000000<0oooo1P00002D0?ooo`00o`3ooonS
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo0000002H0?ooo`00o`3o
oonS0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`2E0?ooo`00o`3ooonS0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2D0?ooo`00o`3ooonS0?ooo`8000000`3oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo09<0oooo003o0?oooj<0oooo00<000000?ooo`0000000P0000030?oo
o`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000070?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0980oooo003o0?oooj<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`2B0?ooo`00o`3ooonS0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool07`3oool300000700oooo003o0?oooj@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo01X0oooo1@0000020?ooo`800000K`3oool0
0?l0ooooY@3oool3000000D0oooo00<000000?ooo`3oool0100000060?ooo`030000003oool00000
00<00000103oool4000000@0oooo100000040?ooo`@000006@3oool4000000L0oooo0P00001_0?oo
o`00o`3oooo/0?ooo`D000002`3oool00`000000oooo0000001^0?ooo`00o`3ooooW0?ooo`D00000
403oool010000000oooo0?ooo`00001]0?ooo`00o`3ooomR0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0JP3oool4000001D0oooo00D000000?ooo`3oool0oooo0000001/0?ooo`00
o`3ooomR0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0I@3oool5000001T0oooo
00D000000?ooo`3oool0oooo0000001/0?ooo`00o`3ooomR0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0H03oool5000001h0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1Y0?ooo`00o`3ooomC0?ooo`H000000`3oool3000000@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`@000000`3oool010000000oooo0?ooo`3oool6000000<0oooo
100000040?ooo`@000001P3oool00`000000oooo0?ooo`0k0?ooo`D000008`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo06P0oooo003o0?oooe@0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03L0oooo1000000X0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0J03oool00?l0ooooE@3oool00`000000oooo0?ooo`080?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0b0?ooo`D00000;03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06L0oooo003o
0?oooeH0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo1@00000a0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0IP3oool00?l0ooooE`3oool00`000000oooo
0?ooo`020?ooo`<0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`D00000=`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo06D0oooo003o0?oooeP0oooo00@000000?ooo`3oool000000`3oool2
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000070?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0
oooo1000000l0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0I@3oool00?l0oooo
F03oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo1@000002
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1T
0?ooo`00o`3ooomC0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool00000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0oooo0000003o
ool0000001`0oooo1@0000070?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`1S0?ooo`00o`3ooomC0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`800000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P3oool2000001P0oooo1000000<0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1R0?ooo`00o`3ooomD0?ooo`@00000103oool4000000H0
oooo00D000000?ooo`3oool0oooo000000050?ooo`@000001P3oool00`000000oooo000000030000
00@0oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`0A0?ooo`D00000CP3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0680oooo003o0?ooojD0oooo1@00001C0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0H@3oool00?l0ooooX03oool5000004/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0600oooo
003o0?ooob40oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1/0?ooo`@00000D03o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0H03o
ool00?l0oooo8@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06L0oooo1@00001D
0?ooo`8000002P3oool2000000d0oooo00<000000?ooo`3oool0G`3oool00?l0oooo8@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0680oooo1@00001I0?ooo`8000002P3oool20000
00h0oooo00<000000?ooo`3oool0GP3oool00?l0oooo4P3oool6000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool6000000<0oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`0m0?ooo`@0
0000GP3oool2000000T0oooo0`00000?0?ooo`030000003oool0oooo05d0oooo003o0?oooa<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0>03oool500000680oooo0P0000090?ooo`<000003`3oool00`000000
oooo0?ooo`1M0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo1@00001W0?ooo`<0
0000203oool300000100oooo00<000000?ooo`3oool0G03oool00?l0oooo5@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0^0?ooo`D00000F`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00H0oooo0`0000080?ooo`@00000403oool00`000000oooo0?ooo`1K0?ooo`00o`3ooolF0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02X0oooo1000001O0?ooo`8000000P3oool010000000oooo0?ooo`3oool4000000H0oooo0`00
00070?ooo`80000000<0mm>V000000000000403oool00`000000oooo0?ooo`1K0?ooo`00o`3ooolG
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0U0?ooo`D00000H`3oool3000000030?ooo`00000000000080oooo00@0000009Jbj`000000
00001P3oool010000000o/Ej0000000000060?ooo`030000003jcIX00000008000004@3oool00`00
0000oooo0?ooo`1J0?ooo`00o`3ooolG0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`H00000I`3oool600000080oooo1@000005
0?ooo`040000003naGX00000000000<0oooo00D000000?ooo`00000000000?[=VP0400000140oooo
00<000000?ooo`3oool0F@3oool00?l0oooo4P3oool00`000000oooo0?ooo`020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool00000103oool01`000000oooo0?ooo`3oool000000?ooo`0000007@3oool5000000D0
oooo00<000000?ooo`3oool0I03oool00`000000nLjL00000005000000040?ooo`000000000009Jb
j`<00000103oool010000000o/Ej0000000000030?ooo`<0000000<0alKI0000003jcIX00`00000B
0?ooo`030000003oool0oooo05P0oooo003o0?oooa80oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000001T0oooo1000000:0?ooo`030000
003oool0oooo0600oooo00D000000?ooo`3oool0oooo000000020?W>W0D0000000<0oooo0000003o
bGd0100000040?ooo`030000003naGX0o/Ej0080000000D0oooo0000002:Zn/000000000S@020000
00030?[=VP000000mm>V008000004@3oool00`000000oooo0?ooo`1H0?ooo`00o`3ooolC0?ooo`@0
00001P3oool00`000000oooo0?ooo`050?ooo`L000001@3oool00`000000oooo0?ooo`04000000@0
oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`0B0?ooo`D000003P3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool00000000000020?W>W004
0000003lcI0000000?N^@`<0000000<0olUm0000000000000`000000103oool000000?ooo`000002
0?k5NP80000000<0oooo0000002:Zn/00`0000000`37a]T000000000000300000180oooo00<00000
0?ooo`3oool0E`3oool00?l0ooooGP3oool5000005H0oooo00<000000?ooo`3oool05@3oool01@00
0000oooo0?ooo`3oool0000000<0oooo100000001@2`_^D000000?W>W0000000o<f@00D000000P3o
bGd2000000060>WF`@000000oooo0000003oool000000P3naGX01@000000l:8^000000000000RZ_[
00T000004`3oool00`000000oooo0?ooo`1F0?ooo`00gP3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo06`0oooo1000001K0?ooo`030000003oool0oooo01D0oooo0P0000000`3oool0
0000000000030?ooo`80000000@0imk;00000000000000000P3icY`00`000000o<f@000000030000
0080olUm1@0000000`3n`gX00000000000020?k5NP<0000000<0oLN50000002:Zn/01@000000103j
cIX0000000000000000B0?ooo`030000003oool0oooo05H0oooo003N0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0I`3oool5000005l0oooo0P0000000`3oool00000000000030?oo
o`030000003oool0oooo00/0oooo00T000000?ooo`00000000000?ooo`000000l<n_0000003oool0
0`000000203Wg//000000000002`_^D000000?W>W0000000o<f@0P0000000`3jd9`000000?o9O@02
0?o9O@@0000000<0o/=j0000000000000P3naGX2000000040?W:V0000000000008Z[j`D0000000@0
n/fJ00000000000000004`3oool00`000000oooo0?ooo`1E0?ooo`00gP3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0680oooo1@00001M0?ooo`030000003oool0oooo00@0oooo1@00
00030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000000`0000000`3`cjl000000000
0002000000030?c:S@000000imk;00<0000000D0nLjL00000000000000000?c8R`02000000<0olUm
100000020?k3NP080000003naGX0o/Ej0?k5NP000000nLZH0000003mahD7000000040?[=VP000000
0000000001<0oooo00<000000?ooo`3oool0E03oool00=80oooo00<000000?ooo`3oool00P3oool6
00000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000<0oooo1P00
00030?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool0?@3oool500000680oooo0P00
00050?ooo`030000003^WbT0000000<000000P3oool3000000X0oooo00<0000003R?k`0000000`00
00001@2m_]X000000?3?[`000000m/nS00<0000000H0imk;000000000000/;kU0000003icY`20000
00030?c8R`000000000000@0olUm0`0000020?k3NP0:0000003naGX0o/Ej0?k5NP000000nLZH0000
003mahD0000008Z[j`D0000000@0n/fJ0000000000000000503oool00`000000oooo0?ooo`1C0?oo
o`00dP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0i0?ooo`@00000I`3oool2000000D0oooo1`000000103oool0000000000000
00050?ooo`030000003oool0oooo0080oooo00<0000003R?k`0000000P0000001P00084000000000
003`cjl000000?K?X`80000000<0o<Z=0000003Wg//00`0000001@3icY`00000000000000000o<R;
008000000`3obGd4000000030?k3NP00000000000080o/Ej00D000000?W:V03ibYP000000?g7Q@06
000000030?[=VP0000000000008000004`3oool00`000000oooo0?ooo`1C0?ooo`00dP3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`0000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d
0?ooo`D00000J`3oool00`000000o;IJ000000040?ooo`D0000000D0kilZ00000000000000000?W@
X004000000030?ooo`00000000000080oooo00<000000?ooo`0000000`000000103naWX000000000
002m_]X200000080m/nS0P0000001`3lbXd00000000000000000/;kU0000003icY`00P0000000`3l
b8/00000000000030?o9O@@000000P3n`gX020000000o/Ej0?k5NP3naGX000000?W:V0000000oLN5
100000000`3dbj@00000000000020?k2L@030000003fZCl0000001<0oooo00<000000?ooo`3oool0
DP3oool00=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0;`3oool5000004`0oooo00<000000?ooo`3oool0
8@3oool00`000000o;IJ000000040?ooo`80000000<0kIPS0000003mc8/0100000000`3id:000000
00000004000000030<O0d`000000000000<0000000@0o/El000000000000o/Ij100000000`3`cjl0
00000?K?X`0200000080o<Z=100000001@3icY`00000000000000000o<R;008000000P3obGd40000
0080o/=j0P0000020?k5NP030000003ibYP000000080oLN51P0000020?k2L@040000003fZCl0mZTo
000001<0oooo00<000000?ooo`3oool0D@3oool00=80oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:`3oool400000540oooo
0P00000B0?ooo`030000003oool0oooo00d0oooo00L000000?bfFP3l]UX000000?ooo`000000oooo
0080000000<0kIPS0000003mc8/0100000020?W@X0/0000000<0o/El0000000000000P3naWX20000
00030;fnfP00000000000080m/nS00<000000?c:S@3lbXd00`0000000`2`_^D00000000000020000
00030?c8R`00000000000080olUm00<000000?o;P@0000000P0000000`3n`gX00000000000030?k5
NP040000003ibYP000000?g7Q@80000000@0e/G900000000000000000`3n`W400`000000mZTo0000
000D0?ooo`030000003oool0oooo0500oooo003B0?ooo`030000003oool0oooo00L0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`D00000E@3oool200000180oooo0P00000>0?oo
o`80000000L0o;IJ0000003oool000000?ooo`000000oL=o0080000000@0oLb;000000000000]dX0
0P0000000`3id:00000000000004000000030<O0d`00000000000080000000<0o/El000000000000
0P3naWX6000000030?K?X`00000000000080o<Z=200000001@3lb8/000000000003obGd000000080
ol^10P0000020?k3NP8000000P3naGX00`000000nLZH000000020?g7Q@H000000P3n`W4010000000
mZTo0?JY?`00000C0?ooo`030000003oool0oooo0500oooo003B0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Q0?ooo`D00000FP3o
ool00`000000o;IO0000000A0?ooo`8000003P3oool3000000030?c3Q@000000000000@0000000@0
kIPS000000000000n<nP0`0000020?W@X080000000<0oL>00000003jb9401@0000020?k5O0040000
003naWX0o/Ij0?k6NP80000000<0_KkJ0000000000000P3fcj<00`000000o<Z=0?c:S@0300000003
0;2ni@000000o/Z60080000000<0o<R;0000003jd9`00P0000020?o;P@<0000000<0o/=j00000000
00000P3naGX00`000000nLZH000000020?g7Q@@0000000<0iXhC0000003n`W400P3n`W4010000000
mZTo00000000000C0?ooo`030000003oool0oooo04l0oooo003@0?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?oo
o`000000oooo000000050?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000oooo0000000N0?oo
o`D000000P3oool00`000000oooo0?ooo`1J0?ooo`030000003l]Ul000000140oooo00<000000?bf
GP0000003@3oool3000000070?c3Q@000000000000000000074000000?g3O`02000000040?g<R`00
000000000;M:0080000000<0nM2P0000000000000P0000000`3jb94000000<O0d`0300000080o/El
00H000000?k6NP3naWX0o/Ij0000003haiL4000000040?K?X`00000000000?c:S@D000000P3nbXH0
0`000000o<R;0?c8R`0300000080ol^100P000000?c@U`000000o/=j0000003]c;4000000?k5NP80
000000<0nLZH0000003mahD0100000000`3VSQ<000000?k2L@030?k2L@040000003fZCl000000000
01<0oooo00<000000?ooo`3oool0CP3oool00=40oooo0P0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000
oooo000000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`020?ooo`8000006P3oool4000000L0oooo00<000000?ooo`3oool0FP3oool0
10000000o;IO0?bfG`00000@0?ooo`80000000<0o;IN0000003oool02`3oool3000000090?c3Q@00
0000000000000000074000000?g3O`000000kIPS0080000000@0n<nP00000000000000000P3id:02
000000030?g3P0000000n/RA00<0000000@0l/bX0000003naG`000000`3naWX3000000030;fnfP00
000000000080m/nS0P0000000`3kdI/000000000000300000080o/Z600D000000?c8R`000000olQl
000000030?o;P@8000000P3n`gX2000000040?k5NP00000000000?W:V08000000P3ocH85000000<0
o/9a00@000000?JY?`00000000004`3oool00`000000oooo0?ooo`1>0?ooo`00dP3oool00`000000
oooo0?ooo`030?ooo`@000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000000`0000040?ooo`@00000103oool4000000H0oooo00<000000?ooo`3o
ool04`3oool5000000/0oooo00<000000?ooo`3oool0FP3oool200000080o;IO00<000000?ooo`3o
ool0303oool00`000000oL=l000000020?bfGP030000003oool0oooo00T0oooo100000000`3l`hD0
0000000000020000L@050000003m`gl000000000003mc8/00P000000102gBP0000000000003id:02
000000030?g3P0000000n/RA00D0000000<0o/El0000003naWX00`3naWX00`000000n<NG00000003
000000030?K?X`00000000000080nm6K0P0000001P3/eKd000000?k:QP3nbXH000000?c8R`800000
00@0olQl0000003obh40ol^10`0000000`3n`gX000000>g</@02000000040?o6MP00000000000000
0080olf20`0000000`3VSQ<000000?k2L@020?k2L@<0000000<0n:e60000003oool04P3oool00`00
0000oooo0?ooo`1=0?ooo`00o`3ooolL0?ooo`D00000403oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo04`0oooo0P0000020?bfG`030000003oool0oooo00/0oooo0P0000001@3m`g`0
00000?bfGP3l]Uh0000000/0oooo100000001P3l`hD000000?g4PP000000001a00000080oL=o0`00
0000103hcj0000000000000000020?W@X0<000000P3jb943000000030?;<Z0000000000000@0o/Ij
00@000000?S7U`000000_KkJ0P0000020?K?X`030000003kdI/0nm6K00D000000P3nbXH300000003
0?o8O0000000ol^10080ol^10P0000000`3n`gX0000000000002000000040?o6MP000000nLZH0000
00<0olf21@0000020?k2L@030000003oaWH000000080n:e600<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1<0?ooo`00V@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06h0
oooo1000000S0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0503oool2000000<0
o;IO00<000000?ooo`3oool02@3oool3000000030?g3O0000000o;IN0080o;IN00<000000?ooo`3o
ool0203oool4000000040?c3Q@000000oLB200000080001a00L000000?g3O`00000000000?g<R`00
0000n<nP00<0000000H0nM2P000000000000oL>00000003jb945000000030?k5O0000000o/Ij00<0
o/Ij00<000000?S7U`0000000`0000000`3fcj<00000000000020?_AV`040000003Te<L000000000
0080o/Z60P000000103ocXL000000?o8O00000020?o;P@80000000T0o/=j000000000000kLba0000
003oaWH000000?W:V00000000`3ocH8500000080o/9a00@000000?o6MP00000000000P3h[DH00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo04/0oooo002I0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0J@3oool5000002L0oooo0P00000f0?ooo`030000003oool0oooo01@0
oooo0P0000030?bfG`030000003oool0oooo00T0oooo0`0000000`3m`g`00000000000030?bfGP03
0000003oool0oooo00L0oooo00/000000?k2N0000000i/^k0000003l`hD000000?g4PP000000001a
000000020?g3O`P0000000@0o]FB00000000000000000P3jb944000000030?k5O0000000o/Ij00<0
o/Ij00<000000?S7U`00000010000000103hZDX000000?_AV`3kdI/500000080o/Z600L000000?o>
Q`3ocXL000000?o8O0000000ol^100D0000000@0kLba0000003oaWH0olIf0`0000020?o=PPD00000
0P3n`W4010000000olIf0000000000020?R]AP<000004@3oool00`000000oooo0?ooo`1;0?ooo`00
V@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06@0oooo1@00000/0?ooo`800000
9P3oool00`000000oooo0?ooo`0=0?ooo`8000005@3oool2000000@0o;IO00<000000?ooo`3oool0
203oool300000080oL=l0P0000020?bfGP800000203oool02`000000o/9h0000003Vbk/000000?c3
Q@000000oLB200000000074000000080oL=o10000000103hcj0000000000000000020?kETP800000
0P3jb942000000050?_7R`00000000000?k5O00000000`3naWX2000000<0o/Ij0P0000000`3hZDX0
0000000000020?_AV`040000003Te<L0000000000080o/Z600H000000?o>Q`3ocXL0olj70000003o
b7`5000000030?k4MP00000000000080olIf0`0000020?o=PP030000003ocH80000000<0000000@0
o/9a0000003oaWH0olIf0P000000103h[DH000000?V^C03i[T`200000100oooo00<000000?ooo`3o
ool0BP3oool009<0oooo1P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool0oooo1P0000030?ooo`@00000103oool4000000H0oooo00<000000?ooo`3o
ool0?`3oool500000340oooo0`00000U0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`00
000000005@3oool200000080o;IO00<000000?bfG`0000000P0000080?ooo`030000003m`7H00000
0080oL=l0`0000000`3l]Uh000000?^`F@02000000@0oooo00T000000?ooo`000000o/9h0000003V
bk/000000?c3Q@0000000P3ma88010000000001a0000003m`gl3000000050?k6O000000000000000
003lfj400`000000103m`h0000000?[8T@3jb944000000070?k5O0000000o/Ij0?k6NP000000olAc
000000040?k6NPD0000000<0nm6K000000000000100000001P3maH<000000?o>Q`3ocXL000000?o8
O080000000L0ol]l000000000000o/Af0000003eejl000000080olIf00H000000?o7O0000000olf2
0000003ocH84000000040?k2L@000000olIf0?o6MP80000000<0n:e60000003i[T`00`3i[T`00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo04T0oooo002D0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0k0?ooo`@00000=P3oool30000
02D0oooo0P00000<0?ooo`@000005@3oool5000000040?bfG`000000o;MW0?bgI`8000001P3oool0
2P000000oL1f000000000000oL=l0000003_VBP000000?bfGP0000030?^`F@090000003oool0oooo
0?ooo`000000oooo0000003n`WP000000080i/^k00<000000?c3Q@0000000P3ma882000000030?g3
O`000000000000H000000P3lfj4300000080n/RA1`000000103naWX000000?o4L`0000050?k6NP@0
00000P3kdI/00`000000i=C700000002000000030?g5P`000000olj70080olj70`0000000`3obg`0
0000000000020?k4MP8000000P3oaWH00`000000olMl0?o7O002000000030?o=PP00000000000080
000000<0o/9a0000003oaWH00P3oaWH3000000@0nJi<0P00000?0?ooo`030000003oool0oooo04T0
oooo002E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0f0?ooo`D00000>@3oool00`000000n[n60?ZoQP02000001D0oooo00<000000?ooo`3o
ool02`3oool00`00000000260000000<0?ooo`D00000403oool010000000oooo0?ooo`3oool70000
00@0o;MW0P0000040?ooo`070000003m`7H0oL1f0000003m`g`000000>nI:003000000@0nk1I00<0
00000?ooo`3oool0100000001P3n`WP000000>K;^`000000o<>500000080oLB20P0000000`3m`gl0
000000000002000000030?k6O0000000n/fI008000000P3lfj43000000030?[8T@000000000000@0
000000<0olYo0000000000000P3oa7<00`000000o/Ij0?k6NP020?k6NP<0000000<0m/jT0000003k
dI/00P0000000`3m`gd00000000000020?g5P`090000003ocXL0olj70?o>Q`000000o/9g0000003o
bg`000000080o/Af00D000000?GG[`000000olIf000000030?o7O080000000<0o/b70000000HHmT0
0`0000030?o6MP80000000<0n:e60000003i[T`00P3i[T`010000000n[9A00000000000>0?ooo`03
0000003oool0oooo04P0oooo002F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0a0?ooo`D00000?P3oool00`000000n[n60?ZoQP02000001D0
oooo00<000000?ooo`3oool02`3oool01000000000260000003oool3000000P0oooo1@00000@0?oo
o`050000003oool0oooo0000003kaX/01P0000050?bgI`8000000`3oool00`000000oL1f0?g0MP02
000000030?g3O0000000000000800000103k/5T00`000000oooo0?ooo`04000000040?k2N0000000
i/^k00000080o<>500<000000?g4PP3ma8800`0000000`3n`GL000000?g;S@02000000050?[=V@00
0000o<bA0000003lfj400`0000001@3jb940000006H000000000olIh0080000000<0olYo00000000
00000P3oa7<00`000000o/Ij0?k6NP020?k6NP@0000000D0m/jT00000000000000000?g3O@020000
0080oLF30P0000020?o>Q`030000003n`WL0o/9g00<000000P3na7H200000080olIf00<000000?o7
O03oag`00P0000020?k<Q`@000000`3oaWH4000000<0nJi<00D000000?ZbD@3j/U40n[9A0000000>
0?ooo`030000003oool0oooo04L0oooo002G0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0/0?ooo`D00000@03oool010000000oooo0?ooo`0000020?ZoQP8000000P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P00000<0?ooo`030000000008H0000000D0
00001`3oool5000000040?ooo`000000oooo000000`0oooo100000020?_6R`D000001@3l]fL20000
00<0oooo00<000000?g0MP3m`7H00P0000000`3m`g`000000>nI:002000000@0nk1I0P000000303o
ool000000?^dD`000000o/=i0000003n`WP000000>K;^`000000o<>500000080oLB20`000000103n
`GL000000?g;S@3mbhd2000000030?[=V@000000o<bA00D000000P1V000010000000olIh00000000
00020?o:O`050000003oa7<0olAc0?o4L`0000000`3naWX4000000030?K>Y0000000000000800000
00<0oL=m0000000000000P3maH<3000000040>?9_P000000o/9g0?k2M`8000000P3na7H01@000000
mMN_0000003oaWH000000080olMl0P0000020?k<Q`040000000HHmT00000000000@0olIf0`000003
0?V^C0030000003j/U40n[9A0080n[9A00<000000?ooo`3oool0303oool00`000000oooo0?ooo`16
0?ooo`00V03oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`@00000@03oool010000000oooo
0?ooo`3oool200000080oooo00P000000?ZoQP3j_hH000000?bgH0000000oooo000000d0oooo00<0
00000?ooo`3oool00P3oool2000000P0oooo00@000000?ooo`3oool0oooo200000070?ooo`<00000
00@0n/ZC000000000000KJCb1000000:0?ooo`@000000`3kaX/4000000D0o;MW00<000000?bgH`00
00000P3oool010000000oL1f0?g0MP3m`7H2000000030?g3O00000000000008000000`3k/5T20000
000<0?ooo`000000nkAC0000003n`gT000000?k2N0000000i/^k0000003l`hD000000P3ma8830000
0080o/5g00@000000?g;S@3mbhd000000P3jcIT01P000000o<bA000000000000o/Eh000000<0IP00
00@000000?o6N000000000000P3obWl01@000000olAc0?o4L`3oa7<000000080o/Ij1@0000001@3f
cZ@000000?k4O@000000oL=m008000000P3maH<3000000030>?9_P000000o/9g0080o/9g0P000002
0?k4MP80000000@0olIf000000000000olMl0`0000020?k<Q`<00000103oaWH00`000000ol]i0000
00040?V^C0040000003j/U40n[9A0?ZbD@8000003@3oool00`000000oooo0?ooo`160?ooo`00V03o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo1@0000140?ooo`040000003oool0oooo
0?ooo`<0000000P0oooo0000003j_hH0n[n60000003l]f0000000?ooo`800000303oool2000000<0
oooo0P0000080?ooo`040000003oool0oooo0?ooo`80000000<00026000000000000100000030?oo
o`060000003oool0oooo0000001KYOL000000P3jbY<3000000030<]N00000000000000800000203o
ool4000000<0nlJ;1@0000040?bgI`060000003l]f<0o;MS0000003oool000000`3m`7H200000003
0?g3O0000000000000800000103k/5T3000000060?^dD`000000o/=i0?k3N@000000o/9h0P000002
0?c3Q@050000003ma88000000?o=N`0000000P3n`GL00`000000oL^=0?g;S@02000000050?[=V@00
0000o<bA0000003caj402P0000020?o:O`080000003oa7<0olAc0?o4L`000000o/Ij0000003db:43
000000040?K>Y0000000o/Am00000080oL=m00<000000?g5P`3maH<00`0000000`3SbKh000000?k2
M`020?k2M`8000000P3na7H00`000000mMN_00000002000000040?o7O0000000000000000080o/b7
00@0000001QSf@00000000000`3oaWH2000000030?o;N@000000nJi<0080nJi<00L000000?ZbD@3j
/U40n[9A0000003j/e40000000d0oooo00<000000?ooo`3oool0A@3oool009<0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000001P3oool0
0`000000oooo000000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
103oool01`000000oooo0?ooo`3oool000000?ooo`000000803oool5000000030?ooo`000000oooo
0480oooo00@000000?ooo`000000oooo0P0000020?ooo`<0000000@0oooo0000003j_hH0n[n61P00
00070?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003eZ3/0000000L0oooo0P00
0000103oool000000000003kc9<200000003001<bP000000OlSn00<0000000D0oooo000000000000
00000?ooo`03000000<0n/ZC00<0000006fTlP0000001@0000070?ooo`80000000<0n/F=00000000
00000`3kaX/4000000@0o;MW00@000000?bgH`3l]f<0o;MS0P0000030?g0MP040000003ja8d00000
0?g3O0<00000103k/5T4000000<0o/=i00@000000?k2N0000000i/^k0`000000103ma88000000?o=
N`0000030?k1M`040000003mbhd0oL^=00000080n/fI0`0000000`3caj4000000?k5N0020?k5N003
0000003na7X000000080olIh00@000000?o:O`3obWl000000P3oa7<010000000o/Ij0000003db:44
000000040?W7TP000000o/Am00000080oL=m00<000000?g5P`3maH<00P0000020>?9_P030000003n
`WL0o/9g008000000`3na7H3000000060?o5L`00000000000000003obGh000000P3nc8L3000000<0
olIf00<000000?o@N00000000`0000000`3i[T`000000?ZbD@020?ZbD@030000003j/e40000000h0
oooo00<000000?ooo`3oool0A03oool009<0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo0P0000060?ooo`030000003oool0000000@0oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P00000L
0?ooo`@000001P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0000000H000000P3oool2
000000030?bgI@00000000000080n[n60P0000001@3l]f0000000000003KP`00000000H0oooo00<0
00000?ooo`3oool00P3oool00`000000iY8F000000020?ooo`<000001`3oool2000000060?ooo`00
000000000?_<T`00000000260P0000000`1ob?h0000008fglP02000000040?RWD@00000000000000
0080nlR?00@000000?[:T`3jbY<0n/ZC200000070?ooo`8000000P3jaHd00`000000nlJ;0?_6R`02
0?_6R`<00000103l]fL010000000o;MS0?bgH`3l]f<2000000@0oL1f0P000000103m`g`000000000
000000040?^`F@040000000007P00000000000@0o/=i1P0000001@3ma88000000?o=N`3ocG/00000
0080o/5g00H000000?g;S@3mbhd0oL^=0000003jcIT3000000030??7X@00000000000080o/Eh00<0
00000?k4NP0000000P3oaWP2000000040?o:O`000000olAc0?o4L`<0000000<0m<RQ000000000000
0P000000103iai8000000?k4O@0000020?g3O@030000003maH<0oLF300<0000000@0hlVn0000003n
`WL0o/9g0`0000001P3na7H000000000003eejl000000?o5L`<0000000H0olUn0000003nc8L0o/b7
0000000HHmT200000080olIf00@000000?o@N03od7P0om1h100000030?ZbD@040000003j/e40n[=A
000000h0oooo00<000000?ooo`3oool0@`3oool009@0oooo100000050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo00000003000000@0oooo100000040?oo
o`@000001P3oool00`000000oooo0?ooo`0E0?ooo`D000002P3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool000000080000000P0kY`W000000000000iiLJ0000003oool000000?S3T0<00000
0P3j_hH2000000050?bgH000000000000=^3000000001P3oool2000000<0oooo00H000000>JB5P00
0000oooo0000003ILP02000000030?ooo`000000oooo00@0oooo1@0000020?_<T`<0000000T0OlSn
0000002=]o80SKOb0000003hYe4000000<[Bg`0000000P3kb8l01P000000n/ZC0?[:T`3jbY<00000
0?G3U`<0000000@0j]2k0000003k/UL000001P3oool200000080n/F=0P0000030?_6R`@000000`3l
]fL00`000000o;MS0?bgH`020?bgH`030000003m`7H0oL1f0080oL1f00<000000?[4S@0000000`00
00030?^`F@80000000<0001h000000000000103n`gT5000000030?k5OP00000000000080olek00D0
00000?k1M`3n`GL0o/5g000000020?g;S@030000003jcIT0n/fI0080000000<0llNQ000000000000
0P3naGP01`000000o/Aj0?k4NP000000olIh0000003n`GL00`0000001`3oa7<000000?k1L`000000
m<RQ0000003K]kD00P000000103iai8000000?k4O@0000020?g3O@040000003maH<0oLF30?g5P`80
000000@0hlVn0000003n`WL0o/9g0`0000001`3na7H000000?k0K`000000oLf=0000003oaG<00P00
00020?o9OP030000003nc8L0o/b700<000000P3oaWH00`000000om1h0?o@N0020?o@N0030000003o
b7<0000000<0n[9A00@000000?ZcD@3j/e40n[=A0P00000<0?ooo`030000003oool0oooo04<0oooo
001P0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0JP3oool5000000l0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo000000040000000:0>jL9`00000000000>NG6P000000
oooo0000003h`i0000000?bgI@80000000<0n[n60000000000000`0000020=^300030000003oool0
oooo00<0oooo0P0000030?ooo`D0000000<0fG800000003eZ3/00`0000030?ooo`030000003jaH`0
000000<000000`3kc9<200000080OlSn00<0000008fglP0000000P0000001@3:d]l000000000003k
b8l0000000@0n/ZC0P0000001P1]Y?800000000000000000nk9G000000H0oooo00<000000?W=VP00
00000P3jaHd00`000000nlJ;0?_6R`020?_6R`<00000103l]fL01@000000o;MS0?bgH`3l]f<00000
00@0oL1f00L000000?[4S@00000000000?R]A`000000nk1I0080000000<0nZeM0000000000000P00
00050?k3N@050000003n`WD000000000003naGh00P0000020?o=N`050000003n`GL0o/5g0?k1M`00
00000P3mbhd2000000050?[=V@000000n/B<0000003caj400P000000103naGP000000?k4NP3na7X3
00000080o/5g00H000000?R]AP00000000000?k1L`0000020?C8X@@0000000@0nLNB0000003na7d0
00000P3m`gd00`000000oLF30?g5P`0400000080o/9g00<000000?k3NP0000000P0000020?k0K`80
000000<0olEc0000000000000`3obGh00`000000o/b700000003000000030?o6MP000000om1h00<0
om1h0P0000001@3ob7<000000?ZbD@3j/U40000000<0n[=A00@000000?^fE`00000000002`3oool0
0`000000oooo0?ooo`120?ooo`00H03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
06D0oooo1@00001C0?ooo`030000003oool0000000T0000000<0oooo0000003h`i000P0000000`3h
b9P000000?ZoQP0500000080fh<00P0000040?ooo`<000000P3oool5000000030=Ub00000000mJPk
00<000000P3oool2000000050?[5S000000000000?c8S00000000`3kc9<300000080OlSn00L00000
08fglP000000nMBR0000003:d]l000000080nlR?00H000000?[:T`3jbY<0n/ZC0000003e`iL30000
00040>[@^`000000nk9G000000<0oooo00D000000?ooo`000000nLfJ000000020?[5S@8000000`3k
aX/4000000<0o;MW00D000000?bgH`000000o;MS000000050?g0MP030000003ja8d0000000<00000
00L0nZeM000000000000nJ]L0000003i[dd0000000D0o/=i00@000000?k2M@00000000000P3naGh0
0`000000olek0?o=N`0200000080o/5g0`000000103maH0000000000003M`Kd2000000030??7X@00
00000000008000000`3na7X200000080o/5g00@000000?R]AP00000000000P3n`G<00`000000m<RQ
00000003000000040?W7TP000000o/Am00000080oL=m00/000000?g5P`3maH<0000000Dk_0000000
hlVn0000003n`WL000000?k3NP0300000080o/1_00D000000?g=S@000000olEc000000030?o9OP04
0000003nc8L000000?oAQP@00000103od7P010000000olQh0000000000030?ZbD@040000003j/e40
n[=A000000<0nkIG0P00000:0?ooo`030000003oool0oooo0440oooo001P0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0H@3oool4000004h0oooo00<000000?ooo`3oool01`3oool3
000000030?bfI0000000n/6800<0000000<0l;jM0000003WUaX00P0000001P3h`i0000000000003h
b9P000000?ZoQPD000000P3KP`03000000<0oooo0`0000000`3oool000000<CGj004000000030=Ub
00000000000000L000000P3jaH`00`000000o<R<000000040?_<T`<0000000<0OlSn000000000000
0P0000001P3ie:800000000000000000nlR?000000<0n/ZC0P0000000`3laHL00000000000020000
0080nk9G0P000000103oool000000000000000020?W=VP040000003jaHd0n/F=000000<0nlJ;0P00
00000`3hZDT000000?bgI`020?bgI`D000001@3m`7H00`000000n/B=00000004000000<0nJ]L0`00
00050?k3N@80000000@0o/9e000000000000o/En1@0000020?k1M`<000000P3maH001P000000gL6m
0000003ja8`000000??7X@<000000`3na7X2000000<0o/5g0`0000020?k1L`040000003db:400000
0=^g]@80000000L0nLNB0000003na7d0o/Am0000003m`gd000000080oLF31@0000001P3n`WL00000
0?k3NP000000o/9h000000<0o/1_00<000000?g=S@0000000P0000030?o9OP80000000<0om660000
000000000P0000030?o@N0040000003ob7P0olQh0?o8N08000000P3j/U4010000000n[=A0?ZcD@00
00040?^fE`8000002@3oool00`000000oooo0?ooo`110?ooo`00D@3oool6000000H0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`<00000103oool010000000oooo0?ooo`3oool6000000<0oooo
100000040?ooo`@00000103oool4000003d0oooo1@00001B0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool0oooo1@0000020?[1R0030000003]a:T000000080000000@0iiLJ00000000
0000n<>@0P0000020?S8V0H0000000D0fh<000000000000001JS000000030?ooo`D0000000H0a=OX
000000000000mjI70000003ILP03000000060?W8U@00000000000000003/e;/000000P3jaH`01000
0000o<R<0?c8S00000030?_<T`@0000000<0OlSn0000002=]o800`0000001@3:d]l000000?_8S`3k
b8l0000000<0n/ZC00<000000?c5Q`000000100000002P3k/UL00000000000000000m<bV0000003h
bI/000000?W=VP0000020?[5S@8000000P3kaX/3000000040?RYB@000000o;MW0?bgI`D000001@3m
`7H00`000000n/B=00000003000000<0nJ]L00@000000?c3PP00000000001@3n`gT01@000000o/Ag
0000003n`WD0000000@0o/En0P0000020?k1M`<000000P3maH001P000000gL6m0000003ja8`00000
0??7X@<000000`3na7X00`000000nLJA000000020?k1M`80000000@0o<5n0000003n`G<000000P3d
b:44000000050?W7TP000000o/Am0000003m`gd00P0000000`3maH<0000000000003000000040?k2
M`000000o/=j0?k3NP8000000`3n`6l00`000000oLf=0?g=S@02000000<0olUn0P0000020?oAQP@0
00000P3od7P00`000000olQh0?o8N0020?o8N0040000003j/U40n[9A000000<0n[=A00@000000?^f
E`3k]UL0nkIG0P00000:0?ooo`030000003oool0oooo0400oooo001B0?ooo`030000003oool0oooo
00P0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0=@3oool5000004@0oooo0P00000@0?ooo`<000000`3oool010000000oooo0?ooo`3oool20000
00030?V/BP00000000000080n/6800<000000>g4Z@0000000P0000000`3WUaX00000000000030000
0080n<RH0P0000000`3dc:H000000000000400000003000FX`00000000000080oooo00<000000?K=
X`0000000P0000002@34enP00000000000000000jmFn0000003ILP0000000>O?_P03000000030?3@
/@00000000000080n/F<00D000000?c8S03lb8`0o<R<000000030?_<T`L0000000D0l<b/00000000
0000b];O000000020?_8S`040000003jbY<0n/ZC00000080o<F710000000203k/UL0000000000000
0000m<bV0000003hbI/000000P3icIX01P000000n/F=0?[5S@000000nlJ;00000080oLN400D00000
0?RYB@3hZDT000000?bgI`03000000030?^dE`000000oL1f00@0oL1f1`0000020?V[G0040000003l
`h80o<>2000000D0o/=i00<000000?k4M`3na7L00`0000030?k5OP<0000000@0o/5g0000003n`gX0
00000P3maH000`000000gL6m0=g1_@02000000030??7X@000000nLNB008000000`3na7X2000000<0
o/5g0`0000020?k1L`030000003db:40000000<0000000D0nLNB0000003na7d000000?g3O@030000
00050?W@W`00000000000000003SbKh00P0000020?k3NP800000103n`6l00`000000oLf=00000002
000000<0olUn00@000000?oAQP3odHH0om660P000000103naGP000000000000000050?o8N0030000
003j/U40000000<0n[=A00L000000?^fE`3k]UL0nkIG0000003k]U@0000000X0oooo00<000000?oo
o`3oool0?`3oool005<0oooo00<000000?ooo`3oool00P3oool700000080oooo00<000000?ooo`3o
ool01P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0<@3oool4000004T0oooo0P00000<0?ooo`040000003oool0oooo0?ooo`<00000
0`3oool200000080oooo0P0000000`3i[4X00000000000030?[1R0040000003]a:T0000000000080
iiLJ0P0000000`3h`i0000000?S8V0020?S8V0060000003dc:H000000?_4R@000000nk=T0P000000
1`005Z<00000000000000000oooo0000003fcJ<00`0000020<CGj080000000D0jmFn0000003ILP00
00000>O?_P02000000040?:G>P0000000000000000<0n/F<00D000000?c8S03lb8`0o<R<00000002
0?_<T`P0000000<0l<b/0000000000000P000000103kb8l000000?[:T`3jbY<200000080o<F70P00
0000103JO00000000000003ib9D2000000060?C<YP000000n<VK0000003icIX000000P3jaHd30000
0080oLN40P0000000`3hZDT0000000000005000000D0oL1f100000000`3j/U000000000000030000
0080o<>20P0000040?k3N@060000003na7L0o/Ag0000003n`WD000000`3naGh3000000030?k1M`00
0000o/=j008000000P3maH001P000000gL6m0000003ja8`000000??7X@<000000`3na7X2000000<0
o/5g0`0000020?k1L`030000003db:40000000@0000000<0nLNB000000000000100000020?W@W`D0
00000P3n`gX00`000000o/9h000000040?k0K`@000000`3obGh2000000<0om660P0000020?k5N080
0000103ob7P3000000<0n[=A00L000000?^fE`3k]UL0nkIG0000003k]U@0000000/0oooo00<00000
0?ooo`3oool0?P3oool005@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0/0?ooo`D00000C@3oool3000000/0
oooo0P0000020?ooo`<000000`3oool200000080oooo1@0000030?[1R0060000003]a:T000000000
003WUaX000000P3faIP2000000<0n<RH00P000000?C<YP000000nlB90000003k/f@000000>c8/@D0
000001<0_DH00000003fcJ<000000?O>X@000000a=OX0000003fcZ<000000>_E_P000000fG800000
003Wckh000000?:G>P000000l=2a008000000P3jaH`00`000000o<R<0?c8S0020?c8S0030000003k
c9<0000000P0000000D0002300000000000000000?_8S`02000000030?[:T`000000000000<0o<F7
100000002@3ib9D000000000003dc:H000000?S9V`000000nLfJ000000030?[5S@8000000`3mah@2
000000030?RYB@000000nk1M00@000001@3m`7H4000000030?ZbD000000000000080n:MD00D00000
0?c3PP3l`h80o<>2000000040?k3N@070000003na7L0o/Ag0?k4M`000000o/9e000000020?k5OP05
0000003maH8000000?k1M`0000000P3n`gX02@000000oLF00?g5P0000000gL6m0000003ja8`00000
0??7X@0400000080o/Aj0P0000030?k1M`80000000L0o<5n0000003n`G<000000?C8X@000000fkNe
00<0000000<0nLNB0000000000000P000000103n`G@000000?W@W`3id9l500000080o/=j00<00000
0?k2N0000000103n`6l3000000070?oAN`000000olUn0?o9OP000000l?J`000000020?oAQP800000
0P3naGP2000000@0olQh0`0000030?ZcD@050000003k]UL0nkIG0?^fE`0000000P3k]U@00`000000
oooo0?ooo`080?ooo`030000003oool0oooo03h0oooo001E0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<0000000<0oooo0000
003oool00P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
9`3oool5000004d0oooo00H000000?ooo`3oool0oooo0000003iZe`2000000/0oooo0P0000020?oo
o`<000000`3oool010000000mjQ20000003oool3000000030?_5RP000000n/6800<0n/6800<00000
0>g4Z@0000000P0000020?K5V0030000003h`i0000000080n<RH00<000000?C<YP0000000P3ka8T0
1@000000nLZG00000000000001JS0080000000D0ml^N000000000000m/fS000000020?O>X@040000
0034enP0000000000080jmFn0P0000001`3Wckh000000000003bUcX000000?3@/@0000000`3jaH`0
0`000000o<R<0?c8S0020?c8S080000000@0m=>/000000000000ml^L100000000`0008<000000000
0003000000050?c7RP00000000000?OAX`0000000`3laHL00`000000fW`0000000020?W8U@800000
00H0m<bV0000003hbI/000000?W=VP0000020?[5S@8000000`3mah@9000000D0oL1f00T000000?k4
LP00000000000?ZbD0000000n:e70000003hYe@00P0000030?c3PP050000003n`gT0o/=i0?k3N@00
0000103na7L200000080o/En00<000000?g5PP0000000P0000020?k3NP8000000P3maH0010000000
gL6m0000000000020??7X@<000000P3na7X300000080o/5g0P000000103l`Gh000000?k1L`000002
0?C8X@@0000000<0nLNB0000000000000P000000103n`G@000000?W@W`3id9l5000000<0o/=j0P00
00040?k0K`<0000000@0om5k0000003obGh000000P3`m[001@000000om660000003obW/000000080
o/Eh00<000000?o@O@0000000`3ob7P3000000<0n[=A00D000000?^fE`3k]UL0nkIG000000020?^f
E0030000003oool0oooo00T0oooo00<000000?ooo`3oool0?@3oool005H0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool2
000000<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0R0?ooo`D0
0000DP3oool02@000000oooo0?ooo`3oool000000?V[G0000000o;Q/0000000:0?ooo`060000003I
N`0000000?ooo`000000n/VD0P0000001P3oool000000000003gZ48000000?ooo`<0000000<0nlF:
0000000000000`3j`HP00`000000kLBY00000002000000<0m/FH0P0000020?S8V0030000003dc:H0
00000080nlB900@000000?W:U`000000k<Ra100000001@3gbih000000000003fcJ<000000080mljQ
00T000000<CGj000000000000>_E_P000000fG800000003Wckh01P0000030?[5S0040000003lb8`0
o<R<0?c8S08000000P3ddj`7000000030000P`00000000000080000000D0o<N:000000000000mm6S
000000030?c5Q`050000003JO00000000000003ib9D00P0000001P3dc:H000000?S9V`000000nLfJ
00000080n/F=0`0000020?g7Q0H0000000@0oKig0000003Ua[T00000103m`7H010000000o/Ab0000
003na784000000030?RWE0000000000000<0o<>200D000000?k3N@3n`gT0o/=i000000050?k4M`80
000000@0o/En0000003maH80oLF20P0000030?k3NP090000003maH00oLF00000003M`Kd000000?[4
S0000000llNQ00<000000P3na7X300000080o/5g00@000000?joLP00000000000P3n`G<00`000000
m<RQ00000002000000060?g6Q@000000nLNB0000003maX8000000P3n`G@00`000000nM2O0?W@W`04
000000<0o/=j0P0000040?k0K`<000000P3odG/2000000<0l?J`0P0000020?o:N`050000003naGP0
00000?o@O@0000000P3ob7P00`000000olj20?o>PP0200000080n[=A00D000000?^fE`3k]UL0nkIG
000000030?^fE0030000003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool005H0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool07P3oool4000005L0oooo0P0000020?ooo`050000003iZe`000000?bhK00000002P3o
ool01P000000fG/00000003oool000000?[9U080000000@0oooo000000000000mjQ20P0000000`2C
bo/00000000000020?_5RP030000003j`HP0n/680080n/68100000030?K5V0<000000P3hb9P20000
0080nlB900<000000?W:U`3ibYL00P0000001@005Z<00000000000000000ml^N00<000000P3gcZ40
0`000000a=OX0<CGj002000000050>_E_P000000fG800000003Wckh00`0000000`3`d;4000000?[5
S0030?[5S0030000003lb8`000000080nlR>00@000000?CC[0000000l/jZ1@0000000`0008<00000
0000000200000080o<N:00@000000?OAX`3gdJ<000000P3laHL400000080nLRE0P0000000`3dc:H0
00000?S9V`04000000030?_AV@000000000000<0oLN400<000000<e`000000000P000000103m_WL0
00000000000000040?g0MP040000003na780o/Ab0?k4LPL000000`3l`h8200000080o/=i00<00000
0?k4M`3na7L00`3na7L2000000040?k5OP000000oLF20?g5PP800000103n`gX020000000oLF00000
003M`Kd000000?[4S0000000llNQ10000000103na7X000000?k4MP0000020?k1M`040000003n_g80
000000000080o/5c00@000000?C8X@000000fkNe0`000000103iai8000000?g6PP0000020?k1M003
0000003id9l0nM2O00@000000`3n`gX00`000000o/9h000000030?k0K`@0000000<0om5k00000000
0000103`m[001P000000olYk0?o:N`000000o/Eh00000080om1m00<000000?o8N00000000P3ocX82
00000080n[=A00D000000?^fE`3k]UL0nkIG000000030?^fE08000002P3oool00`000000oooo0?oo
o`0l0?ooo`00D@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000001@3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0I0?ooo`D00000F`3oool200000080
oooo00<000000?V[G00000000P3l^6`00`000000oooo0?ooo`070?ooo`80000000@0fG/000000000
0000n/VD0P0000000`3oool00000000000020?NX@P040000002Cbo/0000000000080nlF:0P000003
0?[1R0040000003]a:T00000000000<0m/FH00D000000?S3T000000000000?S8V003000000060?_4
R@000000nLZG0?W:U`000000k<Ra100000001@3gbih000000000003fcJ<000000080mljQ00H00000
0<CGj0000000m/jS0000003[eKh2000000030>O?_P000000nLRE0080000000<0l=2a0000003jaH`0
0P3jaH`00`000000o<R<000000020?_8SP030000003ddj`0m=>/00@0000000@0n<ZI000000000000
0023100000020?c7RP0;0000003gdJ<0mm6S0000003laHL000000?bdH0000000oL9l0000003ib9D0
0P0000000`3dc:H000000?S9V`0400000080nm6I0P0000020?g7Q0030000003=L000000000800000
00D0oKig000000000000iLJi000000030?g0MP030000003na780o/Ab0080o/Ab100000000`3ma880
0000000000020?c3PP8000000P3n`gT00`000000o/Ag0?k4M`030?k4M`@000000`3maH800`000000
o/=j0?k3NP020?k3NP090000003maH00oLF00000003M`Kd000000?[4S0000000Wm_l00<0000000@0
o/Aj0000003na7H000000P3n`GL02P000000o[mb0000003l`Gh000000?k1L`000000m<RQ0000003K
]kD3000000040?W7TP000000oLJ2000000<0o/5d00<000000?W@W`000000100000030?k3NP800000
0`3n`6l200000080nlIM2@000000103obW/000000?k5N00000030?o@O@8000000`3ocX8200000003
0?ZcD@000000nkIG0080nkIG00@000000?^fE03k]U@0nkID0P00000;0?ooo`030000003oool0oooo
03/0oooo001A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0503oool500000080oooo00<000000?ooo`3oool0FP3o
ool2000000030?FW?0000000oooo00<000000P3l^6`00`000000oooo0?ooo`070?ooo`80000000H0
fG/00000003jbI@0n/VD0000003R^Jd60000000309?;n`000000000000<0nlF:00T000000?[1R03j
`HP0n/680000003]a:T000000?2nW@0000000`3faIP300000080n<RH00D000000?C<YP000000nlB9
000000020?W:U`80000000D001JS00000000000000000?O;WP02000000060?K=X`000000mljQ0?O>
X@000000a=OX0P0000001@3[eKh00000000000000000ilnn00D000000`3jaH`3000000<0nlR>00<0
00000?CC[03ddj`02`0000020?c7RP0:0000003gdJ<0mm6S0000003laHL000000?bdH0000000oL9l
00000080nLRE0P0000001P3dc:H000000?S9V`000000oL^9000000<0nm6I0P0000000`3mah@00000
0<e`000300000080oKig0`0000030?g0MP030000003na780o/Ab0080o/Ab100000020?g4PP040000
003l`h80o<>20?c3PP80000000<0o/=i0000003na7L0103na7L4000000<0oLF200<000000?k3NP3n
`gX00`3n`gX01`000000oLF00000003M`Kd000000?[4S00000000P2Ofo`40000000:0?k4MP000000
00000?k1M`000000o[mb0000003l`Gh000000?k1L`80000000@0m<RQ000000000000];oR10000000
1@3maX8000000?k1M03n`G@000000080nM2O100000030?k3NP8000000`3n`6l2000000030?_6G@00
0000olQd00<000000`3od8<3000000030?o:N`000000000000<0om1m0P0000030?o>PP<0000000D0
n[=A0000003k]UL0nkIG000000030?^fE0030000003k]U<0000000/0oooo00<000000?ooo`3oool0
>P3oool00580oooo100000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`00
00060?ooo`030000003oool0000000<00000103oool4000000@0oooo100000040?ooo`@000004P3o
ool5000000L0oooo00<000000?ooo`3oool0FP3oool2000000060?FW?0000000oooo0000003ha940
00000P3l^6`00`000000oooo0?ooo`070?ooo`80000000H0fG/00000003jbI@0n/VD0000003R^Jd6
0000000309?;n`000000000000<0nlF:0P0000020?[1R0<0000000<0l;jM0000003faIP00P3faIP0
1@000000n<>@000000000000n<RH00<0000000H0nlB90000003ibYL0nLZG0000003/b;4300000003
0>7@aP000000ml^N00@000000P3gcZ401@000000fm;@000000000000jmFn00T000000P3jaH`00`00
0000o<^@000000040?_8SP030000003ddj`000000080000000D0g<[700000000000000000000P`04
00000080o<N:00<000000?OAX`3gdJ<0100000020?g2O0070000003ib9D0nLRE0000003dc:H00000
0?S9V`03000000<0nm6I0`0000000`3mah@000000000000200000080oKig0P0000001@3Ua[T00000
0?g0MP3m`7H0000000@0o/Ab100000020?g4PP8000000P3l`h82000000030?k3N@000000o/Ag00@0
o/Ag00@000000?k5O`00000000000`3maH800`000000o/=j0?k3NP030?k3NP030000003maH000000
0080000000<0n/B<0000000000000P2Ofo`300000080o/Af00<000000?k1M`0000000P3n_g820000
00060?k1L`00000000000?C8X@000000o<B31@0000000`3maX8000000?k1M0020?k1M0030000003i
d9l0000000<000000`3n`gX300000080o/1_0P0000001@3kaUd00000000000000000o/=a00<00000
00D0om2300000000000000000?o:N`02000000@0om1m00<000000?o>PP3ocX800P3ocX8010000000
o/=^0000000000030?^fE`060000003k]U@0nkID0000003k]U<00000303oool00`000000oooo0?oo
o`0i0?ooo`00903oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06T0oooo1000000<
0?ooo`030000003oool0oooo05T0oooo00<000000?NoS`0000000P3eYc`2000000030?S4T@000000
o;Q/0080o;Q/00<000000?ooo`3oool00`3oool01`000000oooo0000003jai8000000=Uk00000000
0P3jbI@5000000060;kCjP00000000000000002Cbo/00000103kaHX00`000000n/680?[1R0020000
00040>g4Z@000000l;jM000000<0m/FH20000000103ka8T000000?W:U`3ibYL200000006000FX`00
000000000>7@aP000000ml^N0`0000020?O>X@D0000000<001ZQ0000000000000P0000001`3gbYd0
000000000032bn8000000?[5S00000000P3lbi000`000000nlR>0?_8SP020?_8SP030000003ddj`0
000000<0000000D0n<ZI00000000000000000=o:a00300000080o<N:00<000000?OAX`0000000`00
00020?g2O0030000003ib9D0nLRE0080000000@0m<bV000000000000o<5o0P0000030?_AV@800000
00D0oLN4000000000000oK]S000000020?fnM`80000000D0iLJi0000003m`7H0oL1f000000040?k4
LP80000000<0n/670000003ma8800P3ma8801@000000o<>20?c3PP000000oL5m008000001@3na7L0
10000000o/Eo0000000000040?g5PP030000003n`gX0o/=j0080o/=j100000001@3M`Kd000000000
003od8H000000080Wm_l0P0000020?k4MP030000003n`GL000000080o[mb1@0000001@3db:400000
0?c4P`000000];oR00<0000000<0oLJ20000003n`G@00P3n`G@01@000000nM2O000000000000n<NE
008000000`3n`gX200000080o/1_0P000000103kaUd000000?o?P@0000020?k3L@@0000000D0o/n;
000000000000olYk000000040?o@O@8000000`3ocX8010000000o/=^0000000000030?^fE`040000
003k]U@0nkID00000080nkIC00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0i0?ooo`00
903oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06@0oooo1@00000@0?ooo`030000
003oool0oooo05T0oooo00<000000?NoS`3g_hl0100000000`3ha94000000?bhK0020?bhK0030000
003oool0oooo00<0oooo0`000000103jai8000000000000000020?[9U0<0000000@0nL^J0000002n
dnX0_]?Z100000040?_5RP80000000<0n/680000003laXP00P0000000`3`_Yd000000?K5V0020?K5
V0T0000000@0nlB90000003ibYL0nLZG1P0000000`3gbih0000000000003000000050?W5T@000000
fm;@0000002ocND01P0000001P3gbYd00000000000000000n/F<000000<0o<^@00H000000?_8SP3k
b8h0nlR>0000003ddj`3000000030=c:a`000000000000H000000P3lahX2000000040?OAX`000000
0000000000<0oL9l00<000000?W8U@3ib9D0100000020?c1O`8000000P3kdIT6000000@0oKig0`00
00020?g0MP030000003na780o/Ab0080o/Ab100000030?g4PP040000003l`h80o<>20?c3PP<00000
1@3na7L01@000000o/Eo0000003n`7@0000000<0oLF200<000000?k3NP3n`gX00P3n`gX400000003
0=g1_@00000000000080om2600@0000009oKo000000000000P3na7H300000080o[mb100000001@3n
`G4000000<Ya00000000o<B300<0000000@0ihXE0000003maX8000000P3n`G@2000000030?W@W`00
00000000008000000`3n`gX200000080o/1_0P0000000`3kaUd000000?o?P@0200000080o/=a0`00
00000`3nch/0000000000002000000@0om1m00<000000?o9O00000000P3ocX82000000030?k3KP00
0000nkIG0080nkIG00D000000?^fE03k]U@0nkID000000020?^fD`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0>03oool002@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1O0?ooo`D00000JP3oool00`000000oooo0?ooo`040?ooo`030000003g_hl0mkn?00H00000103l
^6`01@000000oooo0?ooo`000000oooo00<0000000@0n/NB00000000000000000`3jbI@200000004
0?W;VP000000_]?Z0;kCjPD00000103kaHX010000000n/680000003laXP2000000030?2nW@000000
000000<0m/FH1`0000001@3dc:H000000?_4R@000000nLZG0080000000@001JS000000000000hM36
1P0000020?W5T@050000003Kd]000000000000006Z4010000000103gbYd0000000000032bn820000
00<0o<^@0P0000030?_8SPX0000000D0gl[400000000000000000?c7RP02000000040?OAX`000000
0000000000<0oL9l00<000000?W8U@3ib9D00P0000000`3hdJ<000000?c1O`030?c1O`030000003k
dIT0nm6I00D00000103m_WL2000000040>G6^@000000oL1f000000@0o/Ab00<000000?k2M`000000
0P0000030?g4PP030000003l`h80o<>200<000001@3na7L00`000000o/Eo0?k5O`02000000@0oLF2
00P000000?k3NP3n`gX0o/=j0000003na7P000000?k=R0<000000`3od8H010000000Wm_l00000000
00020?k4MP8000000P3n_g84000000070?k1L@000000bW400000003la8<000000;BohP0300000004
0?g6PP000000o/5d0?k1M080000000<0nM2O0000000000000P0000030?k3NP040000003gcf400000
0?k0K`<000000P3och42000000<0o/=a0`0000000`3nch/000000000000300000080om1m00<00000
0?o9O00000000P3ocX8200000080o/=^00@000000?^fE`3k]UL000000`3k]U@010000000nkIC0?^f
D`00000<0?ooo`030000003oool0oooo03L0oooo000H0?ooo`030000003oool0oooo00<0oooo1000
00030?ooo`030000003oool0oooo0080oooo100000030?ooo`040000003oool0oooo0?ooo`H00000
0`3oool4000000@0oooo100000040?ooo`@00000?03oool4000006l0oooo0P0000050?ooo`030000
003g_hl0mkn?00<0000000<0m<VQ000000000000103l^6`00`000000oooo00000005000000040?[7
TP0000000000000000<0n/VD0P0000020?W;VP030000002ndnX0_]?Z008000000P3faIP010000000
nlF:0?_5RP3kaHX300000080o<J80P0000000`3ldiX000000?K5V0020?K5V0H0000000H0o<:20000
00000000nlB90000003ibYL6000000030>7@aP000000mlfO0080000000@0mlBF0000003iaI40nLFA
1@0000001@3Wc[`00000000000000000mlZM00@00000103lbi001`000000nlR>0?_8SP000000llNQ
0000003j`XP00P0000000`3Lb/L0000000000005000000040=S;c@00000000000?_0P@@00000103m
`W`2000000040?NVF00000000000000000@0o<5o00<000000?_AV@3kdIT01@0000040?fnM`060000
003l`H0000000000003m`7H00000103na7801@000000o/9g0000003j`HL0000000<0oLB200<00000
0?c3PP0000000P0000000`3n`g@000000?k4M`030?k4M`030000003naGl0o/Eo00<000000`3maH80
1@000000o/=j0?k3NP3n`gX000000080o/Ah0P0000000`3M`Kd000000?o@QP030?o@QP@0000000<0
o/Af0000000000000`3n_g800`000000`?gQ000000020?k1L@8000000P3la8<2000000040?g6Q@00
0000oLJ200000080o/5d00<000000?k6K@0000001@0000020?k3NP040000003gcf4000000?k0K`<0
00000P3och400`000000o]:@000000020?k3L@<000000P3nch/3000000040?o;O@00000000000000
0080olUl00L000000?o>PP000000olj40000003n`fh000000080nkIG00D000000?^fE03k]U@0nkID
000000030?^fD`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=`3oool001P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0=03oool5000007<0oooo0P0000040?ooo`040000003WRAD0
00000?NoS`<000000P3dbJ401P000000o;Q/0?bhK03l^6`000000?bhK0D0000000<0Q@800000003j
ai800`0000040?[9U08000000P3ibiX00`000000_]?Z0;kCjP0200000080m/FH00<000000?_5RP3k
aHX00`0000020?c6R08000000P3ldiX00`000000m/FH0?K5V0040000000409<600000000o<:20?c2
PP/0000000<0mlNH0000003gcIl00`0000030?W5T@P000000P3gbYd3000000D0o<^@00D000000?_8
SP000000llNQ000000020?[2R080000000<0m<FK0000000000000P0000000`3`aJD0000000000002
00000080nl210`0000040?g2O08000000P3gYUP00`000000n=6S000000040?c1O`030000003kdIT0
000000@00000103m_WL010000000o<600000003Ua[T2000000<0o/Ab00D000000?6E<`0000000000
0?[1Q`0200000080oLB200D000000?c3PP000000i^nA000000020?k3M0050000003na7L0o/Ag0?k4
M`0000000`3naGl2000000<0oLF20P0000020?k3NP030000003na7P0o/Ah00@00000103od8H40000
00030?k4MP000000000000<0o[mb0`0000020?k1L@060000003:L@0000000?c4P`000000];oR0`00
00001@3maX8000000?k1M0000000o/I]008000000P3oehP200000080o/=j00@000000?O?H@000000
o/1_1P000000103ndY0000000?k3L@3n`g44000000040?k?R`0000000000000000<0ol]m00@00000
0?o9O03obG`0olUl0P0000020?o>Q0050000003n`fh000000?^fE`0000000`3k]U@01@000000nkIC
0?^fD`3k]U<0000000`0oooo00<000000?ooo`3oool0=P3oool001P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0;`3oool5000007H0oooo00`000000?ooo`000000nkMb0000003oool000000?oo
o`000000ihTE0000003g_hl300000080m<VQ00@000000?bhK03l^6`0o;Q/100000001@3haY@00000
000000250P0000000080n/NB0`0000040?[9U08000000P3ibiX010000000_]?Z0000000000030?K5
V0030000003kaHX00000008000000`3laXP400000080m/FH00@000000?[CWP00000000000P2C1P00
0`000000o<:20?c2PP02000000050?[5S@000000n/fI0000003ed:P00`0000001`3gaiP000000?O=
W`3gcIl000000?O4UP0000000P3iaI400`000000fm;@0000000600000080mlZM00<000000<;;hP00
0000103lbi0300000080llNQ00D000000?[2R03j`XP000000?C5V`07000000040=S;c@000000nl21
0?_0P@<000001@3m`W`6000000@0o<5o1`0000050?fnM`80000000@0iLJi000000000000o/Ab0`00
00001P3aUC<00000000000000000n/67000000<0oLB20P0000000`3Vki4000000?k3M0020?k3M004
0000003na7L0o/Ag000000<0o/Eo0P0000030?g5PP8000000P3n`gX00`000000o/Ah0?k4N0060000
0080om260`000000103^ck@000000?k4MP0000050?joLP040000003n`G40o/5a0?k1L@8000000P3l
a8<4000000040?g6PP000000o/5d00000080o/I]0P0000020?oGR080000000D0o/=j0000003gcf40
00000?k0K`03000000030?k?RP00000000000080o]:@00@000000?k3L@000000o/=a0P0000020?k?
R`<000000P3obgd2000000<0olUl00@000000?o>Q03ocX@0olj40P0000000`3k]UL000000?^fE002
0?^fE0040000003k]U<0nkIC0?^fD`800000303oool00`000000oooo0?ooo`0e0?ooo`00603oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0:P3oool5000007/0oooo0`0000020?^g
LP@000000P3WRAD3000000070>_;]@000000m<VQ0000003l^6`000000?bhK003000000070?O3U@00
0000n<JD0?S6U0000000Q@80000000020?[7TP<000000`3jbI@300000080nL^J00@000000;kCjP00
000000000P3faIP3000000030?[8T@000000000000<0o<J800<000000?_3Q@3k`hD00P0000030?[C
WP<0000000@0T`H00000003l`X80o<:20P0000001@3jaHd000000?[=V@000000mM2X00<0000000<0
mlNH0000003gcIl00P000000103ga9H000000?W5T@3iaI45000000050>O>_000000000000000003g
bYd0100000030?c;T0<000000P3caj400`000000n/:80?[2R002000000030?C5V`00000000000080
000000@0l<FU00000000000000000`3k`842000000D0oL9l00<000000?k5N03naGP00P3naGP00`00
0000o<5o0?c1O`020?c1O`030000003m`GX000000080000000<0jl:Y0000003m_WL0103m_WL01000
0000o<600000003Ua[T2000000030?[WTP000000000000@0000000<0n/670000000000000P3ma882
000000030>K_T@00000000000080o/=d00@000000?k4M`3na7L000000`3naGl00`000000o/1d0000
00020?g5PP050000003Eg]h000000?k3NP0000000`3na7P2000000030?k=R0000000000000<00000
00<0o<R<0000000000000`0000050?joLP8000000P3n`G4200000080o<B300@000000;BohP000000
om^@0P0000000`3n`G@000000?k6K@030?k6K@@0000000<0o/=j0000003gcf40100000000`3Fj>80
00000?k?RP0200000080o]:@0P0000020?k3L@80000000<0o/n;0000000000000P0000000`3obgd0
0000000000030?o9O08000000P3ocX@4000000<0nkID00@000000?^fD`3k]U<0nkIC0P00000=0?oo
o`030000003oool0oooo03@0oooo000H0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool2000000<0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool09P3oool400000640oooo00<000000?ooo`3o
ool06@3oool6000000050?^gLP00000000000000003c`IX00P0000000`3WRAD000000?NoS`030000
00030?C9X@000000000000<0000000@0n;n;0000003g`iD000000P3haY@20000000308D200000000
n/NB0080000000<0l<j_0000000000000P3jbI@300000080nL^J0P0000000`3IbL/0000000000002
0?[<U`040000003jb940n/RA0?[8T@D0000000<0nl>50000000000001@3jdih400000080o<:200L0
00000?[5S@3jaHd000000?[=V@000000mM2X008000000P3gaiP01@000000mlfO0000003ga9H00000
00<0nLFA1@0000000`3Wc[`00000000000020?O:W@@000000P3lbi0300000080llNQ00<000000?[2
R03j`XP00P0000001@3daI/00000000000000000k/2T00<0000000@0eH400000003k`840nl210P00
00050?g2O0030000003naGP0o/Eh00<0o/Eh00P000000?c1O`3l`Gl0o<5o0000003m`GX000000?FT
>`<000001@3m_WL010000000o<600000003Ua[T3000000040?k1MP000000o;ef0?bmMP80000000<0
n/670000000000000P3ma88300000080olAb00H000000?k3M03n`g@000000?k4M`0000040?k5O`80
000000L0oLF20000003Eg]h0eMkN0000003n`gX0000000<0o/Ah00@000000?K<X@00000000000P3l
aXT2000000060?c8S000000000000000003jaHh000001@3n_g82000000<0o/5a0P0000020?c4P`L0
0000103naVd2000000050?oCRP000000o/=j0000003gcf40100000020=KXhP<000000P3ndY020000
0080o/=a2`0000020?o9O08000000`3ocX@3000000<0nkID00L000000?^fD`3k]U<0nkIC0000003k
]U<0000000`0oooo00<000000?ooo`3oool0=03oool001P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo00000002000000@0oooo00D000000?ooo`3oool000000?ooo`03000000@0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0Q0?ooo`D00000I@3oool20000
00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000060000000409:ck@0000000000
0??1VP80000000<0ihTE0000003g_hl00P0000000`3[bkD000000?C9X@04000000050?RoR`000000
ml>E0?O3U@0000000P3haY@20000000308D200000000n/NB008000000P3`cZl00`000000n/VD0000
0003000000030?W;VP000000000000<000000`3jc9L00`000000n/RA0?[8T@030?[8T@<0000000<0
nl>50000000000001@3jdih4000000030?c2PP00000000000080n/F=0`0000000`3ed:P000000000
00020?O7V0050000003gcIl000000?O4UP0000000P3iaI46000000040?ZoQ000000000000?O:W@D0
000000<0o<^@00000000<;000P0000020??7X@030000003j`XP0n/:80080000000<0m<FK00000000
00000P000000103`aJD000000000000000030?_0P@030000003m`W`0oL9l00<0oL9l00<000000?k5
N03naGP00`3naGP01@000000o<5o0?c1O`3l`Gl000000080oL5j100000060?fnM`@000000P3n`GH0
0`000000o;ef0?bmMP020?bmMP040000003j`HL0n/6700000080oLB20P0000030?o4LP80000000@0
o/=d0000000000000000103naGl400000080eMkN0`0000040?k4N0030000003fc:4000000080o<J9
0P0000020?c8S0D00000103n_g800`000000o/1`000000020?k1L@8000000P3la8<2000000030>Kg
d@000000000000800000103naVd2000000050?oCRP00000000000000003gcf401@0000001@3Fj>80
00000000003ld9@000000080o]:@00@000000?k3L@3n`g40o/=a0`0000000`3nc8H0000000000004
00000080olUl00<000000?o5M@0000000P3ocX@3000000<0nkID00L000000?^fD`3k]U<0nkIC0000
003k]U<0000000d0oooo00<000000?ooo`3oool0<`3oool001P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0L0?ooo`D00000JP3oool00`000000l9D`0000000:0?oo
o`030000003oool0oooo00X0oooo0P0000000`3k/fT000000??2V`02000000030?S9V@000000T[?]
008000000P3c`IX2000000030>N95@000000mkn?0080000000@0jl^e000000000000ml6A0`000000
1@3h_h/000000?O3U@3g`iD000000080n<JD0P0000000`250P0000000?[7TP02000000030?3>[`00
0000000000H0000000@0n<nN0000003ic9X00000103jc9L00`000000n/RA0?[8T@020?[8T@030000
003jbi@000000080000000<0nl:50000000000000`3jdih010000000nlN;0000003adk8400000080
n/F=0P0000020?G@Z0080000003gaiP0mlNH0000003gcIl000000?O4UP0000020?W5T@80000000@0
k]6e00000000000000000P3j_h@2000000030?ZnQ0000000000000@0000000<0032`000000000000
0P3caj400`000000n/:80?[2R002000000030?C5V`00000000000080000000@0l<FU000000000000
00000`3k`8400`000000oL9l0?g2O0030?g2O0030000003naGP0o/Eh00<0o/Eh0P0000020?c1O`03
0000003m`GX0oL5j00@000001P3m_WL3000000<0o/5f00<000000?bmMP3l_GH00P3l_GH200000005
0?[1Q`00000000000?g4PP000000103oa7801P000000o/9h000000000000o/Io000000D0o/Eo0`00
00030=GNgP800000103na7P00`000000m/bQ000000020?c6R@<000000P3lb8`2000000030?[5SP00
0000o[mb00<0o[mb00<000000?k0L00000000`3n`G42000000030?c4P`000000olAd00D000000P3n
aVd200000080o=NK2@0000001@3ncXT000000=KXhP000000o=2D0080000000<0o]:@000000000000
0P3n`g43000000030?k<QP000000olEd0080000000D0om6:000000000000olUl000000020?o5M@04
0000003ocX@000000?oBR08000000P3k]U@00`000000nkIC0?^fD`020?^fD`030000003k]U<00000
00d0oooo00<000000?ooo`3oool0<P3oool001H0oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`070?ooo`030000003oool0000000T0oooo00<000000?ooo`000000103oool010000000
oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0H0?ooo`@00000KP3oool010000000m<FL00000000000:0?ooo`<00000
2P3oool2000000040?^cJ@000000ll:K0??2V`80000000<0n<VI0000002B/nd00P0000000`3c`IX0
00000000000200000080mkn?0`0000000`3dbJ4000000?O1T@02000000030?RoR`000000ml>E0080
ml>E00<000000?S6U00000001`0000000`3`cZl0000000000003000000070=o<a@000000n<nN0?S?
WP000000nLbJ000000040?[<U`8000000P3jb9400`000000n/^D0?[;U002000000<0nl:50P000000
2@3jdih000000?_7R`3kah/000000?7C/P000000o<:1000000020?[5S@030000003lbH`000000080
mM2X00<000000?O7V03gaiP00`0000001@3ga9H000000?W5T@000000n/6600@000000`3j_h@00`00
0000n[j40000000500000004000`/0000000i[n_00000080llNQ00<000000?[2R03j`XP00P000000
1P3daI/000000000003^`:@000000?35Y@<000000P3k`8400`000000oL9l0?g2O0030?g2O0030000
003naGP0o/Eh00<0o/Eh0P0000020?c1O`040000003m`GX0oL5j0?g1NP<000001P3m_WL2000000@0
o/5f00<000000?bmMP3l_GH00P3l_GH2000000050?[1Q`00000000000?g4PP000000103oa7801P00
0000o/9h0?k2N0000000o/Io000000D0o/Eo0`0000030=GNgP8000001@3na7P00`000000k/^_0000
00020?c6R@8000000P3lb8`2000000030?[5SP000000o[mb00<0o[mb00@000000?k0L03n`7000000
0P3n`G42000000030?c4P`000000olAd0080olAd1P0000000`3odXT000000?cGV`020?cGV`@00000
00T0o<fA0000003ncXT000000?k>R@000000h]G:0000003ld9@00P0000000`3ldIL000000?k3L@02
0?k3L@<0000000<0o/b60000003oaG@00`0000000`3`ck000000000000030?o5M@80000000<0om:8
0000000000000P3k]U@00`000000nkIC0?^fD`020?^fD`030000003k]U<0000000h0oooo00<00000
0?ooo`3oool0<@3oool001L0oooo0P0000050?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0C0?ooo`H00000L@3oool00`000000m<FL000000030000
00P0oooo0`0000090?ooo`030000003daI`0m<FL008000000P3c`Y/00`000000mlNI000000040000
0080ll6J0P0000001P3WRAD000000?NoS`3g_hl000000>_;]@8000000P3g`I4010000000n;n;0?Ro
R`0000020?O3U@030000003haY@0000000L0000000<0l<j_000000000000100000001`2/hOT00000
0?S?WP3hcih000000?W<VP000000103jc9L2000000030?[8T@000000n/^D00<0n/^D00<000000?_2
Q@3k`XD00P3k`XD2000000<0nlN;00<000000?7C/P0000000P000000103jaHd000000?c9S03lbH`3
000000<0mlNH0P000000103ga9H000000000000000020?[1QP<000000`3j_h@00`000000n[j40?Zn
Q004000000030?[1R0000000032`008000000P3caj400`000000n/:80?[2R002000000030?C5V`00
000000000080000000@0l<FU00000000000000000P3k`8400`000000oL9l0?g2O0030?g2O0030000
003naGP0o/Eh00<0o/Eh0P0000020?c1O`040000003m`GX0oL5j0?g1NP<000001P3m_WL2000000@0
o/5f00<000000?bmMP3l_GH00`3l_GH00`000000n/670?[1Q`03000000@0olAb00L000000?k2N03n
`WP0o/9h0000003naWl0000000@0o/Eo0`0000040=GNgP8000000`3na7P2000000040>k;[`000000
o<J90?c6R@<000000P3lb8`3000000@0o[mb00@000000?k0L03n`70000000P3n`G42000000030?c4
P`000000olAd00<0olAd1@0000020?oBR@030000003lei/0o=NK0080000000@0o/In000000000000
o<fA0P0000001@3ncXT00000000000000000o=2D008000000P3ldIL00`000000o/=a0?k3L@030000
0080o/b60P0000000`3ldIT0000000000002000000<0olEe0P0000020?oBR08000000P3k]U@01@00
0000nkIC0?^fD`3k]U<000000080nkIC00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0a
0?ooo`00603oool00`000000oooo0?ooo`040?ooo`<000001P3oool00`000000oooo0?ooo`030000
00H0oooo00<000000?ooo`0000000`0000040?ooo`@00000103oool4000000@0oooo1000000A0?oo
o`D000001@3oool00`000000oooo0?ooo`1_0?ooo`050000003daI`000000000003j/FP00P000007
0?ooo`@0000000<0oooo0000003oool00`3oool00`000000oooo000000020?C5W0030000003k/fT0
00000080ll:K00D000000?O7V@000000000009:ck@02000000030??1VP0000000000008000000P3g
_hl2000000050>_;]@00000000000?O1T@0000000P3h_h/010000000ml>E0?O3U@3g`iD200000003
0?[6S`00000000000080000000D0lMFd00000000000000000=]X4P03000000040<GTk@0000000000
00000080n<nN00L000000?W<VP00000000000?[<U`000000nL^J00<00000103jbi@2000000@0nl:5
0P0000030?_7R`030000003adk80000000<000000`3lbH`00`000000m=Na000000020?O7V0H00000
0P3j`HH400000080n[n400<000000?ZnQ03j_X@01@0000001`3j`HP000000000003V_jl000000??7
X@0000000P3j`XP200000080m<FK0P0000000`3^`:@000000?35Y@02000000<0nl2100<000000?g2
O03m`W`00P3m`W`00`000000o/Eh0?k5N0020?k5N0060000003m`Wh0oL9n0000003l`Gl00000103m
`GX2000000H0oKig0P0000040?k1MP030000003l_GH0o;ef00<0o;ef00<000000?[1Q`3j`HL00`00
00040?o4LP070000003n`WP0o/9h0?k2N0000000o/Io000000040?k5O`040000003n`gT000000000
00<0eMkN0P0000030?k4N08000000P3^bjl00`000000o<J90?c6R@0200000080o<R<100000030?jo
LP060000003n`700o/1`0?k0L0000000o/5a100000040?o4M0050000003lcVP000000?c>J0000000
0`3odXT2000000060>SB_`000000o/In0?k6OP000000o<fA0P0000020?k>R@040000003ReLX00000
0?c@U080000000@0o=6G0000003n`g40o/=a100000000`3nc8H0000000000003000000030?3?/000
0000olEe00<0olEe00D000000?oBR03odXP0om:8000000020?^fE0050000003k]U<0nkIC0?^fD`00
00000P3k]U<00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0300oooo001N0?ooo`D00000
2P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00<0000000<0m/ZO000000000000
0P0000050?ooo`030000003Vd<4000000080000000<0oooo0000000000000`3oool3000000<0m<FL
0P0000020??2V`80000000<0mlNI0000000000000P0000020??1VP80000000<0ihTE0000003g_hl0
1@0000020?O1T@040000003h_h/0n;n;000000<0ml>E00@000000?[6S`3jaXl0n/J?0`0000001@3a
eK@00000000000000000ffPB00P0000000<0n<nN0000003ic9X00`0000020?W;VP8000001@3jbi@2
000000<0nl:50`0000020?_7R`030000003adk80000000<00000103lbH`200000080mlNH00H00000
0?_=U`00000000000?3?[`0000030?[1QP<000000`3j_h@01@000000n[j40?ZnQ0000000kL6V0080
00000P3j`HP00`000000i[n_000000020??7X@030000003j`XP000000080000000H0m<FK00000000
0000k/2T0000003`aJD300000080nl2100<000000?g2O03m`W`00P3m`W`00`000000o/Eh0?k5N002
0?k5N0060000003m`Wh0oL9n0000003l`Gl00000103m`GX2000000H0oKig00<000000?k0LP000000
0`3n`GH00`000000o;ef0?bmMP030?bmMP80000000@0n/6700000000000000000P3oa783000000@0
o/9h00<000000?k6O`0000000`3naGl01@000000o/=i0000003lbXd000000080eMkN00<000000?G8
W`0000000P3na7P01@000000oLJ20000003^bjl000000080o<J90P0000030?c8S0<000000`3n_g80
20000000o/1`0?k0L03n`70000000?k1L@000000o/5a0P0000040?o4M0050000003lcVP000000?c>
J0000000103odXT00`000000j=:o000000030?k6OP030000003lcI4000000080o/j90`0000000`3l
d9@00000000000020?cAU`030000003n`g40000000<000000P3nc8H2000000040?cAV@0000000000
000000@0olEe0P0000030?oBR0030000003k]U@0000000<0nkIC00<000000?^fD`3k]U<00P00000>
0?ooo`030000003oool0oooo02l0oooo001J0?ooo`@000003`3oool00`000000oooo0?ooo`1[0?oo
o`<0000000`0oooo0000003<i^T000000?K:W`000000m/VN0000003j]6h000000?ooo`0000020?oo
o`030000003Vd<40i]3100D000000`3oool3000000<0m<FL0`0000020??2V`80000000<0mlNI0000
000000000P0000020??1VP<0000000<0mkn?000000000000100000001@3g`I4000000?RoR`3h_h/0
000000<0ml>E0P0000030?[6S`<0000000<0lMFd000000000000100000000`3ka8T000000<GTk@06
000000030<WJiP000000nL^J0080nL^J0P0000050?[;U08000000P3k`XD00`000000o<B600000002
000000030?_7R`000000lM>b00<000001@3lbH`3000000<0nlfG00<000000?3?[`000000103j`HH2
000000<0n[n400<000000?ZnQ03j_X@0100000030?[1R0060000003V_jl000000??7X@000000n/:8
0`0000000`3daI/000000000000200000080l<FU0P0000020?_0P@8000000`3m`W`00`000000o/Eh
0?k5N0020?k5N0060000003m`Wh0oL9n0000003l`Gl000001@3m`GX00`000000oKig0?fnM`040?fn
M`030000003n`780000000<0o/5f00<000000?bmMP3l_GH00`3l_GH2000000030?[1Q`000000o/Ej
00<0000000<0o]:A000000000000103n`WP00`000000o/Io000000030?k5O`030000003n`gT00000
0080o<Z=00<000000=GNgP3Eg]h00`000000103na7P000000?g6PP0000020>k;[`030000003laXT0
o<J9008000000P3lb8`3000000<0o[mb00<000000?k0L03n`7000P3n`702000000030?k1L@000000
000000@0olAd00@000000?c>J03lcVP0o<iX0P0000030?oBR@040000003Xd[l0j=:o00000080o/In
00D000000?c=T@00000000000?k>R@02000000030>;EbP000000o=2D008000000P3ldIL200000005
0?k2LP00000000000000003nc8H00`000000103ldIT00000000Y[`0000030?o5M@030000003ob7<0
00000080om:80`0000030?^fD`030000003k]U<0nkIC008000003P3oool00`000000oooo0?ooo`0_
0?ooo`00E@3oool500000840oooo1@0000002@3<i^T000000?K:W`000000m/VN0000003j]6h00000
0?ooo`02000000040?ooo`00000000000>K@`@P0000000@0jL:]00000000000000000`3daI`20000
00<0ll:K00@000000?O7V@000000iL:d0P0000020??1VP<0000000<0mkn?00000000000010000000
0`3g`I4000000?RoR`020?RoR`060000003g`iD0ml>E0000003jai8000000`3jaXl00`000000k=2h
000000020?7E]0030000003df[80m=Zb00P0000000D0n<fN00000039f^H0bM[V000000020?W;VP03
0000003fc:80000000@0n/^D0`0000001P3k`XD000000?c4QP3la8H000000;CGlPP000000`3lbH`3
000000@0nlfG00<000000?3?[`0000000`3j`HH2000000<0n[n400H000000?ZnQ03j_X@0n[j40000
003]`JH200000080n/6800P000000>Jo[`000000llNQ0000003j`XP000000?c8RP80000000H0m<FK
000000000000k/2T0000003`aJD200000080nl210P0000030?g2O0030000003naGP0o/Eh0080o/Eh
00@000000?g2OP3m`Wh0oL9n0P0000050?g1NP8000001@3m_WL010000000o/1b0?k0LP0000020?k1
MP030000003l_GH0o;ef00<0o;ef0P000000103j`HL000000?k5NP3naGX2000000040?kBT@000000
0000000000@0o/9h00D000000?k6O`000000o/Eo000000030?k3N@030000003lbXd000000080eMkN
1@0000020?g6PP030000003^bjl000000080o<J90P0000020?c8S0@000000P3n_g800`000000o/1`
0?k0L0020?k0L08000000P3n`G400`000000olAd0?o4M0020?o4M0050000003lcVP0o<iX0000003o
aW<00`0000001@3odXT000000000003Xd[l000000080o/In0`000000103lcI4000000000003mdY<2
000000030?c@U000000000000080o=6G0P0000001@3n`W800000000000000000o/b600<000000P3l
dIT2000000<0olEe00H000000?o8L`000000om:80000003obGh2000000<0nkIC00H000000?^fD`3k
]U<000000?ZdC`00000>0?ooo`030000003oool0oooo02h0oooo001@0?ooo`D00000PP3oool20000
0080oooo1@0000001@3<i^T000000?K:W`000000m/VN00L000000P3^dkP9000000040>W2[@000000
llFO000000@0m<FL0P0000020??2V`L000000P3c`IX900000080ml6A00H000000?RoR`3h_h/00000
0?O3U@0000030?[7TP80000000@0n/J?000000000000k=2h0P0000001P3[f<400000000000000000
052n00000080nl>9100000001@3hcIh000000<WJiP39f^H000000080nL^J00H000000?K<XP000000
00000?[;U00000020?S:VP<000000`3la8H01P000000nl>90000003iaY8000000?[7T080000000L0
o<:10000003lbH`0o<V<0000003mci40000000@0nlfG00<000000?3?[`000000103j`HH200000080
n[n400H000000?ZnQ03j_X@0n[j40000003]`JH2000000<0n/680`000000103caj4000000000003l
b8X5000000030>k0Y0000000l<FU008000000P3k`8400`000000nkmo000000020?g2O0030000003n
aGP0o/Eh0080o/Eh00@000000?g2OP3m`Wh0oL9n0P0000050?g1NP8000001@3m_WL01`000000o/1b
0?k0LP3n`78000000?k1MP0000001@3l_GH2000000030?[1Q`000000o/Ej00<0o/Ej100000040?k2
N0<0000000<0o/Eo0000003n`gT00P3n`gT010000000o<Z=0?c:S@0000020=GNgP@000000P3maX80
0`000000k/^_000000020?c6R@@000000P3of94200000080o[mb00<000000?k0L03n`7000P3n`702
00000080o/5a00<000000?o4M03oa7@00P3oa7@010000000o<iX0?c>J00000020?o6L`D000000P3X
d[l00`000000o/In00000002000000060?c=T@00000000000?gBT`000000h]G:100000020?cAU`03
0000003n`W80o/9b00@0000000L0o]NC000000000000o=6I00000000:Jl000000080olEe00<00000
0?o8L`3ob7<00P0000020?o9OP050000003k]U<0nkIC0?^fD`0000000P3k]U<00`000000n[A?0000
000?0?ooo`030000003oool0oooo02d0oooo001;0?ooo`D00000N@3oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo0?ooo`D000000P3eaI/00`000000e=kO000000020<cVj@80000000<0
m/VN0000000000000P0000000`3]e;X00000000000030>kC^0<0000000D0n;f9000000000000mlFG
000000020>W2[@030000003caIl0000000<0m<FL0P0000030??2V`<0000000<0iL:d000000000000
0P3c`IX600000080n/><0P0000000`3g`I4000000?RoR`020?RoR`8000001@3jai84000000040>c@
^0000000jmS10>_H`@8000000P00D;h00`000000nl>90?_3R@04000000050?S=WP000000bM[V0<WJ
iP0000000P3ibiX00`000000m/bR0?K<XP0200000080n<ZJ00<000000?K8V`0000000`3la8H20000
00050?_3R@000000nLJB0000003jai000P000000103l`X4000000000000000020?g?T@030000003k
cIL0nlfG0080nlfG0P0000040?[1QP8000000P3j_h@00`000000n[j40?ZnQ0020?ZnQ0<000000`3j
`HP010000000i[n_0000003caj4200000080o<R:1@0000000`3^`:@000000014aP02000000040?_0
P@000000nkmo00000080oL9l00<000000?k5N03naGP00P3naGP00`000000oL9n0?g2OP020?g2OP03
0000003m`GX0oL5j00<0oL5j0P0000050?fnM`030000003n`780o/1b0080o/1b0P0000050?bmMP@0
00001@3naGX2000000030?W2R`000000o/9h0080o/9h0P0000000`3naWl00000000000040?k3N@05
0000003lbXd0o<Z=0000003Eg]h00P0000000`3n`GL000000?g6PP020?g6PP040000003^bjl00000
0?c6R@@000000P3of94200000080o[mb00<000000?k0L03n`7000P3n`702000000<0o/5a00H00000
0?o4M03oa7@0olAd0000003lcVP50000000:0?k3M@0000000000000]Z`000000j=:o0000003naWh0
00000?o7N`80000000@0o/^80000003mdY<0oM:C0`0000001@3ncH/000000?cAU`3ldIL000000080
o/9b100000020?kGT`80000000D0nlfF000000000000olEe000000040?o8L`030000003obGh0olUn
008000000P3k]U<01`000000nkIC0?^fD`3k]U<000000?ZdC`0000003`3oool00`000000oooo0?oo
o`0/0?ooo`00A`3oool4000007T0oooo00<000000?ooo`3oool00P3oool2000000L0oooo0P000002
0?ooo`8000000P3gaIH010000000mLFK0?G5V`3eaI/40000000;0<cVj@00000000000?K9WP000000
m/:E0000003]e;X000000?FoT`0000000`3^dkP2000000050?RmR@00000000000?O5U`0000000P3Y
`Zd2000000070??5W`000000m<FL0?C5W0000000mkj?000000020??2V`@0000000<0iL:d00000000
00000P3c`IX4000000<0n/><0P0000000`3g`I4000000?RoR`020?RoR`8000001P3jai800`000000
n<ND0000000300000080jmS10`0000001000D;h000000?_3R@3k`hT4000000030?S=WP000000bM[V
008000000P3ibiX010000000m/bR0?K<XP0000030?S:VP050000003fb9/000000000003la8H00P00
00001@3k`hT000000?W6TP3iaY8000000080n/N@0P0000000`3Qc/H00000000000020?g?T@030000
003kcIL0nlfG0080nlfG0P0000030?[1QP8000000`3j_h@01P000000n[j40?ZnQ03j_X@000000>g1
YP8000000P3j`HP01P000000i[n_000000000000ki</00000080o<R:0`0000001@2bWlD000000>k0
Y000000004C60080000000L0nl210000003k_gl0nkmo0000003m`W`0000000@0o/Eh00<000000?g2
OP3m`Wh00P3m`Wh00`000000oL5j0?g1NP030?g1NP8000001@3m_WL00`000000o/1b0?k0LP020?k0
LP8000001@3l_GH010000000o/5W0000000000050?k5NP80000000<0nL:;0000003n`WP00P3n`WP0
0`000000o;MV00000002000000@0o/=i00@000000?c:S@3lbXd0o<Z=0P000000103=`m4000000?k1
M`0000020?g6PP060000003^bjl000000?c6R@000000E@000P0000020?oHT@<0000000<0o[mb0000
003n`7000`3n`702000000@0o/5a00D000000?o4M03oa7@000000?c>J00200000005092ckP000000
00000000003n`gD00`0000020>SB_`80000000<0olMk0000000000000P3nbhP01@000000oM:C0000
003ReLX000000080o/f;0P000000103mb8T000000?k2LP3n`W83000000<0o]NC00<000000?_=UP00
00000`0000040?o8L`8000000P3obGh010000000nkIC0?^fD`0000030?^fD`030000003j]4l00000
00l0oooo00<000000?ooo`3oool0;03oool00480oooo1@00001m0?ooo`8000000P3oool3000000L0
oooo0P0000020?ooo`8000000`3gaIH00`000000mLFK0?G5V`020?G5V`H0000000D0m/VN0000003f
`YD000000>gD^P0300000080k]>h0P0000020?RmR@80000000<0mlFG0000003Y`Zd00P0000000`3c
aIl000000?C5W0020?C5W08000000`3c`Y/01P000000liY9000000000000k=6i00000080ll6J1000
00040?[3S0@000000P3h_h/2000000H0n/NB0P0000001`3hai@000000000003ecJD000000>_H`@00
00000P3ib9H4000000080?_3R@00000000000?;=Z@000000n<fN00000039f^H400000080m/bR0P00
00030?S:VP030000003fb9/0m/RK00@0000000D0nl>90000003iaY80nLJB000000020?[7T0800000
0P3ifJH5000000040?_=U`0000000000000000<0n/660P0000030?ZoQ0030000003j_X@0n[j40080
n[j40`0000020?[1R0@0000000<0ki</0000003lb8X00P3lb8X01@000000nkio000000000000k/2T
00@0000000L0nl210000003k_gl0nkmo0000003m`W`0000000@0o/Eh00<000000?g2OP3m`Wh00P3m
`Wh00`000000oL5j0?g1NP030?g1NP8000001@3m_WL00`000000o/1b0?k0LP030?k0LP030000003l
_GH0o;ef00<0o;ef00@000000?k1I`00000000001@3naGX3000000060?W2R`000000o/9h0?k2N000
0000o;MV0`0000050?k3N@050000003lbXd0o<Z=0000003ja8d00P0000000`3n`GL000000?g6PP02
0?g6PP050000003^bjl000000000001E00000`0000020?oHT@80000000<0o[mb0000003n`7000`3n
`7000`000000oL=S000000030?k1L@030000003oa7@0olAd008000000P3n`WD4000000030?k3M@00
0000o<V<0080000000@0j=:o000000000000olMk0P0000020?k;R0070000003mdY<0oM:C0000003B
e]/000000?k=R`02000000040?g8R@000000o/9b0?k2LP80000000D0oLR80000003nei<0o]NC0000
00020?_=UP<00000103ob7<200000080olUn0P0000020?^fD`040000003k]U<0nkIC00000080n[A?
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0[0?ooo`00?@3oool5000005D0oooo00<0
00000?ooo`3oool08@3oool2000000@0oooo00@000000?ooo`000000llbW0P0000000`3oool00000
0;77jP03000000030?ooo`000000oooo0080oooo100000000`3fbIl000000?O5UP020?O5UP800000
103eaI/700000080m/:E0P0000000`3e_i<0000000000003000000<0n;f900<000000?O5U`000000
0P3Y`Zd2000000070??5W`000000m<FL0?C5W0000000mkj?000000020??2V`@0000000P0k=6i0000
00000000ll6J0000003^U5P000000?K3U`8000000P3j`h`4000000040?RoR`000000j9Uc0>RIL`80
0000103jai8010000000nLND0000003hai@2000000050?G=Y@00000000000000003ib9H01P000000
0`3We<<000000?;=Z@03000000040<WJiP00000000000?GD[08000000P3ed:L010000000n<ZJ0?S:
VP0000020?K8V`<0000000@0n/270000003k`hT000000P3iaY8010000000n/N@0000003iai<20000
00<0nMVV100000000`3jg:L00000000000020?[1QP<000000P3j_h@00`000000n[j40?ZnQ0020?Zn
Q0<0000000D0n/680000003jd9/000000>Jo[`020000000<0>nC;0000000o<R:0?c8RP000000nkio
0000003:G`0000000?[0QP00000004C60`0000020?^oO`<000000P3naGP3000000D0oL9n00<00000
0?g1NP3m`GX00P3m`GX00`000000oL5m000000040?fnM`030000003n`780o/1b00<0o/1b00<00000
0?bmMP3l_GH00`3l_GH010000000o/5W0000000000050?k5NP<0000000H0nL:;0000003n`WP0o/9h
0000003l]fH2000000030?g:RP000000o/=i00<0o/=i00<000000?c:S@3lbXd0100000020?k1M`05
0000003maX80oLJ20000003^bjl00P00000205D000H0000000<0o[mb0000003n`7000`3n`7000`00
0000oL=S000000030?k1L@80000000<0olAd0000000000000P3n`WD00`000000T;?^000000020000
00040?k3M@000000000000000080j=:o00D000000?o7N`000000olMk000000020?k;R0030000003m
dY<000000080000000<0o/f;0000000000000P3mb8T01@000000o/9b0?k2LP000000oLR800800000
0P3nei<00`000000nlfF00000002000000@0olQc00<000000?k2LP0000000P3obGh010000000nkIC
0?^fD`0000020?^fD`040000003j]4l0n[A?00000100oooo00<000000?ooo`3oool0:P3oool003T0
oooo1000000l0?ooo`030000003oool0oooo00X0oooo0P0000030?ooo`030000003oool0oooo00T0
oooo0P00000N0?ooo`040000003oool0oooo0?ooo`<000000`3oool3000000030??<Y`0000000000
00D0000000@0mJ9I00000000000000000P3oool400000080m/VO00@000000?O5UP3gaIH0mlFF0P00
00040?G5V`<0000000@0bm?O00000000000000000P3f`YD2000000040?FoT`000000lLZZ000000@0
n;f90P0000001@3gaIL000000>W2[@000000kknP00<0000000@0m<FL0000003g_Xl000000P3c`Y/0
0`000000nLND0?W7U002000000030>cA^@00000000000080kYAH00P000000?K3U`3f`iL0m/>G0000
003j`h`000000?[3R`80000000<0n;n;0000003XVG<00P3XVG<2000000<0n/NB00<000000?W7U03i
ai@00P000000103Pdl/000000?G=Y@3ecJD3000000030?W6TP000000000000<0000000L0imC30000
003bcJT0000008g2n@000000am?S0080000000<0mMB/0000003ed:L00P3ed:L00`000000n<ZJ0?S:
VP0200000080nL:;00D000000?[0Q`000000nl>9000000020?W6TP<000000P3iai<3000000030?WI
YP0000001FgM00<0000000@0n]bW0000003j`HH0n/660`0000020?ZoQ0030000003j_X@0n[j40080
n[j400<000000>g1YP0000000P0000001@3jd9/000000>Jo[`000000n<fM00<000000P3lb8X01000
0000nkio0000000000020?[0QP@000000`3k_gl4000000040?_1Q@0000000000000000@0oL9n00<0
00000?g1NP3m`GX00P3m`GX00`000000oL5m000000040?fnM`030000003n`780o/1b00<0o/1b00<0
00000?bmMP3l_GH00`3l_GH010000000o/5W0?k1I`0000050?k5NP030000003l_GH000000080nL:;
00<000000?k2N00000000P3l]fH3000000@0o/=i0`0000000`2NZMh000000?[4S@02000000030?k1
M`000000oLJ20080oLJ200<000000>k;[`0000000P000000103naGP000000?o6K`3oaVl200000003
0?joLP000000o/1`00<0o/1`00<000000?g3H`0000000`3n`G4010000000oLAR0000000000040?k2
M@80000000D0o<Z=0000003n`gD000000?c9S002000000060>SB_`000000olMk0000003oag/00000
0`3nbhP01`000000oM:C0000003Be]/000000?k=R`0000000P3mb8T00`000000o/9b0?k2LP040000
0080o]NC00<000000?_=UP3kcIH00P0000040?o8L`030000003n`W8000000080olUn0P0000001@3k
]U<000000?^fD`3k]U<0000000<0n[A?00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Z
0?ooo`00<`3oool6000002<0oooo00<000000?ooo`3oool06P3oool2000000/0oooo0P0000020?oo
o`<000002P3oool2000000D0oooo00<000000?ooo`000000303oool2000000P0oooo0P0000000`3o
ool000000?7=[@02000000<0oooo00@000000?7:Z0000000llbW100000000`2fgo@000000;77jP04
00000080oooo0P0000000`3Xe/<000000?K9W`020?K9W`050000003gaIH0mlFF0?O5UP000000103e
aI/4000000040;Pk00000000000000000080m/:E00<000000?FoT`3e_i<00P0000050?RmR@<00000
0P3Y`Zd00`000000kknP00000007000000@0nLND0P0000000`3/dKT000000>jDF003000000<0m/>G
0P0000001@3j`h/000000000003h_h/000000080j9Uc0P0000001@3jaHh000000?[7TP3jai800000
00<0nLND0P000000103Pdl/000000?G=Y@3ecJD200000080nLJB1@0000001`3We<<0000000000000
0000SL;i00000037dn<00P0000001@3ee:`000000?G@Y`3ed:L000000080n<ZJ0P0000030?W2R`<0
000000H0nl>90000003iaY8000000?[;UP0000030?W7T`060000003l`H80000000000005KMd00000
0P3iaY8200000080n/660`0000030?ZoQ0040000003j_X@0n[j40?ZnQ0D000000P3jd9/010000000
nLNE0000003hcId5000000030?^nO`00000000000080n/26100000030?^oO`800000103k`HD20000
00@0oL9n0P0000030?g1NP030000003m`Gd0000000@0oKig00<000000?k0LP3n`7800`3n`7800`00
0000o;ef0?bmMP030?bmMP040000003n`FL0o/5W000000D0o/Ej00P000000?bmMP00000000000?W2
R`000000o/9h00000080o;MV0P0000000`3mbXX000000?k3N@020?k3N@<0000000<0WZWN0000003j
a8d00P0000020?k1M`060000003maX80oLJ20000003^bjl000000`3naGP010000000olI_0?o6K`3o
aVl3000000@0o/1`00@000000?g3H`3m`f<000000P3n`G400`000000oLAR00000002000000<0o/9e
00P00000092ckP000000o<Z=0000003n`gD000000?c9S080000000<0nM>R0000000000000P3oag/0
0`000000o/^80?k;R005000000030?k=R`00000000000080oLR900<000000?k2LP0000000P000000
0`3ma840000000000002000000040?_=UP000000o/R1000000<0olQc00D000000?k2LP3n`W800000
0?o9OP0400000080nkIC00D000000?ZdC`3j]4l0n[A?0000000@0?ooo`030000003oool0oooo02T0
oooo000R0?ooo`@000002`3oool3000002P0oooo00<000000?ooo`3oool06P3oool3000000X0oooo
0`0000001P3oool00000000000000000oooo000000P0oooo00<000000?RhOP0000000P3oool01000
0000oooo0000003oool2000000/0oooo0`0000060?ooo`80000000L0n;Af000000000000lLf]0000
0004C/`000000080oooo00D000000?7:Z03abZP000000??<Y`0300000080]]od0P0000000`3cbJ<0
00000?2B<002000000050?O5V0000000j=K30>SF``0000000`3fbIl200000080mlFF00H000000?G5
V`3eaI/0mLFK0000003fbYh4000000050?K5V0000000m/:E0?K2U@0000000P3e_i<2000000H0n;f9
00H000000?O5U`000000jL:]0000003__j08000000D0nLND100000020?K9WP030000003f`iL0m/>G
0080m/>G00@000000?[3R`3j`h/0n/>;0P0000020>RIL`8000000P3jaHh3000000@0nLND0`000003
0?G=Y@8000000P3iaY85000000070?O<W`000000lm6]0000002=`_T000000<OCh`0400000080mM2W
00@000000?S:VP00000000000`3i`X/2000000030?_3QP0000000000008000000P3jbiH01@000000
nLNC0?W7T`3iai<000000080o<6200<0000000E]g@0000000`3iaY800`000000n/66000000020000
0080n[n40P0000030?ZnQ0D000000P3jd9/010000000nLNE0000003hcId200000080m/JI00<00000
0?^nO`3k_Wl00P0000020?[0QP<000000`3k_gl00`000000n[f3000000030?_1Q@<00000103m`Wh0
1`000000oL5j0?g1NP3m`GX000000?g1O@000000103m_WL00`000000o/1b0?k0LP030?k0LP030000
003l_GH0o;ef00<0o;ef00D000000?k1I`3n`FL0o/5W000000030?k5NP050000003l_GH0o;ef0?bm
MP0000000P3i`X/200000080o;MV100000030?k3N@0;0000003m_gT0000009jYgP000000n/B=0000
003=`m4000000?k1M`0000000P3maX82000000@0o/Eh00@000000?o6K`3oaVl0olI_0`0000040?k0
L0040000003m`f<0oL=S00000080o/5a00<000000?g4HP0000000P0000030?k2M@<0000000D0o<Z=
0000003n`gD000000?c9S002000000030?WCXP00000000000080olMk00H000000?k;R03nbhP0o/^8
0000003kdIT500000080oLR900X000000?k2LP00000000000?g8R0000000oLB10000003mbXT00000
0P3kcIH4000000060?o8L`000000o/9b0?k2LP000000olUn100000020?^fD`050000003j]4l0n[A?
0?ZdC`0000004@3oool00`000000oooo0?ooo`0X0?ooo`008@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00P0oooo0`00000W0?ooo`<000004`3oool01@000000oooo0?ooo`3oool0
000000<0oooo100000000`3oool000000?ooo`060?ooo`<0000000@0oooo000000000000n[Ab1000
00060?ooo`050000003h^7h0n;Qn0000003oool01@0000000`3i]7@00000000000090?ooo`<00000
1P3oool2000000040?RdMP00000000000?7=[@D0000000H0klf_0000003abZP0lLZX0000003cc:L2
00000080]]od0P0000001@3cbJ<000000000003`TS0000000080mlFH00@000000>SF``3Xe/<00000
103fbIl01P000000mlFF000000000000mLFK000000<0m/ZN100000001@3faIP000000?K2U@3f`YD0
00000080mKnC00<000000?RmR@3h_HT01@3h_HT2000000040>W2[@000000kknP0>noX0D0000000<0
l:1Z0000003iai@01@3iai@01`000000k=6i0000003fbIh000000?CG/00000000`3f`iL200000080
n/>;0P000000103XVG<000000000000000040?[5SP030000003iai@0nLND00<0nLND0`0000020?G=
Y@<000000P3iaY83000000050?[3R@000000mlbO0000003cdJd0200000020?G@Y`<00000103i`X/0
0`000000nl>60000000300000080n/^F00<000000?W7T`3iai<00P3iai<01P000000o<620?c1PP00
00001FgM00000080nLJB00<000000?[1QP0000000`0000000`3j_h@00000000000030?ZnQ0<00000
00<0l;nN0000003jd9/00P3jd9/010000000nLNE0000003hcId2000000030?K6V@000000nkio0080
nkio00<000000?[0QP3j`8H00`0000030?^oO`030000003j_H<0000000<0nl650`0000030?g2OP<0
00000P3m`GX00`000000oL5m000000040?fnM`030000003n`780o/1b00<0o/1b00<000000?bmMP3l
_GH00`3l_GH00`000000o/5W0?k1I`020?k1I`040000003naGX0o/Ej000000<0o;ef00<000000?W2
R`3i`X/00P0000020?bgIP<0000000L0oLZ:0000003n`gT0o/=i0000003m_gT000000080WZWN00@0
00000?[4S@00000000000P3n`GL010000000oLJ20000000000040?k5N0040000003oaVl0olI_0?o6
K`<00000103n`70010000000oL=S0?g3H`0000020?k1L@060000003ma68000000000003n`W800000
0P3n`WD200000003092ckP000000000000H0000000@0nM>R0000003oag/0olMk0P0000020?k;R0<0
000000<0l]Fb0000000000000P0000020?g8R@80000000H0o/5^000000000000oLB10000003mbXT2
000000040?_=UP00000000000?k3M0<000000`3n`W82000000030?k:Q000000000000080nkIC00@0
00000?ZdC`3j]4l0n[A?0P00000A0?ooo`030000003oool0oooo02L0oooo000Q0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool200000080oooo00<000000?ooo`3oool0903o
ool3000000h0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`<0000000<0oooo0000003c_YL0
1@0000050?ooo`030000003XaK40000000@0000000@0n[Ab000000000000nKIh0P0000040?ooo`06
0000003c`9L000000?RhOP000000oooo0P000000103[`JT000000000003i]7@2000000030?ooo`00
0000oooo00<0oooo0P000000103oool000000000003GK@02000000@0oooo0`0000000`2Nc?L00000
0000000500000080klf_00<000000?7:Z03abZP01@000000102fgo@000000000003cbJ<3000000<0
mlFH00<000000>SF``3Xe/<00P0000030?K9W`D00000103fbYh6000000050?K2U@000000mKnC0?Fo
T`0000001`3h_HT200000080jL:]00D000000>noX000000000000?:F?P05000000D0nLND0P000000
0`3/dKT00000000000020?CG/0070000003f`iL0m/>G0000003hfZ/000000?[3R`05000000030>kF
^P000000n/F>00<0n/F>00<000000?W7U03iai@00`3iai@010000000h=?;0000000000020<7Yl@80
00000P3iaY83000000040?[3R@000000mlbO00000080lm6]0`000000103^d[H00000000000000002
0?G@Y`030000003i`X`0000000<0nL:;00H000000?_3QP3k`hH000000?[:U00000030?[;UP050000
003iai<0nLNC0?W7T`0000000P3l`H8300000080nLJB00<000000?[1QP0000000`0000000`3j_h@0
0000000000030?ZnQ0030000003m`Gd00000008000000`3jd9/020000000nLNE0?W7U@000000n<fM
0000003faYT000000`3k_Wl010000000n/260?[0QP3j`8H2000000<0nkmo00<000000?ZmP`000000
0`3k`HD400000080oL9n0`0000020?g1NP030000003m`Gd0000000@0oKig00<000000?k0LP3n`780
0`3n`782000000@0o;ef00<000000?k1I`3n`FL00P3n`FL010000000o/Ej0?k5NP0000040?bmMP03
0000003i`X/0nL:;00D0000000<0n/>:0000000000000P3n`gT01`000000oKmi0?foN@000000WZWN
0000003ja8d00P0000020?k1M`050000003maX8000000?o7N@0000000`3naGP01`000000olI_0?o6
K`3oaVl000000?foMP000000103n`70020000000oL=S0?g3H`3m`f<000000?k1L@000000oLAR0P00
00001P3n`W8000000?k2M@3n`WD000000?k3M`T0000000@0nM>R000000000000olMk100000000`3n
a7T000000?_AV@0500000080oLR90P000000103n`Fh000000000003ma84400000080nlfF00<00000
0?k3M03n`g@00P0000030?k2LP80000000<0o/Z40000000000000P3k]U<010000000n[A?0?ZdC`3j
]4l200000140oooo00<000000?ooo`3oool09`3oool00240oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`070?ooo`8000000`3oool00`000000oooo0?ooo`0S0?ooo`80000000<0nkA]
0000003oool0303oool200000080oooo0P0000001@3g]G`00000000000000000n;Im008000000P3c
_YL5000000D0oooo00<000000>S5/@0000001@0000000`3j]780000000000002000000@0oooo00<0
00000??0U`0000000P3h^7h3000000030>_1Z@00000000000080nKAd100000020?ooo`D0000000<0
m<JN0000000000000P0000030?ooo`80000000<0lLNV0000002Nc?L0100000000`13Z?L000000000
00020>o=[`030000003abZP0lLZX00T0000000<0i<g00000003gaIP00`3gaIP2000000080>SF``00
000000000?K9W`000000mLVQ0000003fb9`2000000D0m/ZN00<000000?;7Y00000001@0000000`3e
_i<000000?RmR@060?RmR@<0000000D0jL:]0000003__j0000000?W?WP03000000<0n<BC00D00000
0?W7U03iai@0nLND000000020?[6T@030000003/dKT000000080m=N`00<000000?K3U`0000000`3h
fZ/00`000000n/>;00000004000000030>kF^P000000n/F>00<0n/F>00<000000?W7U03iai@00P3i
ai@2000000030>3Cb`000000`NWa0080`NWa0P0000020?W6TP<0000000@0n/>90000003gc9l00000
0P3cdJd3000000030>kB]P00000000000080000000<0mjA>000000000000103i`X/01P000000nl>6
0?_3QP000000n/ZD000000<0n/^F00H000000?W7T`3iai<0nLNC0000003l`H820000000300E]g@00
0000nLJB00H0000000<0n[n40000000000000`3j_X@00`000000oL5m00000003000000<0n]2K00<0
00000?W7U@0000000P3hcId2000000<0nkio00@000000?[0QP3j`8H0n/260P0000030?^oO`030000
003j_H<0000000<0nl65100000020?g2OP030000003l_gh000000080oL5j00@000000?g1O@3m`Gd0
00000`3m_WL00`000000o/1b0?k0LP030?k0LP800000103l_GH00`000000o/5W0?k1I`030?k1I`03
0000003naGX0000000@0o;ef00@000000?W2R`3i`X/000000P3n`7D010000000kKVK0000003j`hX2
000000070?k3N@000000oKmi0?foN@000000WZWN000000020?[4S@80000000@0o/5g000000000000
00000P3oagT010000000o/Eh0?k5N00000030?o6K`030000003m_gH0000000@0o/1`00<000000?g3
H`3m`f<00P0000001@3n`G4000000000003n`W8000000080o/9b00`000000?k2M@000000o/=g0000
002@/nh000000?k<R@000000o/9c0000003]g<03000000040?WCXP00000000000?3E]P8000000P3n
a7T2000000040=7?e`0000000000000000<0oLR900<000000?k1KP3n`Fh0100000001@3mbXT00000
0000003kcIH0000000<0o/=d00<000000?k2LP3n`W800P3n`W800`000000o/Z40?k:Q00200000003
0?^fD`000000n[A?0080n[A?00<000000?^gEP0000004@3oool00`000000oooo0?ooo`0V0?ooo`00
8@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`800000
8`3oool2000000030?^dK@000000oooo00P0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`80
000000D0mkEl00000000000000000?RfO@0200000080lkjG0P0000000`3b`9/000000?ZcK@040000
00070?ooo`000000j<Fa00000034b=h000000??0V@02000000060?ZdLP00000000000000003i]gX0
00000`3oool00`000000ll2G000000020?RhOP<0000000P0jl6Y000000000000nKAd0000003X`Zh0
00000:S8l0P000000P3daYh01@000000g][C000000000000oooo0080000000D0m/:D0000003aajH0
000009k<m`0700000080klf_00<000000?7:Z03abZP00P0000000`3b`il000000>g</P05000000H0
mlFH00<000000>SF``0000000P0000020?G9X@030000003fb9`00000008000000`3fbYh01@000000
l/NT0?;7Y0000000m/FH00<0000000<0mKnC0000003h_HT01P3h_HT010000000nKj70000003Y`Zd2
000000<0nLnN0P0000040?S4T`80000000<0nLND0000003jaY400P3jaY44000000030?CG/0000000
000000@0n=Z[0`0000000`3lc94000000000000300000080n/F>00<000000?W=W00000000`3iai@0
10000000n/:;0000003fdJH200000080`NWa0P0000000`3iaY80000000000002000000030?[3R@00
0000000000<0lm6]0`000000203bdJl00000000000000000mjA>0000003i`X`00000103i`X/01P00
0000nl>60?_3QP000000n/ZD000000<0n/^F00<000000?W7T`3iai<00`0000000`3l`H40000000E]
g@07000000040?ZoQ0000000ol]m00000080n[j400<000000?g1O@3m`Gd00P0000001@3Yk/h00000
0?[@V`3jd9/000000080nLNE00<000000?S=W@0000000P0000030?^nO`040000003j`8H0n/260?[0
QP8000000P3k_gl010000000n[f30?ZmP`0000020?_1Q@D0000000<0oL9n0000003l_gh00P000000
1@3m`GX000000?g1O@3m`Gd0000000<0oKig00<000000?k0LP3n`7800`3n`782000000@0o;ef00<0
00000?k1I`3n`FL00`3n`FL3000000@0o;ef00@000000?W2R`3i`X/000000`3n`7D2000000050?[3
RP00000000000?k3N@0000000P3m_gT20000000309jYgP000000n/B=0080000000@0o/5g00000000
000000000`3oagT010000000o/Eh0000003oaVl2000000030?k2M`000000000000@0o/1`00<00000
0?g3H`3m`f<01`0000020?k2LP030000003n`WD000000080o/=g0P0000001@3nc8T000000?k2L`00
0000kMc000<0000000@0nM>R000000000000l=Ff0P0000020?k4N@030000003kdIT0000000@00000
0P3mb8T00`000000o/5^0?k1KP03000000060?BL?`00000000000000003kcIH000000`3n`g@20000
00<0o/9b00<000000?k:Q03nbX@00P0000020?^fD`040000003j]4l0n[A?0?ZdC`8000004P3oool0
0`000000oooo0?ooo`0U0?ooo`008@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`8000001`3oool01@00
0000nkA]0?^dK@3k]6d0000000<0oooo0P0000030?ooo`8000000P3oool010000000n;Mn0000003o
ool200000080mkEl0P0000000`3h]Wd00000000000020?>nU`80000000<0l/2K0000003j/fd01000
00001P3oool000000>S5/@000000a<SN00000080ll2I0P0000000`3c`9L000000>o2X`02000000<0
oooo00<000000??0U`0000000P3h^7h010000000llBM0000003[`JT2000000040?VdM0000000j<:^
00000080Z<S`1@0000000`3ca9h00000000000020?C6WPH000000P3f`Y@010000000lLNV00000000
00020>c;/P030000003[ckT00000008000000P3_cJl00`000000lLZX00000005000000040?7=[@00
00000000000000H0mlFH0P0000000`3Xe/<00000000000030?G9X@050000003fb9`000000>;Cb@00
00000`3fbYh00`000000l/NT0?;7Y003000000030?O1S`000000000000L0n;f900H000000?VnQ`3i
_XL000000>W2[@0000040?W?WP8000000`3ha9<010000000n/B<0000000000050?[6T@D000001@3h
fZ/200000080o<bA0`0000001P2McoT000000?[5SP000000nLfL00000080nLND00@000000?[2R`3j
`X/0n/:;0P000000103fdJH0000000000031jO43000000040?W=W000000000000?[3R@<000000P3c
dJd4000000050?;A[`00000000000000003gY4h00P0000040?W2R`8000000P3k`hH00`000000n/ZD
000000020?[;UP030000003iai<000000080n/F>00<000000?c1P@3l`H400`0000000`3kahh00000
00000004000000050?o;O@000000n[j40?ZnQ00000000`3m`Gd010000000jNk>0>W^cP0000020?[@
V`030000003iaiD0nLNE00@000000`3k_Wl010000000n/260?[0QP3j`8H2000000<0nkmo00D00000
0?ZmP`000000nl65000000020?ZoQ0<0000000L0oL9n0000003l_gh0o;mn0000003m`GX000000080
oL5m00D000000?fnM`3m_WL0oKig000000050?k0LP800000103l_GH00`000000o/5W0?k1I`030?k1
I`<00000103l_GH010000000nL:;0?W2R`0000030?k0M@<0000000@0n/>:00000000000000000`3m
_gT00`000000WZWN000000020?[4S@050000003n`GL000000?k1L@000000103oagT4000000050?o6
L`00000000000?foMP0000000`3n`7001@000000oL=S0?g3H`000000l]Nd00D000000`3n`W820000
0080o/=g00P000000?_9T0000000o/b90000003n`W<000000>gL`08000000P3idj8010000000l=Ff
0?3E]P0000030?k4N@80000000@0dLoG00000000000000000P3mb8T2000000050?k1KP0000000000
0000003dW3l00P000000103F_<0000000>bC800000030?k3M0040000003n`W80o/9b0?k2LP800000
0P3nbX@2000000030?^fD`000000n[A?0080n[A?00<000000?^gEP0000004@3oool00`000000oooo
0?ooo`0U0?ooo`008@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01@3oool2000001L0oooo0P0000060?ooo`8000000`3k]6d010000000oooo0?oo
o`3oool3000000040?ooo`000000000000000080oooo00<000000?RgOP3h]gh00P0000000`3b`9`0
00000?NeO003000000040>O;^P000000lkjG0?>nU`80000000D0l/2K0000003j/fd000000>o1XP06
000000040<C8gP000000ll2I0??0V@80000000L0ll2G0000003_`Z<000000?VgNP000000oooo0080
000000H0ll2G000000000000n;Qn0000003ca9d6000000030>S2[P000000Z<S`0080Z<S`10000002
0??4WP8000000P3daYh4000000@0m/:D00@000000?77YP3aajH000000P3/bk800`000000jlni0000
000200000080klf_0P0000002@3dbJ8000000000003ce:l000000?7=[@000000nKQm000000070?O5
V080000000<0imK40000000000000`3ebJ43000000040>;Cb@000000m/ZN0?K:WP80000000@0l/NT
000000000000mLRO0`0000070?RmR@050000003i_XL0nKj70000003Y`Zd00P0000040?W?WP050000
003ha9<0n<BC0?S4T`0000000P3ja8`00`000000n/JA0?[6T@050?[6T@@000001@3hfZ/700000003
09g?n@00000000000080nLfL00<000000?W7U00000001@3j`X/00`000000m]6V0?KAYP0400000080
nLfL0`0000001@3k`hP00000000000000000m/NJ00@0000000<0l]6_0000000000000P0000000`3i
`X`000000?W2R`020?W2R`8000000P3k`hH2000000030?[:U0000000n/^F00<000000`3jaHh00`00
0000o<610?c1P@02000000030?_7SP000000nlN>00@0000000@0ol]m0000003j_X@00000103m`Gd0
1`000000jNk>0>W^cP3Yk/h000000?[@V`0000000P3iaiD4000000<0nkio00<000000?[0QP3j`8H0
0P3j`8H02@000000nkmo0?^oO`3k_gl000000?ZmP`000000nl65000000020?ZoQ0D000000`3l_gh2
00000080oL5m00D000000?fnM`3m_WL0oKig000000050?k0LP800000103l_GH00`000000o/5W0?k1
I`030?k1I`<000001@3l_GH00`000000nL:;000000030?k0M@040000003]^I/000000?[3RP<00000
0`3m_gT300000080n/B=0`0000020?k1L@040000003oagT0olMi0?o7N@L0000000<0oKmf0000003n
`7000P3n`70010000000oL=S0000003naGT6000000<0o/9b0P0000030?k3M`80000000D0o/b90000
003n`W<000000>gL`003000000040?WCXP000000l=Ff0?3E]P8000000`3na7T7000000040?SDY@00
0000o/5^0?k1KP8000000P3dW3l3000000030>bC80000000o/=d0080o/=d00@000000?k2LP3n`W80
o/9b0P0000020?k:Q080000000<0nkIC0000003j]4l00P3j]4l00`000000nkMF0000000B0?ooo`03
0000003oool0oooo02@0oooo000Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1`3oool3000000P0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3oool300000080
oooo00<000000?ooo`3oool00P0000040?^dK@030000003oool0oooo0080000000D0mkEo00000000
000000000?RfN`0300000080n;Mn00<000000?;0W03b`9`00P0000001@3``J0000000000003WbkX0
00000080lkjG00L000000:X^0000000000000?ZcK@000000kl6R00@0000000@0l<FT000000000000
00000P3c`9T2000000030??0U`000000kl:S00@0000000<0kL:V0000000000000P0000001P3h^7h0
00000??4W@3ca9d000000>_1Z@<000000P3X`Zh00`000000Z<S`0:S8l002000000030=_;b0000000
00000080llBN1@0000000`32]Lh000000?K2U0030?K2U0050000003aajH0lLNV0?77YP0000000P3/
bk800`000000jlni0>_?^@0200000080klf_00@000000?C9XP3dbJ8000000P3ce:l2000000030?Vh
O@000000000000H0mlFH0`0000000`3We/@00000000000040?G9X@80000000<0h]?9000000000000
0`0000001@3`aZD00000000000000000ml6?008000001P3h_HT01@000000nKj70?VnQ`3i_XL00000
0080n;n=10000000103icih000000?S4T`0000040?[4S0800000103jaY400`000000eElI00000005
000000030?SJZ`000000nL:<00@0nL:<0`0000000`2McoT000000?W=W0020?W=W08000001P3j`X/0
0`000000m]6V0?KAYP02000000040?S2T@00000000000?W=W08000000P3k`hP200000080m/NJ1000
00000`3bdJl000000=7HgP03000000<0nL:;00H000000?[6T0000000nl>60000003kaHP400000003
0?OJ[P000000n/F>00<0n/F>00<000000?c1P@3l`H400P0000030?_7SP<0000000@0ol]m0000003j
_X@000001@3m`Gd200000080jNk>0`0000020?W7U@030000003obX40000000<0nkio0P0000030?[0
QP050000003k_gl0nkmo0?^oO`0000000P3j_H<200000080n[n41@0000030?boOP8000000P3m`Gd0
1@000000oKig0?fnM`3m_WL0000000D0o/1b0P0000050?bmMP030000003n`FL0o/5W0080o/5W0`00
00050?bmMP800000103n`7D010000000kKVK0000003j`hX3000000<0oKmi0P0000000`2NZMh00000
0?[4S@03000000<0o/5a0P000000103oagT000000000000000030?o;N`040000003m_gH0oKmf0000
0080o/1`00P000000?g3H`000000o/Ei0000003bek@000000?7N_0<000000`3n`W8030000000o/=g
0?k3M`3n`gL000000?_9T0000000o/b90000003n`W<000000>gL`0<0000000<0o<bB0000003`eKH0
0P0000030?k4N@80000000<0dLoG0000000000000P000000103he:D000000?k1KP3n`Fh600000003
0?k4NP000000000000<0o/=d0P0000020?k2LP030000003n`6h000000080o/Z40`0000030?ZdC`04
0000003k]eH0nkMF00000180oooo00<000000?ooo`3oool08`3oool00240oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo0P0000040?ooo`03
0000003oool0oooo00T0oooo0P0000020?ooo`<0000000<0oooo000000000000100000040?^dK@03
0000003oool0oooo0080000000D0mkEo00000000000000000?RfN`0300000080n;Mn00<000000?;0
W03b`9`00P0000000`3``J000000000000020>O;^P050000003c_YL000000000002Z;P000P000000
1P32bMl00000000000000000gkbd00000080l<FT0P0000020??0V@8000000P3c`9L5000000030>g2
YP000000l;jL00<0000000<0k/BW0000003ca9d00P0000001@3[`JT000000=?6cP000000j<:^0080
00000P2Xb?03000000040>K<_@000000llBN0??4WPH000001@3f`Y@010000000lLNV0?77YP3aajH2
000000040?;<Z@00000000000>SF`P<0000000@0J0000000003dbJ80m<VR0P0000001P3ce:l00000
0?VhO@000000ljah000000D0mlFH00D000000;Chk@00000000000>OFa003000000<0mLVQ0P000000
1@3RdlT000000000003f`YD000000080l<JU1@0000060?RmR@050000003i_XL0nKj70?VnQ`000000
1P3h_hd4000000H0n/B<0P0000020?[6T@050000003EGaT0eElI0000003haY<01@0000060?W2S0H0
00000P3icI`00`000000n/:;0?[2R`040?[2R`H000000P3h`Y401@000000nLfL000000000000nl>8
00<000000P3faiX00`000000nl65000000020?;A[`070000003Af=h000000?W2S0000000nL:;0000
00030?[6T08000000P3kaHP00`000000n/RC000000020?OJ[P030000003jaHh0n/F>0080n/F>00D0
00000?c1P@000000m/JJ000000020?_7SPD0000000<0n[j40000003m`Gd01@3m`Gd3000000030>W^
cP00000000000080nLNE00<000000?o:P@0000000`3k_Wl2000000<0n/260P0000020?^oO`030000
003j_H<0n[f3008000000P3j_h@5000000@0o;mn00D000000?g1O@3m`Gd0oL5m000000020?fnM`03
0000003n`780o/1b00<0o/1b0P0000050?bmMP030000003n`FL0o/5W0080o/5W00<000000?fmM@00
00001@3l_GH2000000@0o/1e00<000000>fiV`000000100000040?foN@<0000000@0n/B=00000000
00000000103n`G45000000<0ol]k0P000000203m_gH000000?k0L03n`70000000?g3H`000000o/Ei
1P0000001@3hgZd000000?k2LP3n`W80000000@0o/=g00@000000?_9T000000000000P3n`W<20000
00040>o?/P000000o<bB00000080l=Ff0P0000020?k4N@D0000000L0bkc<0000003he:D0n=BU0000
003n`Fh0000000<0o/5a0P0000020?k4NP8000000P3n`g@200000080o/9b00<000000?k0KP000000
0P3nbX@3000000<0n[A?00<000000?^gEP3k]eH00P00000=0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool08P3oool00280oooo1000000:0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000T0oooo00T000000?ooo`0000000000
0?ooo`000000kL:W0000003aVS00200000020?^dK@@0000000@0l/6K0000003g]Gl0mkEo1P000002
0?RgOP030000003b`9`0l/2L0080000000<0l<6P0000000000000P3WbkX00`000000lkjG0?>nU`04
00000080`/WO100000030?35Y080000000<0ll2I0000000000000P3c`9L010000000kl:S0000003b
_iX2000000030>g2YP000000000000<0000000D0k/BW0000003ca9d000000>_1Z@0300000080j<:^
0P0000000`2Xb?0000000>g3Z@02000000040>K<_@000000llBN0??4WPD000001P3f`Y@00`000000
lLNV0?77YP0200000080l/bY00<000000>SF`P3Xe/800`000000101X000000000?C9XP3dbJ840000
00<0ljah0P0000020?O5V0040000002dn>d0]?S]0;Chk@<0000000H0imK4000000000000mLVQ0000
003e`ID2000000050?;2V`00000000000?K2U@0000000P3`aZD2000000030?O1S`000000n;f900D0
n;f900D000000?VnQ`3i_XL0nKj7000000070?RoS@<000001P3ja8`00`000000nlN?000000020000
00<0eElI00@000000?S6T`000000m<nX0`0000050?W2S0030000002amO40000000@000000P3icI`0
0`000000n/:;0?[2R`030?[2R`060000003j`HT0n/690000003Gblh000000`3h`Y44000000030?_3
R0000000000000<0m/NJ00<000000?_1Q@0000000P3bdJl01P000000mLNL000000000000nL:;0000
00<0n/J@0P0000030?_5R0030000003jb9<00000008000001@3jaHh01@000000o<610000003faYX0
00000080nlN>1P0000060?g1O@030000003od7H0000000D000000P3obX4010000000nkio0?^nO`3k
_Wl2000000<0n/260P0000020?^oO`030000003j_H<0n[f3008000000`3j_h@2000000030?VkQ000
0000o;mn00<0o;mn00D000000?g1O@3m`Gd0oL5m000000020?fnM`030000003n`780o/1b00<0o/1b
0P0000050?bmMP030000003n`FL0o/5W0080o/5W00<000000?fmM@0000001P3l_GH00`000000o/1e
0?k0M@030?k0M@H00000103m_gT400000080l^jo00<000000?k1L@3n`G400P3n`G400`000000o/=[
00000002000000@0ol]k01<000000?foMP00000000000?k0L0000000oL=S0000003naGT000000?g8
Q@000000l]Nd0000003mb8T000000?SN[@000000o/9b008000000`3n`gL010000000nlV@0?_9T000
00020?k2L`@000000P3lc98010000000l=Ff0000000000020?k4N@040000003oaG@000000=7?e`<0
00000P3he:D00`000000o/5^000000030?k1L@<0000000<0o/Aj0000000000000P3n`g@200000080
o/9b00D000000?k0KP3n`6h000000?k:Q003000000<0n[A?00D000000?^gEP3k]eH000000?^eE@02
00000080oooo00<000000?ooo`3oool01@3oool3000000<0oooo00<000000?ooo`3oool08P3oool0
0300oooo00<000000?ooo`3oool01P3oool2000000@0oooo00<000000?ooo`0000000P0000000`3o
ool000000?ooo`020?ooo`80000000D0oooo00000000000000000>Fk[002000000050>g2Y`000000
lIX`0000002g_]l00P0000000`3X`k00000000000003000000090>k1X`00000000000000003b`I/0
00000?NeO`000000lKnL0080000000@0j<>`000000000000n;Mn0P0000030?;0W080000000<0l<6P
0000003WbkX00P3WbkX00`000000lkjG0?>nU`04000000030<;9g`0000000000008000000`3`aJ@2
000000030??0V@000000000000<0ll2G1@0000000`3]`ZH000000?2nW002000000030>g0Y@000000
k/BW00<0000000@0jl6Y0000003Ca/h000000P3X`Zh2000000030:S8l0000000kL>Y00<000000`3c
a9h4000000L0m/:D0P0000020>oB]080000000@0l/bY000000000000j=K21P0000001@3dbJ800000
000000000000ljah008000000P3i`Xd00`000000mlFH000000050;Chk@80000000@0imK400000000
000000000P3e`ID2000000040?;2V`000000m/:E00000080l<JU100000060?RmR@030000003i_XL0
nKj70080nKj700<000000?RoS@3h_hd0103h_hd00`000000n/:9000000060?[4S0040000003kahl0
nlN?0?_7S`@0000000@0eElI0000003haY<000000P3dcjP2000000@0nL:<00<000000;7el@2amO40
1@0000000`3icI`000000?[2R`030?[2R`030000003j`HT0n/690080n/690`0000040?S2T@H00000
0P3faiX5000000040?:G>`00000000000?W2S0800000103jaY02000000<0nlF800<000000?[8T`3j
b9<00P0000040?[5SP<000000P3faYX00`000000nlN>00000002000000030?W3S@000000000000D0
oL5m00<000000?o@MP3od7H00`000000103l`X0000000000003obX4300000080nkio0P0000030?[0
QP8000000P3k_gl01@000000n[f30?ZmP`3j_H<0000000<0n[n40P0000000`3i^h@000000?boOP03
0?boOP050000003m`Gd0oL5m0?g1O@0000000P3m_WL00`000000o/1b0?k0LP030?k0LP8000001@3l
_GH00`000000o/5W0?k1I`020?k1I`040000003m_GD00000000000D0o;ef00<000000?k0M@3n`7D0
0`3n`7D00`000000kKVK00000002000000030=Vf]@000000oKmi0080oKmi00@000000?k0LP000000
00000P3bk[l2000000<0o/5a00D000000?k3J`000000om1k000000040?o;N`050000003m_gH00000
0000003n`7000P0000020?k5N@030000003mb8D0000000<0000000<0oLR90000000000000`000003
0?k3M`030000003kbI00nlV@0080000000T0o/9c00000000000000000=WAd@000000o<bB0000003`
eKH00`0000000`3na7T000000?o5M0040000000505:Hl@000000n=BU0000003n`Fh00P0000020?k1
L@030000003obG<000000080o/Aj00<000000?k3M00000000P3oaGD00`000000o/9b000000020?k0
KP060000003nbX@000000000003n`Vd000000P3j]4l010000000nkMF0?^gEP0000030?^eE@<00000
1P3oool010000000o;QL0000003l^5T200000080oooo00<000000?ooo`3oool08@3oool00300oooo
00<000000?ooo`3oool01P3oool200000080oooo00<000000?ooo`3oool010000000103oool00000
0000003oool6000000080>fnX`00000000000000003]`ZL000000?6J<00000020;Nng`050000003X
`k0000000000002H_?400P0000001@3^`J<000000?JdO`000000l/6K00<000000P3a_i`200000003
0>S3/0000000n;Mn00<000000P3b`9`01@000000k<2U0000003``J00000000<0il^j00<000000?>n
U`3c_YL0100000001032bMl000000>ZnYP0000040?35Y080000000<0ll2I0000000000000`3c`9L3
000000030?2mV`000000kL:V00D000000P3^a:L200000080jl6Y0P0000020>S2[P040000003_`Z@0
00000:S8l080000000<0fl_80000000000000P3ca9h4000000L0m/:D0P0000030>oB]08000000P3b
c:T00`000000j=K20>SF`P05000000040?C9XP0000000000000000D0nL:=0P0000060;Chk@800000
00<0imK40000000000000P3e`ID200000080l/:K00<000000?K2U@0000000P3`aZD2000000030?O1
S`000000n;f900@0n;f900<000000?VnQ`3i_XL00P3i_XL00`000000n;n=0?RoS@040?RoS@030000
003j`XT0n/:900800000103ja8`00`000000nlN?0?_7S`040?_7S`@0000000@0n<JC0000003dcjP0
m<nX0P0000030?W2S0030000002amO40/OGa00P000000`3j`X/00`000000n/690?[1R@020?[1R@03
0000003Gblh0000000@0n<:A0`000000103Pe/d000000000000000020?K7VP80000000D0nl:40000
003bUc/000000?G7W003000000@0n/J@00<000000?[1Q`0000000`3kaHP01@000000n/RC0?[8T`3j
b9<0000000<0n/F>100000020?K6VP@0000000<0nL>=0000000000001@3m`Gd010000000om1f0?o@
MP3od7H200000080o<:01@0000020?^nO`030000003ob6l000000080n/260P0000030?^oO`040000
003j_H<0n[f3000000<0n[n40P0000000`3i^h@00000000000040?boOP040000003m`Gd0oL5m0000
0080oKig00<000000?k0LP3n`7800`3n`782000000D0o;ef00<000000?k1I`3n`FL00P3n`FL01000
0000oKee0000000000050?bmMP030000003n`7D0o/1e00<0o/1e00D000000>fiV`00000000000?^n
OP02000000<0oKmi100000030?;^_`8000000P3n`G4010000000o/=[0000003od7/300000080ol]k
00<000000?foMP000000100000020?k5N@060000003mb8D0oLR50000002@__D000000`3mb8T20000
00040?k2M0000000o/=g0?k3M`8000000P3kbI0010000000o/9c0000003n`70300000080o<bB00H0
00000?3E]P00000000000?k4N@0000020?o5M0030000003AcmL00000008000000P3he:D300000080
o/5a00<000000?o9L`0000000`3na7X200000080olEe00<000000?k2LP0000000`3n`6h200000003
0?cDV000000000000080n[A?00@000000?^gEP3k]eH000000`3k]ED4000000<0oooo0P0000020?bh
G0050000003l^5T0o;QI0?bhF@0000000P3oool00`000000oooo0?ooo`0P0?ooo`00<03oool00`00
0000oooo0?ooo`060?ooo`040000003hYdl000000?ooo`80000000D0oooo0000003U_Zl000000?Z^
G`06000000050>o2Y0000000gLG20000003]_Z<00`000000103]`ZL000000000000000020;Nng`80
000000@0j<>`000000000000V;ca1@000000103b`I/000000000000000020?6oW080000000@0j<>`
000000000000k<F]0`0000020?;0W0030000003/`:D00000008000000P3WbkX030000000lkjG0?>n
U`000000f/_;0000003W`k4000000<;9g`000000j[jV000000@0l<FT0`000000103``J4000000??0
U`3c`9L300000080l;fK0P0000001@3`_Y`000000000003]`:D000000080k/BW0P0000020>_1Z@80
00000P3X`Zh00`000000kl:T00000003000000050=_;b000000000000??4WP0000000P3dcZP20000
00H0m/:D00@000000?W9U`00000000000`3_d[@010000000l/bY0?;<Z@0000020>SF`PL000001`3i
`Xd4000000@0]?S]0P0000000`3b`I`00000000000020?G1U@80000000D0l/:K0000003f`YD0m/:E
000000020?36Y@<000001@3h_HT00`000000nKj70?VnQ`030?VnQ`030000003h_hd0n;n=00<0n;n=
00@000000?[2R@3j`XT0n/:90`0000020?[4S0030000003kahl0nlN?00@0nlN?00<000000?S8V@00
00001@0000000`21000000000?W2S0020?W2S0040000002amO40/OGa0;7el@D0000000<0n/B=0000
000000000P3j`X/00`000000n/690?[1R@030?[1R@<000000`3h`Y44000000030>3Fc@0000000000
00<0m/NJ0P0000000`3k`X@000000?:G>`04000000D0n/J@10000000103kaHP000000000003jb9<2
000000<0n/F>00<000000?[7T00000000P0000020?K6VP040000003kcYD000000?W3S@8000001@3m
`Gd020000000om1f0?o@MP3od7H000000?_5R@000000o<:00P0000000`3Xel@00000000000020?^n
O`030000003ob6l000000080n/2600<000000>jRM00000000P3k_gl010000000n[f30?ZmP`000004
0?ZoQ0040000003i^h@00000000000@0o;mn00@000000?g1O@3m`Gd000000P3m_WL00`000000o/1b
0?k0LP030?k0LP8000001@3l_GH00`000000o/5W0?k1I`020?k1I`040000003m_GD00000000000D0
o;ef0P0000040?k0M@050000003]^I/000000000003k_Wh00P0000030?foN@80000000<0o/1b0000
003bk[l00`3bk[l00`000000o/5a0?k1L@06000000050?o@QP00000000000000003m_gH01@000002
0?k5N@030000003mb8D0oLR500@000000`3mb8T300000080o/=g0P0000020?_9T0<0000000P0o/1`
000000000000fM7A0000003lc98000000?3E]P@000000P3oaG@2000000050;KDl0000000DYSa0000
003he:D00`0000020?k1L@040000003obG<0olUc00000080o/Aj0P0000020?o5M@030000003n`W80
000000<0o/1^0P0000001P3le9P000000?k2K@000000n[A?000000<0nkMF00D000000?^eE@3k]ED0
00000?^dE002000000030?ooo`0000000000008000000P3l^5`01@000000o;QI0?bhF@3l^5T00000
00<0oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool01P3oool300000003
0?ooo`000000m[B10080000000D0iKj_0000003j[Ul000000>_0Y`04000000040>o2Y0000000gLG2
0=g5`P<0000000H0YL3/0000003]`ZL000000=5M000000020;Nng`D0000000<0V;ca0000003^`J<0
0P0000000`3b`I/000000?V`J`0200000080lKnL0P000000103X`k0000000000003/aJd300000080
l/2L00<000000>c0Y@0000000P0000020>O;^P050000003c_YL0lkjG0000003Jbl/00P0000001@32
bMl000000>ZnYP3Z_ZH0000000@0l<FT00D000000??0V@000000l<6Q000000020??0U`<0000000@0
l;fK000000000000l;jL0`000000103]`:D000000>k4Y`3^a:L2000000030>_1Z@00000000000080
j<:^0P0000000`3_`Z@0000000000002000000040>_D_@0000000000000000<0m<jX0P0000050?K2
U0050000003ibIL0nLVG0?W9U`0000000`3_d[@5000000050>SF`P00000000000000002adO400P00
00070?W2S@040000003h_h`0n;n<0?RoS0@0000000<0m<:H0000000000000P0000030?G1U@060000
003b`Y/0l/:K0000003f`YD000000`3`aZD2000000D0n;f900<000000?VnQ`3i_XL00`3i_XL00`00
0000n;n=0?RoS@030?RoS@030000003j`XT0n/:900<0n/:9100000060?_7S`030000003hb9T0n<RI
00<0000000D0nLFA000000210000P@00000000020?W2S0030000002amO40/OGa0080/OGa1@000000
1@3ja8d000000000003j`X/0000000H0n/690P0000030?S2T@030000003i`Xd0000000D000000P3f
aiX3000000040?_2Q000000000000?G7W08000001@3jaY0200000080nl:40P0000001`3ka8P00000
0000003hcj8000000?[5SP0000000`3jai0200000080m/JJ100000000`3i`hd000000?g1O@040?g1
O@030000003od7H0om1f008000000P3kaHT2000000040?c2P0000000g]O@00000080nkio00H00000
0?o8K`000000n/260000003^XW@200000080nkmo00@000000?ZmP`3j_H<00000103j_h@010000000
nK^40000000000040?boOP070000003m`Gd0oL5m0?g1O@000000oKig000000050?k0LP030000003m
_G@0000000@0o;ef00<000000?k1I`3n`FL00P3n`FL010000000oKee0000000000050?bmMP800000
103n`7D01@000000kKVK000000000000nkin008000000`3m_gT00`000000o/=f0000000300000080
l^jo0P000000103n`G4000000000000000050?o@QPD0000000H0o/9d0000003n`W@000000?k5N@00
00020?g8Q@80000000<0T;ke0000003mb8T00P3mb8T2000000070?k2M0000000o/=g0000003na7P0
00000?_9T003000000030?k0L00000000000008000000P3lc9800`000000l=Vi00000002000000<0
olEd1@0000001`3he:D000000000003n`Vl000000?k1L@0000000P3obG<00`000000o/Aj0?k4NP02
000000<0olEe0P0000040?k0KP030000003le9P0o=BH008000000P3j]4l010000000nkMF0?^gEP00
00020?^eE@040000003k]5@0nkAD0?^dE08000000P3l]eX010000000o;QL0?bhG00000030?bhF@80
00000P3oool00`000000oooo0?ooo`0O0?ooo`00<03oool00`000000oooo000000060?ooo`800000
00/0n:M?00000000000000000?JdP@000000iKj_0000003j[Ul000000>_0Y`03000000<0kl:T00@0
00000=g5`P000000kKjS0P0000000`2U`>`000000>g2Y`03000000040;Nng`00000000000>S3/0<0
000000<0V;ca00000000000010000000200jV?8000000000003a_i`000000>RoZ`000000j<>`0P00
00000`3/aJd00000000000020?;0W0040000003/`:D000000?31X0<0000000<0il^j0000003c_YL0
0P0000001P3Jbl/0000000000032bMl000000>ZnYP800000103`aJ@01@000000ll2I0000003``J40
00000080ll2G0P0000020?2mV`80000000<0l;jL0000000000000P3]`:D010000000k/BW00000000
00020>_1Z@8000000P3X`Zh4000000060?7:Z000000000000000003[e;d00000103dcZP2000000<0
m/:D00<000000?W9U`3ibIL00`3ibIL010000000km:d0>oB]03_d[@200000080llBN00<000000?NY
H`000000100000060?W2S@030000003h_h`0n;n<00D0n;n<0P0000000`3d`YP000000?;1W0020000
0080mL6E0P0000020?;2V`030000003f`YD000000080l<JU0P0000050?RmR@030000003i_XL0nKj7
00@0nKj700<000000?RoS@3h_hd00P3h_hd00`000000n/:90?[2R@030?[2R@L000000`3kahl01000
0000n<RI0?S8V@3hb9T3000000070?W5T@0000000000084000000000nL:<000000040;7el@040000
003h`H`000000=;Lh080000000@0n/B=0000003j`X/000001P3j`HT3000000030?S2T@000000nL:=
0080nL:=1`0000000`3`d;4000000?O6V004000000030?G7W0000000000000D0n/J@00D000000?_2
Q03k`X@0nl:4000000020?_4R0030000003hcj80n<nR00800000103jai0300000080nl:70P000000
0`3i`hd000000?g1O@040?g1O@060000003od7H0om1f0000003lb8d000000P3kaHT00`000000o<:0
0?c2P00200000080nkio00<000000?o8K`3ob6l00P0000000`3^XW@00000000000020?^oO`030000
003j_H<0n[f3008000000`3j_h@2000000030?VkQ0000000o;mn00@0o;mn00H000000?g1O@3m`Gd0
00000?fnM`0000050?k0LP030000003m_G@0000000@0o;ef00<000000?k1I`3n`FL00P3n`FL01000
0000oKee0000000000050?bmMP800000103n`7D2000000030?>[>0000000nkin008000000`3m_gT0
1P000000o/=f0000003n`78000000?_JY080000000<0l^jo0000000000001@0000020?o@QP030000
003lci80o<nB00<0000000<0o/9d0000003n`W@00`0000030?g8Q@@000000P3mb8T4000000030?k3
M`000000o/Ah008000000P3nbH802P000000o/1`0000003n`70000000=WAd@000000o<bB0000003`
fKT3000000@0olEd1@0000001P3he:D000000?k2K`000000o/5a00000080olUc00D000000?k4NP3n
a7X0o/Aj000000030?o5M@800000103n`6h2000000060?cDV0000000o/9]0000003j]4l000000P3k
]eH010000000nkEE0?^eE@0000030?^dE0050000003l]eX0o;MJ0?bgFP0000000`3l^5`00`000000
o;QI0?bhF@02000000<0oooo00<000000?ooo`3oool07P3oool00300oooo0P0000020?ooo`0:0000
003oool0oooo0?ooo`000000kl6S0000003hYdl000000>boY@80000000<0001c0000003U_Zl00P00
0000103[`:L000000000000000040>o2Y0040000003MaL8000000>fnX`80000000<0YL3/00000000
00000P0000020;Nng`@0000000<0l;jL0000000000001@00000203ZHlP80000000<0lKnL00000000
00000P3X`k02000000030>c5[@00000000000080l/2L00@000000>c0Y@00000000000P3/`JP40000
00030?C2V0000000f/_;00<000000P3Z_ZH2000000<0l<FT0`0000020?31X@030000003c`9L0ll2G
0080000000@0l;fK000000000000l;jL0`000000103]`:D000000>k4Y`3^a:L2000000050>_1Z@00
000000000000003X`Zh00`000000103CFQ@000000?7:Z03abZP2000000030>_D_@00000000000080
m<jX00<000000<:ecP0000000P3f`Y@00`000000nLVG0?W9U`040?W9U`<0000000<0ll>L00000000
00000P3ca9h2000000040>o3Y00000000000000000H0nL:=00<000000?RoS03h_h`01@3h_h`20000
0080m<:H00@000000?;1W000000000000P3e`ID01@000000l/:K0?;2V`000000m/:E008000000P3`
aZD2000000@0n;f900<000000?VnQ`3i_XL0103i_XL00`000000n;n=0?RoS@020?RoS@030000003j
`XT0n/:900<0n/:900<000000?g:R@000000200000050?S8V@8000000P3iaI44000000D0/OGa0`00
00000`3Bg>00000000000003000000H0n/690`0000000`3h`Y4000000?W2S@020?W2S@L000000P3`
d;400`000000mlJH0?O6V003000000030?G7W0000000000000@0n/J@0P0000030?_2Q0050000003k
a8P0nlB80000003hcj800P0000040?[7T0<00000103k`XL2000000D0oL5m00H000000?o@MP3od7H0
00000?c8S@0000020?_5R@8000000P3l`X02000000040?^nO`000000olQ_0?o8K`D000000P3k_gl0
0`000000n[f30?ZmP`02000000<0n[n40P0000000`3i^h@00000000000040?boOP060000003m`Gd0
oL5m0000003m_WL000001@3n`7800`000000oKed000000040?bmMP030000003n`FL0o/5W0080o/5W
00@000000?fmM@00000000001@3l_GH00`000000iJ25000000030?k0M@80000000@0lj/h00000000
0000nkin0P0000020?foN@050000003n`gH0o/=f0000003n`7800P0000000`3kfZ@0000000000002
000000040?oIR@000000nnJS0?_VX`<000000P3lci83000000<0o/9d00<000000?k2LP0000000`3m
b8D4000000030?g8R@000000n]JR0080000000<0o/9d0000000000000P3na7P01`000000o/V20?k9
PP000000o/1`0000003n`7000`000000103lc98000000000003`fKT2000000@0olEd1`000000103n
`Vl000000?k1L@0000030?o9L`040000003na7X0o/Aj000000<0olEe0P0000040?k0KP8000000P3l
e9P400000080nkMF00D000000?^eE@3k]ED0nkEE000000020?^dE0050000003l]eX0o;MJ0?bgFP00
00000`3l^5`01P000000o;QI0?bhF@000000nK9;000000<0oooo00<000000?ooo`3oool07@3oool0
0300oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003_`J<000000080000000H0k;nU
000000000000001c0000003U_Zl6000000D0kl:T00@000000=g5`P000000kKjS0P0000001P2U`>`0
00000000003AG@0000000;Nng`D0000000D0l;jL00000000000000000>fnXP030000000303ZHlP00
0000]<CU0080000000<0j;n[0000003X`k000P0000020>c5[@80000000@0l/2L0000003/`:D0k<2U
0P0000020>c1Z0<000000P3d`YP00`000000l9960000000200000080j[jV0P000000103`aJ@00000
09WNoP2Ig_h200000080l<6Q00@000000??0U`00000000000P3`_I/2000000030?2nW00000000000
0080kL2U1@0000020?;6XP030000003X`Zh0j<:^00<0000000<0deXD0000000000000P3abZP20000
00040>_D_@00000000000?C>Z0<0000000<0m/:D0000003ibIL01P3ibIL200000080ll>L0P000002
0??4WP@000001`3i`Xd00`000000n;n<0?RoS0040?RoS0070000003g_H`0mkf<0000003d`YP00000
0?;1W002000000<0mL6E00<000000?;2V`3b`Y/00P0000000`3RLaX000000?36Y@02000000<0n;f9
00<000000?VnQ`3i_XL01@3i_XL200000080n;n=00<000000?[2R@3j`XT0103j`XT00`000000oLZ9
0?g:R@030?g:R@030000003iai<0nLNC00<000001@3hb9T200000080nLFA1@0000030;7el@800000
00<0n/::0000003Bg>000P0000000`3iaY4000000?[1R@050?[1R@030000003k`hL0000000800000
103i`Xd6000000<0l=2a00<000000?O6V03gaYP00P0000020?G7W08000000`3jaY000`000000n/B=
000000030?_2Q0060000003ka8P0nlB80000003hcj8000001@3jai02000000@0nl:700<000000?W3
S@000000103m`Gd010000000om1f0000000000020?c8S@040000003kaHT00000000000<0o<:000<0
00000?^nO`0000000P3ob6l4000000040?[4S@000000nkmo00000080n[f30P0000040?ZoQ0040000
003i^h@00000000000@0o;mn00H000000?g1O@3m`Gd000000?fnM`0000050?k0LP030000003m_G@0
000000@0o;ef00<000000?k1I`3n`FL00P3n`FL010000000oKee0?fmM@0000050?bmMP030000003U
X8D0000000<0o/1e0P000000103cZcP000000000003k_Wh200000080oKmi00@000000?k3MP3n`gH0
00000P3n`783000000@0omV900<000000?_VX`3kiZ<00P3kiZ<00`000000o<nB0?c?TP03000000<0
o/9d00<000000?k2LP000000103mb8D500000080n]JR100000020?k4N0070000003nbH80o/V20000
003n`70000000?k0L002000000080=WAd@00000000000000003`fKT000000?g?TP0000030?o5M0P0
000000<0o/9_0000000000000`3obG<00`000000o/Aj0?k4NP02000000<0olEe00<000000?k0KP3n
`6h00P3n`6h010000000o/EY0000003le9P400000080nkMF00D000000?^eE@3k]ED0nkEE00000002
0?^dE0050000003l]eX0o;MJ0?bgFP0000000`3l^5`01P000000o;QI0?bhF@000000nK9;000000<0
oooo00<000000?ooo`3oool07@3oool00300oooo0P0000000`3oool0000000000002000000040?oo
o`000000kl6S0>o1X`@0000000D0hl:f0000000007<000000>Fn[`05000000H0kl:T0P0000020>fn
X`80000000<0YL3/0000000000000P0000000`2g_]l000000=Vk^`0200000080l;jL0`0000001@3]
_Z8000000>c2Z0000000>YSb0080000000D0lKnL0000003X_j/000000>S3/00200000080k<F]1000
00020>c0Y@8000000P3/`JP2000000<0m<:H0P000000103W`k4000000>ZnYP3Z_ZH400000080VMkn
0`0000020?31X@<000000`3`_I/00`000000l;jL0?2nW00200000080kL2U00@000000?C0U`000000
00000P3baZ82000000040>S2[P000000m<6H0?C1V0@000000P3abZP6000000040<:ecP0000000000
000000L0nLVG00<000000??5W`0000000P3c`i`200000080llBN00<000000>o3Y00000001`3i`Xd0
0`000000n;n<0?RoS0040?RoS0080000003g_H`0mkf<0?NmS0000000m<:H0000003b`I`200000080
mL6E00<000000?;2V`3b`Y/00P0000001@3RLaX000000000003d`iX0000000<0n;f900<000000?Vn
Q`3i_XL01@3i_XL200000080n;n=00<000000?[2R@3j`XT0103j`XT00`000000oLZ90?g:R@030?g:
R@030000003iai<0nLNC0080nLNC0P0000040?S8V@<0000000<0nLFA000000000000200000020?[2
RP060000003Bfn0000000000003iaY4000001@3j`HT00`000000nl>700000002000000D0nL:=0P00
0000103WbKL000000?S3T@0000020?3@/@030000003gaYP0mlJH00H000000P3jaY001@000000n/B=
0?[4S@3ja8d000000080nl:40`000000103ka8P000000?S?XP0000050?[7T0030000003k`XL0nl:7
00<0nl:700<000000?W3S@0000000`3m`Gd01@000000om1f0000003jai0000000080o<R=0P000000
1`3k`H@000000?c2P03l`X0000000?^nO`0000000P3ob6l4000000040?[4S@000000nkmo00000080
n[f30P0000040?ZoQ0040000003i^h@00000000000@0o;mn00H000000?g1O@3m`Gd000000?fnM`00
00050?k0LP030000003m_G@0000000@0o;ef00<000000?k1I`3n`FL00P3n`FL010000000oKee0?fm
M@0000050?bmMP040000003UX8D0iJ2500000080o/1e0P000000103cZcP000000000003k_Wh20000
0080oKmi00P000000?k3MP3n`gH0o/=f0000003n`78000000?k2J`P000000P3kiZ<2000000030?c?
TP0000000000008000000P3n`W@010000000o/9b0?k2LP0000030?g8Q@D000000P3jeZ8200000003
0?k2M0000000o/Ah0080o/Ah00<000000?k9PP3nbH800P0000020?k0L0@0000000<0nmVR0000003`
fKT00`0000020?o5M080000000<0l]6^0000000000000`0000000`3n`Vl00000000000040?o9L`80
000000<0o[m_0000003oaGD00P3oaGD00`000000o/1^0?k0KP020?k0KP030000003naFT000000080
o=BH00<000000?k3L00000000P3k]eH01@000000nkEE0?^eE@3k]ED000000080nkAD00<000000?bg
FP3l]eX00P3l]eX010000000o;QL0?bhG00000030?bhF@800000103oool00`000000oooo0?ooo`0L
0?ooo`00<03oool4000000030>W5/@0000000000008000000P3_`J<4000000040>?2]P000000001c
00000080iKj_0P0000000`3[`:L00000000000050>o2Y0030000003MaL8000000080kKjS0P000000
0`2U`>`0000000000007000000060?2nW000000000000000003]_Z8000000P3/`ZP4000000050?6o
W0000000j;n[0000003X`k000P0000020>c5[@80000000@0lKbG000000000000k<R`0P0000000`3/
`JP0000000000002000000<0m<:H0`0000020>ZnYP@000000P2Ig_h4000000040??8X`0000000000
00000080l;fK00<000000?2nW03`_Y`00P0000020>g0Y@D000000P3baZ82000000030?33XP000000
m<6H00@0m<6H0P0000020?7;ZP80000000<0kl^]0000000000002`0000020??5W`040000003c`i`0
ll>L000000<0llBN0P0000070?W2S@030000003h_h`0n;n<00@0n;n<00L000000?NmS03g_H`0mkf<
0000003d`YP000000080l/6L00D000000?G1U@3e`ID0mL6E000000020?;2V`060000003RLaX0hW<J
0000003d`iX000000`3h_HT00`000000nKj70?VnQ`040?VnQ`060000003k`H@0nl640000003h_hd0
00001P3j`XT00`000000oLZ90?g:R@030?g:R@030000003iai<0nLNC00<0nLNC0P0000030?S8V@03
0000003gb9`000000080000000D0n<NF0000003Jc<`000000?C@ZP02000000030?V]H`0000000000
0080n/::00<000000=;Kh00000000P0000040?[1R@040000003k`hL0nl>70?_3Q`8000001@3i`Xd3
000000040>O9]`000000n<>A00000080l=2a00@000000?O6V0000000nL^I0P0000001@3`d[<00000
0000003jaY00000000<0n/B=00<000000?_2Q03k`X@01P0000000`3hcj8000000?[7T0030?[7T080
0000103k`XL010000000nL>=0?W3S@0000020?g1O@8000000`3jai0010000000o<R=000000000002
0?_1Q0060000003l`X0000000?^nO`000000olQ_0`0000001@3kahl000000?[4S@000000nkmo0080
000000@0n[f30000003l`80000000`3j_h@010000000nK^40000000000040?boOP80000000@0oL5m
0000003m_WL000001@3n`7800`000000oKed000000040?bmMP030000003n`FL0o/5W0080o/5W00@0
00000?fmM@3m_GD000001@3l_GH010000000iJ250>FPQ@0000020?k0M@030000003m_GH000000080
00000P3k_Wh010000000oKmi0?foN@0000030?k3MP070000003n`78000000?k2J`000000nlUQ0000
00040?o?Q@D000000P3lci8300000080o/9d00@000000?k2LP3n`W8000000`3mb8D500000080n]JR
1@0000020?k4N0030000003nbH80o/V2008000000P3n`702000000060=WAd@000000nmVR0?_IXP00
0000l=Vi0P0000020?o5M0040000003nb8@000000?;A[P<0000000@0oLR50000000000000000103o
bG<200000080o[m_00@000000?o5M@3oaGD00000103n`6h020000000o/EY0?k5J@000000o=BH0000
003n`g0000000P3k]eH01@000000nkEE0?^eE@3k]ED0000000<0nkAD00D000000?bgFP3l]eX0o;MJ
000000020?bhG0070000003l^5T0o;QI0?bhF@000000nK9;000000040?ooo`030000003oool0oooo
01/0oooo000_0?ooo`<0000000<0m;1o0000003YaK400P0000000`3d/h@000000>o1X`020>o1X`@0
000000D0hl:f0000000007<000000>Fn[`03000000030>_0Y`000000000000D0kl:T0P0000030>fn
X`80000000@0YL3/000000000000e;o50P0000000`3I^k/0000000000002000000080?:mU`000000
00000>fnXP000000k<:X0000003Y`:X4000000050>RoZ`00000000000000003N^k@00P0000000`3^
_j4000000?6lU`0200000080k<R`0P0000020?76Y0@000000P3d`YP200000080j[jV0`0000000`3`
aZH000000000000209WNoP8000000P3cb:<2000000<0l;fK0P000000103d_9800000000000000002
0>c9/080000000D0jlfg0000003baZ80l/JR000000020?33XP030000003d`IP0m<6H00<0m<6H00@0
00000?7;ZP3abjX0lL^Z0P0000000`3_bjd000000<:ecP09000000040?70W0000000llFO000000<0
ll>L00<000000??4WP3ca9h00P0000070?W2S@030000003h_h`0n;n<00@0n;n<00<000000?NmS03g
_H`00P3g_H`010000000m<:H0000003b`I`2000000060?G1U@00000000000?;2V`000000k/V]0P00
0000103RLaX000000?C3VP0000020?RmR@030000003i_XL0nKj700@0nKj700H000000?_1Q03k`H@0
00000?RoS@0000060?[2R@030000003mbXT0oLZ900<0oLZ900<000000?W7T`3iai<0103iai<20000
00030?S8V@000000mlRL0080mlRL0P0000020?S7UP090000003cbjH000000?C@ZP000000nJeS0000
003f`iL000000080n/::00<000000=;Kh00000000P0000030?[1R@030000003k`hL0nl>70080nl>7
0P0000050?W2S@80000000D0ilVg0000003h`i40n<>A000000020?3@/@8000000P3ibiT00`000000
l=:c00000003000000@0n/B=00<000000?_2Q000000010000000103jaXd000000000000000030?[7
T0800000103k`XL2000000040?W3S@00000000000?g1O@800000103jai03000000<0nl640P000000
1@3k_Wl000000?o8K`000000i=G80080000000@0nlN?000000000000nkmo0P000000103j_H<00000
0?c0P00000030?ZoQ0050000003i^h@000000:Z?^P0000000`3l_gh2000000040?g1O@0000000000
000000D0o/1b00<000000?fmM0000000103l_GH00`000000o/5W0?k1I`020?k1I`030000003m_GD0
oKee00800000103l_GH010000000iJ250>FPQ@0000020?k0M@030000003m_GH00000008000000P3k
_Wh010000000oKmi0?foN@0000040?k3MP<000000P3kbF400`000000oln50?o?Q@020?o?Q@800000
0P3n`782000000030?c?TP000000o<nB0080000000<0o/9d0000003n`W800P3n`W800`000000oLR5
0?g8Q@03000000030?k3M`00000000000080n]JR100000030?k4N0040000003nbH80o/V200000080
o/1`00D000000?k0K`000000n]>O000000020?_IXP@0000000D0olEd0000003nb8@000000?;A[P02
000000030?k9Q@000000oLR500800000103obG<200000080o[m_00<000000?o5M@3oaGD00P000003
0?k0KP030000003naFT0o/EY0080000000H0oLJ20000003n`g0000000?^gEP0000030?^eE@050000
003k]5@0nkAD0?^dE00000000`3l]eX010000000o;QL0?bhG00000030?bhF@030000003i/T/00000
00D0oooo00<000000?ooo`3oool06P3oool002l0oooo00D000000>g6[0000000000007S0o@060000
00<0kl6S100000000`3S`[H00000000000020>Fn[`<0000000<0jl2W0000000000001@3_`Z@20000
0080kKjS0`0000000`2U`>`0000000000003000000040=Vk^`000000000000000080l[fG0P000000
1`3]_Z8000000>c2Z0000000jL2Z0000002da>D00P0000000`3X_j/000000?2mV`0300000080k[nQ
00<000000?6lU`0000000`3/b;0010000000lLJT0?76Y03aaZ@9000000<0l/JR00<000000?36YP3`
aZH00P0000000`2Ig_h000000??8X`020??8X`8000000P3`_I/2000000040?BlTP00000000000000
0080k<V`00@000000?C0U`000000jlfg0P0000001@3baZ8000000?33XP3``j80000000@0m<6H0`00
00030?7;ZP030000003_bjd0000000/000000P3caIl01P000000ll>L0??3W03c`i`000000??4WPD0
0000103i`Xd00`000000n;n<0?RoS0040?RoS0030000003g_H`0mkf<00<0mkf<0P0000020?;1W0<0
000000<07:Ve0000000000000P3^bJd3000000050?C3VP000000n;f90?RmR@0000001P3i_XL01000
0000nl640?_1Q03k`H@2000000H0n/:900<000000?g:R@3mbXT00P3mbXT010000000n/:900000000
00040?W7T`040000003haI800000000000<0mlRL0`0000020?S7UP090000003cbjH000000?C@ZP00
0000nJeS0000003f`iL000000080n/::1@0000020?[1R@030000003k`hL0nl>700<0nl>700<00000
0?W2S@3i`Xd00`3i`Xd3000000040>O9]`000000n<>A00000080l=2a0P0000020?W;V@80000000@0
l=:c0000003i`hh000001@3ja8d2000000030?_3Q@000000emKG0080000000<0n/J=000000000000
0P3jai0010000000n/><0?[3S00000030?_2Q`80000000<0nL>=0000003k`hT00P0000000`3ka8T0
00000?[7T0030?[7T0030000003k`XL000000080nl640P0000000`3k_Wl000000?o8K`0300000004
0>[=^000000000000?[4S@<0000000@0n[f30000003l`80000000`3j_h@00`000000nK^40?VkQ002
000000<0o;mn0P000000103m`Gd000000000000000050?k0LP030000003m_G@0000000@0o;ef00<0
00000?k1I`3n`FL00P3n`FL00`000000oKee0?fmM@02000000@0o;ef00/000000>FPQ@3UX8D0iJ25
0000003n`7D000000?fmMP000000lj/h000000020?^nOP80000000<0oKmi0000003n`gH00`3n`gH3
00000080nlUQ0`0000020?o?Q@060000003jdil000000?k0LP000000n]2M0P0000001@3lci800000
0000003n`W@0000000<0o/9b00<000000?g8Q@0000000P3mdYH5000000060?[FXP00000000000000
003oaWL000000P3na7P2000000050?k9PP000000o/1`0?k0L00000000P3n`6l01P000000n]>O0000
003kfJ8000000?3I^@@000000P3nb8@500000080oLR500<000000?o9L`3obG<00P3obG<2000000<0
o[m_00@000000?o5M@00000000000`3n`6h02`000000o/EY0?k5J@3naFT000000?g6PP000000o/=`
0000003k]eH0000000<0nkEE00D000000?^dE03k]5@0nkAD000000030?bgFP040000003l^5`0o;QL
000000<0o;QI00@000000?VbB`3i/T/00000103oool00`000000oooo0?ooo`0J0?ooo`00;`3oool0
10000000kLJ/00000000000207S0o@<000000P3]aZ`00`000000kl6S0>o1X`03000000080>boY@00
000000000000L`000000iKj_0000003N_kX2000000040>_0Y`0000000000000000<0kl:T10000000
1@3a`Il00000000000000000j<Vf00D0000000<0d]3H0000000000000`3b_IL00`000000kKjR0>fn
XP03000000030>W0ZP000000]<CU0080000000@0jKfW000000000000g[^d0P0000001@3^_j400000
0?6lU`3a_9L0000000<0k<R`00<000000?76Y03aaZ@00P3aaZ@2000000030>S:]`000000l[fE0080
0000103baZ8200000080l<JV100000020??8X`030000003`_I/0l;fK008000000P3d_982000000<0
k<V`00<000000?C0U`0000000P3[cKL200000080l<>R00<000000?C1V03d`IP00P3d`IP010000000
mL>H0?G3V00000030?7;ZP80000000<0kl^]0000000000000P3cbZH2000000050>C@a00000000000
0?70W00000000P3caIl010000000ll>L0??3W03c`i`300000080kl>T1P0000060?RoS0030000003g
_H`0mkf<00@0mkf<0P0000001@3b`I`000000000000000007:Ve008000000P3^bJd00`000000m<:H
0?C2V00200000080n;f900<000000?VnQ`3i_XL0103i_XL010000000nl640?_1Q03k`H@2000000H0
n/:900D000000?g:R@3mbXT0oLZ9000000020?[2R@040000003`cJh0000000000080nLNC00@00000
0?S5TP3haI800000103gb9`300000080n<NF00@000000??;YP000000m=2Z0P0000020?K3U`040000
003j`XX000000?[2RP<000000P3j`HT00`000000nl>70?_3Q`040?_3Q`030000003i`Xd0nL:=0080
nL:=0`0000001@3WbKL000000?S3T@3h`i4000000080l=2a00@000000?W;V@3ibiT0nL^I0P000000
103`d[<000000?W3SP0000050?[4S@050000003k`hD0nl>50000003Ge]L00P0000001@3jaXd00000
0000003jai0000000080n/><00H000000?_2Q`3k`XL0nl:70000003l`hH200000080nl>900@00000
0?_4R@3ka8T000000`3jai000`000000nl:7000000030?_1Q0<0000000H0olQ_000000000000i=G8
0000003ZcKP5000000040?ZmP`000000o<20000000<0n[n400<000000?VkQ03i^h@00P0000030?bo
OP030000003n`WX0000000<000001@3n`7800`000000oKed000000040?bmMP030000003n`FL0o/5W
0080o/5W00<000000?fmM@3m_GD00P0000040?bmMP0:0000003UX8D0iJ250>FPQ@000000o/1e0000
003m_GH000000?>[>080000000D0nkin000000000000oKmi000000050?k3MP050000003kbF40nlUQ
0?_9H@0000000P3ngIP3000000060?[CW`000000o/1b0?k0LP000000n]2M0P000000103efk400000
0000000000040?k2LP8000000P3mdYH2000000030?k3M`00000000000080n]JR100000020?k4N004
0000003obW`0000000000080o/1`00H000000?k0K`3n`6l000000?[CW`0000020?_IXP80000000<0
oLN30000000000000P3nb8@01`000000l]6^000000000000o/V50000003mb8D00`0000020?o9L`80
00000`3n_fl010000000olEe0000000000030?k0KP050000003naFT0o/EY0?k5J@0000000P3maX82
000000030?^gEP000000nkEE0080nkEE00D000000?^dE03k]5@0nkAD000000030?bgFP040000003l
^5`0o;QL000000<0o;QI00@000000?VbB`3i/T/000001@3oool00`000000oooo0?ooo`0I0?ooo`00
;`3oool3000000060>b;@P00000000000000002le>`000000`3]aZ`00`000000kl6S0>o1X`030000
00060>boY@00000000000000L`000000iKj_100000001`3[`:L000000>[3[@000000kl:T0000003`
`j400`0000030?71W`80000000<0j<Vf0000003D_lD00P0000020=;@f08000000P3b_IL300000003
0?6jU@000000f/G500<0000000D0k<F/0000003Y_JL000000?2mV`0300000080k[nQ00@000000?6l
U`3a_9L000000`3/b;000`000000lLJT0?76Y0020?76Y0@0000000<0l[fE0000003baZ80103baZ82
00000080l<JV10000000103cb:<000000?2mV`3`_I/2000000<0m;bB0P0000030>c9/0050000003d
`9L000000000003[cKL00P0000020?33XP040000003d`IP0m<6H000000@0mL>H00@000000?7;ZP3a
bjX0lL^Z0P0000000`3_bjd0000000000002000000070?7>[P00000000000>O;^P000000lL2L0000
00020??5W`030000003c`i`0ll>L0080000000@0m;fB000000000000c[>n0P0000030?>nU@030000
003h_h`0n;n<00<0n;n<00<000000?NmS03g_H`0103g_H`2000000030?;1W0000000000000@00000
0`3^bJd010000000m<:H0000000000020?RmR@030000003i_XL0nKj700@0nKj700<000000?_1Q03k
`H@00P3k`H@00`000000n/:90?[2R@040?[2R@040000003mbXT0oLZ9000000@0n/:900<000000?3=
[P3`cJh00`0000030?S5TP030000003gb9`0mlRL0080mlRL00T000000??=Z000000000000?S7UP00
0000ll^V0000003dd:X00P0000020?K3U`8000000P3j`XX3000000030?[1R@000000nl>700@0nl>7
0P0000040?W2S@060000003jaHl000000000003WbKL000000P3h`i42000000030?S2SP000000nL^I
0080nL^I0`0000000`3i`hh000000?[4S@040?[4S@8000000P3k`hD8000000<0n/><00D000000?_2
Q`3k`XL000000?c3QP02000000<0nl>900@000000?_4R@00000000000P3jai02000000040?_2Q`00
0000nl640?_1Q0<0000000D0olQ_0000003l`Gl000000>CEb006000000050?ZmP`000000o<200?c0
P00000000`3j_h@010000000nK^40000000000020?boOP030000003n`WX0o/9j00@000001@3n`780
0`000000oKed000000040?bmMP030000003n`FL0o/5W0080o/5W00<000000?fmM@3m_GD00P000004
0?bmMP070000003UX8D0iJ250>FPQ@000000o/1e000000020?fmMP<000000P3k_Wh00`000000oKmi
000000050?k3MP040000003kbF40nlUQ000000D0o]fH00L000000?[CW`3jdil000000?k0LP000000
n]2M008000000P3efk42000000@0o/9b0P0000030?gBUPD0000000<0n]JR0000003mahL00`000000
0`3na7P000000?o:O003000000030?k0L0000000o/1_0080o/1_00@000000?[CW`000000nmVR0`00
00000`3mah<000000?k8Q0020?k8Q0D000000P3mb8D00`000000o[m^00000003000000@0o[m_0P00
00001@3odhD000000?k0KP3n`6h0000000<0o/EY0P0000000`3maX800000000000020?^gEP040000
003k]ED0nkEE000000<0nkAD00D000000?bgFP3l]eX0o;MJ000000020?bhG0050000003l^5T0o;QI
0?bhF@0000000P3i/T/2000000D0oooo00<000000?ooo`3oool0603oool002l0oooo00<000000?oo
o`0000000P0000001@3/Rd8000000;cDk02le>`0000000<0kLJ/00<000000>o1X`3_`J<010000000
103S`[H000000000003U_Zl4000000040>_0Y`000000j/>]0>[3[@8000000P3``j42000000D0lL6O
00@000000>S9]P000000k[nQ0P000000103Bd=P000000>^mY00000020?:mU`8000000P3a^YD30000
00030<W;g000000000000080jKfW0P0000001@3N^k@000000000003^_j40000000<0lKbG00<00000
0>c8/03/b;000`0000030?76Y0<0000000@0l[fE00000000000000001@3baZ82000000<0l/JS0P00
00001@3cb:<000000000003ZVVl0000000<0m;bB0`0000030>c9/0050000003d`9L000000000003[
cKL00P0000020?33XP030000003d`IP0000000D0mL>H0`0000020?7<Z`<0000000<0Rkgg0000003a
cZh0100000020?70W0080000003caIl000000??3W0000000m;fB0000003d_I82000000040<jc_P00
0000000000000080lkjE00<000000?RoS03h_h`00`3h_h`00`000000mkf<0?NmS0040?NmS0H00000
0`3f_Hd010000000k/V]0>k9[@0000020?C2V080000000<0n;f90000003i_XL01@3i_XL00`000000
nl640?_1Q0020?_1Q08000001@3j`XT010000000oLZ90?g:R@0000040?[2R@<0000000<0mLRN0000
00000000103haI800`000000mlRL0?O8W0020?O8W0030000003ccJP0llfX00<0000000@0ll^V0000
0000000000000`3f`iL010000000n/::0?[2RP3j`XX4000000D0nl>700<000000?VnQP0000000`3i
`Xd00`000000n/F?0?[5S`0300000080n<>A0P0000020?S2SP090000003ibiT0nL^I0?W;V@000000
l=:c0000003i`hh0000000@0n/B=00<000000?_4RP0000000P3k`hD3000000040?[6S@0000000000
000000<0n/><00@000000?_2Q`3k`XL000000P3l`hH00`000000nl>90?_3R@020?_3R@<0000000H0
n/N@0000003i`HX000000?_2Q`0000020?_1Q0@000000P3l`Gl010000000i=G80000003ZcKP40000
00050?ZmP`000000o<200?c0P00000000`3j_h@00`000000nK^400000002000000040?boOP000000
o/9j0?k2NP@000001@3n`7800`000000oKed000000040?bmMP030000003n`FL0o/5W0080o/5W00D0
00000?fmM@3m_GD0oKee000000040?bmMP040000003UX8D0iJ250>FPQ@<000000P3m_GH300000080
nkin00<000000?foN@0000001@3n`gH00`000000nlUQ0?_9H@02000000@0o]fH0P0000020?[CW`05
0000003n`78000000?[@W@0000000P3efk42000000@0o/9b0P0000030?gBUP<0000000@0o/=g0000
0000000000000`3mahL00`000000o/Ah000000020?o:O080000000<0o/1`0000003n`6l00P3n`6l2
000000030?[CW`00000000000080000000<0oLN30000000000000P3nb8@020000000l]6^00000000
0000o/V50000003mb8D000000`3n_fh00`000000o/1e000000030?joK`80000000D0om>50000003n
`6h0o/1^000000030?k5J@80000000H0oLJ20000003n`g0000000?^gEP0000020?^eE@050000003k
]5@0nkAD0?^dE00000000`3l]eX010000000o;QL0?bhG00000030?bhF@060000003i/T/0nK9;0000
003h[4L00000103oool00`000000oooo0?ooo`0H0?ooo`00;`3oool010000000oooo0?ooo`3oool5
000000030;cDk0000000kLJ/0080kLJ/00D000000>o1X`00000000000=nn]`02000000060>?2]P00
000000000>Fn[`000000g[nj1@0000000`3XcK/000000?33X@020?33X@8000001@3a`Il300000003
0>joX@000000000000<000000`3b_IL010000000lKZE0?6jU@3a^YD2000000070<W;g00000000000
0000003Y_JL000000?2mV`04000000030>joX@000000lKbG0080lKbG0P000000103/b;0000000000
000000020?76Y0@0000000@0l[fE0000003``j800000103baZ82000000@0l/JS100000020>ZJK`07
0000003d_980m;bB0?BlTP000000kl6Q000000020>c9/0040000003d`9L000000?GO]0<000000`3`
`j82000000L0mL>H00P000000?7<Z`3ac:/0lLb[0000003b`I/0000008^mm`H0000000<0lL2L0000
003caIl00`0000020?BmTP040000003d_I8000000<jc_P<0000000@0lkjE0000003de[000000103h
_h`00`000000mkf<0?NmS0040?NmS0H00000103f_Hd010000000k/V]0>k9[@0000020?C2V0030000
003h_HT0000000H0nKj700<000000?_1Q03k`H@0103k`H@2000000<0n/:900<000000?g:R@000000
1@3j`XT00`000000nKn9000000020?G8WP800000103haI8010000000mlRL0?O8W03gb9`300000008
0?3=[P00000000000000003cbjH000000<?Gj@0000020?K3U`8000000`3j`XX3000000D0nl>700<0
00000?VnQP0000000P3i`Xd00`000000n/F?0?[5S`020?[5S`040000003ccjX000000?S3T@800000
0`3h`Xh00`000000nL^I0?W;V@0300000080nL>>00D000000?[4S@3ja8d0n/B=000000020?_4RP<0
000000@0emKG00000000000000000P3da9`01`000000n/><0?[3S03j`h`000000?_2Q`0000000P3l
`hH00`000000nl>90?_3R@020?_3R@80000000<0o<F70000000000000P3i`HX010000000nl:70000
003k`H@400000080o<5o0P0000000`3TeLP000000>[=^003000000050?ZmP`000000o<200?c0P000
00000`3j_h@01`000000nK^40000002ZSkX000000?boOP0000000P3n`WX2000000030?bmNP000000
o/1b00@0o/1b00@000000?fmM03m_G@000000`3l_GH00`000000o/5W0?k1I`020?k1I`050000003m
_GD0oKee0?fmM@000000103l_GH010000000iJ250>FPQ@3UX8D300000080oKef0`0000020?^nOP<0
00001@3n`gH01@000000nlUQ0?_9H@000000o/9b0080000000@0o]fH0000003jd9X000000P3jdil0
0`000000o/1b0000000300000080mM^a0P0000030?k2LP030000003n`W80000000<0oM:F0P000000
0`3n`gL0000000000002000000<0oLN70P0000020?o:O080000000<0o/1`0000003n`6l00P3n`6l0
1P000000o/5_0000003jdil000000?;F/P80000000<0oLN30000003nb8@00P3nb8@5000000030?g8
Q@000000o[m^0080o[m^00<000000?k0M@0000000`3n_fl2000000050?oCQ@000000o/1^0?k0KP00
00000`3naFT010000000oKe]0000003maX82000000030?^gEP000000nkEE0080nkEE00@000000?^d
E03k]5@000000`3l]eX010000000o;QL0?bhG00000030?bhF@040000003i/T/0nK9;00000080n:a7
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`00;`3oool00`000000oooo0?oo
o`020?ooo`<0000000<0il>a0000002le>`00P0000020>g6[0X0000000<0k<V`0000003UcKh00P00
0000103_aJH000000>S=^`3XcK/200000080l<>Q0`0000050?71W`030000003^_j40k[nQ00<00000
00D0jkfT0000003b_IL0l[fG000000030?6jU@040000003JaLD000000<W;g08000000P3Y_JL20000
00050=jk]000000000000>joX@000000103a_9L2000000030>c8/0000000fMSG008000000P3_`:42
00000080l[fE00<000000?33XP0000000P3baZ8010000000lKjI0?6nV@0000040?;6X`<0000000<0
jYY_0000000000000`3d_982000000040>o1X@000000k<V`0>c9/08000000P3egk@3000000<0l<>R
00<000000?G3V03e`iP01@3e`iP3000000040?7<Z`00000000000?;1V`L000000P3a`9`200000007
0?>mU0000000m;fB0?BmTP000000m;fB000000020<jc_P060000003d_90000000000003de[000000
103h_h`00`000000mkf<0?NmS0040?NmS080000000@0mKb?0000003c^i400000103f_Hd200000003
0>k9[@000000m<:H0080000000<0n;f90000003i_XL01@3i_XL00`000000nl640?_1Q0040?_1Q005
0000003l`hD000000000003j`XT00P0000060?[2R@040000003i_hT0nKn900000080mLRN0P000004
0?S5TP030000003gb9`000000080n<BC00<000000?3=[P3`cJh01P0000020?K3U`030000003iai@0
000000<0n/::0P0000050?_3Q`060000003i_XH0nKj60000003i`Xd00000103jaHl3000000040?S3
T@000000m<^T000000<0n<:>00<000000?W;V@0000000`0000001@3i`hh000000?[4S@3ja8d00000
00D0nlB:1P0000000`3da9`000000?[3S0020?[3S0030000003k`XL0000000<0o<>600<000000?_3
R@3k`hT00P3k`hT010000000o<F70?c5Q`0000020?W1RP030000003k`XL000000080nl640`000002
0?c1O`030000003l`Gl0000000@0000000<0n/B=0000000000000P3l`8001@000000n[n40?ZoQ03j
_h@000000080nK^40P000000103l_gh000000?k2NP3n`WX2000000030?bmNP000000o/1b00@0o/1b
00@000000?fmM03m_G@000000`3l_GH00`000000o/5W0?k1I`020?k1I`050000003m_GD0oKee0?fm
M@000000103l_GH010000000iJ250>FPQ@3UX8D300000080oKef0`0000020?^nOP<000001@3n`gH0
10000000nlUQ0?_9H@0000030?k2LP8000000P3jd9X00`000000n]>O0?[CW`04000000030?g<SP00
0000mM^a008000000`3n`W8010000000o/9b0?k2LP0000020?gBUP<0000000@0o/=g000000000000
00000`3mahL200000080olYl100000030?k0K`030000003n`Fl000000080000000@0l]Jb00000000
0000oLN30P0000020?k8Q0@0000000@0o/V500000000000000000P3n_fh3000000<0o[m_0`000000
103odhD000000?k0KP0000030?k5J@040000003m_Fd000000?g6PP80000000<0nkMF0000003k]ED0
0P3k]ED010000000nkAD0?^dE00000030?bgFP050000003l^5`0o;QL0?bhG00000000P3l^5T01@00
0000nK9;0?VbB`3i/T/000000080n:a700<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F
0?ooo`00;`3oool00`000000oooo0?ooo`030?ooo`<0000000<0il>a0000000000000P0000020>g6
[0030000003``Il000000080000000@0k<ng00000000000000000P3/bK000`000000iLfn00000004
00000080j<fk00<000000?33X@3``j400`0000030?71W`030000003aa:80000000<0k[nQ0P000000
1@3[_J@000000?:mU`3b_IL0000000<0lKZE00@000000=[5a@000000bL_L0P0000000`3Y_JL00000
0?2mV`04000000030>joX@000000lKbG0080lKbG00<000000?>lU@000000100000020>o0X@<00000
00<0l[fE000000000000100000030?6nV@800000103baZ<200000080lkbD00@000000?BlTP3d_980
m;bB0P000000103_`J4000000>c9/03/bK05000000040>nlW0000000l<>R0?33XP8000001P3e`iP0
1P000000mKjB0?FnTP000000lLb[000000<0l/6K0`0000000`3/`ZT00000000000020?70W0030000
003c_I@0000000<0m;fB00@000000?BmTP000000c[>n100000020?CF/0040000003h_h`0n;n<0000
00L0mkf<00D000000?JkRP00000000000?>kT@02000000@0m[f=00<000000>k9[@3^bJd00`000000
0`3h_HT000000?VnQ`050?VnQ`030000003k`H@0nl6400@0nl6400@000000?c3Q@3l`hD0o<>50`00
00060?[2R@040000003i_hT0nKn9000000<0mLRN0P0000020?S5TP040000003iaI400000000000<0
n<BC00@000000?3=[P000000n<:@0P000000103fbj4000000000000000030?W7U080000000<0n/::
0000000000000P0000030?_3Q`060000003i_XH0nKj60000003i`Xd000001@3jaHl4000000030?C;
Y0000000n<:>00<0n<:>0`0000001`3Kb<L000000?W3SP3i`hh000000?[4S@0000001P3ka8X50000
0080m<BL00@000000?[3S03j`h`0n/><0P0000030?c3QP030000003k`hT0nl>90080nl>90P000000
0`3laHL000000?W1RP020?W1RP040000003k`XL000000?_1Q0<000000P3l`Gl020000000o<5o0000
003TeLP000000?Z^F@000000n/B=0P0000030?c0P0040000003j_h@0n[n400000080nK^40P000000
103l_gh000000?k2NP3n`WX2000000030?bmNP000000o/1b00@0o/1b00@000000?fmM03m_G@00000
0`3l_GH00`000000o/5W0?k1I`020?k1I`050000003m_GD0oKee0?fmM@000000103l_GH010000000
iJ250>FPQ@3UX8D3000000<0oKef0`0000020?^nOP8000001@3n`gH010000000nlUQ000000000003
0?k2LP030000003n`G@000000080n]2J00P000000?[CW`00000000000?k0LP000000oLb>00000080
mM^a0P0000020?k2LP040000003n`W80o/9b000000<0oM:F0P0000001@3n`gL000000000003deJl0
000000<0oLN700D000000?o:O03obW`000000?o:O002000000<0o/1_00L000000?k1K`3n`Fl00000
0?g5P`000000l]Jb0080000000@0oLN30000003nb8@0o/R40P0000020?gRW@@000000P3n_fh30000
00<0o[m_0P0000001@3n`GH000000000003n`6h0000000<0o/EY00<000000?fmK@0000000P3maX80
0`000000nkMF000000030?^eE@050000003k]5@0nkAD0?^dE00000000P3l]eX01@000000o;QL0?bh
G03l^5`000000080o;QI00D000000?VbB`3i/T/0nK9;000000020?R/A`800000103oool00`000000
oooo0?ooo`0E0?ooo`00;`3oool00`000000oooo0?ooo`050?ooo`<0000000<0k<F]000000000000
0P0000000`3^`Z@0000000000008000000040>c9/000000000000>G=_P80000000@0klFV0000003X
cK/0j<fk0P000000103``j4000000000000000020?71W`040000003aa:80lLBR000000<0k[nQ00H0
00000>^mY03[_J@000000?:mU`0000040?6jU@050000003JaLD000000<W;g00000000P3Y_JL20000
00050=jk]000000000000>joX@0000000P3a_9L01@000000lkbE0?>lU@3c_9D000000080lL6N0P00
00020>o0X@8000000P3b_ID200000080l[fG00@000000?6nV@3a_YT0lKjI0`0000030?;6X`800000
0P3c_9@010000000m;bB0?BlTP3d_98200000080kl6Q0P0000040?K7W0030000003__9`0kkbL0080
00000P3caj400`000000mL>H0?G3V0030?G3V0040000003e_Y80mKjB0?FnTP<000000`3b`I/60000
00050?70W0000000lkfD0?>mU00000000P3d_I800`000000m;fB000000020<jc_P030000003d_900
000000<0m=J`00<000000?RoS00000001`3g_H`01@000000m[^:000000000000lk^A00800000103f
_Hd2000000040>k9[@00000000000:Cfj08000001P3i_XL00`000000nl640?_1Q0040?_1Q0030000
003l`hD0o<>500<0o<>500<000000?[2R@3j`XT0103j`XT01@000000nKn90?VoR@3i_hT0000000<0
mLRN0P0000001@3haI8000000?W5T@3iaI40000000@0n<BC00@000000?3=[P000000n<:@0P000000
0`3fbj400000000000050?W7U080000000<0nL280000003Cfml00P0000000`3k`hL000000?VnQP02
0?VnQP8000001P3jaHl300000080m<^T00<000000?S2SP3h`Xh00P3h`Xh01P000000n<ZJ0000003L
a/@000000?W3SP<000001P3ka8X6000000030?C4W0000000n/><0080n/><0P0000040?c3QP090000
003k`hT0nl>90?_3R@000000nl230000003laHL000000080nL6:00@000000?_2Q`000000nl640P00
0000103j_h<000000?c1O`0000020?c1O`030000003gbYd0000000@000000`3l`80010000000n[n4
0?ZoQ00000020?VkQ0@000000`3n`WX010000000o;ej0?bmNP0000040?k0LP040000003m_G@0oKed
000000<0o;ef00<000000?k1I`3n`FL00P3n`FL01@000000oKee0?fmM@3m_GD0000000@0o;ef00D0
00000>FPQ@3UX8D000000?fmM002000000<0oKef0`0000020?^nOP8000001@3n`gH010000000nlUQ
0000000000030?k2LP030000003n`G@0000000<0n]2J00<000000?[CW`0000000P3n`7802@000000
oLb>0000003efk4000000?k3NP000000o/9b000000030?k2LP030000003mdYH0oM:F00<0000000@0
o/=g00000000000000000`3mahL4000000030?o:O0000000000000@0o/1_00H000000?k1K`000000
oLF30000003be[82000000040?g7P`000000000000000080olUd1P0000020?joKP80000000@0o/1e
0000003n_fl0o[m_0P0000030?k1MP8000000`3naFT01@000000oKe]0?fmK@000000oLJ200<00000
0`3k]ED01@000000nkAD0?^dE03k]5@000000080o;MJ00D000000?bhG03l^5`0o;QL000000030?bh
F@040000003i/T/0nK9;00000080n:a700<000000?N[A00000000`3oool00`000000oooo0?ooo`0E
0?ooo`00;`3oool00`000000oooo0?ooo`060?ooo`8000000P3/aJd3000000<0k/:T0P0000020>o4
YP80000000<0kLFZ0000000000000P3/bK001@000000iLfn000000000000klFV008000000P3XcK/7
00000080lLBR00<000000>joX@3^_j400P3^_j401@000000jkfT0000003b_IL0000000D0lKZE0P00
00020<W;g0030000003Y_JL0jKfW00<0000000H0lKfJ0000003^_j4000000?6lU`0000040?>lU@04
0000003a`Ih0lL6N000000<0kl2Q0P000000103b_ID000000000000000020?:mU`070000003a_YT0
lKjI0?6nV@000000k<:X000000020?;6X`8000000P3c_9@00`000000m;bB0?BlTP020?BlTP800000
0P3_`J42000000@0m/NL00@000000>nlW000000000000`3caj4200000080mL>H00<000000?FnTP3e
_Y800`3e_Y82000000@0l/6K0P000000103/`ZT000000000003a`9`2000000050?>mU0000000m;fB
0?BmTP0000000P3d_I8010000000c[>n0000003d_90200000080m=J`00<000000?RoS00000001`3g
_H`01`000000m[^:0000003e_8l000000?>kT@000000103f_Hd3000000030>k9[@00000000000080
00001P3i_XL00`000000nl640?_1Q0030?_1Q0030000003l`hD0o<>500@0o<>500<000000?[2R@3j
`XT0103j`XT00`000000nKn90?VoR@020?VoR@040000003eb9h0mLRN0?G8WP<000000`3iaI400`00
0000n<BC0?S4T`020?S4T`040000003`cJh000000?S2T080000000<0m/^Q0000003iai@01@3iai@0
0`000000nL280?W0R002000000030?W3S`000000000000<0nKj60P0000060?[5S`<000000P3dbj@0
0`000000n<:>0?S2SP020?S2SP80000000@0n<ZJ000000000000nL>>0`0000060?_4RP80000000<0
nl:60000003haI@00P000000103He]H000000?[3S03j`h`2000000@0o<>600D000000?_3R@3k`hT0
nl>9000000020?_0P`8000000`3i`HX500000080n[n30P0000030?c1O`030000003gbYd0000000<0
00000`3l`80010000000n[n40?ZoQ00000020?VkQ0@000000`3n`WX01@000000o;ej0?bmNP3l_GX0
000000<0o/1b00@000000?fmM03m_G@000000`3l_GH00`000000o/5W0?k1I`020?k1I`040000003m
_GD0oKee0?fmM@8000000`3l_GH01@000000iJ250>FPQ@000000oKed008000000`3m_GH300000080
nkin0P0000050?k3MP040000003kbF400000000000<0o/9b00@000000?k1M03n`G@000000P3jd9X3
00000080o/1b00<000000?g<SP3mc8h01P0000040?k2LP80000000H0o<N9000000000000o/=g0000
003cdjh200000080oLN71`0000040?k0K`070000003n`Fl0o/5_0000003maH<000000?;F/P050000
00@0olUd100000020?joKP80000000L0o/1e0000003n_fl0o[m_0000003oaG@000000080o/5f0P00
00030?k5J@050000003m_Fd0oKe]0000003maX800`0000030?^eE@050000003k]5@0nkAD0?^dE000
00000P3l]eX01@000000o;QL0?bhG03l^5`0000000<0o;QI00@000000?VbB`3i/T/000000P3h[4L0
10000000mj]40?N[A00000030?ooo`030000003oool0oooo01@0oooo000G0?ooo`H000000`3oool4
000000/0oooo100000060?ooo`8000000`3/aJd2000000<0k/:T0`0000020>o4YP030000003]aJX0
00000080000000@0k<V`0000003UcKh0iLfn2P0000000`3YckX000000?74XP020?74XP050000003^
_j40k[nQ0>joX@0000000P3[_J@2000000D0lKZE00D000000=[5a@000000bL_L000000020>VmY`80
000000<0g[^d0000000000000P0000000`3a_9L000000?>lU@030?>lU@8000000P3a`Ih02@000000
kl2Q0>o0X@3_`:4000000?:mU@000000kKbO000000020?:mU`030000003a_YT0lKjI0080lKjI00<0
00000>c2Z00000000P0000001@3b_9@000000?>lU03c_9@0000000<0m;bB0P0000020>o1X@@00000
0P3fai`010000000kkbL0>nlW00000050??7X@030000003e`iP0000000H0mKjB0P0000030?;1V`P0
00000P3c_I@020000000m;fB0?BmTP000000m;fB0000003>/kh000000P3d_903000000030?CF/000
0000000000L0mkf<00L000000?JkRP000000mKb?0000003c^i40000000@0m[f=1@0000000`3ibYP0
0000000000060?VnQ`030000003k`H@0nl6400<0nl6400<000000?c3Q@3l`hD0103l`hD00`000000
n/:90?[2R@030?[2R@030000003i_hT0nKn900@0nKn900<000000?G8WP3eb9h00`0000030?W5T@03
0000003ha9<0n<BC00<0n<BC0P0000020?S2T080000000<0m/^Q0000003iai@0103iai@200000080
nL280P0000000`3i`hl000000?VnQP030?VnQP030000003jaHl0n/F?00@0n/F?0P0000001@3gb9/0
00000?C;Y03dbj@0000000<0n<:>00D000000?[1R000000000000=c6a002000000030?W3T0000000
nlB:00D0nlB:00<000000?[4S0000000100000020=SFeP050000003j`h`000000?_3R0000000103l
`hH010000000nl>90?_3R@0000030?_0P`040000003i`HX0nL6:0?W1RPD000000P3j_h<2000000<0
o<5o00<000000?O:W@0000000`0000030?c0P0040000003j_h@0000000000080nK^400@000000:Z?
^P00000000000`3n`WX200000080o;ej0P0000020?k0LP040000003m_G@0oKed000000<0o;ef00<0
00000?k1I`3n`FL00P3n`FL010000000oKee0?fmM@3m_GD2000000<0o;ef00D000000>FPQ@3UX8D0
00000?fmM002000000@0oKef0P0000020?^nOP8000001@3n`gH010000000nlUQ0000000000030?k2
LP050000003n`G@0o/5d0?k1M00000000P3jd9X00`000000m<ZS000000020?k0LP030000003mc8h0
oLb>00D00000103n`W8200000080o<N90P0000002`3n`gL000000??C[P000000oLN70000003oeXd0
00000?g6Q0000000nl^B00800000103n`6l01`000000o/5_0?k1K`000000oLF30000003be[801@00
00040?o9M0<0000000@0lL>P0000003n_fh0o[m^0`0000020?joK`030000003oaG@000000080o/5f
0P0000030?k5J@050000003m_Fd0oKe]0000003maX800`0000030?^eE@<0000000<0nkAD0000003l
]eX00P3l]eX010000000o;QL0?bhG00000030?bhF@040000003i/T/0nK9;000000<0n:a700@00000
0?N[A03gZd@000000`3oool00`000000oooo0?ooo`0C0?ooo`00603oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`8000000P3/aJd2000000@0k/:T0P0000020>o4YP030000003]aJX0kLFZ00P000000P3_aJL0
0`000000jLbg0000000600000080lLBR00<000000>joX@3^_j400P0000020>^mY08000001@3a^YD0
1@000000f/G500000039bm`000000080jKfW200000050?>lU@8000000P3a`Ih00`000000kl2Q0>o0
X@0600000080l[fG00<000000?6nV@3a_YT00P3a_YT01P000000k<:X0>c2Z0000000l[bD00000080
lkbD00<000000?BlTP3d_9800P3d_982000000030>o1X@000000000000D000000P3__9`3000000@0
llNQ0P0000070?FnTP8000000P3b`I/00`000000m<JM00000004000000040?BL?@000000lkfD0000
0080m;fB00P000000?BmTP3d_I8000000<jc_P000000m;b@00000080lkbB0`0000070?NmS0030000
003f^hX0m[^:0080000000<0lk^A0000000000000`3f_Hd00`000000n/:;00000005000000H0nKj7
00<000000?_1Q03k`H@00`3k`H@00`000000o<>50?c3Q@040?c3Q@030000003j`XT0n/:900<0n/:9
00<000000?VoR@3i_hT0103i_hT01`000000mLRN0000003f_Xl000000?G3V@0000000`3iaI400`00
0000n<BC0?S4T`020?S4T`<0000000<0n<:@0000000000000P3fbj400`000000nLND0?W7U0020?W7
U08000000P3i`8P01@000000YcT00000003i`hl0000000@0nKj600<000000?[5S`3jaHl00`3jaHl0
10000000n<NG0000000000020?C;Y0060000003h`Xh0n<:>0?S2SP000000n/681@0000020?W3T003
0000003ka8X0nlB:00<0nlB:00L000000?[4S0000000nl:60000003haI@000000080f=KF00<00000
0?[3S00000000P3k`hP010000000o<>60?c3QP3l`hH2000000030?_3R@000000nl2300<0nl2300H0
00000?W1RP3i`HX0nL6:0000003ka8P200000080n[n30P0000040?c1O`030000003gbYd000000080
0000103l`802000000040?o6M`000000nK^40?VkQ0<000000`3n`WX200000080o;ej00D000000?6g
S`000000o/1b000000020?fmM0050000003l_GH0o;ef0?bmMP000000103n`FL00`000000oKee0?fm
M@020?fmM@050000003l_GH0o;ef0?bmMP0000000P3UX8D010000000oKed0000000000040?fmMP80
00000P3k_Wh2000000D0o/=f00<000000?_9H@000000103n`W800`000000o/5d0?k1M0020?k1M005
0000003jd9X000000?C:X`0000000`3n`7800`000000oLb>00000002000000030?k8PP000000o/9b
00<0o/9b0P0000020?c7R@050000003ddjh000000000003cdjh00`0000020?oFS@80000000@0nl^B
0000003nb88000000`3n`6l00`000000o/5_0?k1K`02000000030?g5P`000000l]Jb0080000000<0
o>JQ0000000000000`3obG@00`000000o]6>0000000200000080o[m^0`0000020?joK`030000003o
aG@000000080o/5f0P0000030?k5J@040000003m_Fd0oKe]0?fmK@@000000P3k]ED00`000000o/E[
0?k5J`03000000<0o;MJ00@000000?bhG03l^5`000000`3l^5T010000000nK9;0?VbB`0000030?R/
A`030000003gZd@0mj]4008000000`3oool00`000000oooo0?ooo`0B0?ooo`006@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0:0?ooo`8000000P3/aJd2000000D0k/:T00@000000>o4YP3_a:H000000`3]aJX20000
00030>OB`@000000fMCD00<0000000@0klFW000000000000jLbg10000000103YckX000000000003a
a:82000000040?72W`000000jkfT0>^mY08000001P3a^YD010000000kKfR0000000000020>VmY`80
000000<0g[^d0000000000000`0000050?>lU@8000000P3a`Ih01P000000kl2Q0>o0X@3_`:400000
0?:mU@<000000P3b_IL00`000000lKjI0?6nV@030?6nV@050000003/`ZP000000?:lU00000000P3c
_9@00`000000m;bB0?BlTP020?BlTP030000003H_Kl0000000P0000000D0kkbL0000003eaI/0mLFK
000000040??7X@030000003e_Y80mKjB00D0mKjB0P0000000`3b`I/000000?C6W@020?C6W@@00000
00@0m9`m0000003c_I@000000P3d_I801P000000m;fB0?BmTP000000c[>n00000080m;b@00D00000
0?>lTP3c_980lkbB000000070?NmS0030000003f^hX0m[^:008000000P3c^i401@000000m[f=0?Jm
S@3f_Hd0000000D0n/:;0P0000060?VnQ`030000003k`H@0nl6400<0nl6400<000000?c3Q@3l`hD0
103l`hD00`000000n/:90?[2R@030?[2R@030000003i_hT0nKn900@0nKn90`0000020?JnS`030000
003e`iT0000000<0nLFA00H000000?S4T`3ha9<0n<BC0000003g_X`3000000030?RoRP000000m/^Q
008000000P3iai@010000000ml>D0?O3U00000020?W0R080000000<0nL>?0000003i_XH0103i_XH0
1@000000n/F?0?[5S`3jaHl000000080n<NG0`0000020?C;Y0040000003h`Xh0n<:>00000080n/68
0P0000000`3La/@000000?W3T0020?W3T0050000003ka8X0nlB:0?_4RP0000000`3ja8`500000080
f=KF0P0000030?_3R0030000003l`hH0o<>60080000000<0nl>90000003k`8<00`3k`8<01P000000
nL6:0?W1RP3i`HX000000?_4R08000000P3j_h<2000000@0o<5o0P0000000`3gbYd0000000000004
0?c0P080000000@0olIg0000003i^h@0nK^40`0000030?k2NP8000000P3l_GX00`000000lKN?0000
000200000080oKed00D000000?bmMP3l_GH0o;ef000000040?k1I`030000003m_GD0oKee0080oKee
00D000000?bmMP3l_GH0o;ef000000020>FPQ@030000003m_G@00000008000000`3m_GH200000080
nkin0P0000050?k3MP<00000103n`W800`000000o/5d0?k1M0020?k1M080000000@0T[C^0000003d
bZ<000000P3n`784000000040??C[P000000o/R2000000<0o/9b00<000000?k4M`0000000P3lahT4
000000030??C[P00000000000080omJ=0`0000000`3kbi800000000000030?k0K`030000003n`Fl0
o/5_0080000000@0oLF3000000000000olb20P0000020?cVX@80000000<0olUd0000003ndHh00`00
00020?joKP80000000H0o/1e0000003n_fl000000?o5M00000020?k1MPH000000`3m_Fd200000004
0>gaU`000000nkEE0?^eE@@000000P3n`VT010000000o;MJ0?bgFP0000020?bhG0050000003l^5T0
o;QI0?bhF@0000000P3i/T/01@000000n:a70?R/A`3h[4L000000080mj]40P0000030?ooo`030000
003oool0oooo0180oooo000J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo0P0000030>c5[@8000000`3^
`Z@500000080kLFZ1P0000000`3Ie=@00000000000020>o5Y`060000003Yc;L000000000003``j80
00000P3YckX300000080lL:O0P0000000`1_f?L000000?6jU@050?6jU@80000000<0kKfR00000000
00000P3Y_JL2000000050?2iU000000000000?V/C00000001P3c_9D200000080lL6N00@000000>o0
X@3_`:40kl2Q1@0000020?:mU`030000003a_YT0lKjI0080lKjI0P000000103h]W/000000?:lU000
00020?>lU0040000003d_980m;bB0?BlTP`00000103eaI/010000000llNQ0??7X@3caj42000000H0
mKjB100000040?C6W@D000000P3c_I@020000000m;fB0?BmTP000000m;fB0000003>/kh000000P3d
_9001@000000lkbB0?>lTP3c_980000000L0mkf<00<000000?JkRP3f^hX00P0000020?>kT@050000
003f_Hd0m[f=0?JmS@0000001P3j`X/00`000000nKj70?VnQ`040?VnQ`030000003k`H@0nl6400<0
nl6400<000000?c3Q@3l`hD0103l`hD00`000000n/:90?[2R@030?[2R@030000003i_hT0nKn900@0
nKn900<000000?VnR00000000P3f_Xl010000000mL>I0?G3V@0000020?W5T@80000000<0n<BC0000
003g_X`00P3g_X`200000080n;n:100000001@3iai@000000?O3U03g`i@0000000<0nL280`000005
0?VnQP8000000P3jaHl010000000n<NG0?S7U`3haiL3000000040?C;Y0000000n<:>000000@0n/68
0P0000000`3La/@000000?W3T0020?W3T0040000003ka8X0nlB:000000<0n/B<00<000000?_2QP00
00000`0000000`3He]H00000000000030?_3R0050000003l`hH0o<>60000003i`Xd00P0000050?_0
P`030000003i`HX0nL6:0080000000L0nlB8000000000000n[n30000003l`H00000000<0o<5o0P00
00000`3gbYd00000000000040?c0P080000000@0olIg0000003i^h@0nK^40`0000030?k2NP800000
0P3l_GX00`000000lKN?0000000200000080oKed00D000000?bmMP3l_GH0o;ef000000040?k1I`03
0000003m_GD0oKee0080oKee00D000000?bmMP3l_GH0o;ef000000020>FPQ@030000003m_G@00000
008000000`3m_GH3000000040?^nOP000000o/5e000000@0o/=f0`0000040?k2LP030000003n`G@0
o/5d0080o/5d0P000000102B]>h000000?C:X`0000020?k0LP<0000000<0mMbc0000000000000P3n
b8801P000000o/9b0?k2LP000000o/Ag000000<0o<N9100000000`3iiJd00000000000020?oFS@80
000000@0nl^B0000003nb88000000P3n`6l01@000000o/5_0?k1K`3n`Fl000000080oLF300@00000
0?o<PP3oc880olb20`0000000`3ochL00000000000020?kASP8000000P3n_fh2000000040?k0M@00
0000o[m_00000080olEd00@000000?k1MP00000000000P3m_W@2000000@0oKe]00<000000>gaU`00
00000P0000030?oIS@8000000P3n`VT00`000000o;MJ000000020?bhG0050000003l^5T0o;QI0?bh
F@0000000`3i/T/010000000n:a70?R/A`0000020?N[A0030000003cYCL0000000<0oooo00<00000
0?ooo`3oool04@3oool001/0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03P3oool3000000050:cFmP00000000000>k2Y00000000P3^
aj/2000000030>S=^P000000000000<0klBV0P0000000`3Wd/4000000=WDe003000000030>o5Y`00
0000jLbg00H0000000@0k/FZ0000003a`Yl0lL:O0P0000000`1_f?L000000?6jU@050?6jU@800000
00<0kKfR0000000000000P3Y_JL2000000060?2iU000000000000000003i[4`000001@3c_9D01@00
0000k[fN0000003a`Ih0000000<0kl2Q1@0000020?:mU`030000003a_YT0lKjI0080lKjI0P000000
103h]W/000000?:lU00000020?>lU0040000003d_980m;bB0?BlTP80000000<0f;fo000000000000
0`000000103d_90000000000000000050?G5V`<0000000<0lk^B0000003e_Y801@3e_Y84000000@0
m<JM10000000103dW3d000000?>mU00000020?BmTP030000003d_I80m;fB008000000P3d_9001000
0000lkbB0?>lTP3c_982000000H0mkf<00<000000?JkRP3f^hX00P0000020?>kT@8000000P3f_Hd0
0`000000n/:;0?[2R`040?[2R`030000003i_XL0nKj700@0nKj700<000000?_1Q03k`H@00`3k`H@0
0`000000o<>50?c3Q@040?c3Q@030000003j`XT0n/:900<0n/:900<000000?VoR@3i_hT0103i_hT0
0`000000nKj8000000030?JnS`050000003e`iT0mL>I0000003iaI400P0000000`3ha9<000000?Nn
S0020?NnS08000000`3h_hX00`000000eL7700000002000000<0ml>D00<000000?W0R03i`8P00`00
00050?VnQP050000003j_X@000000?[5S`000000103haiL010000000lknF0000003dbj@2000000@0
n/6800@000000?BoUP00000000000`3i`i0010000000nlB:0?_4RP0000040?[4S0@0000000@0nLB@
0000003He]H00000103k`hP010000000o<>60000003i`Xd2000000D0nl2300<000000?W1RP3i`HX0
0P0000001`3ka8P000000000003j_h<000000?c1P00000000`3l`Gl00`000000o<:0000000020000
00@0o<200P000000103oaWL000000?VkQ03i^h@2000000040?NjQ`000000o/9j0?k2NP8000000P3l
_GX01@000000lKN?0000003X/IT000000080oKed00D000000?bmMP3l_GH0o;ef000000040?k1I`03
0000003m_GD0oKee0080oKee00D000000?bmMP3l_GH0o;ef000000020>FPQ@030000003m_G@00000
00800000103m_GH2000000030?^nOP000000o/5e008000000`3n`gH3000000@0o/9b00<000000?k1
M03n`G@00P3n`G@03`000000o/5f0000002B]>h000000?C:X`000000o/1b0000003n`74000000?GL
/`000000lm>^000000020?k8PP030000003n`W8000000080o/Ag00<000000?c7R@3lahT010000002
0?WU[@H0000000<0nl^B0000000000000P3n`6l010000000o/5_0?k1K`3n`Fl2000000030?g5P`00
0000000000<0olb200@000000?o;OP000000oln70P0000001`3ndHh000000?73X0000000o[m^0000
003n`6@00P0000020?joK`040000003oaG@000000?k1MP8000000P3m_W@2000000@0oKe]1`000000
1@3ofHd000000?oFS`000000o/9Y00<000000P3l^5`01@000000o;QI0?bhF@3l^5T0000000<0nK9;
00D000000?R/A`000000o/5X000000020?N[A0800000103oool00`000000oooo0?ooo`0@0?ooo`00
703oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03`3oool200000080[=Kf0`0000030>k7Z`@00000103_a:H2000000040>OB`@000000fMCD0=WD
e0D0000000D0jLbg000000000000l<>R000000020>k5ZP80000000D0lL:O000000000000KmSg0000
00050?6jU@040000003b^Y8000000>fmXP<0000000@0kkjN0000003`^I@0l;VD0P0000000`3i[4`0
00000?>lU@040?>lU@030000003^_Ih0k[fN00<000000P3_`:42000000040>FdX`000000h[R/0000
0080l[fG00@000000?6nV@3a_YT0lKjI100000020?:lU0040000003c_9@0lkbD00000080m;bB00@0
00000?O2T@00000000000`3g`Y400`000000m;b@0?BlT002000000L0mLFK00@000000?>kTP3c^i80
00001@3e_Y8010000000m[j@0000000000050?C6W@80000000D0lKfI000000000000lkfD00000003
0?BmTP050000003d_I8000000<jc_P0000000P3d_9001@000000lkbB0000003f_hl0000000H0mkf<
00@000000?JkRP3f^hX0m[^:0P0000020?>kT@040000003f_Hd0m[f=000000D0n/:;0P0000060?Vn
Q`030000003k`H@0nl6400<0nl6400<000000?c3Q@3l`hD0103l`hD00`000000n/:90?[2R@030?[2
R@030000003i_hT0nKn900@0nKn900@000000?VnR03i_XP000000`3f_Xl00`000000mL>I0?G3V@02
000000030?S0S@000000000000@0mkj<00@000000?RoRP3h_hX0n;n:0`0000000`3d`IL000000?O3
U0030?O3U0030000003i`8P0000000<00000103i_XH00`000000n[j40?ZnQ002000000@0n<NG00@0
00000?>oUP000000m<^T0P0000040?[1R0050000003d_iH000000=c6a00000000`3i`i000`000000
nlB:000000040?[4S0L0000000<0f=KF0000003k`hP00`3k`hP200000080nL:=00<000000?_0P`3k
`8<00`3k`8<02P000000nL6:0?W1RP000000nl>60000003ka8P000000?ZoP`0000020?c1P0040000
003l`Gl0o<5o00000080o<:00P0000050?c0P0<000000P3i^h@2000000040?NjQ`00000000000?k2
NP8000000P3l_GX01@000000lKN?0000003X/IT000000080oKed00D000000?bmMP3l_GH0o;ef0000
00040?k1I`030000003m_GD0oKee0080oKee00D000000?bmMP3l_GH0o;ef000000020>FPQ@030000
003m_G@0000000800000103m_GH2000000060?^nOP000000o/5e0000003l_W/000000P3n`gH50000
0080o/9b00<000000?k1M03n`G@00P3n`G@02@000000o/5f0000002B]>h000000?C:X`000000o/1b
000000020?k0L@070000003eg;<000000000003nb88000000?kAS00200000080o/Ag00H000000?c7
R@3lahT0o<N90000003gi;8300000080nNF]100000001P3kbi8000000?k8PP000000o/1_000000<0
o/5_0P0000000`3maH<000000?oEQ@02000000060?o<PP000000ol]n0?o;OP000000oln70P000000
1P3ndHh000000000003n_fh000000?k0I08000000P3n_fl010000000olEd0000003n`GH200000080
oKid0P0000040?fmK@030000003i_U800000008000000P3n`f@2000000060?oFS`000000o/9Y0000
003n`6H000000P3l^5`01@000000o;QI0?bhF@3l^5T0000000<0nK9;0P0000030?k1J0050000003g
Zd@000000?>U=`0000000`3oool00`000000oooo0?ooo`0@0?ooo`00703oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0403oool3000000030:cF
mP000000000000D0k/N[100000040>o4YP@0000000L0fMCD0000003TcL4000000>c:/P000000g];<
0080000000<0l<>R0000003^aJX00P3^aJX00`000000lL:O0?72W`02000000@0lKZE00D000000?:j
TP3b^Y8000000>fmXP03000000040>nnWP000000l;VD0?2iU0D000001@3c_9D2000000030?FfQ@00
0000j[VQ0080000000<0mkV50000000000000`0000020?:mU`060000003a_YT0lKjI0?6nV@000000
lKbH0`0000001@3b_9@000000?>lU03c_9@000000080m;bB00<000000?O2T@3g`Y40103g`Y400`00
0000m;b@0?BlT002000000L0mLFK00@000000?>kTP3c^i8000001@3e_Y800`000000m[j@00000002
000000@0m<JM10000000103dW3d000000?>mU00000020?BmTP030000003d_I800000008000000P3d
_9001@000000lkbB0000003f_hl0000000H0mkf<00@000000?JkRP3f^hX0m[^:0P0000020?>kT@04
0000003f_Hd0m[f=000000D0n/:;00<000000?_VT00000001@3i_XL00`000000nl640?_1Q0030?_1
Q0030000003l`hD0o<>500@0o<>50P0000040?[2R@030000003i_hT0nKn900@0nKn900@000000?Vn
R03i_XP000000`3f_Xl00`000000mL>I0?G3V@0200000080n<2=00<000000?NnS03g_X`00`3g_X`0
2@000000n;n:0?RoRP3h_hX000000=G1a`000000m<6G000000030?O3U0040000003i`8P000000?Zo
Q`8000000`3i_XH00`000000n[j40?ZnQ0020?ZnQ0030000003haiL0n<NG00<0n<NG00<000000?>o
UP0000000P0000050?[1R0040000003d_iH00000000000@0nL>@0P0000050?[4S0D0000000<0n<^L
000000000000103k`hP200000080nL:=00<000000?_0P`3k`8<00`3k`8<2000000040?W1RP000000
nl>60?_3QP80000000D0n[n30000003l`H00o<60000000020?c1O`030000003l`X00o<:000800000
1@3l`80300000080nK^40P0000000`3g^XL000000?ZmO`03000000<0o;ej0P0000000`3X/IT00000
0?fmM0020?fmM0040000003l_GH0o;ef000000@0o/5W00<000000?fmM@3m_GD00P3m_GD01@000000
o;ef0?bmMP3l_GH000000080iJ2500<000000?fmM00000000P0000040?fmMP80000000/0nkin0000
003n`GD0o/5e0000003l_W/000000?k3MP000000000J000000020?k3L@<00000103n`G@00`000000
o/5f0?k1MP0200000080m<ZS0P0000020?k0L@030000003eg;<0mMbc00<000000P3ndH`01@000000
o/Ag0?k4M`3na7L000000080o<N90P0000020?OT/PH0000000<0oKme0000000000000P0000000`3n
`6l000000?k1K`020?k1K`80000000<0oLF30000003oeHD00P3oeHD200000080ol]n00D000000?o?
Q`00000000000?kASP020000000;0?joKP000000o/1T0000003n`7D000000?joK`000000olEd0000
003n`GH00P0000030?fnM08000000`3m_Fd00`000000nKiB0?VnDP02000000<0o/=T0P0000000`3o
eXl00000000000020?k0IP040000003l^5`0o;QL00000080o;QI00@000000?VbB`3i/T/0nK9;0P00
00030?k1J0<0000000<0ljDg0000003oool00`3oool00`000000oooo0?ooo`0?0?ooo`005`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0000000A0?ooo`<0000000@0[=Kf0000000000000000103^aj/4000000D0klBV
00H000000<;Ej0000000Y]Ch0000002;d_l4000000030=kBc0000000l<>R008000000P3^aJX20000
00030?72W`000000lKZE00<0lKZE00@000000?:jTP3b^Y80l[ZB100000020>nnWP030000003`^I@0
l;VD0080000000<0nJa<0000003c_9D0103c_9D2000000030?FfQ@000000j[VQ0080000000P0mkV5
000000000000iKBS0000003R^:`000000?:mU`80000000@0lKjI0000003a_9P0lKbH0`0000020?:l
U0050000003c_9@000000?BlTP0000001`3g`Y4010000000m;b@0?BlT03d_903000000D0mLFK00D0
00000?>kTP3c^i80lk^B000000030?FnTP070000003f_Y00m[j@0?JnT0000000ll2H000000040?C6
W@80000000D0lKfI000000000000lkfD000000020?BmTP030000003d_I800000008000000P3d_900
0`000000lkbB000000020?JoS`030000003g_H`0mkf<0080mkf<00<000000?JkRP3f^hX00P3f^hX2
00000080lk^A00@000000?JmS@3f_Hd000001@3j`X/00`000000nnJ@000000050?VnQ`030000003k
`H@0nl6400<0nl6400<000000?c3Q@3l`hD00`3l`hD2000000060?K7V`00000000000000003j`XT0
00001P3i_hT010000000nKj80?VnR00000040?JnS`8000000P3f`9800`000000n<2=000000050?Nn
S0040000003h_hX0n;n:0?RoRP<0000000<0m<6G0000003g`i@00`3g`i@200000080n[n700D00000
0?VnQP3i_XH0nKj6000000050?ZnQ0030000003haiL0n<NG0080n<NG00<000000?>oUP3c_iH00P00
00050?[1R0050000003d_iH000000=c6a00000000`3i`i02000000D0n/B<1@0000020?S;W0800000
0`3k`hP2000000<0nL:=00<000000?_0P`3k`8<00P3k`8<2000000030?W1RP000000nl>60080nl>6
0`0000030?c1P0030000003l`Gl0000000<0o<:00P0000040?c0P0030000003oaGD000000080nK^4
00@000000>6[W000000000000`3j_Gl010000000o;ej0?bmNP3l_GX2000000030>RaV@000000oKed
0080oKed00@000000?bmMP3l_GH00000103n`FL00`000000oKee0?fmM@020?fmM@050000003l_GH0
o;ef0?bmMP0000000P3UX8D00`000000oKed00000002000000@0oKef0P0000001@3k_Wh000000?k1
M@3n`GD000000080o;ik0P0000001`0001X000000?k3L@3n`g4000000?k5N@000000103n`G@01`00
0000o/5f0?k1MP000000T[C^0000003dbZ<00P0000030?k0L@030000003eg;<00000008000000`3n
dH`010000000o/Ag0?k4M`0000020?c7R@0;0000003nhI@000000000003gi;8000000?k3M@000000
W=km0000003m_gD01P0000030?k1K`@00000103oeHD010000000ol]n0?o;OP3obgh20000000<0?o8
NP00000000000000003n_fh000000?k0I0000000o/1e0000003n_fl000000P3oaG@3000000<0oKid
0P0000030?fmK@030000003i_U80nKiB008000000`3n`f@01@000000o/5[0000003oeXl000000080
o/1V00@000000?bhG03l^5`000000P3l^5T010000000nK9;0?VbB`3i/T/2000000<0o/5X00<00000
0?k1J@0000000P3cYCL00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo000G0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`07
0?ooo`800000503oool2000000030:cFmP0000000000008000000`3^aj/00`000000l<6P00000002
000000<0klBV1`0000001@2;d_l000000>c:/P000000g];<0080000000@0l<>R0000003^aJX0k/FZ
0`0000040?6jU@040000003b^Y80l[ZB0?:jTPD0000000@0kkjN0000003`^I@0l;VD0P0000000`3i
[4`00000000000040?>lU@8000000P3e]XD010000000j[VQ0000003g^HD2000000050>FdX`000000
00000000003b_IL00P0000000`3a_YT000000?6lV0020?6lV08000000P3b_9@00`000000lkbD0000
0002000000L0ml:A00H000000?BlT03d_900m;b@0000003a_IT2000000<0mLFK00<000000>JfXP00
00000P3c^i801@000000mKjB0?FnTP3e_Y80000000@0m[j@00@000000??0V000000000000P3daYd2
00000080lKfI0P0000000`3c_I@000000?BmTP03000000040>k9[@00000000000?BlT0<000000P3f
_hl00`000000mkf<0?NmS0020?NmS0030000003f^hX0m[^:0080m[^:0P0000030?>kT@8000001P3j
`X/00`000000nnJ@000000050?VnQ`030000003k`H@0nl6400<0nl6400<000000?c3Q@3l`hD00`3l
`hD01P000000m<>K0000003fai/000000?C1U`8000001@3i_hT00`000000nKj80?VnR0020?VnR004
0000003f_Xl0m[j?0?JnS`8000000P3f`98010000000n<2=0?S0S@0000040?NnS0030000003h_hX0
n;n:0080n;n:0P0000020?C1U`040000003g`i@0ml>D0?O3U08000000P3j_hL200000080nKj600<0
00000?ZnQ03j_X@00`3j_X@2000000<0n<NG00<000000?>oUP3c_iH00`0000040?[1R0030000003d
_iH0m;nF008000000`3i`i000`000000n/66000000040?[4S080000000@0nl650000000000000000
0P3hbi`200000080nl>800<000000?_4RP0000000P3i`Xd00`000000nl230?_0P`020?_0P`800000
00<0nL6:0000003k`hH00P3k`hH3000000<0o<6000<000000?c1O`000000103l`X000`000000o<20
0?c0P0020?c0P0050000003oaGD0olEe0000003i^h@00`000000103g^XL000000?ZmO`3j_Gl20000
0080o;ej0P0000000`3X/IT000000?fmM0020?fmM0040000003l_GH0o;ef000000@0o/5W00<00000
0?fmM@3m_GD00P3m_GD200000080o;ef00D000000>FPQ@3UX8D000000?fmM003000000@0oKef00@0
00000:J;^000000000000P3n`GD01`000000o;ik0?bnN`3l_W/0000000006P0000000P3n`g401000
0000o/Ei0?k5N@0000030?k1M0040000003n`GH0o/5f0?k1MP8000000P3dbZ<00`000000o/1a0?k0
L@020?k0L@040000003eg;<00000000000@0o]6<00<000000?k4M`3na7L00P0000040?kQU0040000
003cf;<000000?k3M@T000000`3n`Fl4000000@0omF50P0000020?o;OP8000000P3ob7X010000000
lL>P0000000000020?k0I080000000@0o[m_0000003oaG@0olEd0P000000102WUL<000000?fnM03m
_W@2000000<0oKe]00D000000?VnDP3i_U80nKiB000000030?k3I0040000003n`F/000000?oFS`80
00000P3n`6H00`000000o;QL000000030?bhF@050000003i/T/000000?k1J00000000`3n`FP01P00
0000o/5Y000000000000ljDg000000D0oooo00<000000?ooo`3oool03@3oool001P0oooo10000004
0?ooo`@000002P3oool00`000000oooo0?ooo`0D0?ooo`P0000000<0k/N[0000000000001P000003
0>o4YP0300000032eNP0000000@0000000<0k<Zb0000000000000P0000000`3``j8000000>k5ZP02
0>k5ZP8000000`3a^YD00`000000l[ZB0?:jTP020?:jTP@0000000<0kkjN0000003`^I@00P3`^I@4
000000@0lkbE0`000000103e]XD000000>ZiX@3Z^J43000000040>FdX`00000000000>:h[0800000
00<0mj=90000000000000`3a_9P01P000000jkbT0000003b_9@000000?>lU0<000001P3g`Y420000
00@0m;b@00@000000?6mV@00000000000P3eaI/00`000000i[JR000000030?>kTP040000003e_Y80
mKjB000000@0m[j@00H000000??0V03c`9P0ll2H0000003daYd3000000060?6mV@00000000000?>m
U0000000m;fB0`000000103^bJd000000000003d_903000000<0m[n?00D000000?NmS03g_H`0mkf<
000000050?JkRP040000003c^i40lk^A0?>kT@8000001P3j`X/00`000000nnJ@000000050?VnQ`03
0000003k`H@0nl6400<0nl6400<000000?c3Q@3l`hD00P3l`hD200000080m<>K0`0000020?C1U`03
0000003i_hT0nKn90080nKn900<000000?VnR03i_XP00P3i_XP00`000000m[j?0?JnS`020?JnS`07
0000003f`980m/2B0?K0TP000000n<2=000000050?NnS0040000003h_hX0n;n:0?RoRP<0000000<0
m<6G0000003g`i@00`3g`i@01@000000n[n70?ZoQ`3j_hL000000080nKj600<000000?ZnQ03j_X@0
103j_X@200000080n<NG0P000000103c_iH000000000000000040?[1R0030000003d_iH0m;nF00<0
00000P3i`i0010000000n/660?[1QP0000030?[4S0080000003idIh000000?_1Q@000000nLB@0000
003hbi`200000080nl>800<000000?_4RP0000000P3i`Xd00`000000nl230?_0P`020?_0P`040000
003k_h000000000000@0nl>60P0000040?c1P0800000103l`X000`000000o<200?c0P0020?c0P005
0000003oaGD0olEe0000003i^h@00`000000103g^XL000000?ZmO`3j_Gl200000080o;ej00<00000
0?6gS`0000000P0000020?fmM0040000003l_GH0o;ef000000@0o/5W00<000000?fmM@3m_GD00`3m
_GD010000000o;ef0?bmMP0000020>FPQ@030000003m_G@0000000800000103m_GH400000080o/5e
00L000000?bnN`3l_W/0o;ik0000000001X000000080o/=a00@000000?k5N@3naGT000000`3n`G@0
2@000000o/5f0?k1MP3n`GH0000009:dkP000000m<ZS000000040?k0L@80000000<0^<k[00000000
00000`3ndH`00`000000o/Ag0?k4M`02000000@0o^6D0`0000020?k3M@<000000P3n`V`3000000<0
o/5_00@000000?k0K@00000000000`3oeHD020000000o]>@0?kCT0000000ol]n0000003of8l00000
0P3ob7X300000080o/1T0P000000103n_fl000000?o5M03oaG@2000000040:NE``000000oKid0?fn
M08000000`3m_Fd01@000000nKiB0?VnDP3i_U80000000<0o/=T00<000000?k1J`3n`F/00P000000
0`3od8P000000?k0IP03000000<0o;QI00D000000?VbB`000000o/5X000000030?k1J0050000003n
`FT0o/5Y0000003cYCL00P0000040?ooo`030000003oool0oooo00d0oooo000^0?ooo`030000003o
ool0oooo01D0oooo100000020>o2X`<000000P3]`ZH01@000000l<6P0000003WbkT0000000@0klBV
400000000`3^aZ/000000?6jU@020?6jU@030000003b^Y80l[ZB0080l[ZB0`0000000`3^^9P00000
000000030?2iU0D000000`3c_9D00`000000m;jC0?BnT`0200000080j[VQ100000000`3c`9T00000
0>:h[002000000030?NSB@000000000000@0lKbH0P0000020?:lU080000000@0V<;d0000003g`Y40
ml:A100000000`3e`iT000000?BlT0030?BlT0030000003a_IT0000000@0000000<0i[JR0000003c
^i800`3c^i800`000000mKjB000000050?JnT0040000003c`9P0ll2H0??0V0@000000P3a_IT01`00
0000lkfD0000003d_I8000000?BmTP0000000P3^bJd00`000000m;b@00000002000000<0m[n?00D0
00000?NmS03g_H`0mkf<000000050?JkRP8000000P3c^i42000000H0n/:;0P0000000`3of8/00000
0?VnQ`030?VnQ`030000003k`H@0nl6400<0nl6400H000000?c3Q@3l`hD0o<>50000003g`Y820000
00<0m<>K00@000000?C1U`3d`IL00000103i_hT00`000000nKj80?VnR0020?VnR0030000003f_Xl0
m[j?0080m[j?00L000000?K0TP3f`980m/2B0000003h`8d0000000D0mkj<00@000000?RoRP3h_hX0
n;n:0`0000020?C1U`040000003g`i@0ml>D0?O3U08000000P3j_hL010000000nKj60?VnQP000006
0?ZnQ08000000P3haiL300000080nLVF0P0000030?[1R080000000H0m;nF00000000000000000?W3
T00000040?[1QP040000003ja8`0n/B<00000080nM6N00H000000?_1Q@000000nLB@0000003hbi`2
000000050?_3R0000000nlB:0?_4RP0000000P3i`Xd010000000nl230?_0P`0000020?^oP0800000
103k`hH2000000@0o<600P0000040?c2P0030000003l`800o<200080o<2000D000000?o5M@3oaGD0
00000?VkQ003000000040?NjQ`000000n[eo0?ZmO`8000000P3l_GX00`000000lKN?000000020000
0080oKed00@000000?bmMP3l_GH00000103n`FL00`000000oKee0?fmM@030?fmM@040000003l_GH0
o;ef00000080iJ250P000000103m_G@000000000000000030?fmMP@000000P3n`GD01`000000o;ik
0?bnN`3l_W/0000000006P0000000P3n`g401@000000o/Ei0?k5N@3naGT000000080o/5d00<00000
0?k1MP3n`GH00P3n`GH2000000030?C:X`000000000000<0o/1a0P0000000`2hc^/000000?c:S@02
000000040?kAS000000000000?k4M`800000103nhI@2000000030??H/`000000o/=e00<000000`3n
`V`2000000<0o/5_00<000000?k0K@0000000P0000020?oEQ@060000003ndi00o]>@0000003obgh0
00000P3of8l00`000000olQj0000000200000080o/1T100000020?o5M080000000<0YiG30000003m
_W@00P3m_W@01@000000oKe]0?fmK@3m_Fd0000000<0nKiB00D000000?k3I03n`f@0o/=T00000003
0?k1J`040000003od8P000000?k0IP<000000`3l^5T200000080o/5X00D000000?k1J03n`FP0o/5X
000000020?k1J@@000000`3oool3000000h0oooo000^0?ooo`030000003oool0oooo01H0oooo1000
00020>o2X`0300000038dN4000000080kL:V0`0000000`3WbkT000000>o4YP030>o4YPP0000000D0
l<6P00000000000000000?33X`02000000030>k6Z`000000lKZE0080lKZE00<000000?:jTP3b^Y80
0`3b^Y8200000080k[RH00<000000?2iU03`^I@00P3`^I@010000000nJa<0000000000030?>lU@05
0000003d_Y<0m;jC0?BnT`0000000P3Z^J4010000000j;VS0000000000020??0V@030000003R^:`0
00000080mj=900<000000?6lV03a_9P00P3a_9P200000080l[bD0P0000000`2H`_@0000000000003
000000050?6kUP000000mL>I0?G3V@000000103d_90020000000lKfI000000000000HIkb0000003V
]Z800000103c^i800`000000mKjB000000050?JnT0030000003c`9P0ll2H0080ll2H00D000000?G4
V@00000000000?6mV@05000000090?BmTP000000k/V]0>k9[@000000m;b@0000003g_Xd0000000<0
m[n?00D000000?NmS03g_H`0mkf<000000050?JkRP8000000P3c^i42000000H0n/:;0P0000000`3o
f8/000000?VnQ`030?VnQ`030000003k`H@0nl6400<0nl6400P000000?c3Q@3l`hD000000?NoS`00
0000ml:B000000<0m<>K0P0000020?C1U`050000003i_hT0nKn90?VoR@0000001@3i_XP010000000
m[j?0?JnS`3f_Xl2000000<0m/2B00<000000?S0S@000000103g_X`200000080n;n:1P0000030?O3
U08000000`3j_hL00`000000nKj6000000060?ZnQ0<0000000@0n<NG00000000000000000P3ibIH2
000000<0n/680P0000000`3d_iH000000?RoRP03000000@0n/6600@000000?[4S03ja8`000000P3i
dIh020000000nl650000003ia90000000?S;W0000000m<^U0P0000020?_4RP040000003i`Xd0nL:=
00000080nl2300D000000?^oP03k_h00nkn0000000050?_3QP030000003l`H00o<600080o<600P00
00050?c2P0050000003l`800o<200?c0P00000000P3oaGD00`000000nK^400000002000000040?Nj
Q`000000n[eo0?ZmO`8000000P3l_GX00`000000lKN?0000000200000080oKed00@000000?bmMP3l
_GH00000103n`FL00`000000oKee0?fmM@030?fmM@040000003l_GH0o;ef00000080iJ250P000000
103m_G@000000000000000030?fmMP@000000P3n`GD01P000000o;ik0?bnN`3l_W/0000000006P<0
000000D0o;ml0000003naGT0o/Ei000000020?k1M0030000003n`GH0o/5f0080o/5f00D0000009:d
kP000000m]Z_000000030?k0L@060000003n_g4000000;S>j`000000o<Z=0`0000000`3ndHl00000
000000060000000308S>oP000000lmRc00@000000`3n`V`300000080o/5_00@000000?k0K@3n`6d0
o/1]100000030?kCT08000000P3of8l00`000000olQj00000002000000030?k0I0000000000000<0
00000`3oaG@00`000000YiG3000000030?fnM0050000003m_Fd0oKe]0?fmK@0000000`3i_U801@00
0000o/=T0?k3I03n`f@0000000<0o/5[0P0000001@3od8P000000000003m_f80000000<0o;QI0`00
00000`3n`FP000000?k1J0020?k1J0030000003n`FT0o/5Y00L000000P3oool00`000000oooo0?oo
o`0<0?ooo`00;P3oool00`000000oooo0?ooo`0H0?ooo`@0000000@0kl:S00000038dN4000000`3]
`ZH4000000D0klBV0P0000020?31W`<0000000<0l<6P0000000000001@0000030?6jU@030000003b
^Y80l[ZB00<0l[ZB0P0000020>jhV0030000003`^I@0l;VD0080l;VD1@0000020?>lU@030000003d
_Y<0m;jC0080m;jC00@000000>ZiX@000000j;VS0P0000020??0V@060000003R^:`000000000003g
XdT000001@3a_9P01`000000l[bD0?:lU03b_9@0000009S2m00000000P3c_982000000050?6kUP00
0000mL>I0?G3V@000000103d_90010000000lKfI0000003`_I/200000080i[JR00<000000?>kTP3c
^i800P3c^i82000000H0m[j@00@000000??0V03c`9P0ll2H100000020?6mV@@000000P3d_I800`00
0000k/V]0>k9[@02000000030?NnS@000000m[n?00<0m[n?00@000000?NmS03g_H`000001@3f^hX2
000000<0lk^A00@000000?[2R`3j`X/0n/:;100000000`3of8/00000000000040?VnQ`030000003k
`H@0nl6400<0nl6400L000000?c3Q@3l`hD000000?NoS`000000ml:B008000000P3d`i/200000003
0?C1U`000000000000<0nKn900<000000?VnR03i_XP00`3i_XP010000000m[j?0?JnS`3f_Xl20000
00<0m/2B00<000000?S0S@000000103g_X`200000080n;n:1@0000001`3f`Y<000000?O3U03g`i@0
00000?K4U`0000000P3j_hL00`000000nKj6000000060?ZnQ080000000<0kLJ/0000000000000P00
00030?W9UP8000000P3j`HP300000080n;n:0`0000050?[1QP030000003ja8`0000000<0nM6N00H0
00000?_1Q@000000nLB@0000003hbi`300000080nlB:00@000000?W2S@3i`Xd000000P3k`8<01@00
0000nkn00?^oP03k_h00000000D0nl>600<000000?c1P03l`H000P3l`H000`000000o<J700000004
0?c2P0050000003l`800o<200?c0P00000000P3oaGD00`000000nK^400000002000000040?NjQ`00
0000n[eo0?ZmO`8000000P3l_GX01@000000lKN?0000003X/IT000000080oKed00@000000?bmMP3l
_GH00000103n`FL00`000000oKee0?fmM@030?fmM@040000003l_GH0o;ef00000080iJ250P000000
103m_G@000000000000000030?fmMP@000000`3n`GD01`000000o;ik0?bnN`000000000J00000035
OH400P0000001`3l_g`000000000003naGT000000?k1M00000001@3n`GH200000080m]Z_00P00000
0?k0L@3n`74000000?joL@000000^<k[00000080o<Z=0P0000020?kAS`050000003na7@0o/Ad0?k4
M00000000P3oaWL00`000000R<kn00000002000000040?k1L@000000o/9/0?k2K080000000D0o=6F
0000003n`Fl0o/5_000000040?k0K@040000003n`FX0o/5Z000000<0o]>@00@000000?oHS`3of8l0
omR?1@0000000`3nc8T0000000000002000000<0olEd00<000000:NE``0000000`3m_W@01@000000
oKe]0?fmK@3m_Fd0000000<0nKiB00D000000?k3I03n`f@0o/=T000000030?k1J`8000000P3od8P2
000000090?o9L000000000000?bhF@000000olQa0000003n`FP0000000<0o/5X00<000000?k1J@3n
`FT01@0000040?ooo`030000003oool0oooo00`0oooo000^0?ooo`030000003oool0oooo01X0oooo
0`000000103_`Z<000000000000000040>g2YP@000000`3_a:H4000000030?31W`000000000000@0
000000<0i/fn0000003``j<00P0000020?6jU@030000003b^Y80l[ZB00@0l[ZB0P0000020>jhV003
0000003`^I@0l;VD0080l;VD100000000`3c_9D000000?BnT`040?BnT`030000003Z^J40j[VQ0080
000000L0kKRJ0000003c`9T0ll2I0000003__Id000000080mj=900<000000?6lV03a_9P00P3a_9P2
000000030?:lU000000000000080V<;d0P0000000`3eY6000000000000030?G3V@030000003d_900
m;b@00<0m;b@0P0000020?2mV`80000000<0i[JR0000003c^i800`3c^i82000000H0m[j@00D00000
0??0V03c`9P0ll2H000000020?K3U`030000003a_IT000000080000000D0mKfA0000003d_I80m;fB
000000020>k9[@8000000P3g_Xd01@000000m[n?0?JoS`3f_hl000000080mkf<00<000000?JkRP3f
^hX0103f^hX010000000lk^A0?>kT@3c^i44000000<0mlFG00@000000?oHR`0000000000103i_XL0
0`000000nl640?_1Q0030?_1Q0030000003l`hD0000000<0mkn?00<000000?O2TP0000000P000002
0?;;Z080000000D0nLFB0000003i_hT0nKn9000000050?VnR0070000003f_Xl0m[j?0?JnS`000000
ml6?000000030?K0TP800000103g_X`200000080n;n:00<000000?[1R00000000P000000103f`Y<0
00000?O3U00000020?K4U`060000003j_hL0n[n70000003i_XH000001P3j_X@010000000nkn30000
003]aZ`3000000@0nLVF00<000000?[1R03j`HP00`0000030?RoRP8000001@3j`HH3000000@0nM6N
0`0000000`3ia900000000000002000000<0nlB:00H000000?W2S@3i`Xd000000?_0P`0000030?^o
P0030000003k`hH0nl>600<0nl>60P0000030?c1P0040000003laXL0o<J7000000<0o<:000D00000
0?c0P03l`800o<20000000020?o5M@030000003i^h@000000080000000@0mkZ70000003j_Gl0n[eo
0P0000020?bmNP050000003a]hl000000>RaV@0000000P3m_G@010000000o;ef0?bmMP0000040?k1
I`030000003m_GD0oKee00<0oKee00H000000?bmMP3l_GH0o;ef0000003UX8D2000000040?fmM000
00000000000000<0oKef100000030?k1M@030000003l_W/0o;ik008000000P35OH42000000<0o;ml
100000050?k1MP<000000P3ffZl00`000000o/1a000000020?joL@040000002hc^/000000?c:S@<0
00000P3ndHl010000000o/Ad0?k4M00000030?o6M`0500000028c_h000000000003n`G401P000000
103ldIH000000?k1K`0000040?k0K@050000003n`FX0o/5Z0?k1JP0000000P3ndi03000000030?oH
S`000000000000@0000000@0o/b900000000000000000`3oaG@00`000000YiG3000000030?fnM005
0000003m_Fd0oKe]0?fmK@0000000`3i_U801@000000o/=T0?k3I03n`f@0000000<0o/5[00D00000
0=K@E@000000om28000000020?o9L0030000003kbV4000000080000000<0olQa0000000000000`3n
`FP00`000000o/5Y0?k1J@02000000040?k4O0000000001=000000<0oooo00<000000?ooo`3oool0
303oool002h0oooo00<000000?ooo`3oool06`3oool300000080kl:S0P0000030>g2YPD0000000@0
klBV0000003Oe<d0gmC=0`0000000`3``Il000000000000800000080lKZE00<000000?:jTP3b^Y80
103b^Y8200000080k[RH00<000000?2iU03`^I@00P3`^I@6000000D0m;jC00X000000>ZiX@3Z^J40
00000>RiX`000000kKRJ0000003c`9T000000P3__Id00`000000mj=9000000050?6lV0060000003b
_9@000000?:jT@000000V<;d0P0000020?FTH0030000003e`iT0mL>I0080mL>I00<000000?BlT03d
_9000P3d_9000`000000lKfI00000003000000030>JfXP000000lk^B00@0lk^B00<000000?JnT03f
_Y00103f_Y0200000080ll2H00<000000?K3U`3f`iL00`000000103j[Ul000000?FmT@0000030?Bm
TP040000003^bJd0000000000080mkj=00D000000?JoS`3f_hl0m[n?000000020?NmS0030000003f
^hX0m[^:00@0m[^:00L000000?>kT@3c^i40lk^A0000003h`H`0000000@0mlFG0P0000020300C004
0000003i_XL0nKj7000000H0nl640P0000040?NoS`D000000P3bbjP200000080nLFB00<000000?Vo
R@0000001@3i_XP01`000000m[j?0?JnS`3f_Xl000000?O1S`0000000`3f`9800`000000n<2=0000
00030?NnS0060000003h_HP000000?RoRP000000n/680`000000103f`Y<000000000000000030?K4
U`050000003j_hL000000?VnQP0000001P3j_X@020000000nkn3000000000000lLZY0000003h_8H0
00000`3ibIH2000000040?[1R0000000nKb5000000<0n;n:00<000000?W3SP000000103j`HH00`00
0000n/66000000040?WAWP<0000000<0nLB@0000000000000`0000020?_4RP060000003i`Xd0nL:=
0000003k`8<00000103k_h000`000000nl>60?_3QP020?_3QP8000000`3l`H001@000000o<J70?c6
Q`3laXL000000080o<:00P0000020?c0P0050000003oaGD0olEe0000003i^h@00`0000000`3g^XL0
00000?ZmO`020?ZmO`040000003l_GX0o;ej0?bmNP80000000D0j;6I0000003m_G@0oKed00000002
0?bmMP030000003n`FL0o/5W0080o/5W00<000000?fmM@3m_GD00`3m_GD01P000000o;ef0?bmMP3l
_GH000000>FPQ@80000000@0oKed00000000000000000`3m_GH2000000030:J;^0000000o/5e0080
o/5e00<000000?bnN`3l_W/00P0000001035OH4000000000000000040?boO0<000001@3n`GH01000
0000o/5c0000000000020?KJ[`8000000`3n_g42000000030?c:S@000000o]>=00<0000000@0o]6?
0000000000000000103oaWL5000000040?k1L@00000000000>CRd@<0000000<0o/5_0000003n`6d0
0`3n`6d010000000o/5Z0?k1JP3n`FX3000000<0omJ<0P0000000`3ndY4000000000000200000004
0?k<R@000000o/9d000000<0olEd00@000000:NE``2WUL<000000P3m_W@200000080oKe]00D00000
0?VnDP3i_U80nKiB000000030?k3I0050000003n`F/0o/5[0?k1J`0000000P3Fd5D200000080olU`
0P0000020?o7L`@000000`3n`FP01`000000o/5Y0?k1J@000000o/=]0000003na7`00P0000030?oo
o`030000003oool0oooo00`0oooo000]0?ooo`@00000703oool7000000040>g2YP000000kl>T0>o3
Y080000000<0j<^h0000000000000`3Oe<d300000080l<6O0`0000001@3``J0000000000003VcKh0
00000080lKZE00<000000?:jTP3b^Y80103b^Y8200000080k[RH00<000000?2iU03`^I@00`3`^I@5
000000H0m;jC00H000000>ZiX@000000j;VS0000003]^9X3000000<0kkfM00<000000?NSB@000000
103a_9P010000000l[bD0000003b^Y4400000080mJAP00<000000?G3V@3e`iT00P3e`iT00`000000
m;b@0?BlT0020?BlT0@0000000@0l[^D0000003V]Z8000001@3c^i82000000D0m[j@0P0000000`3c
`9P000000?K3U`030?K3U`80000000@0nZiO0000003e_I400000103d_I83000000<0mkj=00L00000
0?JoS`3f_hl0m[n?0000003g_H`0000000H0m[^:00D000000?>kT@3c^i40lk^A000000020?S1S006
0000003gaIL0mlFG0000003of8/000000P0`04`010000000nKj70?VnQ`0000060?_1Q0800000103g
_hl00`000000ml2>00000002000000<0l/^X00H000000?W5TP3iaI8000000?VoR@0000060?VnR004
0000003f_Xl0m[j?00000080ml6?00@000000?K0TP3f`980m/2B0P0000030?NnS0050000003h_HP0
00000?RoRP0000000P3j`HP200000080m/:C0P0000030?K4U`030000003j_hL0n[n7008000001P3j
_X@01P000000nkn30?^oP`000000lLZY00000080n;b600T000000?W9UP3ibIH0nLVF0000003j`HP0
00000?VlQ@000000103h_hX2000000@0n/6600@000000?[1QP3j`HH00000103idIh01@000000n/::
000000000000n/>;00<000000P3ka8X010000000nL:=0000003icY/2000000@0nkn000<000000?_3
QP3k`hH00P3k`hH00`000000nkn2000000020?c1P0050000003laXL0o<J70?c6Q`0000000P3l`X02
00000080o<2000D000000?o5M@3oaGD000000?VkQ002000000030>6[W0000000000000<0n[eo0P00
00020?bmNP80000000D0j;6I0000003m_G@0oKed000000020?bmMP030000003n`FL0o/5W0080o/5W
00<000000?fmM@3m_GD00`3m_GD01P000000o;ef0?bmMP3l_GH000000>FPQ@80000000@0oKed0000
0000000000000`3m_GH010000000oKia0000000000030?k1M@030000003l_W/0o;ik0080000000@0
aGf10000000000000000103l_g`00`000000o<5o000000050?k1MP040000003n`G<0000000000080
m]Z_0P0000040?joL@<000000`3ndhd3000000030?oARP000000olIg00<0olIg0`000000103`gK`0
00000?k1L@3n`G42000000030>CRd@000000000000800000103n`6d01P000000o/5Z0?k1JP3n`FX0
00000?k1J`8000000`3oeX`4000000060?k3LP00000000000000003n`W@000000`3oaG@200000004
0:NE``000000oKid0?fnM08000000P3m_Fd01@000000nKiB0?VnDP3i_U80000000<0o/=T00D00000
0?k1J`3n`F/0o/5[000000020=K@E@8000000P3obG03000000040?o7L`000000olMf0?o7MP800000
0P3n`FP02P000000o/5Y0?k1J@000000o/=]0000003na7`000000000C@0000020?ooo`030000003o
ool0oooo00`0oooo000]0?ooo`030000003oool0oooo01l0oooo0`000000103_`Z<0000000000000
00030>o3Y0@00000103Oe<d00`000000jl:[0000000900000080lKZE00<000000?:jTP3b^Y801@3b
^Y8010000000k[RH0>jhV00000050?2iU0<0000000<0f;>d0000003d_Y<01@3d_Y<00`000000j[VQ
0>ZiX@0200000080kKRJ00<000000??0V@0000000P3__Id00`000000mj=9000000050?6lV0800000
00<0l[ZA0000003K/Zh00P0000030?FTH08000000P3e`iT00`000000m;b@0?BlT0020?BlT0@00000
00@0l[^D0000003V]Z8000001@3c^i82000000D0m[j@00@000000?G0U@0000000000103f`iL20000
0080nZiO00<000000?FmT@000000103d_I82000000<0mkj=00L000000?JoS`3f_hl0m[n?0000003g
_H`0000000H0m[^:0P0000020?>kT@060000003h`H`0n<6<0?S1S0000000mlFG0P0000020300C080
00000P3i_XL00`000000nl640?_1Q0040?_1Q08000000`3g_hl010000000ml2>0?O0SP3g`8h30000
00<0l/^X0P0000000`3iaI800000000000060?VnR0030000003f_Xl0000000<0ml6?00@000000?K0
TP3f`980m/2B0P0000030?NnS0050000003h_HP000000?RoRP0000000P3j`HP010000000nJaO0000
003f`Y<2000000@0m/BG00@000000?ZoQ`00000000001P3j_X@010000000nkn30?^oP`3k_h<20000
00<0n;b600<000000?W9UP3ibIH00`0000000`3i_8D000000?RoRP030?RoRP030000003i`hh00000
00<0n/6600@000000?[1QP3j`HH0n/660P0000020?WAWP@0000000<0n/>;0000003gbY`00P000002
0?_4RP80000000<0nLjK0000000000001@3k_h0010000000nl>60?_3QP0000020?^oPP040000003l
`H00o<60000000@0o<J700@000000?c2P000000000000P3l`80010000000olEe0?o5M@3oaGD30000
00040>6[W0000000mkZ700000080n[eo0P0000020?bmNP80000000D0j;6I0000003m_G@0oKed0000
00020?bmMP030000003n`FL0o/5W0080o/5W00<000000?fmM@3m_GD00`3m_GD01P000000o;ef0?bm
MP3l_GH000000>FPQ@80000000@0oKed00000000000000000`3m_GH010000000oKia000000000003
0?k1M@030000003l_W/0o;ik0080000000D0aGf1000000000000oLb=000000030?boO0030000003l
`Gl0000000D0o/5f00<000000?k1L`3n`G<00P0000020?KJ[`030000003n_g40o[ma0080o[ma0`00
00040?kCS@8000000P3odHX200000080olIg00<000000?o6N@0000000P0000020?k1L@<0000000@0
nLVE0000000000000000103n`6d01@000000o/5Z0?k1JP3n`FX0000000<0o/5[0P0000000`3oeX`0
000003^gkP02000000070?k3LP00000000000?k<R@000000o/9d000000020?o5M080000000@0YiG3
0000003m_W@0oKid0P0000020?fmK@050000003i_U80nKiB0?VnDP0000000`3n`f@01@000000o/5[
0?k1J`3n`F/0000000<0e]1E10000000103QLRP000000?o7L`0000030?o7MP80000000D0o/5X0000
003n`FT0o/5Y000000020?k3K@040000003na7`0000000000080oooo00<000000?ooo`3oool0303o
ool002d0oooo00<000000?ooo`3oool0803oool6000000D0kl>T100000030=oDc@050000003[`Z/0
jl:[0000003a`Yl0200000070?:jTP8000000P3^^9P00`000000l;VD0?2iU0030?2iU0@0000000<0
kLV`0000003d_Y<0103d_Y<00`000000j[VQ0>ZiX@0200000080kKRJ0`0000030>nmW@<00000103a
_9P2000000030?:jT@000000fk:^008000001@3eY60010000000mL>I0?G3V@0000030?BlT0040000
003d_Y<0000000000080l[^D00<000000>JfXP000000103c^i800`000000m[n@000000040?JnT004
0000003e`9D00000000000D0m/>G00H000000?Z^G`3j[Ul000000?FmT@0000040?BmTP800000103g
_Xd00`000000m[n?0?JoS`03000000L0m[^:00@000000?>kT@3c^i400000103h`H`300000080<01<
0`0000000`3i_XL000000?_1Q0040?_1Q0@000000P3g_hl01@000000ml2>0?O0SP3g`8h000000080
ml6A00@000000?;;Z03bbjP0l/^X100000060?VnR0030000003f_Xl0000000<0ml6?00@000000?K0
TP3f`980m/2B0P0000020?NnS0040000003h_HP0n;f80?RmR08000000`3j`HP2000000040?K2T`00
00000000000000<0m/BG00@000000?ZoQ`00000000001P3j_X@010000000nkn30?^oP`3k_h<20000
00@0n;b600<000000?W9UP0000000P0000020?VlQ@030000003h_hX0n;n:0080n;n:0P0000030?[1
QP030000003j`HH0n/660080n/660`000000103j/FX000000?[2RP0000020?[3R`<000000P3ka8X2
000000030?W>V`000000000000D0nkn000@000000?_3QP3k`hH000000`3k_h800`000000o<600000
00050?c6Q`<000000P3l`80010000000olEe0?o5M@3oaGD3000000040>6[W0000000mkZ700000080
n[eo0P0000020?bmNP80000000<0j;6I0000003m_G@00P3m_G@00`000000o;ef000000040?k1I`80
0000103m_GD200000080o;ef00D000000>FPQ@00000000000?fmM003000000<0oKef00@000000?fn
L@00000000000`3n`GD00`000000o;ik0?bnN`02000000050<EmP@00000000000?g<S@0000000`3l
_g`2000000030?c1O`000000o/5f00<0o/5f00@000000?k1L`3n`G<0o/5c100000040?joL@<00000
103ndhd300000080om6:100000002P3oaWT000000000003`gK`000000?k1L@000000o/5`0000003i
bID3000000@0o/1]00D000000?k1JP3n`FX0o/5Z000000030?k1J`050000003n`FX000000000000k
]nh00`0000001P3n`g800000000000000000o/9d00000080olEd0P000000102WUL<000000?fnM03m
_W@200000080oKe]00D000000?VnDP3i_U80nKiB000000030?k3I0050000003n`F/0o/5[0?k1J`00
00000P3Fd5D5000000040>5b:00000000000000000<0olMf0P0000000`3n`FP000000?k1J@020?k1
J@040000003n`fd000000?k4O08000000P3oool00`000000oooo0?ooo`0<0?ooo`00;@3oool00`00
0000oooo0?ooo`0R0?ooo`<0000000<0kl:S000000000000103_`j@500000080gmC=00<000000>_2
Z`0000002@0000070?:jTP8000000P3^^9P00`000000l;VD0?2iU0030?2iU0@000000P3]bK000`00
0000m;jC0?BnT`020?BnT`80000000<0j[VQ0000000000000P3]^9X400000080kkfM0`0000040?6l
V08000000P3b^Y400`000000]KSK00000002000000@0mJAP0`0000030?BlT0040000003d_Y<00000
00000080l[^D00<000000>JfXP000000103c^i8010000000m[n@0?JoT00000030?JnT0040000003e
`9D0mL2E000000D0m/>G0P000000103j[Ul000000?FmT@0000050?BmTP030000003g_Xd0mkj=0080
mkj=00<000000?JoS`3f_hl00`0000060?JkRP8000000P3c^i400`000000n<6<0?S1S0030?S1S004
0000000`04`0<01<0300C0<0000000<0nKj70000003k`H@0103k`H@010000000mLFK000000000002
0?NoS`030000003g`8h0ml2>0080ml2>00@000000?O1T@3g`I4000000P3bbjP4000000L0nKj80P00
00040?O1S`030000003f`980m/2B00<0000000<0mkj<0000003h_HP00P3h_HP2000000@0n/680P00
00000`3f`Y<00000000000040?K4U`<000001@3j_X@00`000000nkn30?^oP`030?^oP`030000003h
_8H0n;b60080n;b60`0000001@3i_XH000000?VlQ@3i_8D0000000@0n;n:0`0000020?[1QP030000
003j`HH0n/660080n/66100000000`3j/FX00000000000030?[3R`<0000000<0nlB:000000000000
0P3icY/00`000000nkn00?^oP0030?^oP080000000<0nl>60000003k_h800`3k_h82000000D0o<J7
0P000000103k_gl000000?c0P00000030?o5M@80000000D0n[I@000000000000mkZ7000000020?Zm
O`8000000P3l_GX010000000lKN?0000000000030?fmM0030000003l_GH0000000<0o/5W0`000004
0?fmM@8000000P3l_GH2000000030?joLP000000000000<000000`3m_GH01@000000oKia0?fnL@3m
_W40000000<0o/5e00D000000?bnN`00000000000<EmP@02000000030?g<S@000000o;ml0080o;ml
0P0000000`3l`Gl000000?k1MP030?k1MP040000003n`G<0o/5c0?k1L`<0000000<0nJe<0000003n
_g400P3n_g4010000000o/1^0000000000020?kCS@040000003ocHD0olf50?o=Q@<000000P3nchT0
0`000000olIi00000002000000030?3M_000000000000080o/5`00<000000?W9U@0000000P000003
0?k0K@050000003n`FX0o/5Z0?k1JP0000000`3n`F/010000000o/5Z0?k1JP3n`FX800000080o/9d
00H000000?o5M000000000000:NE``0000020?fnM08000000P3m_Fd01@000000nKiB0?VnDP3i_U80
000000<0o/=T00D000000?k1J`3n`F/0o/5[000000020=K@E@8000000P3oc7@3000000030?o;O@00
0000olMf0080olMf100000030?k1J@030000003n`fd000000080o/Al0P0000020?ooo`030000003o
ool0oooo00/0oooo000]0?ooo`030000003oool0oooo02<0oooo0`0000000`3_`Z<0000000000004
0>o3Y0H0000000<0gmC=0000000000000P3_a:H00`000000lL:O00000004000000L0l[ZB00<00000
0?7CHP0000000P3^^9P00`000000l;VD0?2iU0020?2iU0030000003mdI400000008000000P3]bK02
00000080m;jC0P0000020>ZiX@8000000P3]^9X3000000<0kkfM0P0000040?6lV08000000P3b^Y40
10000000]KSK0000003c_I@2000000<0mJAP100000020?BlT0090000003d_Y<000000?>lT`000000
l[^D0000003V]Z80000000<0lk^B00D000000?JoT03f_i00m[n@000000020?JnT0030000003e`9D0
mL2E0080mL2E0P0000040?K3U`060000003j[Ul0nZiO0000003e_I400000103d_I82000000@0mkj=
00<000000?JoS`0000000P0000060?JkRP8000000P3c^i400`000000n<6<0?S1S0030?S1S0040000
000`04`0<01<00000080l/BO00<000000?VnQ`000000103k`H@010000000mLFK0?G5V`3eaI/20000
00030?NoS`000000ml2>00@0ml2>00@000000?O1T@3g`I4000000P3bbjP3000000L0nKj80P000004
0?O1S`030000003f`98000000080m/2B00<000000?NnS0000000103h_HP00`000000n/680?[1R003
0?[1R0050000003f`Y<000000>o;[@0000000`3fa9L3000000D0n[j400<000000?^oP`3k_h<0103k
_h<02@000000n;b60?RlQP3h_8H000000?g3P0000000nKj6000000020?VlQ@030000003h_hX0n;n:
00<0n;n:0P0000020?[1QP030000003j`HH0n/6600<0n/6600<000000?_4R@3ka8T00P0000000`3j
`XX000000?[3R`020?[3R`D000000P3icY/00`000000nkn00?^oP0030?^oP080000000<0nl>60000
003k_h800`3k_h82000000D0o<J70P000000103k_gl000000?c0P00000020?o5M@<0000000D0n[I@
000000000000mkZ7000000020?ZmO`8000000P3l_GX01@000000lKN?0000003X/IT000000080oKed
00<000000?bmMP0000000`3n`FL3000000@0oKee0P0000020?bmMP80000000<0o[mb000000000000
0P0000001@3b]X`000000?fmMP3m_GH0000000<0oKia00H000000?k1M@3n`GD0o/5e0000003l_W/2
000000050<EmP@00000000000?g<S@0000000`3l_g`200000080o<5o00D000000?k1MP3n`GH0o/5f
000000030?k1L`80000000<0o<B70000000000000`3n_g400`000000o/1^0?k0KP04000000@0olf5
0P0000030?k?R@80000000D0olIi000000000000l=fl000000020?k1L0050000003ibID000000?GB
ZP0000000`3n`6d01@000000o/5Z0?k1JP3n`FX0000000<0o/5[00@000000?k1JP3n`FX0o/5Z2@00
00001@3n`W@000000?o5M0000000oKid008000000P3m_W@200000080oKe]00D000000?VnDP3i_U80
nKiB000000020?k3I0<000000P3n`F/01@000000e]1E0=K@E@000000nl]R00<0000000D0o=1]0000
003obgd0ol]m000000020?o7MP040000003oagL00000000000<0o/5Y00D000000?k3K@3n`fd00000
0?k4O00200000080oooo00<000000?ooo`3oool02`3oool002d0oooo00<000000?ooo`3oool09@3o
ool5000000<0kl>T1@000000103Vc[l000000000000000030>o4YP80000000@0lL:O000000000000
00001`3b^Y800`000000lM=R000000020>jhV0030000003`^I@0l;VD0080l;VD00D000000?gAT@00
000000000?2WNP0200000080kLV`00@000000?BnT`00000000000P3Z^J4200000080kKRJ0P000000
0`3Qj=L000000>nmW@020>nmW@8000000`3a_9P2000000<0l[ZA00@000000;Fhf`000000lkfD0P00
00020?FTH080000000D0m<2F0000003d_900m;b@000000020?BnT`80000000@0l[^D0000003V]Z80
00000`3c^i800`000000m[n@0?JoT0020?JoT0030000003f_Y00000000H0mL2E00@000000?K3U`3f
`iL0m/>G0P000000103j[Ul000000?FmT@0000040?BmTP800000103g_Xd01@000000m[n?0000003i
`Xh0000000H0m[^:0P0000020?>kT@030000003h`H`0n<6<00<0n<6<00@000000300C00`04`00000
0P3ba9l00`000000nKj7000000030?_1Q08000000`3eaI/2000000030?NoS`000000ml2>00D0ml2>
00<000000?O1T@0000000P000000103cbJ@000000000000000050?VnR0<000001@3g`Hl200000080
m/2B00<000000?NnS0000000103h_HP00`000000n/680?[1R0030?[1R080000000@0m/:C0000003_
bjd000000`3fa9L2000000D0n[j400<000000?^oP`3k_h<0103k_h<02@000000n;b60?RlQP3h_8H0
00000?g3P0000000nKj6000000030?VlQ@030000003h_hX0n;n:0080n;n:0`0000000`3j`HH00000
0?[1QP040?[1QP8000000`3ka8T2000000<0n/>;10000000103ccZT000000?W>V`0000050?^oP004
0000003j_Gl00000000000D0nkn200<000000?c6Q`3laXL00`3laXL2000000040?^oO`000000o<20
00000080olEe0`0000001@3j]U0000000000003g^XL000000080n[eo0P0000020?bmNP050000003a
]hl000000>RaV@0000000P3m_G@00`000000o;ef000000030?k1I`<00000103m_GD200000080o;ef
0P0000000`3n_g8000000000000400000080oKef00<000000?fnL@3m_W400P3m_W401@000000o/5e
0?k1M@000000o;ik0080000000<0aGf10000000000000P3mc8d00`000000o;ml0?boO00200000080
o<5o00D000000?k1MP3n`GH0o/5f000000030?k1L`030000003m`7D00000008000000`3n_g401`00
0000o/1^0?k0KP3n`6h000000?[KY`000000103ocHD3000000<0o/n900<000000?o6N@0000000P00
00001P3lc90000000?k1L03n`G0000000?W9U@<000000P3n`6d01@000000o/5Z0?k1JP3n`FX00000
00<0o/5[00H000000?k1JP3n`FX0o/5Z0000003naVL2000000030?k<QP0000000000008000000P3n
`W@2000000050?fnM0000000YiG30000003m_W@00P0000020?fmK@040000003i_U80nKiB0?VnDPH0
00000P3n`F/010000000e]1E0000000000020?_;HP050000003ld6d000000?k2J`0000000P3obgd0
0`000000olMf000000020?o7M`8000000P3n`FT01@000000o/=]0?k3K@000000o/Al008000000P3o
ool00`000000oooo0?ooo`0;0?ooo`00;@3oool00`000000oooo0?ooo`0W0?ooo`H000000`3_a:D4
000000040>K>_`0000000000000000<0klBV100000070?:jTP030000003adf8000000080k[RH00<0
00000?2iU03`^I@00P3`^I@010000000oM6A0000000000030?2WNP030000003]bK00kLV`00<00000
0P3Z^J4200000080kKRJ00@000000>RSP`00000000000`3__Id2000000<0lKbH0P0000030?:jT@04
0000002e^=/000000?>mU0H0000000@0m<2F0000003d_90000000`3d_Y<200000080l[^D00<00000
0>JfXP0000000P3c^i800`000000m[n@0?JoT0030?JoT08000001`3e`9D00`000000m/>G0?K3U`02
000000040?Z^G`0000000000000000@0m;fB00<000000?S3S`0000000`3g_Xd3000000030?W2SP00
0000m[^:00D0m[^:00@000000?ZoQP00000000001P3h`H`00`000000<01<0300C00200000080l/BO
0P0000020?_1Q080000000D0kknO0000003eaI/000000?BmT`03000000H0ml2>00D000000?O1T@00
0000mkn>000000020??9Y08000001@3i_XP00`000000n;f8000000050?O1S`8000000P3f`9830000
00D0n;f800<000000?[1R03j`HP00P3j`HP2000000040?K2T`000000kl^]000000<0m/BG0`000004
0?ZnQ0030000003k_h<0nkn300@0nkn300T000000?RlQP3h_8H0n;b60000003m`h0000000?VnQP00
00000`3i_8D00`000000n;n:0?RoRP020?RoRP050000003j_h@000000?[1QP0000001@3j`HH00`00
0000nl65000000020?_4R@030000003j`XX0000000<0n/>;0`0000020??>Z@030000003icY/00000
00@0nkn000@000000?ZmO`00000000001@3k_h82000000@0o<J700@000000?O:W@000000nkmo0P00
00000`3oaGD0000000000002000000050?ZfD000000000000?NjQ`0000000P3j_Gl200000080o;ej
00D000000?6gS`000000j;6I000000020?fmM0030000003l_GH0000000<0o/5W0`0000040?fmM@80
00000P3l_GH2000000040?joLP00000000000?fmM0<000000P3m_GH00`000000oKia0?fnL@020?fn
L@050000003n`GD0o/5e0000003l_W/00P0000000`35OH400000000000020?g<S@060000003l_g`0
o;ml0000003m_gT000000P3l`Gl010000000o/5f0?k1MP0000030?k1L`040000003m`7D000000?c4
Q`8000000P3n_g4010000000o/1^0?k0KP3n`6h500000080olf500<000000?g@S`0000000P000000
203nchT00000000000000000o/El0000003lc90000000P3n`G000`000000nLVE0?W9U@0200000080
o/1]00D000000?k1JP3n`FX0o/5Z000000030?k1J`040000003n`FX0o/5Z0?k1JP@000000P3nc8H3
00000080o/9d0P0000001@3m_W@000000:NE``000000oKid00<0000000<0oKe]0000003i_U800P3i
_U801@000000o/=^000000000000oLB00080000000<0o/5[0000003Fd5D00P0000020?_;HP<00000
00L0o/9[000000000000ol]m0000003oagH0000000<0olMg0P000000103n`FT000000?k3K@3n`fd5
000000030?ooo`000000oooo00`0oooo000]0?ooo`030000003oool0000002P0oooo1@0000040>o4
Y@@0000000@0i/jo0000003TcL000000103_a:H2000000L0l[ZB00<000000?7CHP0000000P3^^9P0
1@000000l;VD0?2iU03`^I@0000000<0oM6A10000000203d`iT000000>g9/03]bK0000000?W/Z`00
0000j[VQ0P0000020>fhVP050000003XXh<0j:>30>RSP`0000000P3__Id3000000040?6lV0000000
lL2L000000@0l[ZA00@000000;Fhf`000000lkfD0P0000000`3a_IT00000000000020?C0UP800000
0`3d_Y<200000080l[^D00<000000>JfXP0000000P3c^i800`000000m[n@0?JoT0030?JoT0800000
1`3e`9D6000000040?Z^G`000000mKfA000000<0m;fB00<000000?S3S`0000000`3g_Xd300000003
0?W2SP000000m[^:00D0m[^:00@000000?ZoQP00000000001P3h`H`00`000000<01<0300C0020000
0080l/BO0P0000020?_1Q08000000P3__il200000080m;fC0P0000060?O0SP<000000P3g_hh00`00
0000llVT0??9Y002000000@0nKj800<000000?RmR00000001P3g`Hl00`000000m/2B0?K0TP030000
00H0n;f800/000000?[1R03j`HP0n/680000003j`HT000000?K2T`000000kl^]000000020?K4U`<0
0000103j_X@00`000000nkn30?^oP`040?^oP`050000003h_8H0n;b60?RlQP0000000P3m`h020000
00<0nKb500<000000?RoRP3h_hX00P3h_hX00`000000n[n40?ZoQ002000000D0n/6600@000000?_1
Q@3k`HD000000P3ka8T200000080n/>;0P0000000`3/`ZP00000000000020??>Z@800000103k_h00
10000000n[eo0?ZmO`0000050?^oPP030000003l`Gh0000000<0o<J700@000000?O:W@000000nkmo
0P0000000`3oaGD0000000000002000000050?ZfD000000000000?NjQ`0000000P3j_Gl2000000<0
o;ej0P0000001`3X/IT000000?fmM03m_G@000000?bmMP0000000`3n`FL3000000@0oKee0P000002
0?bmMP80000000@0o[mb000000000000oKed0`0000020?fmMP030000003m_W40oKia0080oKia00D0
00000?k1M@3n`GD000000?bnN`03000000050?k2J`000000oLb=0?g<S@0000000P3l_g`00`000000
oKmi000000020?c1O`040000003n`GH0o/5f000000<0o/5c00<000000?g0M@0000000P3la8L01000
0000o[ma0?joL@0000030?k0KP030000003n_fl000000080n>Fb0`0000020?g@S`030000003cfKD0
000000<0000000H0o/El000000000000o<b@0000003n`G02000000060?W9U@00000000000000003n
`6d000000`3n`FX01@000000o/5[0?k1J`3n`F/0000000<0o/5Z100000030?k<QP040000003keih0
00000?k2M080000000D0oKid0000002WUL<000000?fnM003000000030?fmK@000000nKiB0080nKiB
00@000000?k3KP000000nk9M0`0000001@3n`F/000000000003na6H000000080nl]R0`0000000`3n
`V/000000?k2K@04000000<0olMg0P000000103n`FT000000?k3K@3n`fd3000000040?k:P`000000
oooo000000d0oooo000]0?ooo`800000:`3oool5000000@0klBU0`000000103Vc[l0000000000000
00030>o4YP8000001`3b^Y800`000000lM=R000000020>jhV0050000003`^I@0l;VD0?2iU0000000
1P3mdI400`000000m<>I0?C3V@06000000050=jFPP00000000000>fhVP0000000P3XXh<2000000<0
kkfM0P000000103a_9P000000?70W00000050?:jT@80000000<0lkfD0000000000000`0000020?C0
UP800000103d_Y<2000000040?:kU0000000i[JR00000080lk^B00<000000?JoT03f_i00103f_i00
0`000000mL2E0?G0U@050?G0U@030000003g`Y<0ml:C00<0000000@0nZiO0000003e_I4000000`3d
_I8010000000n<>?0?S3S`0000020?NnS@030000003i`H/00000008000001P3f^hX010000000n[n6
0000000000060?S1S0030000000`04`000000080l/BP00H000000?;4W`00000000000?_1Q0000002
0?K0T`040000003__il0kknO00000080m;fC0P0000060?O0SP030000003h`8d0000000<0mkn>00@0
00000??9Y03cbJ@00000103i_XP010000000n;f80?RmR00000050?O1S`040000003f`980m/2B0?K0
TP8000001P3h_HP200000080n/6800D000000?[1R@000000m/:C000000020>o;[@8000000P3g`900
0`000000n[j40?ZnQ0020?ZnQ0030000003k_h<0nkn300@0nkn300D000000?RlQP3h_8H0n;b60000
00020?g3P0030000003i_XH0000000<0nKb500D000000?RoRP3h_hX0n;n:000000020?ZoQ0800000
1@3j`HH030000000nl650?_1Q@3k`HD000000?_4R@000000n/::0000003j`h/000000?_4R@@00000
0P3ccZT00`000000nkn00?^oP0020?^oP0040000003j_Gl0n[eo000000D0nkn200<000000?c1OP3l
`Gh00P0000001@3laXL000000?O:W@000000nkmo00<0000000D0lLFS00000000000000000?ZfD002
00000080mkZ700<000000?ZmO`0000000P0000020?bmNP80000000L0j;6I0000003m_G@0oKed0000
003l_GH0000000<0o/5W0`0000040?fmM@8000000P3l_GH2000000040?joLP00000000000?fmM0<0
00000P3m_GH00`000000oKia0?fnL@030?fnL@040000003n`GD000000?bnN`<0000000D0o/9[0000
003mc8d0oLb=000000020?boO0030000003m_gT000000080o<5o00@000000?k1MP3n`GH000000`3n
`G<01P000000oL1e0?g0M@000000o<B700000080o[ma00D000000?k0KP3n`6h0o/1^000000020?jo
K`050000003hiK80n>Fb0?SU/P0000000`3md8l010000000lmVe0000003k`hP2000000040?k5O000
0000o<b@0?c<T0<000000P3ibID4000000<0o/5Z00D000000?k1J`3n`F/0o/5[000000030?k1JP80
000000<0o=ZO0000000000000P3nc8H010000000nmNN0000003n`W@200000080oKid0P0000001P3m
_W@00000000000000000oKe]000000<0nKiB00H000000?k3KP000000nk9M0000003ma80400000006
0?k4IP000000nl]R0?_;HP000000olMf0`0000020?k2K@030000003ocH<0000000<0olMg10000002
0?k3K@040000003oagD000000?k:P`<000003@3oool002d0oooo00<000000?ooo`3oool0;03oool4
000000D0klBU200000000`3``Z4000000?:jTP060?:jTP060000003adf80lM=R0000003^^9P00000
0`3`^I@00`000000oM6A0?gAT@040?gAT@@0000000<0m<>I0000003d`iT00`000000103c`IT00000
0>fhVP0000020>RSP`<000000P3__Id4000000030?70W0000000l[ZA00@0l[ZA00@000000;Fhf`00
0000lkfD0P000000103a_IT000000?C0UP3d`9H2000000@0m;jC0P000000103b^i@000000>JfXP00
00020?>kTP030000003f_i00m[n@00@0m[n@0P0000060?G0U@030000003g`Y<0ml:C0080ml:C1@00
00030?BmTP040000003h`hl0n<>?00000080mkj=00D000000?W1R`3i`H/0nL6;000000060?JkRP04
0000003j_hH00000000000H0n<6<00@000000300C000000000000P3ba:04000000<0m/2C00@00000
0>noW`3__il000000`3d_I<2000000D0ml2>00@000000?S0S@3h`8d000000`3g_hh00`000000llVT
000000040?VnR0040000003h_HP0n;f8000000D0ml6?00@000000?K0TP3f`980m/2B0P0000060?Rm
R0050000003[^j<000000?[1R00000000P3j`HT3000000030>o;[@00000000000080ml2@0P000003
0?ZnQ0030000003k_h<0nkn300@0nkn300D000000?RlQP3h_8H0n;b6000000020?g3P0030000003i
_XH0000000<0nKb500D000000?RoRP3h_hX0n;n:000000030?ZoQ0030000003j`HH0n/6600<0n/66
00<000000?_1Q@3k`HD00P3k`HD4000000050?[3R`000000nlB90000003/`ZP00`0000000`3ccZT0
00000?^oP0030?^oP0050000003j_Gl0n[eo0?ZmO`000000103k_h800`000000o<5n0?c1OP020?c1
OP80000000<0mlZM0000003k_gl01`0000001`3j]U0000000>6[W0000000mkZ70000003j_Gl00`00
00020?bmNP80000000L0j;6I0000003m_G@0oKed0000003l_GH0000000<0o/5W0`0000040?fmM@80
00000P3l_GH2000000040?joLP00000000000?fmM0<000000P3m_GH00`000000oKia0?fnL@030?fn
L@030000003n`GD0000000@0000000<0o/9[0000003mc8d00P3mc8d01@000000o;ml0000003m_gT0
00000080o<5o0P0000000`3n`GH000000?k1L`020?k1L`040000003m`7D0oL1e00000080o<B700<0
00000?joL@0000000`3n`6h010000000o[m_0?joK`3n_fl3000000040?;O^P000000oM2?0?g@S`<0
000000@0nl>8000000000000o/El0P000000203lc90000000000003n`Fd000000?W9U@000000olAe
0P0000030?k1JP050000003n`F/0o/5[0?k1J`0000000`3n`FX2000000030?cJW`000000000000<0
o/b60P0000000`3n`W@00000000000020?fnM080000000H0oKid00000000000000000?fmK@000003
0?VnDP050000003n`fh000000?^bG@0000000P3ma803000000030?k4IP000000nl]R008000000P3o
agH200000080o/9]0P0000001P3ocH<000000?o7M`3oagL000000?oGQ`8000000P3n`fd010000000
olMe0000003nbX<3000000d0oooo000]0?ooo`030000003oool0oooo02d0oooo1@0000030>o4Y@@0
000000H0jlRa00000000000000000?32X@0000070?:jTP050000003adf80lM=R0000003^^9P00P00
00020?2iU0030000003mdI40oM6A00<0oM6A2`0000000`3c`IT00000000000020>RSP`80000000<0
lknG0000003__Id01@0000000`3a`9`000000?:jT@050?:jT@80000000H0lkfD0000000000000000
0?6mV@0000020?C0UP030000003d_Y<0m;jC0080m;jC0P0000020?:kU08000000P3c^i800`000000
m[n@0?JoT0040?JoT0030000003f`980000000D0mL2E00<000000?O2T`3g`Y<00P3g`Y<5000000<0
m;fB00L000000?S3S`3h`hl0n<>?0000003g_Xd0000000<0nL6;00<000000?JkRP3f^hX0103f^hX0
10000000n[n60000000000060?S1S0040000000`04`00000000000<0l/BP100000030?K0T`040000
003__il0000000000080m;fC00<000000?2lV@000000103g`8h010000000n<2=0?S0S@0000030?No
SP040000003cbJ@0llVT000000<0nKj800D000000?RmR03h_HP0n;f8000000040?O1S`8000000P3f
`982000000H0n;f80P0000000`3[^j<00000000000020?[1R@80000000@0n<>@0000003_bjd00000
0`3g`9001@000000n[j40?ZnQ03j_X@0000000H0nkn30P0000000`3h_8H000000?g3P0020?g3P003
0000003i_XH0000000<0nKb500D000000?RoRP3h_hX0n;n:000000030?ZoQ0800000103j`HH00`00
0000nl650?_1Q@030?_1Q@D000000P3ka8T2000000050?^cF`000000lljY0??>Z@0000000`3k_h00
1@000000n[eo0?ZmO`3j_Gl0000000@0nkn200<000000?c1OP3l`Gh00`3l`Gh01@000000mlZM0?O:
W@000000nkmo00<0000000X0lLFS000000000000n[I@0000003QZi`000000?NjQ`000000n[eo0`00
00020?bmNP80000000L0j;6I0000003m_G@0oKed0000003l_GH0000000<0o/5W0`0000040?fmM@80
00000P3l_GH2000000030?joLP000000o/1Y00@000000P3m_GH00`000000oKia0?fnL@030?fnL@L0
000000<0o/9[0000003mc8d00P3mc8d00`000000o;ml000000020?foN@060000003l`Gl000000000
003n`GH00000103n`G<00`000000oL1e000000020?c4Q`030000003n_g40000000<0o/1^00<00000
0?joK`3n_fl00P3n_fl200000080l]nj00<000000?g@S`3md8l010000000103n`78000000?k5O000
00020?c<T0d000000P3n`F/01@000000o/5Z000000000000oLJ50080000000<0o=ZO000000000000
0P3nc8H500000080oKid0P0000001P3m_W@00000000000000000oKe]000000<0nKiB00@000000?k3
KP000000nk9M0P0000000`3ma8000000000000020?k4IP0:0000003kbf8000000?k7O`000000olMf
0000003RhM<000000?k2K@80000000T0olf30000003oagL0olMg0000003oehL000000?o7M@000000
0P3n`fd200000080o/Z30P00000=0?ooo`00;@3oool00`000000oooo0?ooo`0_0?ooo`H000000`3_
`jD4000000030=oBb`000000000000L0l[ZB00D000000?7CHP3adf8000000>jhV00200000080l;VD
00<000000?gAT@3mdI400`3mdI46000000<0m;jE0P0000001`3c`IT000000000003XXh<000000??1
V@0000000P3c_iL4000000050?S4TP000000lL2L0?70W00000001@3b^Y4010000000]KSK0000003c
_I@200000080lKfI00<000000?C0UP0000001@3d_Y<020000000l[^D0?:kU0000000i[JR0000003c
^i8000001P3f_i0010000000m/2B0?K0TP0000030?G0U@030000003g`Y<0ml:C00@0ml:C0`000000
103e_I4000000?BmTP0000040?S3S`030000003g_Xd0000000<0nL6;00<000000?JkRP3f^hX0103f
^hX010000000n[n60000000000050?S1S0030000000`04`000000080m/2A00<000000?;4X03ba:00
100000020?K0T`<0000000<0nKIh0000003d_I<00P3d_I<3000000<0ml2>00D000000?S0S@3h`8d0
n<2=000000030?NoSP030000003cbJ@0000000<0nKj800D000000?RmR03h_HP0n;f8000000040?O1
S`8000000P3f`982000000H0n;f80P0000000`3[^j<00000000000030?[1R@030000003h`i000000
008000000`3g`9001@000000n[j40?ZnQ03j_X@0000000H0nkn30P0000000`3h_8H000000?g3P002
0?g3P0030000003i_XH0000000@0nKb500<000000?RoRP0000001@3j_h@01@000000n/660?[1QP3j
`HH0000000H0nl6500<000000?C0U@0000000P0000020?_4R@030000003/`ZP000000080000000<0
lljY0000003k_h000P3k_h001@000000n[eo0?ZmO`3j_Gl0000000@0nkn200<000000?c1OP3l`Gh0
0`3l`Gh2000000030?O:W@000000nkmo00<0000000X0lLFS000000000000n[I@0000003QZi`00000
0?NjQ`000000n[eo0`0000020?bmNP040000003a]hl0000000000080oKed00<000000?bmMP000000
0`3n`FL20000000308c@oP000000oKee0080oKee00@000000?jnL0000000o;ef100000000`3n`6T0
00000000000200000080oKef00<000000?fnL@3m_W400`3m_W45000000040<EmP@000000o/9[0000
00<0oLb=00<000000?boO00000000P3m_gT010000000o<5o0000003m_WP2000000@0o/5c00P00000
0?g0M@3m`7D000000?c4Q`000000o[ma000000<0o/1^00<000000?joK`3n_fl00P3n_fl01@000000
o[m^0000003bgkX000000080oM2?0`000000103k`hP000000000003naG`2000000030?c<T0000000
0000008000000P3mdI@500000080o/9h10000000103jdI`000000?g6Q@3maXD6000000030?k9PP00
0000000000<000000P3m_W@500000080oKe]00L000000?VnDP00000000000?k3KP000000nk9M0080
000000<0oLB00000000000000P3na6H200000080o/Mo00<000000?o7MP0000000P000000203n`Vd0
00000?o@Q`000000olf30000003oagL000000P3oehL200000080o/=]00@000000?o7M@000000o/Z3
0P00000=0?ooo`00;@3oool00`000000oooo0?ooo`0`0?ooo`D00000103_`jD5000000030=oBb`00
0000l[ZB00D0l[ZB00D000000?7CHP3adf8000000>jhV00200000080l;VD00<000000?gAT@3mdI40
0P3mdI43000000030=SAdP000000000000<000000`3d_YD01P000000ll6I000000000000ll6I0000
00<0lknG1P0000020?70W0030000003b^Y40l[ZA00<0l[ZA0`0000001@3c_I@00000000000000000
lKfI0080000000<0m<2F0000003d_Y<00`3d_Y<2000000060?:kU0000000i[JR0000003c^i800000
1P3f_i001@000000m/2B0?K0TP3f`98000000080mL2E00<000000?O2T`3g`Y<0103g`Y<500000003
0?BmTP000000n<>?00@0n<>?0P0000030?W1R`030000003f^hX0m[^:00@0m[^:00@000000?ZoQP3j
_hH000001@3h`H`00`000000<01<000000030?K0T@030000003ba:00l/BP0080000000P0klV/0000
003f`9<000000?K3UP000000nKIh000000<0m;fC00<000000?2lV@0000000`3g`8h01@000000n<2=
0?S0S@3h`8d0000000<0mkn>100000020?VnR0030000003h_HP0n;f80080n;f800L000000?O1S`3g
`Hl0ml6?0000003g_Xh000000080m/2B00<000000?RmR03h_HP0103h_HP2000000040>^kX`000000
0000000000<0n/6900D000000?S3T0000000_ET0000000030?O0T0040000003j_X@0n[j4000000D0
nkn300D000000?c1PP000000n;b6000000040?g3P0800000103i_8D00`000000n;n:000000050?Zo
Q08000000P3j`HH00`000000nl650?_1Q@040?_1Q@<0000000<0n[n40000003ka8T00P3ka8T30000
00030?ZoQP000000000000<0nkn000D000000?ZmO`3j_Gl0n[eo000000040?^oPP030000003l`Gh0
o<5n00<0o<5n0P0000002@3gbYd000000?^oO`3k_gl000000?^mOP000000lLFS000000020?ZfD080
000000<0mkZ70000003j_Gl00`0000020?bmNP040000003a]hl0000000000080oKed00<000000?bm
MP0000000`3n`FL20000000308c@oP000000oKee0080oKee00@000000?jnL0000000o;ef10000000
1P3n`6T00000000000000000l[J<00000080oKef00<000000?fnL@3m_W400P3m_W400`000000m[i=
00000002000000040<EmP@000000o/9[000000<0oLb=00<000000?boO00000000P3m_gT010000000
o<5o0000003m_WP2000000@0o/5c00@000000?g0M@3m`7D000000P3la8L2000000<0o/1^00<00000
0?joK`3n_fl00P3n_fl01@000000o[m^0?joKP000000l]nj0080000000P0o/Mo000000000000nl>8
0000003n`78000000?k5O0@0000000<0olai0000003mdI@00P3mdI@4000000<0o/9h0`0000020?[A
W0050000003maXD000000000003n`WT00`0000020?k9PP80000000@0gN;I0000003m_W@0oKid1@00
00020?fmK@030000003i_U80000000H0000000<0oLB00000003na6H00P3na6H300000080o/Mo0P00
0000103oc80000000000000000020?o@Q`@000000P3oehL01`000000olMe0000003n`fd000000?o7
M@0000000P3nbX<00`000000oooo0?ooo`0;0?ooo`00;03oool00`000000oooo0?ooo`0b0?ooo`04
0000003[_jH000000>c2Z08000000`3_`jD3000000030>_8/@000000000000H0l[ZB00<000000?7C
HP3adf800P0000001@3ha98000000?2iU03`^I@0000000@0oM6A100000000`3HdM80000000000002
0>nlW0040000003d_YD0m;jE0?BnU@<0000000<0ll6I0000003c_iL00`3c_iL00`000000lknG0000
00020?30WP030000003a`9`0000000H0l[ZA1P0000020?6mV@030000003d`9H0000000@0m;jC0P00
00020?:kU0<000001`3f_i000`000000m/2B0?K0TP020?K0TP030000003e`9D0000000L0ml:C1000
00000`3d_I8000000?S3S`040?S3S`80000000<0nL6;0000000000000P0000050?JkRP040000003j
_hH0n[n6000000D0n<6<00<000000300C00000000`3f`9401@000000l/BP0?;4X03ba:0000000080
klV/0P0000001@3f`iH000000?VfN03i]WP000000080m;fC00@000000?2lV@00000000000P3g`8h0
0`000000n<2=0?S0S@020?S0S@050000003g_hh0mkn>0000003h`H`00P0000020?VnR0030000003h
_HP0n;f80080n;f800@000000?O1S`3g`Hl000000P3g_Xh00`000000m/2B0?K0TP02000000D0n;f8
0`0000020?S6UP8000000P3j`HT00`000000n<>@0?S3T002000000<0ml2@00@000000?ZnQ03j_X@0
00001@3k_h<01@000000o<620000003h_8H0000000@0oL>00P0000040?VlQ@030000003h_hX00000
00D0n[n40P0000020?[1QP030000003k`HD0nl6500@0nl650`0000020?ZoQ0060000003ka8T0nlB9
0000003/`ZP000000P3j_hH200000080nkn000<000000?ZmO`3j_Gl00P3j_Gl01@000000nkn20?^o
PP3k_h80000000D0o<5n100000020?^oO`050000003k_Gh000000?75X`0000000P3j]U0200000003
0?NjQ`000000n[eo00<000000P3l_GX010000000lKN?0000000000030?fmM08000000`3n`FL20000
000308c@oP000000oKee0080oKee00@000000?jnL0000000o;ef100000001P3n`6T0000000000000
0000l[J<00000080oKef00<000000?fnL@3m_W400P3m_W400`000000m[i=00000002000000040<Em
P@000000o/9[000000@0oLb=0P0000020?foN@030000003l`Gl000000080oKih00<000000?k1L`3n
`G<00P3n`G<01P000000oL1e0?g0M@3m`7D000000?c4Q`8000000`3n`6h00`000000o[m_0?joK`02
0?joK`080000003n_fh0o[m^0?joKP000000l]nj0000003nagl200000080nl>82P0000020?gAU0@0
00000`3n`WP300000080n]6L00<000000?g6Q@0000001@0000030?k9PP030000003Mh]T000000080
oKid1P0000001@3m_Fd000000?VnDP000000olEh00@0000000<0o]2=0000000000000`3na6H30000
0080o/Mo0P000000103oc80000000000000000020?o@Q`@000000`3oehL4000000050?o7M@000000
o/Z30?k:P`0000003@3oool001P0oooo00<000000?ooo`3oool00P3oool4000000/0oooo00<00000
0?ooo`3oool00P00000a0?ooo`040000003[_jH000000>c2Z0800000103_`jD4000000H0l[ZB00L0
00000?7CHP3adf80lM=R0000003ha98000000080l;VD00P000000?gAT@3mdI40oM6A0000003^`jD0
00000>7=a080000000@0f=7B000000000000kkbL0P0000020?BnU@<0000000<0ll6I0000003c_iL0
1@3c_iL01P000000l<2N000000000000lL2L000000H0l[ZA10000000103bcJX000000000003a_IT2
000000030?C0UP000000m;jC0080m;jC0P0000020?:kU0<000001`3f_i000`000000m/2B0?K0TP03
0?K0TP8000001P3g`Y<7000000H0n<>?0P0000030?O2T@030000003f^hX0m[^:00<0m[^:00@00000
0?ZoQP3j_hH000001@3h`H`3000000@0m/2A00<000000?;4X03ba:000P0000000`3_bJ`000000000
00020?K3UP<000000`3d_I<01P000000l;bI000000000000ml2>000000@0n<2=00@000000?NoSP3g
_hh000000P3h`H`2000000030?VnR0000000n;f800@0n;f800<000000?O1S`0000000`3g_Xh01000
0000m/2B0000000000050?RmR0030000003j_hH0000000<0n<JF0`0000001P3j`HT000000?S3T000
0000_ET000000080ml2@00@000000?ZnQ03j_X@000001@3k_h<01@000000o<620000003h_8H00000
00@0oL>00P0000040?VlQ@<000001P3j_h@2000000030?[1QP000000nl6500D0nl650P000000203d
`9D000000?ZoQ03j_h@000000?_4R@000000k<:X0P0000000`3j_hH00000000000020?^oP0030000
003j_Gl0n[eo0080n[eo00D000000?^oPP3k_h80nkn2000000050?c1OP<0000000D0mlZM0000003k
_gl000000?^mOP0300000080n[I@0P0000000`3g^XL000000?ZmO`0300000080o;ej00D000000?6g
S`000000nl:7000000020?fmM08000000P3n`FL01@000000o[i`0000002<d?h0000000<0oKee00@0
00000?jnL0000000o;ef0`0000020?k0J@<0000000D0l[J<0000003m_GH0oKef000000040?fnL@03
0000003f_Td0m[i=0080000000@0aGf10000003n`V/00000103mc8d2000000<0oKmi0P0000020?fn
N0030000003n`G<0o/5c0080o/5c00@000000?g0M@3m`7D0oL1e100000030?k0KP030000003n_fl0
o[m_0080o[m_00@000000?joKP3n_fh0o[m^10000000103nagl000000000003k`hP7000000040?SH
Z0000000000000000080oM6D0P0000001`3nah0000000?k2N03n`WP000000?k5N00000000`3jdI`4
000000040?k2N@000000000000000080o/V20`0000020?fnM0H0000000@0oKe]0000003i_U800000
0P3oaGP6000000<0o/AV0P0000000`3ke9`000000?k7O`0200000080olb00P0000030?o@Q`050000
003ncXL000000000003oehL01@0000020?o7M@030000003nbX<0000000d0oooo000H0?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`080?ooo`<00000=03oool00`000000
jknV00000003000000<0kl>U100000060?:jTP040000003adf80lM=R0?7CHP<000000P3`^I@01@00
0000oM6A0?gAT@3mdI4000000080k/>U00T000000>Mm:000000000000>G=_`000000kkbL0000003_
^YT00`0000020?>oUP8000001`3c_iL2000000030;Y300000000000000H0l[ZA00<000000=Rc/`00
0000100000000`3a_IT0000000000002000000@0m;jC00H000000?:kU03b^i@000000>JfXP000006
0?JoT0030000003f`980m/2B00D0m/2B00<000000?O2T`3g`Y<0103g`Y<00`000000ml:B00000004
000000H0n<>?00<000000?O2T@3g`Y400P3g`Y400`000000m[^:0?JkRP030?JkRP050000003j_hH0
n[n60?ZoQP000000103h`H`3000000D0m/2A0P0000020?7<Z`030000003_bJ`0000000@0m/>F00P0
00000?BmT`3d_I<0m;fC0000003`_9T000000>[1Z`8000001@3h`8d00`000000mkn>000000030?S1
S0030000003i_XP0000000D0n;f800<000000?O1S`0000000`3g_Xh010000000m/2B0?K0TP000005
0?RmR0030000003j_hH0000000D0n<JF100000000`3h`i000000000000020?O0T0040000003j_X@0
n[j4000000D0nkn300D000000?c1PP000000n;b6000000040?g3P0800000103i_8D3000000H0n[n4
0P0000000`3j`HH000000?_1Q@050?_1Q@80000000<0m<2E0000003j_h@00P3j_h@01@000000nlB9
0000003/`ZP000000080n[n600@000000?^oP03k_h000000103j_Gl01@000000nkn20?^oPP3k_h80
000000D0o<5n1@000000203k_gl000000?^mOP3k_Gh000000?JkRP000000n[I@0P0000020?NjQ`80
000000@0o/5f000000000000o;ej0`0000003@3k`XL000000?fmM03m_G@000000?bmMP000000o/5W
0000003n_W00000008c@oP0000000`3m_GD010000000o[i`0000003l_GH300000080o/1Y1@000002
0?fmMP030000003m_W40oKia0080oKia00<000000?JnC@3f_Td00P0000001035OH4000000?k2J`00
00040?g<S@8000000`3m_gT200000080oKih0P0000030?k1L`040000003m`7D0oL1e0?g0M@800000
00<0m^nR0000003n`6h00P3n`6h00`000000o[m_0?joK`020?joK`080000003n_fh0o[m^0?joKP00
0000o[m^0000003UO1@300000080nl>80`0000020>KVO0030000003hf:P0n=RX008000000P3mdI@2
000000050?k7P0000000o/9h0?k2N00000000P3naGP00`000000n]6L0?[AW002000000030?g3O@00
0000o/9i00<000000`3nbH82000000<0oKid0`0000001P3[_3l000000?fmK@000000nKiB00000080
olEh1P0000020?k4IP030000003mdY@0oM:D0080000000@0o/Mo0000003oagX000000P3oc8020000
00<0om2700<000000?k>Q`0000000P000000103mcHl000000?;F/`0000020?o7M@<000003@3oool0
01<0oooo1`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0e0?ooo`030000003[_jH000000080kkbL0`0000030>nnWP030000003b^Y80l[ZB
00<0l[ZB00<000000?7CHP3adf800P3adf801P000000jl2X000000000000l;VD00000080oM6A0P00
00001@3^`jD000000:CAn0000000igdX00D000000P3_^YT2000000<0lknF00<000000?>oU`3c_iL0
1@3c_iL200000080^T<000<000000?:jT@3b^Y40103b^Y42000000050>o5YP000000lLJV0000003L
^KD00P000000103R]ZT000000000000000030?BnT`80000000@0l[^D0000003V]Z8000001P3f_i00
0`000000m/2B0?K0TP050?K0TP<00000103g`Y<00`000000ml:B00000004000000H0n<>?00<00000
0?O2T@3g`Y400P3g`Y400`000000m[^:0?JkRP030?JkRP030000003j_hH0n[n60080n[n600@00000
0?S1S03h`H`0n<6<100000040?K0T@8000000`3ac:/00`000000klV/000000040?K3UP040000003d
_I<0m;fC00000080l;bI00<000000>[1Z`0000001@3h`8d00`000000mkn>000000030?S1S0030000
003i_XP0000000H0n;f80P0000030?NnSP040000003f`980m/2B000000D0n;f800@000000?ZoQP3j
_hH000001@3haYH3000000040?S3T0000000_ET000000080ml2@00<000000?ZnQ00000001@3k_h<0
1@000000o<620000003h_8H0000000D0oL>000<000000?VlQ@3i_8D00P3i_8D3000000H0n[n400@0
00000?VoR000000000001P3k`HD010000000nKj50000000000040?ZoQ080000000D0k<:X0000003j
_hH0n[n6000000020?^oP0030000003j_Gl0n[eo0080n[eo00D000000?^oPP3k_h80nkn200000005
0?c1OPD0000000P0nkmo0000003k_Gh0nken0000003f^hX000000?ZfD08000000P3g^XL200000004
0?k1MP00000000000?bmNP<0000000d0nl:70000003m_G@0oKed0000003l_GH000000?k1I`000000
o[i`0000002<d?h0000000<0oKee00@000000?jnL0000000o;ef0`0000020?k0J@D000000P3m_GH0
0`000000oKia0?fnL@020?fnL@030000003f_Td0m[i=00<000000P3n`V/00`000000oLb=0?g<S@02
0?g<S@8000000`3m_gT2000000<0oKih00D000000?k1L`3n`G<0o/5c000000030?g0M@80000000<0
m^nR0000003n`6h00P3n`6h00`000000o[m_0?joK`020?joK`050000003n_fh0o[m^0?joKP000000
0P3n_fh400000080nl>80`0000001@3ViW`000000?g6QP000000n=RX00@0000000L0nm6K0000003n
ah00o/N00000003n`WP000000080o/Eh00H000000?[AW03jdI`0n]6L0000003m`gd6000000040?k9
PP000000o/N2000000<0oKid0`0000001P3[_3l000000?fmK@000000nKiB000000<0olEh20000002
0?gBU0040000003ke9`0000000000080olMj00<000000?o<P00000000P0000020?o@Q`030000003n
cXL0o/j7008000000P3mcHl010000000l]Jc0000003oagD3000000d0oooo000C0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0=@3oool010000000jknV0000000000020>nlW08000000`3__Yh00`000000
l[ZB0?:jTP030?:jTP030000003adf80lM=R0080lM=R00H000000>_0Z03[`:P000000?2iU0000002
0?gAT@@000000P2TdOP01`000000igdX0000003_`:4000000>nlW00000000P3_^YT2000000<0lknF
00<000000?>oU`3c_iL00`3c_iL01P000000lKnJ0?6oVP000000^T<0000000D0l[ZA00<000000?Bj
S`0000000P3_aJH00`000000lLJV00000004000000030=Foa0000000m;jC0080m;jC0P0000020?:k
U08000001P3f_i000`000000m/2B0?K0TP050?K0TP030000003f`940m/2A008000000P3g`Y<01@00
0000ml:B0?O2TP000000m/BH008000001P3h`hl00`000000ml:A0?O2T@020?O2T@030000003f^hX0
m[^:00<0m[^:00<000000?ZoQP3j_hH00`3j_hH2000000050?S1S000000000000=_Fd`0000001@3f
`9401@000000lLb[0?7<Z`3ac:/000000080klV/00D000000?K3UP3f`iH0m/>F000000020?BmT`05
0000003`_9T0l;bI0000003Z`J/00P0000040?S0S@<00000103h`H`2000000H0n;f80P0000040?Nn
SP030000003f`980000000D0n;f800D000000?ZoQP3j_hH0n[n6000000040?S6UP@0000000<0n<>@
0000000000000P3g`9000`000000n[j4000000050?^oP`030000003l`H80o<62008000001@3m`h02
000000<0nKb500<000000000600000001P3j_h@4000000H0nl6500@000000?VnQ@0000000000103j
_h@400000080n[n60P0000000`3k_h0000000?ZmO`040?ZmO`040000003k_h80nkn2000000D0o<5n
00L000000?ZmP@000000cjN`0000003k_gl000000080nken00@000000?JkRP000000n[I@0P000002
0?NjQ`80000000@0o/5f000000000000o;ej1@0000020?fmM0090000003l_GH000000?k1I`000000
o[i`0000002<d?h0000000<0oKee00@000000?jnL0000000o;ef0`0000030?k0J@@000000P3m_GH0
0`000000oKia0?fnL@020?fnL@030000003f_Td0m[i=00<000000P3n`V/00`000000oLb=0?g<S@03
0?g<S@040000003m_gT0oKmi0?foN@8000000`3m_WP200000080o/5c00@000000?g0M@3m`7D0oL1e
1@0000020?k0KP030000003n_fl0o[m_0080o[m_00D000000?joKP3n_fh0o[m^000000030?joKP<0
00000P3k`hP3000000090>KVO0000000oLJ60?g6QP000000n=RX0000003id9d000000080nm6K00D0
00000?k7P0000000o/9h000000030?k5N0040000003jdI`0n]6L00000080oL=m0P0000000`3n`gX0
00000000000200000080o/N200<000000?fnM03m_W@00`0000001P3[_3l000000?fmK@000000nKiB
000000<0olEh0P0000000`3LdLh00000000000020=CShP8000000P3mdY@300000080olMj1@000000
1@3od8L000000?k6O`000000o/j700<0000000D0oLf?0000003be[<000000?o7M@02000000030?oo
o`000000oooo00/0oooo000D0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=P3oool3000000@0kkbL
00@000000>nnWP3__Yh000001@3b^Y800`000000lM=R0?7CHP020?7CHP@0000000<0l;VD0000003m
dI401@0000030:CAn08000000P3_`:42000000<0kkZI0P0000030?>oUP030000003c_iL0lknG0080
lknG00@000000?6oVP3a_iX0lKnJ0P0000050?:jT@040000003d^Xl0m;Z?00000080klFV0P000000
1`3L^KD000000000003R]ZT000000>boY@0000000P3d_Y<200000080l[^D100000040?JoT0030000
003f`980m/2B00D0m/2B00<000000?K0T@3f`9400P3f`943000000<0ml:B00<000000?K4V0000000
1`0000040?O2T@030000003f^hX0m[^:00<0m[^:00<000000?ZoQP3j_hH00`3j_hH00`000000mLiM
00000002000000030=_Fd`000000000000@0m/2A0P0000030?7<Z`040000003_bJ`0klV/00000080
m/>F00D000000?BmT`3d_I<0m;fC000000020?2lV@040000003ab:L0lLRW000000<0n<2=0`000004
0?S1S08000001P3h_HP2000000@0mkj>00@000000?K0TP0000000000103h_HP00`000000n[n60?Zo
QP020?ZoQP060000003haYH0n<JF0?S6UP000000n<6=1@0000020?O0T0030000003j_X@0000000D0
nkn300<000000?c1PP3l`H800P0000050?g3P08000000`3i_8D00`000000000H000000060?ZoQ080
000000<0nKn80000003k`HD0103k`HD01P000000nKj50?VnQ@000000m<2E00000080n[n400L00000
0?c2P03l`X0000000>c2Z0000000n[n60080000000<0nkn00000003j_Gl0103j_Gl010000000nkn2
0?^oPP0000050?c1OP040000003j_H4000000<nW/0<000000P3k_Gh020000000m[^:0000003j]U00
00000>6[W0000000mkZ70P000000103n`GH000000000003l_GX500000080oKed00T000000?bmMP00
0000o/5W0000003n_W00000008c@oP0000000`3m_GD010000000o[i`0000003l_GH3000000<0o/1Y
100000020?fmMP030000003m_W40oKia0080oKia00<000000?JnC@3f_Td00`0000020?k2J`800000
103mc8d00`000000oKmi0?foN@020?foN@030000003m_WP0oKih0080oKih0P0000000`3n`G<00000
0?g0M@020?g0M@030000003n`Fl0o/5_0080o/5_0`0000040?joK`050000003n_fh0o[m^0?joKP00
00000`3n_fh4000000030?_3R000000000000080000000H006OH0000003maXH0oLJ60000003hf:P3
00000080nm6K100000030?k5N080000000@0n]6L0000003m`gd0oL=m0P0000000`3n`gX000000000
000200000080o/N200<000000?fnM03m_W@00`0000001P3[_3l000000?fmK@000000nKiB000000<0
olEh1P0000001@3Dhn800000000000000000oM:D00<000000`3oagX2000000050??G/P0000000000
0000003naWl01@0000020?g=S`040000003be[<0000000000080oooo00<000000?ooo`3oool02P3o
ool001D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0=`3oool00`000000WL3a000000040>nlW0030000003_
_Yh0000000D0l[ZB00<000000?7CHP3adf800P3adf8500000080oM6A00@000000?31X0000000k[nS
0`0000020:CAn080000000<0kl2Q0000000000000`3_^YT400000080lknF0P0000020?>oU`030000
003a_iX0lKnJ0080lKnJ00<000000?:jT@3b^Y400`3b^Y401@000000m;Z?0?BjS`3d^Xl0000000<0
klFV00@000000>N1?0000000h[JY100000000`3d_Y<00000000000020?:kU08000000P3daI`01@00
0000m[n@0?JoT03f_i00000000L0m/2B00<000000?K0T@3f`940103f`94300000080ml:B0P000000
1@3fa9P000000?NoSP3g_hh000000080n<2<0P0000020?O2T@030000003f^hX0m[^:00<0m[^:00<0
00000?ZoQP3j_hH00`3j_hH00`000000mLiM0?G>G@0200000080fmKC00D000000?K0T@3f`940m/2A
000000020?NoSP040000003ac:/0lLb[0?7<Z`<000000`3f`iH010000000m;fC0?BmT`0000020?2l
V@050000003ab:L0lLRW0?78Y`0000000P3h`8d00`000000nL>=000000050?S1S0030000003h_HP0
n;f800@0n;f80P0000050?NnSP<00000103h_HP00`000000n[n60?ZoQP020?ZoQP040000003haYH0
n<JF000000<0n<6=1@0000020?O0T08000001@3k_h<00`000000o<620?c1PP02000000D0oL>00P00
00030?VlQ@030000000001P0000000H0n[n40P0000020?VoR0030000003k`HD0nl650080nl6500@0
00000?VnQ@3i_XD0nKj50P0000020?ZoQ0040000003l`X00o<:00?c2P080000000D0n[n600000000
0000nkn0000000050?ZmO`040000003k_h80nkn2000000D0o<5n00@000000?ZmP@000000cjN`0`00
00020?^mOP<0000000D0n[I@0000003QZi`000000?NjQ`02000000040?k1MP00000000000?bmNPD0
00000P3m_G@02@000000o;ef0000003n`FL000000?jnL0000000S=3n000000040?fmM@80000000@0
o;ef00000000000000000`3n`6T400000080oKef00<000000?fnL@3m_W400P3m_W400`000000m[i=
0?JnC@03000000040?k2J`0000000000000000@0oLb=00<000000?foN@3m_gT00P3m_gT00`000000
oKih0?fnN0020?fnN0040000003m_WL00000000000<0oL1e00<000000?k1K`3n`Fl00P3n`Fl00`00
0000o/E[000000040?joK`050000003n_fh0o[m^0?joKP000000103n_fh010000000o/5Z0000003k
`hP600000080oLJ6100000000`3lbXh000000?_AV`04000000<0o/Eh0`0000001@2o`=/000000?g3
O@3m`gd000000080o/=j0`0000020?k7PP050000003m_W@0oKid0?fnM00000000P3[_3l01P000000
oKe]000000000000o=NL00000080olEh0`0000001@3LdLh000000?g?SP000000e>?R008000000P3m
dY@2000000<0olMj00<000000?ooo`0000000`0000020?k6O`<0000000D0oLN50000003mcHl00000
0?;F/`0200000080oooo00<000000?ooo`3oool02P3oool001D0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
>03oool00`000000WL3a000000040>nlW08000001@3b^Y800`000000lM=R0?7CHP020?7CHPD00000
00<0oM6A0000003``J000P3``J001@000000k[nS0000003XbkP000000080Y=7h0P0000000`3_`:40
0000000000030>njV@80000000P0j/J`0000003c_iH000000?6nVP000000lknG000000@0lKnJ00<0
00000?:jT@3b^Y400`3b^Y400`000000m;Z?0?BjS`020?BjS`030000003_aJH0klFV0080000000L0
ih4l0000003e]H@000000>boY@000000m;jC00<0000000<0l[^D0000000000000`3daI`010000000
m[n@0?JoT00000070?K0TP030000003f`940m/2A00@0m/2A00<000000?JoS`3f_hl01`0000000`3g
_hh000000?S0S0020?S0S080000000<0ml:A0000003f^hX0103f^hX00`000000n[n60?ZoQP030?Zo
QP040000003ecUd0mLiM0?G>G@80000000<0fmKC0000000000000P3f`94010000000mkn>0?NoSP3g
_hh200000080lLb[00<000000?BMB00000000P3f`iH010000000m;fC0?BmT`0000020?2lV@800000
0P3ab:L010000000n<2=0?S0S@0000020?W3S@030000003h`H`0n<6<0080n<6<00<000000?RmR03h
_HP0103h_HP00`000000n[n6000000040?NnSP<000000`3h_HP00`000000n[n60?ZoQP040?ZoQP03
0000003haYH0000000D0n<6=0`000000103g`90000000000000000050?^oP`030000003l`H80o<62
00800000103m`h03000000<0nKb500@000000000600001P000001@3j_h@01@000000n/260000003i
_hP0000000@0nl6500@000000?VnQ@3i_XD0nKj50P0000020?ZoQ0040000003l`X00o<:00?c2P080
000000<0n[n60000000000000P0000050?ZmO`80000000<0nkn20000003l`Gh0103l`Gh00`000000
n[f10000000400000080nken1@0000000`3QZi`000000?NjQ`02000000040?k1MP00000000000?bm
NP<0000000/0nlN>0000003m_G@0oKed0000003l_GH000000?k1I`000000o[i`0000000208c@oP06
0000003m_GD0oKee0?fmM@000000o[i`100000030?k0J@<0000000@0l[J<0000003m_GH00000103m
_W400`000000m[i=0?JnC@03000000050?k2J`00000000000?joL00000000`3mc8d00`000000oKmi
0?foN@020?foN@030000003m_WP0oKih0080oKih00@000000?fnM`00000000000`3m`7D00`000000
o/5_0?k1K`020?k1K`040000003naF/0o/E[000000<0o[m_00D000000?joKP3n_fh0o[m^00000004
0?joKP030000003n`FX000000080000000@0olag000000000000o/Al0P0000000`3maXH000000?k;
R002000000070?c:SP000000nm6K0?_AV`000000oLR7000000030?k5N0050000003naX0000000;o0
f`0000000P3m`gd00`000000o/=j0?k3NP0300000080o/N200D000000?fnM03m_W@0oKid00000002
0>^l?`030000003m_Fd0000000<000000P3oaGP00`000000o/f600000003000000030?g?SP000000
000000<0000000<0o/Ei0000000000000P3oagX010000000oooo0000003cek8200000080o/Io1@00
00020?g=S`030000003be[<000000080oooo00<000000?ooo`3oool02P3oool001H0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0>@3oool2000000@0kkbL00<000000>nnWP000000103b^Y8020000000lM=R0?7CHP3a
df8000000>G5]`000000lKnJ0P0000000`3mdI4000000?31X0030?31X0050000003^_j<000000>S;
^00000000P2TdOP4000000<0kkZI1P0000020?6nVP8000001@3a_iX00`000000l[ZA0?:jT@020?:j
T@030000003d^Xl0m;Z?00<0m;Z?00@000000>o5YP3_aJH0klFV200000000`3e`IH000000?:kU002
000000@0m<FL0`0000060?K0TP030000003f`940m/2A00D0m/2A00<000000?JoS`3f_hl00`3f_hl6
000000050?S0S000000000000000003jaXl00P0000050?JkRP030000003j_hH0n[n600<0n[n600P0
00000?G>G@3ecUd0mLiM0000003^d;D000000=_Fd`80000000<0m/2A0000003g_hh0103g_hh04000
0000lLb[000000000000m9e80000003f`iH000000?BmT`000000mkj=0000003`_9T000000?JmSP00
00020?78Y`030000003h`8d0000000<0nL>=00D000000?S1S03h`H`0n<6<000000060?RmR0030000
003j_hH0000000D0mkj>0P0000030?RmR0030000003j_hH0n[n600@0n[n60`0000060?S1S@H00000
1@3k_h<00`000000o<620?c1PP02000000<0oL>000@000000?RmR@00000000000`3i_8D010000000
000H0000600000040?ZoQ0040000003j`8H0n/2600000080nKn800D000000?_1Q@3k`HD0nl650000
00030?VnQ@8000000P3j_h@00`000000o<:00?c2P0020?c2P0040000003j_hH000000?k7OP800000
1@3j_Gl2000000030?^oPP000000o<5n00@0o<5n00<000000?ZmP@000000100000030?^mOP070000
003f^hX000000000003QZi`000000?NjQ`02000000040?k1MP00000000000?bmNP<0000000/0nlN>
0000003m_G@0oKed0000003l_GH000000?k1I`000000o[i`0000000208c@oP060000003m_GD0oKee
0?fmM@000000o[i`100000030?k0J@<0000000@0l[J<0000003m_GH00000103m_W400`000000m[i=
0?JnC@03000000030?k2J`00000000000080o[m`00@000000?g<S@3mc8d00000103m_gT00`000000
oKih0?fnN0020?fnN0040000003m_WL0oKig000000<0oL1e00<000000?k1K`3n`Fl00P3n`Fl01000
0000o/E[0?k5J`3naF/2000000030?joK`000000o[m^0080o[m^00<000000?joKP3n_fh00P3n_fh0
0`000000o/5Z00000003000000030?o9N0000000o/Al0080000000X0oLJ60000003nbhP000000?W=
V`000000o<Z>0000003kdI/000000P3mb8L01@000000o/Eh0?k5N0000000o/J000<000000P3m`gd2
00000080o/=j0`0000000`3nah8000000?fnM0020?fnM0030000003[_3l0jk`o00@0000000H0oLF0
000000000000olEh0000003ncHH2000000030=cAcP000000000000<0000000D0oooo0000003naGT0
o/Ei000000020?o7NP030000003oool0oooo0080000000d0jmJo0000003naWl0o/Io0000003Aam40
00000?g7Q@000000oLf?0000003be[<000000080oooo00<000000?ooo`3oool02P3oool001L0oooo
0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0000000j0?ooo`8000000P3__9`010000000lKfJ0000000000040?:jTP040000003adf80lM=R0?7C
HP80000000<0j/Rc0000000000000P0000000`3Qc<@00000000000030?31X0030000003^_j<00000
00<0000000@0Y=7h00000000000000000`3_^YT2000000040>bmXP000000mZEM000000<0lKjJ00<0
00000?6oVP3a_iX00`3a_iX00`000000l[ZA0?:jT@020?:jT@030000003d^Xl0m;Z?00@0m;Z?00<0
00000>o5YP3_aJH00P0000020?71W@050000003/_jD000000000003e`IH00P0000000`3f`I@00000
0?C5W0050?C5W0030000003f`980m/2B00@0m/2B00<000000?K0T@3f`9401@3f`9400`000000m[n?
0?JoS`030?JoS`030000003g_hl0mkn?00D0000000<0n<2>0000000000000P0000050?JkRP030000
003j_hH0n[n600<0n[n600<000000?G>G@3ecUd00P0000020>k@]@050000003^cK8000000?K0T@00
00001P3g_hh2000000030=_JeP000000000000@0000000@0mkj=0000003`_9T000000P3f_Hh00`00
0000lLRW0?78Y`02000000@0nL>=0P0000000`3h`H`00000000000050?RmR0030000003j_hH00000
00D0mkj>0`0000020?RmR0030000003j_hH0n[n600@0n[n600<000000?ZoQP0000001P3h`Hd40000
00030?W8U@000000nkn300@0nkn300<000000?c1PP3l`H800P0000030?g3P0040000003h_HT00000
000000<0nKb500D000000000600001P0000H000000030?ZoQ0040000003j`8H0n/26000000<0nKn8
00@000000?_1Q@3k`HD00000103i_XD2000000030?ZoQ0000000o<:000<0o<:00`0000000`3nagh0
0000000000050?ZmO`80000000<0nkn20000003l`Gh00`3l`Gh00`000000n[f10?ZmP@0300000003
0?^nP0000000nken0080nken00@000000?JkRP000000n[I@0P0000020?NjQ`030000003n`GH00000
00D0000000/0nlN>0000003m_G@0oKed0000003l_GH000000?k1I`000000o[i`0000000208c@oP06
0000003m_GD0oKee0?fmM@000000o[i`100000030?k0J@<0000000@0l[J<0000003m_GH00000103m
_W400`000000m[i=0?JnC@04000000040?jnL0000000o[m`0?joL0<0000000<0oKie0000003m_gT0
0P3m_gT00`000000oKih0?fnN0020?fnN080000000<0oKig0000003m`7D00P3m`7D00`000000o/5_
0?k1K`020?k1K`060000003naF/0o/E[0?k5J`000000olIj0P0000030?joKP030000003n_fh0o[m^
0080o[m^00<000000?k1JP0000000`000000103obGP000000?k4O03na7`300000080o/^80P000002
0?c:SP<000000P3mb8L00`000000o/Eh000000020?k6P0040000002o`=/000000?g3O@8000000P3n
`gX3000000030?k7PP000000oKid0080oKid00<000000>^l?`3[_3l01@000000103maH0000000000
000000020?k=QPD000000`3oool01`000000o/Ei0?k5N@3naGT000000?o7NP0000000P3oool01000
0000lmNb0000000000020?k6O`<0000000D0oLN5000000000000oooo000000030?ooo`030000003o
ool0oooo00X0oooo000H0?ooo`030000003oool0oooo0080oooo1000000;0?ooo`800000?03oool2
000000050>nlW0000000lKfJ0?6mVP000000103b^Y8010000000lM=R0?7CHP3adf8300000080j/Rc
0`0000020>7<a00;0000003``J00l<6P0000003^_j<000000>o5YP000000j<^h00000030dnP00P00
00030>njV@070000003ccJP000000>bmXP000000mZEM000000030?6nVP030000003a_iX0lKnJ0080
lKnJ00<000000?:jT@3b^Y400P3b^Y400`000000m;Z?0?BjS`050?BjS`@000000`3a`Id010000000
k;nU0000003e`IH200000080m/6D00<000000?C5W03daI`00`3daI`3000000@0m/2B00<000000?K0
T@3f`9401@3f`9400`000000m[n?0?JoS`030?JoS`030000003g_hl0mkn?0080mkn?1@0000020?C1
V0030000003f^hX0m[^:00<0m[^:00<000000?ZoQP3j_hH00`3j_hH00`000000mLiM0?G>G@040000
00030>k@]@000000k/fb008000001P3g_hh200000080fm[F1@0000000`3g_Xd00000000000030?Jm
SP040000003ab:L0lLRW0?78Y`800000103i`hd4000000D0n;f800@000000?ZoQP3j_hH00000103g
_Xh00`000000n;n;000000020?RmR0030000003j_hH0n[n600@0n[n600@000000?ZoQP3j_hH00000
1@3h`Hd4000000030?W8U@000000nkn300@0nkn300<000000?c1PP3l`H800P0000020?g3P0050000
003h_HT000000?_2QP0000000`3i_8D01@000000000H0000600001P0000000<0n[n400D000000?[0
QP3j`8H0n/26000000020?VoR080000000<0nl650000003i_XD00`3i_XD2000000030?ZoQ0000000
o<:000<0o<:00`0000000`3nagh00000000000050?ZmO`80000000<0nkn20000003l`Gh00`3l`Gh0
10000000n[f10?ZmP@3j_H42000000030?^nP0000000nken0080nken00@000000?JkRP000000n[I@
0P0000020?NjQ`030000003n`GH0000000<0000000@0o/1d0000003kahh000000P3m_G@01`000000
o;ef0000003n`FL000000?jnL00000000P2<d?h01P000000oKee0?fmM@3m_GD000000?jnL0800000
00<0o[i`0000003n`6T00P3n`6T3000000040?:fS0000000oKef000000@0oKia00<000000?JnC@3f
_Td010000000103n_W0000000?joL03n_g05000000<0oKmi0P0000030?fnN08000000P3m_WL01000
0000oL1e0?g0M@0000040?k1K`050000003naF/0o/E[0?k5J`0000000P3oaWX01@000000o[m^0?jo
KP3n_fh0000000@0o[m^1@0000020?o9N0040000003na7`0o/Al0?k4O08000000P3nbhP00`000000
nLfK000000020?c:SP8000000`3mb8L200000080o/J00`0000001@3m`gd00000000000000000o/=j
00@0000000H0o/N20000003m_W@0oKid0000003[_3l6000000040?g5P0000000000000000080o/f6
0P0000000`3LdLh00000000000040?ooo`030000003naGT0o/Ei00<000000`3oool3000000<0o/Io
0`0000000`3mahD000000?ooo`040?ooo`030000003oool0oooo00X0oooo000/0?ooo`030000003o
ool0oooo03`0oooo0`0000020?6mVP030000003b^Y80l[ZB0080l[ZB00@000000?7CHP3adf80lM=R
0P0000000`3ccJT000000>[8/`02000000050?6oVP00000000000>7<a00000000P3``J0200000080
klFV00<000000>[9/`0000000`0000020>njV@030000003ccJP000000080k;fR0P0000030?6nVP03
0000003a_iX0lKnJ0080lKnJ00<000000?:jT@3b^Y400P3b^Y400`000000m;Z?0?BjS`050?BjS`80
00000P0004D01@000000lL6M0?71W@000000k;nU00@000000`3f`I@00`000000m<FL0?C5W0020?C5
W0040000003d_Y<0m;jC000000<0m/2B00<000000?K0T@3f`9401@3f`9400`000000m[n?0?JoS`03
0?JoS`030000003g_hl0mkn?00@0mkn?00<000000?C1V03d`IP00P3d`IP00`000000m[^:0?JkRP03
0?JkRP030000003j_hH0n[n600<0n[n600T000000?G>G@3ecUd000000?O1T@000000ml6A0000003^
d;D00`0000060?NoSP030000003g`8h0000000H0000000<0mkj=000000000000103f_Hh01@000000
lLRW0?78Y`000000ml2A00<0000000<0nL>=0000003e`9D00P0000040?RmR0050000003j_hH0n[n6
0?ZoQP000000103g_Xh300000080n;f800<000000?ZoQP3j_hH0103j_hH010000000n[n60?ZoQP00
00050?S1S@040000003h_XT0000000000080nLRE00<000000?^oP`3k_h<00P3k_h<01P000000o<62
0?c1PP3l`H8000000?g3P080000000@0n;f90000003k`XH000000`3i_8D00`000000000H00006002
000060040000003j_h@0n[n4000000<0n/2600<000000?VoR03i_hP00P0000000`3k`HD000000?Vn
Q@030?VnQ@80000000<0n[n40000003l`X000`3l`X03000000030?k7OP000000000000D0n[eo00@0
00000?bnN`0000000000103l`Gh010000000n[f10?ZmP@3j_H44000000<0nken00@000000?JkRP00
0000n[I@0P0000020?NjQ`030000003n`GH0o/5f00<0000000H0o/1d0000003kahh0nlN>0000003m
_G@400000080o[i`00@0000008c@oP2<d?h000000`3m_GD01P000000o[i`000000000000o[i`0000
00<0o/1Y0P0000001@3MYIX000000000003m_GH0000000@0oKia00<000000?JnC@3f_Td00`000002
0?jnL0050000003n_g00o[m`0000003m_gP00`0000030?foN@8000000`3m_WP200000080oKig00@0
00000?g0M@3m`7D00000103n`Fl01@000000o/E[0?k5J`3naF/0000000<0olIj00@000000?joKP3n
_fh00000103n_fh500000080olUh00@000000?k4O03na7`0o/Al0P0000030?k;R08000000P3lbXh0
0`000000o<J;000000020?g8Q`8000000P3naX02000000060;o0f`00000000000?ooo`000000o/=j
10000000203nah8000000?fnM03m_W@000000>^l?`000000nM6O100000020?g5P08000000`3ncHH3
000000D0oooo00<000000?k5N@3naGT00`0000030?ooo`040000003cek80000000000080o/Io0`00
00000`3mahD000000?ooo`040?ooo`030000003oool0oooo00X0oooo000/0?ooo`030000003oool0
oooo03d0oooo0P0000020?6mVP030000003b^Y80l[ZB0080l[ZB00@000000?7CHP3adf80lM=R0P00
00020??=Z@80000000<0j/Rc0000000000000P0000000`3^`:<0000000000002000000<0klFV0P00
00000`3ZbK<00000000000020>njV@040000003ccJP0llfX00000080k;fR0P0000030?6nVP050000
003a_iX0lKnJ0?6oVP000000103b^Y400`000000m;Z?0?BjS`050?BjS`040000000004D000150000
A@<0000000<0n<VH0000003/_jD00`0000040?K1U080000000<0m<FL0000003d_Y<00`3d_Y<01000
0000m/2B0?K0TP0000070?K0T@030000003f_hl0m[n?00<0m[n?00<000000?NoS`3g_hl0103g_hl2
000000@0m<6H00<000000?JkRP3f^hX00P3f^hX00`000000n[n60?ZoQP030?ZoQP040000003ecUd0
mLiM00000080ml6A0`0000000`3^d;D00000000000050?NoSP030000003g`8h0ml2>0080ml2>1@00
00020?NnS@030000003f_Hh0m[f>00<0m[f>0P0000050?O0T@8000000P3e`9D00`000000n;f80?Rm
R0020?RmR0050000003j_hH0n[n60?ZoQP000000103g_Xh300000080n;f800<000000?ZoQP3j_hH0
103j_hH01@000000n[n60?ZoQP3j_hH0000000@0n<6=00D000000?RnR@000000mkb:000000020?W8
U@050000003k_h<0nkn30?^oP`0000000`3l`H84000000030?RmR@000000nl:6008000000P3i_8D0
10000000000H0000600001P200000080n[n400D000000?[0QP3j`8H0n/26000000020?VoR0040000
003i_XD00000000000@0nKj50P0000000`3j_h@000000?c2P0030?c2P0<0000000<0o/Mn00000000
00001@3j_Gl010000000o;ik0000000000040?c1OP040000003j_H40n[f10?ZmP@@000000`3k_Gh0
0`000000m[^:0000000300000080mkZ70P0000001P3n`GH00000000000000000o/1d00000080nlN>
00<000000?fmM00000000`0000020?jnL0040000002<d?h0S=3n000000<0oKee00H000000?jnL000
000000000?jnL00000040?k0J@060000003MYIX000000000003m_GH00000103m_W400`000000m[i=
0?JnC@03000000<0o[i`00D000000?joL03n_g0000000?foN002000000<0oKmi0P0000030?fnN080
00000P3m_WL01@000000oL1e0?g0M@3m`7D0000000<0o/5_00D000000?k5J`3naF/0o/E[00000004
0?o6NP<000000P3n_fh6000000<0olUh00@000000?k4O03na7`0o/Al0`0000020?k;R0050000003i
cI/000000000003bdJh00P0000001P3mb8L000000?g6PP3maX8000000?k6P0D0000000D0oooo0000
003n`gX000000?ooo`0400000080oKid00<000000>^l?`0000001P000000103maH00000000000000
00020?k=QP030000003oool0oooo00H0oooo00D000000?k5N@000000oooo000000040?ooo`<00000
0P3naWl5000000D0oooo00<000000?ooo`3oool02P3oool002/0oooo00<000000?ooo`3oool0?`3o
ool010000000lKfJ0?6mVP0000040?:jTP030000003adf80lM=R008000001@3ccJT01P000000j/Rc
0>[8/`000000lL6N00000080k/2S00@000000?33X`00000000000`3_aJH01@000000j/Vc0000003_
^YT0000000<0llfX00@000000>bmXP3/_J80k;fR0P0000030?6nVP040000003a_iX0lKnJ000000@0
l[ZA00<000000?BjS`3d^Xl01@3d^Xl01000000000150000A@0004D300000080n<VH1P0000040?K1
U08000001@3d_Y<3000000H0m/2A00<000000?JoS`3f_hl0103f_hl00`000000mkn?0?NoS`040?No
S`800000103d`IP00`000000m[^:0?JkRP020?JkRP030000003j_hH0n[n600<0n[n600@000000?G>
G@3ecUd00000103g`I45000000@0mkn>00<000000?O0SP3g`8h00`3g`8h400000080mkj=00<00000
0?JmSP3f_Hh0103f_Hh00`000000ml2A0?O0T@040?O0T@8000000P3e`9D01@000000n;f80?RmR03h
_HP0000000@0n[n600L000000?NnSP3g_Xh0mkj>0000003h`Hh000000080n;f800<000000?ZoQP3j
_hH0103j_hH01@000000n[n60?ZoQP3j_hH0000000@0n<6=00L000000?RnR@3h_XT000000?NlRP00
0000nLRE008000000P3k_h<010000000o<620?c1PP3l`H83000000030?ZoQ000000000000080nl:6
00@000000?VlQ@3i_8D000000`0001P200000080n[n400D000000?[0QP3j`8H0n/26000000020?Vo
R0040000003i_XD0nKj5000000D0nKj50`0000040?c2P0060000003l`Wl000000000003l`Wl00000
1@3j_Gl010000000o;ik0000000000040?c1OP040000003j_H40n[f10?ZmP@@000000`3k_Gh20000
00080?JkRP00000000000>6[W0000000mkZ70000003]dUd4000000060?k0M0000000nlN>0?_7SP00
0000oKed100000020?jnL0040000002<d?h0S=3n000000<0oKee00H000000?jnL000000000000?jn
L00000040?k0J@@0000000<0oKef0000003m_W400`3m_W400`000000m[i=0?JnC@03000000<0o[i`
00D000000?joL03n_g0000000?foN002000000<0oKmi0P0000030?fnN08000000`3m_WL010000000
oL1e0?g0M@0000030?k1K`050000003naF/0o/E[0?k5J`0000000`3oaWX600000080o[m^0P000000
0`3oa7<0000000000003000000<0o/Al0P0000000`3ka8L000000?k;R004000000030?;A[P000000
o<J;008000000P3maX800`000000o/J00?k6P004000000050?ooo`00000000000000003oool01000
00020?fnM0030000003[_3l0000000@0000000@0oooo0000003maH00oLF00`0000000`3ncHH00000
0?ooo`070?ooo`030000003naGT0000000P0oooo0P0000000`3naWl000000?ooo`03000000D0oooo
00<000000?ooo`3oool02P3oool002/0oooo00<000000?ooo`3oool0@03oool00`000000lKfJ0000
00040?:jTP030000003adf80lM=R008000001P3ccJT2000000040>[:]0000000lL6N00000080k/2S
0P0000000`3``j<000000>o5YP020>o5YP040000003ZbK<00000000000@0llfX00<000000>bmXP3/
_J800P0000020?6nVP8000000P3a_iX00`000000l[ZA0?:jT@020?:jT@030000003d^Xl0m;Z?00D0
m;Z?00H000000000A@0004D000150000003[_:<4000000040>boY@00000000000?>nUP8000000`3f
`I@2000000L0m;jC00<000000?K0T@3f`940103f`9400`000000m[n?0?JoS`040?JoS`030000003g
_hl0mkn?00@0mkn?00<000000?JoT00000000`3d`IP00`000000m[^:0?JkRP020?JkRP030000003j
_hH0n[n600<0n[n600@000000?G>G@3ecUd000001@3g`I4010000000ml6@0000000000040?NoSP03
0000003g`8h0ml2>00@0ml2>0`0000020?NnS@030000003f_Hh0m[f>00@0m[f>0P0000050?O0T@80
00000P3e`9D01@000000n;f80?RmR03h_HP0000000@0n[n600H000000?NnSP3g_Xh0mkj>0000003h
`Hh2000000030?RmR0000000n[n600D0n[n600<000000?ZoQP3j_hH00P3j_hH010000000n<6=0?S1
S@0000030?RnR@030000003g_8X0mkb:00<000000P3k_h<020000000o<620?c1PP3l`H8000000?c1
PP000000n[n40P0000020?_2QP040000003i_8D0nKb5000000<0000H00D000000?VmQ0000000n[n4
000000040?[0QP030000003i_hP000000080nKj500<000000?VnQ@3i_XD00`3i_XD3000000@0o<:0
00<000000?c2O`0000000`0000050?ZmO`040000003l_W/00000000000@0o<5n00@000000?ZmP@3j
_H40n[f1100000040?^mOP080000003f^hX000000000003QZi`000000?NjQ`0000020>gBG@<00000
00H0o/1d0000003kahh0nlN>0000003m_G@400000080o[i`00@0000008c@oP2<d?h000000`3m_GD0
1P000000o[i`000000000000o[i`000000@0o/1Y100000000`3m_GH000000?fnL@030?fnL@030000
003f_Td0m[i=00800000103n_W0020000000o[m`0?joL0000000oKmh0000003m_WD000000P3m_gT2
000000<0oKih0P0000030?fnM`040000003m`7D0oL1e000000<0o/5_00<000000?k5J`0000001@00
0000103oaWX000000<mD303?E0`200000080o[m^0`0000001@3oa7<000000000003n`gL0000000<0
o/Al0P0000000`3ka8L000000?k;R00400000080l]6^0`0000030?g6PP030000003naX00000000<0
00000P3oool200000080oooo00<000000?ooo`0000000P3m_W@00`000000jk`o0000000400000080
oooo0`000000103oool000000?k=QP0000090?ooo`8000002@3oool200000080oooo0`0000050?oo
o`030000003oool0oooo00X0oooo000[0?ooo`030000003oool0oooo0400oooo0`0000040?:jTP03
0000003adf80lM=R008000001`3ccJT01P000000j/Zd0>[:]0000000lL6N00000080k/2S0P000000
0`3``j<000000>o5YP020>o5YP<00000103ccJP010000000k;fR0>bmXP3/_J82000000060?6nVP00
0000lKbG0000003a_iX00000103b^Y400`000000m;Z?0?BjS`040?BjS`030000000004D000150080
001500@000000>^lX`00000000000P3_`Z8700000080m/6D00<000000?JoT00000001P3d_Y<30000
00@0m/2A00<000000?JoS`3f_hl0103f_hl00`000000mkn?0?NoS`040?NoS`040000003f_i00m[n@
00000080m<6H00D000000?JkRP3f^hX0m[^:000000060?ZoQP030000003ecUd0000000H0ml6A1@00
00030?NoSP030000003g`8h0ml2>00@0ml2>100000020?NnS@030000003f_Hh0m[f>00<0m[f>0P00
00050?O0T@050000003f`I8000000?G0U@0000000`3h_HP00`000000n[n60?ZoQP020?ZoQP050000
003g_Xh0mkj>0?NnSP0000000P3h`Hh00`000000n;f8000000050?ZoQP030000003j_hH0n[n600<0
n[n600@000000?S1S@3h`Hd000000`3h_XT00`000000mkb:0?NlRP020?NlRP80000000<0nkn30000
003l`H80103l`H8010000000n[n40000000000020?_2QP040000003i_8D0nKb5000000<0000H00D0
00000?VmQ0000000n[n4000000040?[0QP030000003i_hP000000080nKj500<000000?VnQ@3i_XD0
0`3i_XD3000000@0o<:000<000000?c2O`0000000`0000050?ZmO`040000003l_W/0o;ik000000@0
o<5n00<000000?ZmP@3j_H400P3j_H42000000030?^nP0000000nken0080nken00P000000?JkRP00
000000000>6[W0000000mkZ700000080kM9M0`0000020?k0M0040000003kahh000000?fmM0@00000
0P3n_W0010000000S=3n08c@oP0000030?fmM@060000003n_W0000000000003n_W000000103n`6T4
000000030?fmMP000000oKia00<0oKia00<000000?JnC@3f_Td00P0000040?jnL0040000003n_g00
o[m`00000080oKmh0P0000020?foN@030000003l`7d000000080oKih00<000000>fA9@0000000P3m
_WL00`000000oL1e0?g0M@0600000080o/E[0`0000020?o6NP040000003?E0`0ce@<0<mD30L00000
00D0oL1l000000000000o/=g000000020?k4O0040000003kdI/000000?_4Q`80000000<0o<B40000
000000000P3bdJh00`000000o<J;000000030?g6PP040000003naX0000000=2ia08000000P3oool2
000000@0oooo00L000000?fnM03m_W@000000>^l?`000000oooo00<000000P3oool2000000<0oooo
0P0000090?ooo`8000002@3oool2000000<0oooo0P0000050?ooo`030000003oool0oooo00X0oooo
000[0?ooo`030000003oool0oooo0440oooo0P0000040?:jTP030000003adf80lM=R008000001P3c
cJT01@000000kk^J000000000000j/Zd008000000`3^`:<2000000050?33X`00000000000000002Q
a_<00P0000050??=Z0030000003/_J80k;fR00@000000P3a_9L2000000@0l[ZA00<000000?BjS`3d
^Xl0103d^Xl00`00000000150000A@020000A@040000003[_:<0jkbS00000080kl:R0P0000001@3d
_I800000000000000000l[fG00<0000000<0m[n@0000003d_Y<01@3d_Y<010000000ml:B0?O2TP00
00030?K0T@030000003f_hl0m[n?00<0m[n?00<000000?NoS`3g_hl01@3g_hl01`000000m[n@0?Jo
T03f_i0000000?C1V00000000`3f^hX00`000000n[n60?ZoQP040?ZoQP030000003ecUd0000000H0
ml6A00<000000?O1T@3g`I400`0000020?NoSP030000003g`8h0ml2>00@0ml2>00@000000?NoS`00
000000000P3g_Xd00`000000m[f>0?JmSP030?JmSP030000003h`Hd0000000@0ml2A00D000000?K1
TP000000mL2E000000030?RmR0030000003j_hH0n[n600<0n[n600<000000?NnSP0000000`3h`Hh0
0`000000n;f8000000050?ZoQP030000003j_hH0n[n600@0n[n600<000000?S1S@0000000`3h_XT0
0`000000mkb:0?NlRP020?NlRP@000000`3l`H83000000030?ZoQ000000000000080nl:600@00000
0?VlQ@3i_8D000000`0001P00`000000nKf40?VmQ002000000@0n/2600<000000?VoR00000000`3i
_XD00`000000nKj50?VnQ@020?VnQ@<000000`3l`X03000000040?_3QP000000oLN5000000D0n[eo
00@000000?bnN`3l_W/00000103l`Gh00`000000n[f10?ZmP@020?ZmP@80000000<0nkj00000003k
_Gh00P3k_Gh020000000m[^:000000000000hJ^L0000003g^XL000000`3]dUd200000080o/1d00@0
00000?_7SP000000oKed100000020?jnL0050000002<d?h0S=3n08c@oP0000000P3m_GD01P000000
o[i`0?jnL0000000o[i`000000@0o/1Y0`0000000`3b]X`00000000000040?fnL@030000003f_Td0
m[i=00800000103n_W0010000000o[m`0?joL00000020?foN08000000P3m_gT00`000000o<1m0000
00020?fnN0030000003]TBD0000000H000000`3n`Fl010000000o/E[0?k5J`0000030?fnLP<00000
0P3?E0`3000000070?K6V`00000000000000003m`7`000000?g0O00300000080o/Al00<000000?_A
V`0000000P3ka8L02@000000o<B40000003jaY0000000?;A[P000000o<J;000000040?g6PPD00000
0`3oool00`000000oooo0?ooo`030?ooo`050000003m_W@000000>^l?`0000000P3oool200000080
oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3oool02P3oool002/0oooo0`0000110?ooo`03
0000003^^i`000000080l[ZB00<000000?7CHP3adf802P0000030>nkVP040000003Zb[@0j/Zd0000
00<0k/2S1@0000000`2Qa_<00000000000050??=Z0030000003/_J80k;fR00@000000P3a_9L20000
00@0l[ZA00<000000?BjS`3d^Xl0103d^Xl00`00000000150000A@020000A@80000000<0jkbS0000
000000000P3_`Z82000000030?BmTP000000000000<0l[fG00@000000?JoT03f_i0000001@3d_Y<0
1@000000ml:B0?O2TP3g`Y8000000080m/2A00<000000?JoS`3f_hl00`3f_hl00`000000mkn?0?No
S`050?NoS`070000003f_i00m[n@0?JoT0000000m<6H000000030?JkRP030000003j_hH0n[n600@0
n[n600<000000?G>G@0000001P3g`I4010000000ml6A0?O1T@3g`I43000000030?NoSP000000ml2>
00D0ml2>00@000000?NoS`00000000000P3g_Xd00`000000m[f>0?JmSP030?JmSP030000003h`Hd0
000000@0ml2A00H000000?K1TP3f`I8000000?G0U@0000020?RmR0030000003j_hH0n[n600<0n[n6
00<000000?NnSP0000000`3h`Hh00`000000n;f8000000050?ZoQP030000003j_hH0n[n600@0n[n6
00<000000?S1S@0000000`3h_XT00`000000mkb:0?NlRP030?NlRP030000003k`X@0000000<00000
0P3k_h@010000000n[n40000000000020?_2QP040000003i_8D0nKb5000000<0000H00<000000?Vm
Q03i_H@00P0000050?[0QP8000000`3i_XD00`000000nKj50?VnQ@020?VnQ@040000003mcV`00000
0?c2P0800000103k`hH00`000000oLN5000000050?ZmO`050000003l_W/0o;ik0?bnN`0000000`3l
`Gh00`000000n[f10?ZmP@020?ZmP@@000000`3k_Gh020000000m[^:000000000000hJ^L0000003g
^XL000000`3]dUd2000000<0o/1d0P0000000`3m_G@000000000000200000080o[i`00D0000008c@
oP2<d?h0S=3n000000020?fmM@060000003n_W00o[i`0000003n_W000000103n`6T3000000030?:f
S0000000000000@0oKia00<000000?JnC@3f_Td00P0000040?jnL0060000003n_g00o[m`0?joL000
0000oKmh0P0000020?foN@030000003l`7d0000000D000000`3m_WL00`000000oL1e000000030?k1
K`040000003naF/0o/E[000000<0oKib00<000000?joK@0000000`000000203k`ET000000?K6V`00
0000nLRC0000003m`7`000000P3m`7`3000000040?k4O0000000nm6K00000080nlB700<000000?c4
Q03la8@00P0000020?;A[P<000000`3maX83000000/0oooo00D000000?fnM0000000jk`o00000002
0?ooo`8000000`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`00:`3oool00`000000oooo0?ooo`120?oo
o`8000000P3b^Y801P000000lM=R0?7CHP000000k[nR00000080kkfM0P0000030?6mV0050000003_
^iX0kk^J0>nkVP0000000P3Zb[@02`000000k/2S0000003_`Z@000000?70WP000000klFX0000002Q
a_<0000000H0llfX0P000000102R:00000000000000000030?6lU`8000000`3b^Y400`000000m;Z?
0?BjS`040?BjS`030000000004D00015008000150`0000000`3a^iH000000>o2XP030>o2XP<00000
103b_IL3000000D0m;jC00<000000?O2TP3g`Y800P3g`Y83000000D0m[n?00<000000?NoS`3g_hl0
1@3g_hl00`000000m[n@0?JoT0020?JoT08000000`3f^hX00`000000n[n60?ZoQP040?ZoQP030000
003ecUd0000000H0ml6A00<000000?O1T@3g`I400P3g`I42000000030?NoSP000000ml2>00@0ml2>
00@000000?NoS`3g_hl0mkn?0P0000020?NnS@030000003f_Hh0m[f>0080m[f>00@000000?S1S@3h
`Hd000000P3g`9401`000000m/6B0?K1TP3f`I8000000?G0U@0000000P3h_HP00`000000n[n60?Zo
QP030?ZoQP030000003g_Xh0000000<0n<6>00<000000?RmR00000001@3j_hH00`000000n[n60?Zo
QP040?ZoQP<00000103h_XT00`000000mkb:0?NlRP020?NlRP030000003k`X@0nl:400800000103k
_h@300000080nl:600@000000?VlQ@3i_8D000000`0001P01@000000nKf40?VmQ03i_H@0000000D0
n/260P0000030?VnQ@030000003i_XD0nKj50080nKj500H000000?g>K000000000000?g>K0000004
0?_3QP040000003mahD0oLN5000000@0n[eo00<000000?bnN`3l_W/00P3l_W/010000000o<5n0?c1
OP0000040?ZmP@@000000`3k_Gh00`000000m[^:0?JkRP03000000030?NjQ`000000kM9M00<0kM9M
00@000000?k0M03n`7@0o/1d0P0000000`3m_G@000000000000200000080o[i`00D0000008c@oP2<
d?h0S=3n000000020?fmM@060000003n_W00o[i`0000003n_W000000103n`6T3000000030?:fS000
0000000000@0oKia00<000000?JnC@3f_Td00P0000040?jnL0060000003n_g00o[m`0?joL0000000
oKmh1`0000020?fnN0030000003]TBD0000000<0oKig00<000000?g0M@0000000`3n`Fl010000000
o/E[0000000000030?fnLP030000003n_fd0o[m]0080o[m]00<000000?_1F@3k`ET0100000020?g0
O0030000003m`7`000000080000000H0o/Al0000003kdI/0nm6K0000003ka8L2000000050?c4Q000
0000n/J@0000003bdJh00`0000030?g6PP800000303oool00`000000oKid0000000200000080oooo
0P0000030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02P3oool002/0oooo00<0
00000?ooo`3oool0@P3oool200000080l[ZB00@000000?7CHP3adf8000000P3^_j800`000000kkfM
0000000200000080lKfH00<000000>nkVP3_^iX00P3_^iX500000080kl:T1`0000050??=Z0800000
0P2R:002000000@0lKbG00D000000?:jT@3b^Y40l[ZA000000060?BjS`030000000004D000150080
00150`0000020?6kUP040000003_`Z80kl:R0>o2XP80000000<0m;jB0000003b_IL00`3b_IL30000
00@0m;jC00<000000?O2TP3g`Y80103g`Y800`000000m[n?0?JoS`030?JoS`030000003g_hl0mkn?
00D0mkn?00<000000?JoT03f_i000`3f_i001@000000m[^:0?JkRP3f^hX0000000H0n[n600<00000
0?G>G@0000001P3g`I400`000000ml6A0?O1T@040?O1T@8000001@3g`8h010000000mkn?0?NoS`3g
_hl200000080mkj=00<000000?JmSP3f_Hh00P3f_Hh01`000000n<6=0?S1S@3h`Hd000000?O0T@00
0000103f`I8200000080n;f800<000000?ZoQP3j_hH00`3j_hH3000000@0n<6>0P0000050?ZoQP03
0000003j_hH0n[n600@0n[n60`0000040?RnR@030000003g_8X0mkb:0080mkb:1@0000040?^oQ003
0000003j_h@000000080nl:600@000000?VlQ@3i_8D000000P0001P00`000000nKf40?VmQ0020?Vm
Q0030000003j`8H0n/2600<0n/260P0000030?VnQ@030000003i_XD0nKj50080nKj500<000000?g>
K03mcV`00P3mcV`2000000<0nl>600@000000?g7Q@3mahD00000103j_Gl00`000000o;ik0?bnN`02
0?bnN`80000000<0o<5n0000003j_H400`3j_H44000000<0nken00<000000?JkRP3f^hX00`000000
0`3g^XL000000>gBG@020>gBG@800000103n`7@00`000000oKed0000000300000080o[i`00D00000
08c@oP2<d?h0S=3n000000020?fmM@060000003n_W00o[i`0000003n_W000000103n`6T300000003
0?:fS0000000000000@0oKia00<000000?JnC@3f_Td00P0000040?jnL0P000000P3m_gT00`000000
o<1m000000020?fnN0030000003]TBD0000000<0oKig00<000000?g0M@0000000`3n`Fl010000000
o/E[0000000000030?fnLP030000003n_fd0o[m]0080o[m]00<000000?_1F@3k`ET0100000030?g0
O0H000000P3kdI/020000000nlB7000000000000o<B40000003jaY0000000P3bdJh00`000000oL9o
000000020?g6PP030000003oool0oooo00/0oooo00<000000?fnM00000000P00000^0?ooo`030000
003oool0oooo00T0oooo000[0?ooo`030000003oool0oooo04<0oooo00@000000?:jTP3b^Y800000
0P3adf8010000000k[nR0>joXP0000020>nmW@030000003Vbk/000000080lKfH00<000000>nkVP3_
^iX00`3_^iX00`000000k[jQ000000040>o2Y0030000003a`9h0000000H0000000<0llfX00000000
00000P2R:003000000<0lKbG00@000000?:jT@3b^Y4000001`3d^Xl00`00000000150000A@020000
A@<000000`3a^iH01`000000kl:R0>o2XP3_`Z8000000?BnTP000000103b_IL00`000000i<6c0000
00030?BnT`030000003g`Y80ml:B00D0ml:B0P0000040?JoS`030000003g_hl0mkn?00@0mkn?00<0
00000?JoT03f_i00103f_i001@000000m[^:0?JkRP3f^hX0000000H0n[n600@000000?G>G@000000
00001@3g`I400`000000ml6A0?O1T@040?O1T@8000001@3g`8h02@000000mkn?0?NoS`3g_hl00000
0?BmTP000000mkj=000000040?JmSP070000003h`Hd0n<6=0?S1S@000000ml2A000000040?K1TP80
00000P3h_HP00`000000n[n60?ZoQP030?ZoQP<00000103h`Hh2000000D0n[n600<000000?ZoQP3j
_hH0103j_hH00`000000nKj6000000040?RnR@030000003g_8X0mkb:0080mkb:00<000000?NkR03g
^hP00`0000030?^oQ0030000003j_h@000000080nl:600@000000?VlQ@3i_8D000000P0001P00`00
0000nKf40?VmQ0020?VmQ0030000003j`8H0n/2600<0n/260P0000030?VnQ@030000003i_XD0nKj5
0080nKj500<000000?g>K03mcV`00P3mcV`01P000000oLF4000000000000nl>600000080oLN500<0
00000?ZmO`3j_Gl00P3j_Gl00`000000o;ik0?bnN`020?bnN`040000003l_g/00000000000D0n[f1
0`0000040?^mOP030000003f^hX000000080000000<0mkZ70000003]dUd00P3]dUd2000000@0o/1d
00<000000?fmM03m_G@00`0000020?jnL0050000002<d?h0S=3n08c@oP0000000P3m_GD01P000000
o[i`0?jnL0000000o[i`000000@0o/1Y0`0000000`3b]X`00000000000040?fnL@030000003f_Td0
m[i=00L000000`3n_g000`000000oKmh00000002000000070?foN@000000o<1m0?c0O@000000oKih
000000020>fA9@030000003m_WL0oKig00<000000`3n`Fl010000000o/E[0000000000030?fnLP03
0000003n_fd0o[m]0080o[m]00P000000?_1F@3k`ET000000?_?U`000000o<N<000000<0oL1l1@00
00030?_AV`<000000P3la8@02@000000n/J@0000003bdJh000000?g2O`000000oLJ20000000>0?oo
o`030000003m_W@0000000800000;P3oool00`000000oooo0?ooo`090?ooo`00:`3oool00`000000
oooo0?ooo`130?ooo`040000003b^Y80l[ZB00000080lM=R00D000000>joXP3^_j80k[nR00000002
0>nmW@030000003Vbk/00000008000001@3_^iX2000000030>jnX@000000kl:T00<0kl:T00D00000
0?70WP000000klFX000000020?6kUP<0000000@0ilBc0000002R:000XRP00P0000030?6lU`040000
003b^Y40l[ZA000000L0m;Z?00@000000000A@0004D00015100000040?6kUP030000003_`Z80kl:R
0080000000<0m;jB0000003b_IL00P3b_IL400000080m;jC00<000000?O2TP3g`Y801@3g`Y800`00
0000m/6C000000030?JoS`030000003g_hl0mkn?00@0mkn?00<000000?JoT03f_i00103f_i001@00
0000m[^:0?JkRP3f^hX0000000H0n[n60P0000020?JoT0030000003g`I40ml6A0080ml6A00<00000
0?O1T@3g`I40103g`I43000000@0ml2>00<000000?NoS`3g_hl00P3g_hl200000080mkj=00D00000
0?JmSP3f_Hh0m[f>000000040?S1S@8000001@3f`I82000000030?RmR0000000n[n600@0n[n60`00
00040?S1SP8000001@3j_hH00`000000n[n60?ZoQP040?ZoQP030000003i_XH0000000@0n;j900<0
00000?NlRP3g_8X00P3g_8X00`000000mk^80?NkR00400000080nkn40`0000030?_2QP030000003i
_8D000000080000H00<000000?VmQ03i_H@00`3i_H@00`000000n/260?[0QP020?[0QP800000103i
_XD01@000000nKj50?VnQ@3i_XD0000000<0oLi/00D000000?g5Q03maH@000000?g5P`0200000003
0?g7Q@000000000000@0n[eo00<000000?bnN`3l_W/00P3l_W/010000000o;mk0000000000050?Zm
P@<00000103k_Gh00`000000m[^:00000002000000030?NjQ`000000kM9M0080kM9M100000030?k0
M0030000003m_G@00000008000000P3n_W001@000000S=3n08c@oP2<d?h000000080oKee00<00000
0?jnL03n_W000P3n_W000`000000o/1Y0?k0J@020?k0J@80000000D0gJFJ00000000000000000?fn
L@08000000@0o[i`00@000000?joL03n_g00o[m`1@0000001`3m_gT000000?c0O@3l`7d000000?fn
N00000000P3]TBD00`000000oKig0?fnM`03000000<0o/5_0P0000000`3m`V@000000?fnLP020?fn
LP030000003n_fd0o[m]0080o[m]00D000000?_1F@00000000000?_?U`03000000<0oL1l0P000000
0`3ka8X00000000000030?_AV`80000000D0o<J:0000003la8@000000?[6T00300000080oL9o0P00
000>0?ooo`030000003m_W@0000000800000;P3oool00`000000oooo0?ooo`090?ooo`00:`3oool0
0`000000oooo0?ooo`130?ooo`080000003b^Y80l[ZB0000003adf8000000?2kV00000030>joXP04
0000003__Id0kkfM00000080i/^k0P0000040>nkVP8000000P3^_Z400`000000kl:T0>o2Y0020>o2
Y0@000000P3a^iH01`000000hkFX000000000000ilBc0000002R:0000`0000020?6lU`040000003b
^Y40l[ZA000000L0m;Z?00T000000000A@0004D000150000003a_i`000000?BoU@0000000`3a^iH0
0`000000kl:R000000020?76Y08000000P3b_IL020000000l/BO000000000000l[ZC0000003d_Y<0
00001`3g`Y800`000000m/6C0?K1T`02000000030?JoS`000000mkn?00D0mkn?00<000000?JoT03f
_i00103f_i001@000000m[^:0?JkRP3f^hX0000000H0n[n60P0000030?JoT08000000P3g`I400`00
0000ml6A0?O1T@040?O1T@040000003f`9400000000000<0ml2>00<000000?NoS`3g_hl00P3g_hl2
00000080mkj=00@000000?JmSP3f_Hh000001@3h`Hd2000000D0m/6B0P0000000`3h_HP000000?Zo
QP040?ZoQP030000003j`8L0000000@0n<6>0P0000050?ZoQP030000003j_hH0n[n600@0n[n600@0
00000?VnQP3i_XH000000`3h_XT00`000000mkb:0?NlRP020?NlRP030000003g^hP0mk^800@00000
0P3k_h@2000000070?ZoQ0000000nl:60?_2QP000000nKb500000002000060030000003i_H@0nKf4
00<0nKf400<000000?[0QP3j`8H00P3j`8H2000000@0nKj500D000000?VnQ@3i_XD0nKj500000003
0?g>K0030000003maH@0000000L00000103j_Gl00`000000o;ik0?bnN`020?bnN`040000003l_g/0
0000000000D0n[f10`0000040?^mOP050000003f^hX000000000003QZi`00P0000030>gBG@800000
00<0jKXk0000000000000P3n`7@010000000oKed0000000000030?jnL0050000002<d?h0S=3n08c@
oP0000000P3m_GD00`000000o[i`0?jnL0020?jnL0030000003n`6T0o/1Y0080o/1Y1`0000030?fn
L@050000003f_Td000000?g1H@000000103n_W0010000000o[m`0?joL03n_g05000000050?foN@00
0000o<1m0?c0O@0000000P3m_WP00`000000kI4U000000020?fnM`<000000`3n`Fl2000000030?g2
I0000000oKib0080oKib00<000000?joK@3n_fd00P3n_fd00`000000nl5I00000005000000<0oL1l
00@000000?foNP000000nlB:0P0000020?_AV`80000000X0o<J:0000003la8@0o<B40000003jaY00
00000<]a00000000oL9o0P00000?0?ooo`<00000;`3oool00`000000oooo0?ooo`090?ooo`00:`3o
ool00`000000oooo0?ooo`130?ooo`060000003b^Y80l[ZB0000003adf8000000P3`^iP010000000
k[nR0>joXP0000030>nmW@040000003Vbk/0i/^k000000@0kk^J00<000000?70W@0000000P3^_Z42
00000080kl:T0`0000001`3`^IH000000?6kUP3a^iH000000>_6[P0000000P3Wa;<010000000XRP0
0000000000020?6lU`040000003b^Y40l[ZA000000L0m;Z?00@000000000A@0004D000150`000000
0`3d_iD000000?6kUP030?6kUP8000000`3aaZ@2000000040?:mU`000000l/BO0?;4W`<0000000<0
m;jC0000003g`Y801P3g`Y800`000000m/6C0?K1T`020?K1T`8000001P3g_hl00`000000m[n@0?Jo
T0040?JoT0050000003f^hX0m[^:0?JkRP0000001@3j_hH00`000000mLiM000000030?JoT0050000
003g`8l000000?O1T@0000001P3g`I400`000000m/2A0?K0T@03000000030?O0SP000000mkn?00<0
mkn?00D000000?BmTP000000mkj=000000020?JmSP030000003h`Hd0n<6=00@0n<6=00<000000?K1
TP3f`I80103f`I800`000000n;f8000000050?ZoQP030000003j`8L0000000D0n<6>00<000000?Zo
QP3j_hH00`3j_hH00`000000n[n60?ZoQP030?ZoQP050000003i_XH0nKj60?VnQP000000103h_XT0
10000000mkb:0?NlRP3g_8X20000000@0?NkR000000000000000003h_8H000000?^oQ0000000n[j5
0000003j_h@000000?_2QP000000nKb500000080000H00<000000?VmQ03i_H@00`3i_H@2000000<0
n/260P0000040?VnQ@050000003i_XD0nKj50?VnQ@0000000`3mcV`4000000<0o=ao0`0000040?Zm
O`030000003l_W/0o;ik0080o;ik00@000000?boN`3l_g/000001@3j_H44000000<0nken00D00000
0?JkRP00000000000>6[W00200000080kM9M00@000000?foN0000000jKXk1@0000000`3m_G@00000
000000030?jnL0050000002<d?h0S=3n08c@oP0000000P3m_GD00`000000o[i`0?jnL0020?jnL0L0
000000@0gJFJ00000000000000001@3m_W44000000@0o[i`00<000000?joL03n_g000P3n_g040000
00050?foN@000000o<1m0?c0O@0000000P3m_WP00`000000kI4U000000020?fnM`030000003n_fh0
000000<0o/5_00@000000?g2I03m`V@000000`3m_W800`000000o[m]0?joK@020?joK@070000003k
`ET000000000003naG`000000?_2QP0200000080oL1l00D000000?foNP00000000000?_4RP020000
0080nm6K00<000000?c6RP0000000P3la8@00`000000n/J@0000000200000080oL9o00<000000?oo
o`3oool03@3oool3000002l0oooo00<000000?ooo`3oool02@3oool002/0oooo00<000000?ooo`00
0000@`3oool01@000000l[ZB0?:jTP000000lM=R008000000P3`^iP01@000000k[nR0>joXP000000
kkfM00<000000P3Vbk/01@000000kk^J0>nkVP3_^iX000000080lL2M00H000000>jnX@3^_Z40k[jQ
0000003_`Z@3000000050?2iUP000000lK^F0?6kUP0000000P3[aZh02@000000ilBc0000002R:000
00000?>lT`000000lKbG000000020?:jT@030000003d^Xl0m;Z?00D0m;Z?00@000000000A@0004D0
00151@0000050?6kUP030000003aaZ@0lLJT0080lLJT00<000000?:mU`0000000P3ba9l200000003
0?:jT`000000000000H0ml:B00<000000?K1T`3f`I<0103f`I<00`000000mkn?0?NoS`040?NoS`03
0000003f_i00m[n@00@0m[n@0P0000020?JkRP030000003j_hH0n[n600<0n[n600@000000?G>G@00
000000000P3f_i000`000000ml2?00000002000000H0ml6A00H000000?K0T@3f`940m/2A0000003f
`942000000D0mkn?0P0000001@3g_Xd000000000003f_Hh0000000H0n<6=0P0000050?K1TP030000
003h_HP0000000D0n[n600@000000?[0Q`3j`8L00000103h`Hh00`000000n[n60?ZoQP030?ZoQP03
0000003j_hH0n[n600<0n[n600D000000?VnQP3i_XH0nKj6000000040?RnR@040000003g_8X0mkb:
0?NlRP8000000P3g^hP01000000000^I0000003h_8H2000000040?ZnQ@000000n[n40?ZoQ0800000
00D0nKb50000000001P0000H000000060?VmQ0070000003j`8H0n/260?[0QP000000mkj;00000003
0?VnQ@050000003i_XD0nKj50?VnQ@0000000`3mcV`00`000000o/J1000000040?cLO`030000003n
dXd0000000@0n[eo00<000000?bnN`3l_W/00P3l_W/010000000o;mk0?boN`0000050?ZmP@@00000
0`3k_Gh01@000000m[^:0?JkRP000000hJ^L008000000P3]dUd01@000000oKmh0000003Y^S/00000
0080o/5a0P0000000`3m_G@00000000000030?jnL0050000002<d?h0S=3n08c@oP0000000P3m_GD6
000000<0o/1Y00L000000?jnL0000000gJFJ0000003b]X`0000000D0oKia100000040?jnL0030000
003n_g00o[m`0080o[m`100000001@3m_gT000000?c0O@3l`7d000000080oKih00<000000>fA9@00
00000P3m_WL00`000000o[m^0000000400000080oL9T00D000000?fnLP3m_W80oKib000000040?jo
K@030000003k`ET000000080o/El00@000000?_2QP00000000000P3m`7`010000000oKmj0000003k
a8X300000080nm6K00<000000?c6RP3laXX0100000000`3_c:l00000000000020?g2O`030000003o
ool0oooo00d0oooo0`00000_0?ooo`030000003oool0oooo00T0oooo000Z0?ooo`<00000A@3oool0
10000000l[ZB0000003adf8200000080l;^H00@000000>joXP3^_j80k[nR0P0000000`3`^iP00000
0000000200000080kk^J00<000000?70W@3a`9d00P3a`9d00`000000k[jQ0>jnX@03000000040=K1
a0000000l;VF00000080lK^F0P0000020>_6[P040000003Wa;<000000:8X0080000000D0lKbG0000
003b^Y40l[ZA000000070?BjS`040000000004D000150000A@80000000@0l;nN0000000000000000
103a^iH3000000<0lLJT0P0000030?;4W`040000003b^Y<00000000000H0ml:B00<000000?K1T`3f
`I<0103f`I<3000000@0mkn?00<000000?JoT03f_i00103f_i0200000080m[^:00<000000?ZoQP3j
_hH00`3j_hH010000000mLiM0000000000020?JoT0030000003g`8l0ml2?008000001@3g`I400`00
0000m/2A0?K0T@020?K0T@040000003f`9400000000000D0mkn?0P0000001@3g_Xd000000000003f
_Hh0000000H0n<6=0P0000050?K1TP<000001@3j_hH010000000n/270?[0Q`0000040?S1SP030000
003j_hH0n[n600<0n[n600<000000?ZoQP3j_hH00`3j_hH01@000000nKj60?VnQP3i_XH0000000@0
n;j900@000000?NlRP3g_8X0mkb:0P0000020?NkR003000000002iT000000080n;b600<000000?Zn
Q@0000000P3j_h@2000000030?VlQ@000000000H008000001P3i_H@200000080n/2600<000000?Nn
R`0000000`3i_XD01@000000nKj50?VnQ@3i_XD0000000<0oLi/00<000000?k6P@0000000`3lg7l0
10000000o]:=0?kBS@0000040?ZmO`030000003l_W/0o;ik0080o;ik00<000000?boN`3l_g/00P00
00040?ZmP@@000000`3k_Gh01@000000m[^:0?JkRP000000hJ^L008000000P3]dUd01@000000oKmh
0000003Y^S/000000080o/5a0P0000000`3m_G@00000000000030?jnL0P00000103n_W001P000000
o/1Y0?k0J@3n`6T000000?jnL0<0000000<0l[J<0000003m_W40103m_W44000000@0o[i`00<00000
0?joL03n_g000P3n_g02000000040?k1L@0000000000000000<0o<1m00D000000?fnN0000000kI4U
000000020?fnM`030000003n_fh0o[m^0080o[m^00<000000?g2I03m`V@00`0000020?fnLP030000
003n_fd0o[m]0080o[m]00<000000?_1F@0000000P3naG`2000000050?_2QP000000oL1l0?g0O000
00000P3m_gX00`000000nlB:0000000400000080o<J:0P0000000`3ja8d000000>o<[`0200000080
oL9o00<000000?ooo`3oool03@3oool3000002l0oooo00<000000?ooo`3oool02@3oool002X0oooo
00<000000?ooo`3oool0A@3oool010000000l[ZB0000003adf8300000080l;^H00<000000>joXP3^
_j800P000000203`^iP00000000000000000kK^M0000003_^iX00000103a`9d010000000k[jQ0000
003Z_JH2000000040=K1a0000000l;VF0?2iUP8000000P3c_9@01@000000jlJ^0>_6[P000000ilBc
00D000000P3b^Y400`000000m;Z?0?BjS`050?BjS`040000000004D000150000A@8000000P3`_ih2
000000@0lK^F00<000000?BnT`3d_Y<00P0000000`3aaZ@00000000000030?;4W`80000000<0m[n@
0000000000001@3g`Y800`000000m/6C0?K1T`040?K1T`040000003gaYH0mlJF000000<0mkn?00<0
00000?JoT03f_i00103f_i0200000080m[^:00<000000?ZoQP3j_hH00`3j_hH00`000000mLiM0000
0002000000030?JoT0000000ml2?0080ml2?0P0000040?O1T@030000003f`940m/2A00<0m/2A1000
00040?NoS`D0000000<0m[f>0000003h`Hd01@3h`Hd00`000000mkj=000000040?K1TP<000001@3j
_hH01@000000n/270?[0Q`3j`8L0000000@0n<6>00<000000?ZoQP3j_hH00P3j_hH00`000000n[n6
0?ZoQP030?ZoQP030000003i_XH0nKj60080nKj600D000000?RnR@3h_XT0n;j9000000030?NlRP80
00000P3g^hP00`00000000^I000000020?RlQP050000003j_XD0n[j50000003j_h@00P0000000`3i
_8D0000000006002000000H0nKf40P0000020?[0QP030000003g_X/0000000@0nKj500@000000?Vn
Q@3i_XD000000P3mcV`010000000o/J10?k6P@0000030?cLO`040000003ndXd0o]:=000000@0n[eo
00<000000?bnN`3l_W/00P3l_W/00`000000o;mk0?boN`02000000@0n[f1100000030?^mOP050000
003f^hX0m[^:0000003QZi`00P0000001`3]dUd000000?foN03m_gP000000>Vj>`0000000P3n`G42
000000030?fmM0000000000000@00000102<d?h00`000000oKee000000040?jnL0050000003n`6T0
o/1Y0?k0J@0000000P3n_W02000000030?:fS0000000oKia00@0oKia100000040?jnL0030000003n
_g00o[m`0080o[m`0P000000103n`G4000000000000000030?c0O@030000003m_WP000000080kI4U
00@000000?fnM`3m_WL000000`3n_fh00`000000oL9T0?g2I00300000080oKib00<000000?joK@3n
_fd00P3n_fd00`000000nl5I000000020?k5O080000000D0nl:60000003m`7`0oL1l000000020?fo
NPH0000000<0kY<V0000003laXX00P0000000`3ja8d000000>o<[`03000000030?g2O`000000oooo
00h0oooo0`00000_0?ooo`030000003oool0oooo00T0oooo000Z0?ooo`030000003oool0oooo04D0
oooo00T000000?:jTP00000000000?ooo`000000hkRY0000003`^iP00P0000000`3^_j8000000000
00020?2kV0060000003^^id000000000003_^iX000001@3a`9d200000080j[fV0P0000000`3F`L@0
00000?2iUP02000000<0lkbD00<000000>_6[P0000000P3Wa;<400000080l[ZA00<000000?BjS`3d
^Xl01@3d^Xl01`00000000150000A@0004D000000?>mU@0000000P3`_ih00`000000lK^F0?6kUP02
0?6kUP030000003d_Y<0m;jC0080m;jC0`0000030?;4W`8000000`3f_i02000000<0ml:B00<00000
0?K1T`3f`I<0103f`I<01@000000mlJF0?O6UP3gaYH000000080mkn?00<000000?JoT03f_i000`3f
_i000`000000m[n@000000020?JkRP030000003j_hH0n[n600<0n[n61`0000040?O0S`8000000`3g
`I400`000000m/2A0?K0T@040?K0T@<000001@3g_hl3000000030?RoS0000000000000H0n<6=00@0
00000?NnS@3g_Xd000000`3f`I83000000D0n[n600<000000?[0Q`3j`8L00P3j`8L01P000000n<6>
0?S1SP000000m/2B000000<0n[n600<000000?ZoQP3j_hH00`3j_hH00`000000nKj60?VnQP020?Vn
QP050000003h_XT0n;j90?RnR@0000000`3g_8X200000080mk^800<00000000;V@0000000`3h_8H0
10000000n[j50000003j_h@2000000060?VlQ@000000000H0000003k`XD000001@3i_H@300000004
0?[0QP000000mkj;000000@0nKj500@000000?VnQ@3i_XD000000P3mcV`010000000o/J10?k6P@00
00020?cLO`050000003ndXd0o]:=0?kBS@000000103j_Gl00`000000o;ik0?bnN`020?bnN`030000
003l_g/0o;mk00800000103j_H4010000000olAb0000000000030?^mOP80000000<0m[^:00000000
00000P0000001P3]dUd000000?foN03m_gP000000>Vj>`P000000`3n_W000`000000S=3n08c@oP02
08c@oP030000003m_GD0000000@0o[i`00D000000?k0J@3n`6T0o/1Y000000020?jnL080000000<0
l[J<0000003m_W40103m_W44000000@0o[i`00<000000?joL03n_g000P3n_g06000000<0o<1m00<0
00000?fnN00000000P3]TBD010000000oKig0?fnM`0000030?joKP030000003m`V@0oL9T00<00000
0P3m_W800`000000o[m]0?joK@020?joK@030000003k`ET000000080o/El0P0000020?_2QP030000
003m`7`000000080oKmj0P000000103oool000000000003naGl200000080o<J:00<000000?[4S@00
00000P3_c:l2000000030?g2O`000000oooo00h0oooo0P00000`0?ooo`030000003oool0oooo00T0
oooo000Z0?ooo`030000003oool0oooo04D0oooo00@000000?:jTP00000000000P3oool200000003
0?2kV0000000lK^G0080000000@0kkbK0000003`^iP0l;^H0P0000000`3]^id00000000000060?70
W@030000003Z_JH0j[fV0080000000<0e/740000003`^IH00P0000030?>lU080000000H0jlJ^0000
00000000jlbf0000003d_I82000000030?:jT@000000m;Z?00H0m;Z?00L000000000A@0004D00015
0000003c_ID000000080l;nN0P0000030?6kUP030000003d_Y<0m;jC00@0m;jC0P0000020?;4W`80
00001@3f_i02000000030?O2TP000000m/6C00D0m/6C00<000000?O6UP3gaYH00P3gaYH3000000D0
m[n@00<000000?JoT00000000P3f^hX00`000000n[n60?ZoQP030?ZoQP80000000<0m[n@0000003e
`YL00P0000060?O0S`80000000<0ml6A0000003f`9401@3f`942000000030?JmSP000000mkn?0080
mkn?0P0000000`3f`90000000?RoS002000000H0n<6=00@000000?NnS@3g_Xd000000P3f`I801000
0000n/VC0000000000050?ZoQP030000003j`8L0n/270080n/2700@000000?S1SP3h`Hh000000P3f
`98010000000n[n60?ZoQP0000050?ZoQP030000003i_XH0nKj60080nKj600D000000?RnR@3h_XT0
n;j9000000030?NlRP8000000`3g^hP2000000<0n;b600@000000?ZnQ@000000n[n40P0000001P3i
_8D00000000060000000nl:5000000D0nKf40`0000001@3j`8H000000?NnR`3g_X/0000000<0nKj5
00@000000?VnQ@3i_XD000000P3mcV`010000000o/J10?k6P@0000020?cLO`060000003ndXd00000
0000003h`i4000000`3j_Gl00`000000o;ik0?bnN`020?bnN`030000003l_g/0o;mk00800000103j
_H4010000000olAb0?o4LP0000030?^mOP80000000<0m[^:0000000000000P0000000`3]dUd00000
0000000400000080o/5a0P0000000`3m_G@000000?jnL0040?jnL0070000002<d?h0S=3n08c@oP00
0000oKee000000040?jnL0050000003n`6T0o/1Y0?k0J@0000000P3n_W02000000030?:fS0000000
oKia00@0oKia100000040?jnL0030000003n_g00o[m`0080o[m`00<000000?jnL03n_W000`000003
0?c0O@030000003m_WP000000080kI4U00@000000?fnM`3m_WL000000`3n_fh00`000000oL9T0?g2
I00300000080oKib00<000000?joK@3n_fd00P3n_fd00`000000nl5I000000020?k5O08000000P3k
`XH00`000000oL1l000000030?foNP030000003oool0oooo0080000000D0o/Eo000000000000o<J:
000000020?[4S@060000003_c:l000000000003m`Wl00000403oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00T0oooo000Z0?ooo`030000003oool0oooo04D0oooo00@000000?:jTP00
000000000P3oool010000000hkRY0000000000020?6kU`030000003__9/000000080l;^H00<00000
0>jkW@0000000P0000060?70W@8000000P3Z_JH300000080l;VF00@000000?>lU03c_9@0lkbD0`00
0000103[aZh000000>_<]P3[c;H3000000030?:jT@000000m;Z?00H0m;Z?00@000000000A@0004D0
00150P0000001@3c_ID000000?2oWP3`_ih0000000<0lK^F00<000000?BnT`3d_Y<0103d_Y<30000
0080l/BO00<000000?JoT03f_i00103f_i03000000D0m/6C00<000000?O6UP3gaYH01@3gaYH00`00
0000m[n@0?JoT0030?JoT0030000003f_i0000000080m[^:00<000000?ZoQP3j_hH00`3j_hH20000
00050?JoT000000000000?G2U`0000001P3g`8l4000000H0m/2A0P0000000`3f_Hh000000?NoS`02
0?NoS`050000003i`hd000000000003h_h`00P0000060?S1S@070000003g_Xd0mkj=0?NnS@000000
m/6B000000020?[9T`030000003j_hH0n[n600<0n[n600<000000?[0Q`3j`8L00`3j`8L00`000000
n<6>000000030?K0TP030000003j_hH0000000D0n[n600<000000?VnQP3i_XH00`3i_XH00`000000
n;j90?RnR@02000000040?NlRP000000oKa]000000<0mk^80P0000030?RlQP030000003j_XD0n[j5
00<0000000H0nKb50000000001P000000?_2Q@0000050?VmQ080000000<0nKf50000000000000P3g
_X/01@000000nKj50?VnQ@3i_XD000000080nKj500@000000?g>K03mcV`000000P3naX400`000000
o=ao00000006000000<0n[eo00<000000?bnN`3l_W/00P3l_W/00`000000o;mk0?boN`02000000@0
n[f100@000000?o4LP3oa78000000`3k_Gh8000000<0oKmh00<000000>Vj>`0000000`3n`G400`00
0000oKed000000050?jnL0070000002<d?h0S=3n08c@oP000000oKee000000040?jnL0050000003n
`6T0o/1Y0?k0J@0000000P3n_W02000000030?:fS0000000oKia00@0oKia100000040?jnL0030000
003n_g00o[m`0080o[m`00<000000?jnL03n_W000`0000030?c0O@030000003m_WP000000080kI4U
00@000000?fnM`3m_WL000000`3n_fh00`000000oL9T0?g2I00300000080oKib00<000000?joK@3n
_fd00P3n_fd00`000000nl5I000000020?k5O0070000003l`hH000000?_2QP000000oL1l00000003
0?foNP060000003oool0oooo0?ooo`000000o/Eo0P000000203laXX000000?[4S@3ja8d000000>o<
[`000000k/JY0P00000@0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02@3oool0
02X0oooo00<000000?ooo`3oool0A@3oool010000000l[ZB0000000000020?ooo`040000003S^:T0
0000000000<0lK^G00<000000>nlV`0000000P3`^iP2000000030>fkW@000000lL2M00D0lL2M0P00
00020>ZmYP030000003`^iP000000080l;VF00<000000?>lU03c_9@00P3c_9@00`000000l[bF0000
0003000000050>_<]P00000000000?:jT@0000001`3d^Xl02`00000000150000A@0004D000000?6k
UP000000lkfE0000003`_ih0000000<0lK^F00<000000?BnT`3d_Y<0103d_Y<2000000040>fiW000
0000l/BO000000H0m[n@00@000000?BmTP3d_I800000103f`I<00`000000mlJF0?O6UP050?O6UP80
0000103f_i000`000000m[n@000000020?JkRP030000003j_hH0n[n600<0n[n60P0000001@3f_i00
00000?K0T0000000mL:G00800000103g`8l010000000m/2@0000000000060?K0T@050000003ia940
00000?JmSP0000000P3g_hl01`000000nL>=0000003f`90000000?RoS00000001@3h`Hd00`000000
mkj=0?NnS@030?NnS@8000000P3jbI<00`000000n[n60?ZoQP030?ZoQP030000003j`8L0n/2700<0
n/270`0000040?K0TP8000001@3j_hH00`000000nKj60?VnQP030?VnQP030000003h_XT0n;j90080
000000@0mkb:0000003m_6d000000`3g^hP2000000@0n;b600D000000?ZnQ@00000000000?ZnQ002
00000004000060000000nl:5000000D0nKf40P0000000`3i_HD00000000000020?NnR`040000003i
_XD0nKj50?VnQ@80000000@0nKj50000003mcV`000000`3naX400`000000o=ao00000006000000<0
n[eo00<000000?bnN`3l_W/00P3l_W/00`000000o;mk0?boN`02000000@0n[f100<000000?o4LP3o
a7801P000000103f^hX000000000003QZi`2000000<0oKmh00<000000>Vj>`0000000`3n`G400`00
0000oKed000000050?jnL0070000002<d?h0S=3n08c@oP000000oKee000000040?jnL0050000003n
`6T0o/1Y0?k0J@0000000P3n_W02000000030?:fS0000000oKia00@0oKia100000040?jnL0030000
003n_g00o[m`0080o[m`00@000000?jnL03n_W00o[i`0P0000040?c0O@8000000P3]TBD010000000
oKig0?fnM`0000030?joKP030000003m`V@0oL9T00<000000P3m_W800`000000o[m]0?joK@020?jo
K@030000003k`ET000000080o/El00<000000?c3QP0000000P3k`XH2000000<0oKmj00<000000?oo
o`3oool00P3oool010000000o/Eo0000003laXX200000080n/B=00<000000>o<[`0000000P00000@
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02@3oool001<0oooo100000040?oo
o`@000002`3oool00`000000oooo0?ooo`02000004<0oooo0`0000040?ooo`030000003S^:T00000
00<0lK^G00<000000>nlV`0000000P3`^iP01@000000k[^M0000003]^id0000000D0lL2M00<00000
0>c0Y@0000000P3Z_JH200000080l;VF0P0000030?>lU0030000003b_9H0l[bF00@0000000@0jlbf
0000003b^Y4000001`3d^Xl01000000000150000A@0000030?6kUP070000003c_ID000000?2oWP00
0000lK^F000000070?BnT`<0000000<0kKZL0000000000001`0000030?BmTP050000003f`I<0m/6C
0?K1T`0000001`3gaYH00`000000mL>H000000030?JoT0030000003f_i0000000080m[^:00<00000
0?ZoQP3j_hH00`3j_hH2000000050?JoT0000000m/2@0?K0T00000000P3e`YL200000080ml2?00<0
00000?K0T03f`9000P0000050?K0T@030000003ia94000000080m[f>00<000000?NoS`0000000P3i
`hd010000000m/2@0000000000050?S1S@030000003g_Xd0mkj=00<0mkj=0P0000030?[9T`030000
003j_hH0n[n60080n[n600<000000?[0Q`3j`8L00`3j`8L3000000@0m/2B0P0000050?ZoQP030000
003i_XH0nKj600<0nKj600<000000?RnR@3h_XT00P000000103g_8X000000?flK@0000030?NkR080
0000103h_8H01@000000n[j50?ZnQ@000000n[j40080000000@0000H0000003k`XD000001@3i_H@0
1@000000n[j40000003i_HD000000080mkj;00@000000?VnQ@3i_XD0nKj50P000000103i_XD00000
0?g>K00000030?k6P@L0000000<0YBH00000003j_Gl00P3j_Gl00`000000o;ik0?bnN`020?bnN`06
0000003l_g/0o;mk0?boN`000000n[f11`0000030?^mOP80000000@0m[^:000000000000hJ^L0P00
00030?foN0030000003Y^S/0000000<0o/5a0`0000050?jnL0070000002<d?h0S=3n08c@oP000000
oKee000000040?jnL0050000003n`6T0o/1Y0?k0J@0000000P3n_W000`000000gJFJ000000020000
00@0oKia100000040?jnL0030000003n_g00o[m`0080o[m`00@000000?jnL03n_W00o[i`0P000004
0?c0O@8000000`3]TBD00`000000oKig000000030?joKP040000003m`V@000000?k4KP8000000P3m
_W800`000000o[m]0?joK@020?joK@080000003k`ET000000000003naG`000000?c3QP0000020?_2
QP8000000`3m_gX00`000000oooo0?ooo`020?ooo`H000000P3ja8d00`000000klb_000000020000
0100oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`090?ooo`004P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool30000
04D0oooo0`0000040?ooo`040000003S^:T00000000000<0lK^G00<000000>nlV`0000000P3`^iP2
00000080kK^M00D000000?70W@3a`9d0lL2M000000030>c0Y@040000003Z_JH0000000000080l;VF
00<000000>nhU`0000000P3c_9@00`000000l[bF0?:lUP040?:lUP80000000<0l[ZA0000003d^Xl0
1P3d^Xl01000000000150000A@0000030?6kUP070000003c_ID000000?2oWP000000lK^F00000007
0?BnT`<0000000P0kKZL00000000000000000?^fL@000000Whg000000080gkF]00@000000?BmTP3d
_I80m;fB0P0000000`3f`I<000000?O6UP050?O6UP040000003e`iP0mL>H0?G3V080000000@0m[n@
0000003f_i0000000P3f^hX00`000000n[n60?ZoQP030?ZoQP80000000<0m[n@0000003f`9000P3f
`90010000000mL:G0000003f`iH3000000<0m/2@00<000000?K0T@3f`9400`3f`9400`000000nLBA
000000020?JmSP030000003g_hl000000080nL>=00<000000?K0T03f`9000P0000040?S1S@030000
003g_Xd0mkj=00@0mkj=1P0000030?ZoQP030000003j`8L0n/2700<0n/2700<000000?[0Q`000000
103f`9800`000000n;n<000000040?ZoQP030000003i_XH0nKj600<0nKj60P0000001`3h_XT00000
0000003g_8X000000?flK@000000103g^hP2000000@0n;b600@000000?ZnQ@000000n[j41P000005
0?VmQ0050000003j_X@000000?VmQ@0000000`3g_X/00`000000nKj50?VnQ@02000000040?VnQ@00
0000oLi/000000<0o/J10P0000001@3l`X@00000000000000000n<>@008000000`3j_Gl00`000000
o;ik0?bnN`020?bnN`H000000`3j_H401@000000olAb0?o4LP3oa78000000080nken0P000000103f
^hX000000000003QZi`2000000<0oKmh00<000000>Vj>`0000000`3n`G43000000D0o[i`00L00000
08c@oP2<d?h0S=3n0000003m_GD0000000@0o[i`00D000000?k0J@3n`6T0o/1Y000000020?jnL003
0000003MYIX0000000800000103m_W44000000@0o[i`00<000000?joL03n_g000P3n_g0010000000
o[i`0?jnL03n_W02000000@0o<1m0P0000030>fA9@030000003m_WL0000000<0o[m^00T000000?g2
I0000000o/A^0000002GT<T000000?fnLP000000103n_fd00`000000nl5I00000003000000040?c3
QP000000nl:60?_2QP8000000`3m_gX00`000000oooo0?ooo`030?ooo`@0000000<0nl:60000003j
a8d01@0000110?ooo`030000003oool0oooo00T0oooo000B0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04D0
oooo0`0000050?ooo`0300000000;Y/0000000@0lK^G0P0000020?2kV0040000003^^id000000>fk
W@<0000000<0lL2M0000003/`:D00P3/`:D00`000000j[fV0>ZmYP0200000080l;VF00<000000>nh
U`0000000P3c_9@00`000000l[bF0?:lUP030?:lUP80000000<0l[ZA0000003d^Xl01P3d^Xl01000
000000150000A@0000040?6kUP@0000000<0lK^F0000003d_Y<01P3d_Y<300000080kKZL0P000000
103k]W40000009n=`00000020=ne[@030000003d_I80m;fB0080m;fB0`0000060?O6UP030000003e
`iP0mL>H00<0mL>H0P0000001@3f_i0000000?JkRP3f^hX0000000D0n[n600@000000?JoT03f_i00
0000103f`90200000080m/>F0P0000040?K0T0050000003f`940m/2A0?K0T@0000000P3ia9400`00
0000m[f>0?JmSP03000000<0nL>=00D000000?K0T0000000n;n<000000030?S1S@030000003g_Xd0
mkj=00@0mkj=00<000000?_4R@3ka8T00`3ka8T2000000030?ZoQP000000n/2700@0n/2700<00000
0?[0Q`0000001@3f`982000000@0n[n600<000000?VnQP3i_XH00`3i_XH2000000070?RnR@000000
00000?NlRP000000oKa]000000040?NkR0800000103h_8H010000000n[j50000003j_X@400000003
0?RlQP000000000000@0nKf400D000000?ZnQ0000000nKf5000000030?NnR`030000003i_XD0nKj5
0080000000@0nKj50000003mcV`000000`3naX42000000030?c2Q000000000000080000000@0n<>@
0000003j_Gl0n[eo1`0000030?boN`8000000`3j_H401@000000olAb0?o4LP3oa780000000<0nken
00H000000?JkRP00000000000>6[W00000040?foN0800000103n`G43000000D0o[i`00L0000008c@
oP2<d?h0S=3n0000003m_GD0000000@0o[i`00D000000?k0J@3n`6T0o/1Y000000020?jnL0030000
003MYIX0000000800000103m_W44000000@0o[i`00<000000?joL03n_g000P3n_g000`000000o[i`
0?jnL0020?jnL0030000003l`7d0o<1m0080o<1m0P0000030>fA9@030000003m_WL0000000<0o[m^
00T000000?g2I0000000o/A^0000002GT<T000000?fnLP000000103n_fd01P000000nl5I00000000
0000oL5h00000080o<>600@000000?_2QP00000000000`3m_gX00`000000oooo0?ooo`030?ooo`@0
000000<0nl:60000003ja8d00P0000000`3_c:l00000000000120?ooo`030000003oool0oooo00P0
oooo000B0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo04H0oooo0P0000050?ooo`0400000000;Y/002jK0000
00<0lK^G00<000000>nlV`0000000P3`^iP200000080kK^M00@000000>NjYP0000000000103/`:D0
10000000j[fV0000000000020?2iUP030000003_^9L000000080lkbD00<000000?:lUP3b_9H00`3b
_9H2000000030?:jT@000000m;Z?00H0m;Z?00@000000000A@0004D000001@3a^iH00`000000lKbH
00000002000000L0m;jC0`0000020>fjW080000000<0nkIa0000002OSL000P0000000`3O]Jd00000
000000030?BmTP030000003h`i00000000<000000`3gaYH00`000000mL>H0?G3V0040?G3V0030000
003f_i0000000080m[^:00<000000?ZoQP3j_hH00`3j_hH010000000m[n@0?JoT00000050?K0T003
0000003f`iH0m/>F0080m/>F00<000000?K0T03f`9000P3f`90010000000m/2A0?K0T@0000030?W4
T@030000003f_Hh000000080000000D0nL>=00000000000000000?K0T002000000050?RoS0000000
00000?S1S@0000001P3g_Xd00`000000nlB90?_4R@030?_4R@040000003h`8/00000000000D0n/27
00@000000?[0Q`3j`8L00000103f`983000000<0n[n600<000000?VnQP3i_XH00`3i_XH200000003
0?RnR@000000oLN40080000000<0oKa]0000003g^hP00`3g^hP2000000@0n;b600<000000?ZnQ@3j
_XD01@0000020?RlQP030000003i_H@0nKf40080nKf400<000000?ZnQ00000000P3i_HD010000000
mkj;0?NnR`0000020?VnQ@80000000@0nKj50000003mcV`000000`3naX4010000000o<:40?c2Q000
00020?;@[@D0000000<0n[eo0000003l_W/00`3l_W/010000000o;mk0?boN`3l_g/2000000<0n[f1
00D000000?o4LP3oa780olAb000000030?^mOP@0000000<0hJ^L0000003m_gP00`3m_gP2000000@0
o/5a0`0000050?jnL0040000002<d?h0S=3n08c@oP<00000103n_W001@000000o/1Y0?k0J@3n`6T0
00000080o[i`00<000000=fUVP0000000P0000040?fnL@@00000103n_W000`000000o[m`0?joL002
0?joL0030000003n_W00o[i`0080o[i`0P0000030?c0O@8000000`3]TBD00`000000oKig00000003
0?joKP090000003m`V@000000?k4KP000000Ui390000003m_W80000000@0o[m]00H000000?_1F@00
000000000?g1N00000020?c3QP80000000<0oLnA0000003m_gX00P3m_gX00`000000oooo0?ooo`04
0?ooo`<0000000@0nl:60000003ja8d0n/B=100000120?ooo`030000003oool0oooo00P0oooo000B
0?ooo`8000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0AP3oool2000000H0oooo0P0000001000;Y/000000?6kU`3a^iL300000080l;^H
0`0000000`3]^id000000>NjYP02000000@0k<2U00@000000>ZmYP3Z_JH000000P3`^IH010000000
kkRG0>nhU`0000020?>lU0030000003b_9H0l[bF0080l[bF0P0000000`3b^Y4000000?BjS`050?Bj
S`050000000004D000150000A@0000001@3a^iH00`000000lKbH0?6lV002000000L0m;jC0`000002
0>fjW0040000003aY34000000?^fL@<0000000<0gkF]0000000000000`3d_I800`000000n<>@0?S3
T0030?S3T0@000001P3e`iP300000080m[^:00<000000?ZoQP3j_hH00`3j_hH010000000m[n@0?Jo
T00000050?K0T0<000000`3f`iH010000000m/2@0?K0T03f`902000000030?K0T@000000nLBA0080
nLBA00@000000?JmSP000000n/:<0P0000030?[2S080000000@0nL:<000000000000m[b<0P000006
0?NnS@030000003ka8T0nlB900<0nlB900@000000?S0R`3h`8/000001@3j`8L010000000n/270?[0
Q`0000050?K0TP030000003hbIX000000080n[n600<000000?VnQP3i_XH00`3i_XH2000000030?Rn
R@000000oLN40080000000<0oKa]0000003g^hP00`3g^hP2000000@0n;b60P0000000`3j_XD00000
0000000300000080n;b600<000000?VmQ03i_H@00P3i_H@00`000000n[j4000000020?VmQ@040000
003g_X/0mkj;00000080nKj500<000000?o8MP0000000P0000030?k6P@X000000`3j_Gl00`000000
o;ik0?bnN`020?bnN`040000003l_g/0o;mk0?boN`8000000`3j_H401@000000olAb0?o4LP3oa780
000000<0nken100000000`3QZi`000000?foN0030?foN0800000103n`G43000000D0o[i`00@00000
08c@oP2<d?h0S=3n0`0000040?jnL0030000003n`6T0o/1Y008000000P3n_W000`000000gJFJ0000
0002000000@0oKia100000040?jnL0030000003n_g00o[m`0080o[m`00<000000?jnL03n_W000P3n
_W02000000@0o<1m00L000000>fA9@3]TBD0kI4U0000003m_WL0000000<0o[m^00T000000?g2I000
0000o/A^0000002GT<T000000?fnLP000000103n_fd010000000nl5I0000000000020?g1N0060000
003l`hH000000000003mci4000000`3m_gX00`000000oooo0?ooo`040?ooo`030000003@K`000000
0080nl:600<000000?[4S@0000000P0000130?ooo`030000003oool0oooo00P0oooo000B0?ooo`03
0000003oool00000008000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`070?ooo`<0000000<0lK^G0000003a
^iH00P0000001@3`^iP00000000000000000kK^M0080000000<0ikZV000000000000103/`:D00`00
0000j[fV000000020?2iUP070000003_^9L0kkRG0>nhU`000000lkbD000000030?:lUP040000003f
aYT00000000000L0m;Z?00@000000000A@0004D000150P0000040?6kUP80000000<0lKbH00000000
00001P3d_Y<010000000gKZf0=fj]P0000030>fjW080000000@0nkIa00000000000000000P3O]Jd2
00000080m;fB00<000000?S3T03h`i000P3h`i001P000000n<FD0?S5U0000000m[n@000000D0mL>H
00H000000?G3U`3e`iL000000?JkRP0000050?ZoQP030000003f_i00000000H0m/2@00@000000?Jo
T03f_i0000000P3f`iH200000080m/2@0P0000000`3f`94000000?W4T@020?W4T@030000003f_Hh0
000000H0n/:<0P0000020?W2S0040000003f_8`0m[b<000000H0mkj=00<000000?_4R@3ka8T00`3k
a8T010000000n<2;0?S0R`3h`8/2000000<0n/2700D000000?[0Q`3j`8L0n/27000000040?K0TP06
0000003hbIX000000000003j_hH000001@3i_XH01@000000o<:2000000000000oLN4008000000P3m
_6d010000000mk^80?NkR03g^hP2000000@0n;b60P0000000`3j_XD000000000000300000080n;b6
00<000000?VmQ03i_H@00P3i_H@00`000000n[j4000000020?VmQ@040000003g_X/0mkj;00000080
nKj500<000000?o8MP0000002P0000000`3bbZL000000?;@[@02000000<0n[eo00<000000?bnN`3l
_W/00P3l_W/010000000o;mk0?boN`3l_g/2000000<0n[f100D000000?o4LP3oa780olAb00000003
0?^mOP@0000000<0hJ^L0000003m_gP00`3m_gP2000000@0o/5a0`0000050?jnL0040000002<d?h0
S=3n08c@oP<00000103n_W000`000000o/1Y0?k0J@0200000080o[i`00H000000=fUVP0000000000
09jWg00000030?fnL@@00000103n_W000`000000o[m`0?joL0020?joL0030000003n_W00o[i`0080
o[i`0P0000040?c0O@030000003]TBD0kI4U0080kI4U0P0000030?joKP090000003m`V@000000?k4
KP000000Ui390000003m_W80000000@0o[m]00@000000?_1F@00000000000P3m`GP010000000o<>6
0000000000020?g?T@040000003m_gX0oKmj000000L0oooo00T000000=1_00000000nl:60000003j
a8d000000?ooo`000000@`3oool00`000000oooo0?ooo`080?ooo`004P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo00P0oooo0P0000000`3a^iL000000?6kUP02000000030?2kV000
0000c/?@00@0000000@0ikZV0000003]^Yd00000103/`:D200000080l;VF00<000000>nhU`3_^9L0
0P3_^9L300000080l[bF00@000000?K6V@00000000001`3d^Xl01000000000150000A@0004D20000
00@0lK^F0P0000020?6lV0030000003d_Y<0m;jC00@0m;jC00<000000=fj]P3M^[H00P0000020>fj
W0@0000000T0Whg0000000000000gkF]0000003b^i<000000?BmTP0000000`3h`i0200000080n<FD
00@000000?JoT03f_i0000000`3e`iP01`000000mL>G0?G3U`3e`iL000000?JkRP000000103j_hH0
10000000m[n@0?JoT00000060?K0T0040000003f_i00m[n@0?JoT0@000000P3f`90010000000n<:?
0000000000040?W4T@8000001P3j`X`500000080m[b<00<000000?NnS@3g_Xd0103g_Xd00`000000
nlB90?_4R@030?_4R@030000003h`8/0n<2;00<0n<2;00@000000?[0Q`3j`8L000000`3j`8L00`00
0000m/2B0?K0TP020?K0TP80000000@0n<VJ0000003j_hH000001@3i_XH01@000000o<:200000000
0000oLN4008000000P3m_6d010000000mk^80?NkR03g^hP2000000@0n;b60P0000000`3j_XD00000
0000000300000080n;b600D000000?VmQ03i_H@0nKf4000000030?ZnQ0030000003i_HD000000080
mkj;200000020?k6P@80000000@0nLJC0000003Je=8000000P3bbZL3000000<0n[eo00<000000?bn
N`3l_W/00P3l_W/010000000o;mk0?boN`3l_g/2000000<0n[f100D000000?o4LP3oa780olAb0000
00030?^mOPH00000103m_gP2000000@0o/5a0`0000050?jnL0040000002<d?h0S=3n08c@oP<00000
103n_W000`000000o/1Y0?k0J@0200000080o[i`100000000`2NYm`000000?fnL@020?fnL@800000
0P3n_W001@000000o[i`0?jnL03n_W00000000@0o[m`00<000000?jnL03n_W000P3n_W02000000@0
o<1m00<000000>fA9@3]TBD00P3]TBD2000000<0o[m^00T000000?g2I0000000o/A^0000002GT<T0
00000?fnLP000000103n_fd01`000000nl5I0000003oool000000?g1N00000000P3l`hH010000000
oLnA0?g?T@0000020?foNP030000003oool0oooo00D0oooo00<000000=1_000000000P0000000`3j
a8d000000?ooo`140?ooo`030000003oool0oooo00P0oooo000B0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool02@3oool300000080lK^F0`0000002P3>`m000000000000000000kKjR
0000003g[F/000000>fjW@0000030>c0Y@8000000P3`^IH01P000000kkRG0>nhU`3_^9L000000:9L
N`8000000P3b_9H010000000m/JI0?K6V@0000070?BjS`040000000004D000150000A@800000103a
^iH01@000000lKVB0000003a_9P0000000H0m;jC00<000000=fj]P3M^[H00P0000020>fjW0050000
003aY34000000000002OSL000P0000001P3O]Jd000000?:kT`000000m;fB00000080n<>@00<00000
0?S2T00000000`3haI@2000000050?JoT000000000000?G3V00000000`3e`iL00`000000m[^:0000
00040?ZoQP040000003f_i00m[n@000000H0m/2@00<000000?JoT03f_i000`3f_i001@000000m/JI
0000003f`90000000080n<:?1`0000060?[2S0050000003g_X`0mkj<0?NnS00000000`3f_8`00`00
0000mkj=0?NnS@030?NnS@030000003ka8T0nlB900<0nlB900<000000?S0R`3h`8/00`3h`8/40000
00@0n/2700H000000?K0TP3f`980m/2B0000003g^hP4000000D0nKj600<000000?c2PP0000001000
00020?flK@040000003g^hP0mk^80?NkR08000000`3h_8H00`000000nl210?_0P@0600000080n;b6
00D000000?VmQ03i_H@0nKf4000000020?ZnQ0H0000000D0mkj;0000003i_XD000000?o8MP030000
00050?k6P@00000000060000003iaY<00P0000000`3Jclh000000?;:Y`02000000050>;Gc0000000
n[eo0?ZmO`000000103l_W/010000000o;mk0?boN`3l_g/2000000<0n[f100D000000?o4LP3oa780
olAb000000030?^mOPD000001@3m_gP2000000@0o/5a0`0000050?jnL0030000002<d?h0S=3n0080
S=3n0P0000040?jnL0030000003n`6T0o/1Y008000000`3n_W030000000309jWg0000000oKia0080
oKia0P0000020?jnL0050000003n_W00o[i`0?jnL0000000103n_g000`000000o[i`0?jnL0020?jn
L0030000003n_W00000000<0o<1m0P0000030>fA9@8000000`3n_fh2000000070?k4KP0000000000
09N@b@000000oKib000000050?joK@80000000L0oooo0000003m`GP0oL5h0000003l`hH000000080
oLnA00@000000?foNP3m_gX000001`3oool3000000040?_2QP0000000000000004D0oooo00<00000
0?ooo`3oool0203oool001<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01`3oool010000000oooo00000000001B0?ooo`<000000`3a
^iH200000080c/?@0P0000001P3]_Z8000000?N]J`000000kKZM000000@0k<2U0P0000000`3`^IH0
00000>nhU`020>nhU`070000002RG7/000000>fhVP000000l[bF000000020?K6V@030000003d^Xl0
m;Z?00D0m;Z?00L000000000A@0004D000150000003b^i@0000000<0lK^F00<000000?6iTP000000
0P3a_9P2000000@0m;jC00<000000=fj]P3M^[H00P0000030>fjW0H000000P3O]Jd01P000000l[^C
000000000000n<>@00000080n<:@00@000000?S5U03haI@0n<FD0`0000020?JoT08000000`3e`iL0
0`000000m[^:000000030?ZoQP050000003f_i00m[n@0?JoT00000001P3f`9000`000000m[n@0?Jo
T0030?JoT0D000001@3h`Xl010000000ml:A0000000000040?[2S080000000<0mL2C0000003g_X`0
0P3g_X`010000000m[b<0?JlS00000050?NnS@030000003ka8T0nlB90080nlB900<000000?S0R`3h
`8/0103h`8/010000000n/::0000000000040?[0Q`050000003f`980m/2B0?K0TP0000000P3g^hP0
0`000000nKj6000000050?VnQP030000003l`X80o<:200@000000P3m_6d010000000mk^80?NkR03g
^hP2000000<0n;b600<000000?_0P@3k`84010000000103j_X@000000?RlQP3h_8H7000000050?Zn
Q0000000nKf50?VmQ@0000000P3g_X/010000000nKj50000003ob7H7000000030?W6T`000000lljZ
008000000P3bbZL300000080n[eo00<000000?bnN`3l_W/00P3l_W/00`000000o;mk0?boN`020?bo
N`8000000P3j_H401@000000olAb0?o4LP3oa780000000<0nken1@0000050?foN0800000103n`G43
000000D0o[i`00<0000008c@oP2<d?h00P2<d?h2000000D0o[i`00@000000?k0J@00000000000`3n
_W030000000309jWg0000000oKia0080oKia0P0000020?jnL0050000003n_W00o[i`0?jnL0000000
103n_g000`000000o[i`0?jnL0020?jnL0030000003n_W00000000<0o<1m00<000000?fnM@000000
0P3]TBD2000000<0o[m^0P0000001@3na6h000000?o4K@000000Ui39008000001@3n_fd200000080
oooo00@000000?g1N0000000o<>60P0000001@3mci4000000?foNP3m_gX0000000L0oooo0P000000
0`3@K`0000000?_2QP02000004D0oooo00<000000?ooo`3oool0203oool001@0oooo0`0000040?oo
o`@000002P3oool2000005D0oooo00<0000007[3oP0000000`3a^iH030000000c/?@0<k3d0000000
kKVL0000003]_Z8000000?N]J`000000kKZM000000<0k<2U0P0000020?2iUP0:0000003_^9L0kkRG
0000002RG7/000000>fhVP000000l[bF00000080m/JI00<000000?BjS`3d^Xl01@3d^Xl01`000000
00150000A@0004D000000?:kU00000000`3a^iH01@000000lKVB0?6iTP000000lKbH00<000000`3d
_Y<01P000000gKZf0=fj]P000000l[ZC00000080kKZL1`0000000`3O]Jd000000?:kT`03000000<0
n<:@00@000000?S5U000000000000`3d`IH4000000<0mL>G00<000000?JkRP0000000`3j_hH01@00
0000m[n@0?JoT03f_i00000000H0m/2@00<000000?JoT03f_i000`3f_i000`000000m[n@0?JoT008
000000030?O2T@00000000000080n/:<0P0000020?NnS@8000000`3g_X`010000000m[b<0?JlS000
00050?NnS@030000003ka8T0nlB90080nlB900<000000?S0R`3h`8/00`3h`8/010000000n/::0?[2
RP3j`XX2000000@0n/2700@000000?K0TP3f`98000000`3g^hP2000000D0nKj600D000000?c2PP3l
`X8000000?c2PP0200000080oKa]00L000000?NkR03g^hP0mk^80000002dXQ8000000080n;b600H0
00000?_0P@3k`840nl210000003k`H<700000080nKf400D000000?ZnQ03j_X@0n[j4000000020?Vm
Q@070000003g_X/0mkj;0000003i_XD000000?o8MP06000000040>c>]P00000000000??>ZP<00000
0P3bbZL200000080n[eo00<000000?bnN`3l_W/00P3l_W/00`000000o;mk0?boN`020?boN`800000
0P3j_H401@000000olAb0?o4LP3oa780000000<0nken0`0000000`3``j<000000?foN0040?foN080
0000103n`G43000000D0o[i`00<0000008c@oP2<d?h00P2<d?h00`000000oKee000000040?jnL004
0000003n`6T00000000000<0o[i`0`0000000`2NYm`000000?fnL@020?fnL@8000000P3n_W001@00
0000o[i`0?jnL03n_W00000000@0o[m`00<000000?jnL03n_W000P3n_W000`000000o[i`00000003
0?c0O@050000003m_WD0oKie0000003]TBD00P0000030?joKP@0000000H0olA]0000002GT<T00000
0?fnLP0000040?joK@8000000P3oool01P000000oL5h0000003l`hH000000?bnNP<0000000<0oKmj
0000003oool01`3oool300000080nl:600<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`08
0?ooo`00:@3oool00`000000oooo0?ooo`1E0?ooo`<000000`3a^iH00`000000c/?@0<k3d0020000
00040>fnXP000000mje[00000080kKZM00D000000>c0Y@000000ll:K000000020?2iUP070000003_
^9L0kkRG0000002RG7/000000>fhVP0300000080m/JI00<000000?BjS`3d^Xl01@3d^Xl010000000
00150000A@0000020?:kU0050000003a^iH0lK^F0?6kUP0000000P3a^I8010000000lKbH0000003_
^YT200000080m;jC00H000000=fj]P3M^[H000000?:jT`0000020>fjW0L0000000<0gkF]0000003b
^i<00P0000040?S2T08000001@3d`IH010000000mL6G0000003f`982000000030?G3U`0000000000
00@0n[n60`0000000`3f_i0000000?K0T0040?K0T0030000003f_i00m[n@00@0m[n@00<000000?Jo
T03f_i000P3f_i05000000030?S1SP000000000000D000000P3g_Xd00`000000mL2C000000020?Nn
S0050000003f_8`0m[b<0?JlS0000000103g_Xd00`000000nlB90?_4R@020?_4R@030000003h`8/0
n<2;00<0n<2;00@000000?[2RP3j`XX0n/::0`0000030?[0Q`030000003f`980000000@0mk^800<0
00000?VnQP000000103i_XH00`000000o<:20?c2PP020?c2PP8000000P3m_6d01`000000mk^80?Nk
R03g^hP000000;BR4P0000000P3h_8H700000080n[j400@000000?RlQP00000000000P3i_H@01@00
0000n[j40?ZnQ03j_X@000000080nKf500@000000?NnR`3g_X/0mkj;0`000000103naGd000000000
003naWl2000000030>c>]P00000000000080lljZ00<000000=[?cP0000000P3bbZL01@000000n[eo
0?ZmO`3j_Gl0000000<0o;ik00<000000?boN`3l_g/00P3l_g/200000080n[f100H000000?o4LP3o
a78000000?k2M@0000020?^mOP030000003na6`00000008000001@3m_gP2000000@0o/5a00<00000
0?k6J00000001@3n_W000`000000S=3n08c@oP0208c@oP030000003m_GD0000000@0o[i`00@00000
0?k0J@00000000000`3n_W000`000000gJFJ0000000209jWg0030000003m_W40oKia008000000P3n
_W001@000000o[i`0?jnL03n_W00000000@0o[m`00<000000?jnL03n_W000P3n_W0010000000o[i`
0?jnL00000020?c0O@040000003m_WD0oKie0?fnM@<000000`3n_fh2000000080?k1L@000000olA]
0000002GT<T000000?fnLP0000040?joK@8000000P3oool01@000000oL5h0000003l`hH0000000<0
o;ij00@000000?foNP3m_gX000001`3oool300000080nl:60P0000140?ooo`030000003oool0oooo
00P0oooo000Y0?ooo`030000003oool0oooo05L0oooo0P0000020?6kUP070000003>`m00c/?@0000
003]^I`000000>fnXP02000000<0kKZM0P0000001@3c`Y/000000?2iUP3`^IH000000080kkRG00<0
00000:9LN`2RG7/0100000000`3faYT00000000000070?BjS`040000000004D0001500000080l[^D
0P0000000`3a^iH000000?6iTP030?6iTP80000000<0kkZI0000000000000`0000030=fj]P800000
0P3]^Y`7000000040=ne[@000000l[^C000000@0n<:@0P0000060?C1UP040000003e`IL0mL6G0000
0080m/2B0`0000030?ZoQP040000003fb9`0m/RL0?K8W08000001@3f`9000`000000m[n@0?JoT004
0?JoT0030000003f_i00m[n@00<0m[n@00<000000?S1SP3h`Hh00`3h`Hh200000080ml:A00<00000
0?FoT`0000000P3g_Xd200000080mkj<00D000000?JlS03f_8`0m[b<000000030?NnS@030000003k
a8T0nlB900<0nlB900<000000?S0R`3h`8/00`3h`8/00`000000n/::0?[2RP020?[2RP@0000000@0
n/270000000000000000103g^hP00`000000nKj6000000040?VnQP030000003l`X80o<:20080o<:2
0P0000020?flK@040000003g^hP0mk^80?NkR0H000001@3k`8401@000000n[j40?ZnQ0000000n;b6
008000000P3i_H@01@000000n[j40?ZnQ03j_X@000000080nKf500@000000?NnR`3g_X/0mkj;0`00
0000203naGd000000000003naWl000000??9Y@000000k<jf0P0000020??>ZP050000003Jclh00000
0?;:Y`0000000`3j_Gl01@000000o;ik0?bnN`3l_W/0000000@0o;mk0P0000020?ZmP@060000003o
a780olAb0000003n`WD000000P3k_Gh00`000000o/A/00000002000000D0oKmh0P0000040?k1L@03
0000003naVP0000000D0o[i`00<0000008c@oP2<d?h00P2<d?h00`000000oKee000000040?jnL004
0000003n`6T00000000000<0o[i`00<000000=fUVP0000000P2NYm`00`000000oKia0?fnL@020000
0080o[i`00<000000?jnL03n_W000P3n_W001@000000o[m`0?joL03n_g00000000@0o[i`00@00000
0?jnL03n_W0000000P3l`7d00`000000oKie0?fnM@020?fnM@8000000`3n_fh2000000080?k1L@00
0000olA]0000002GT<T000000?fnLP0000040?joK@030000003oool0oooo0080oooo100000030?bn
NP040000003m_gX0oKmj000000L0oooo00P000000?ooo`00000000000?_2QP000000oooo000004<0
oooo00<000000?ooo`3oool0203oool002T0oooo00<000000?ooo`3oool0F03oool01`000000lK^F
0?6kUP3a^iH000000<k3d00000000P3]^I`010000000kKjR0000000000030>fjW@<000000P3`^IH0
10000000kkRG0>nhU`0000020:9LN`80000000<0hIn;0000000000000P0000070?BjS`0400000000
04D0001500000080l[^D0P0000000`3a^iH000000?6iTP030?6iTP080000003a_9P000000000002b
XlT000000>ZjX@0000030=fj]P030000003b^Y<000000080kKZL0P000000103b^Y<0000000000000
00020=ne[@8000000`3h`Y04000000@0m<6F00<000000?G1U`3e`IL00P3e`IL00`000000m/2B0?K0
TP02000000<0n[n600<000000?K8W03fb9`00P3fb9`00`000000m/2@0?K0T0030?K0T0030000003f
_i00m[n@00@0m[n@00<000000?JoT03f_i000`3f_i000`000000n<6>0?S1SP030?S1SP0300000039
cU8000000080000000<0mKnC0000003g_Xd00P3g_Xd2000000030?NnS0000000000000<0m[b<00@0
00000?NnS@3g_Xd000001@3ka8T00`000000n<2;0?S0R`030?S0R`030000003j`XX0n/::0080n/::
200000050?NkR0800000103i_XH00`000000o<:20?c2PP020?c2PPT0000000D0]:8B0000003h_8H0
n;b6000000050?_0P@80000000<0n[j40000003h_8H00P0000020?VmQ0030000003j_X@0n[j40080
n[j400<000000?VmQ@0000000`3g_X/3000000040?k5O@000000o/Io0?k6O`80000000H0llVU0000
00000000k/JZ0000003ccZX5000000<0n[eo00D000000?bnN`3l_W/0o;ik000000040?boN`800000
0P3j_H401P000000olAb0?o4LP000000o/9e00000080nken00<000000?k4K00000000`0000040?fo
N0800000103n`G43000000D0o[i`00<0000008c@oP2<d?h00P2<d?h3000000@0o[i`00@000000?k0
J@00000000000`3n_W000`000000gJFJ0000000209jWg0030000003m_W40oKia008000000P3n_W00
0`000000o[i`0?jnL0020?jnL0050000003n_g00o[m`0?joL0000000103n_W0010000000o[i`0?jn
L00000020?c0O@030000003m_WD0oKie0080oKie0P0000030?joKP80000000@0o/5a0000003oa6d0
olA]0P0000000`3m_W8000000?joK@030?joK@030000003oool0oooo0080oooo100000030?bnNP04
0000003m_gX0oKmj000000T0oooo0P000000103k`XH000000?ooo`0000130?ooo`030000003oool0
oooo00P0oooo000Y0?ooo`030000003oool0oooo05T0oooo00<000000?6kUP3a^iH00P0000001@3>
`m0000000>fiW0000000kKjR008000000`3]^Yd00`000000g?^`000000020?2iUP040000003_^9L0
kkRG00000080XUak1`0000070?BjS`0:0000000004D000150000003b^i@000000?:iTP000000lK^F
000000D0lKVB0P0000001@3_^YT000000000003Z^Z40000000<0gKZf00<000000?:jT`0000000P3]
^Y`5000000030?6kU0000000gkF]008000000P3h`Y0200000080mKjB0P0000030?C1UP030000003e
`IL0mL6G00<0mL6G100000020?ZoQP030000003fb9`0m/RL00<0m/RL0P0000040?K0T0030000003f
_i00m[n@00@0m[n@00<000000?JoT03f_i000`3f_i000`000000n<6>0?S1SP030?S1SP0300000039
cU80bLiB008000000P3e_i<01P000000mkj=0?NnS@3g_Xd000000?NnS08000000`3f_8`010000000
mkj=0?NnS@0000050?_4R@030000003h`8/0n<2;00<0n<2;00<000000?[2RP3j`XX00`3j`XX30000
00040>KII@000000mkf:000000D0mk^80P0000040?VnQPP0000000<0oKa]0000003g^hP00P3g^hP0
0`000000]:8B000000020?RlQP030000003k`840nl2100<0nl210P0000000`3j_X@000000?RlQP02
00000080nKf400<000000?ZnQ03j_X@00P3j_X@010000000nKf50?VmQ@0000020?NnR`<0000000@0
o/Em0000003naWl000000P37enH01`000000llVU000000000000k/JZ0000003ccZX0100000030?Zm
O`050000003l_W/0o;ik0?bnN`000000103l_g/200000080n[f100H000000?o4LP3oa78000000?k2
M@0000020?^mOP060000003na6`000000000003oool00000103m_gP2000000@0o/5a0`0000050?jn
L0030000002<d?h0S=3n0080S=3n0`0000040?jnL0040000003n`6T00000000000<0o[i`00<00000
0=fUVP0000000P2NYm`00`000000oKia0?fnL@0200000080o[i`00<000000?jnL03n_W000P3n_W00
1@000000o[m`0?joL03n_g00000000@0o[i`00L000000?jnL03n_W00o[i`0000003l`7d0000000@0
oKie0P0000030?joKP050000003n`G40o/5a0000003oa6d00`0000000`3m_W8000000?joK@030?jo
K@030000003oool0oooo00<0oooo0`0000040?bnNP030000003m_gX0000000X0oooo00<000000?_2
QP0000000P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00P0oooo000Y0?ooo`03
0000003oool0oooo05X0oooo00@000000?6kUP000000lkfF0P0000020>fiW0040000003]_Z800000
00000080kKZM00H000000=ck/03Lnk0000000?2iUP0000020>nhU`030000002RG7/0000000<00000
00@0l;nN00000000000000001`3d^Xl01P00000000150000A@000000l[^D00000080l[VB0P000005
0?6iTP80000000H0kkZI00000000000000000?O2TP0000020=fj]P030000003b^Y<000000080kKZL
1`0000000`3O]Jd00000000000020?S2T08000000P3e_Y801P000000lkbD000000000000m<6F0000
00H0mL6G0`0000020?ZoQP030000003fb9`0m/RL0080m/RL00@000000?C5W@3daId000000`3f`900
0`000000m[n@0?JoT0030?JoT0030000003f_i00m[n@00@0m[n@00<000000?S1SP3h`Hh00`3h`Hh0
1P000000bLiB0<W>DP000000l<Z[00000080mKnC00<000000?NnS@3g_Xd0100000030?JlS0040000
003g_Xd0mkj=000000D0nlB900<000000?S0R`3h`8/00`3h`8/00`000000n/::0?[2RP030?[2RPD0
000000<0mkf:0000003g^hP0103g^hP00`000000nKj600000004000000@0o<:200D000000?ZoQ@00
0000oKa]000000030?NkR0030000002dXQ8000000080n;b600<000000?_0P@3k`8400`3k`8420000
00080?ZnQ0000000n;b60000003j_X<000000?VmQ00000040?ZnQ0040000003i_HD0nKf500000080
mkj;0P000000103naGd000000?k6O`3naWl2000000040<OGiP000000llVU0??9Y@80000000<0oooo
0000000000000P3oool01@000000n[eo0?ZmO`3j_Gl0000000<0o;ik00<000000?boN`3l_g/00P3l
_g/200000080n[f100H000000?o4LP3oa78000000?k2M@0000020?^mOP060000003na6`000000000
003oool00000103m_gP2000000@0o/5a0`0000050?jnL0030000002<d?h0S=3n0080S=3n0`000004
0?jnL080000000<0S=3n0000000000000P3n_W000`000000gJFJ0000000209jWg0030000003m_W40
oKia008000000P3n_W000`000000o[i`0?jnL0020?jnL0050000003n_g00o[m`0?joL0000000103n
_W001`000000o[i`0?jnL03n_W0000000?c0O@000000103m_WD00`000000kjZ0000000020?joKP05
0000003n`G40o/5a0000003oa6d00`0000000`3m_W8000000?joK@030?joK@030000003oool0oooo
00<0oooo00<000000?g0M`000000103l_WX00`000000oKmj0000000:0?ooo`<000000`3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo00P0oooo000Y0?ooo`030000003oool0oooo05/0
oooo0P0000000`3c_IH00000000000030>fiW0<000000P3]^Yd01@000000g?^`0=ck/0000000l;VF
0080000000D0kkRG0000002RG7/000000?71W@02000000<0l;nN00<000000?BjS`3d^Xl01@3d^Xl0
1P00000000150000A@000000l[^D00000080l[VB0P0000060?6iTPL000000P3M^[H00`000000l[ZC
000000030>fjW0H0000000@0gkF]000000000000n<:@0P0000040?FnTP030000003c_9@0lkbD0080
00001@3e`IL010000000m;fB0000000000020?ZoQP@0000000<0m/RL0000003daId00P3daId20000
00030?K0T0000000m[n@00@0m[n@00<000000?JoT03f_i00103f_i000`000000n<6>0?S1SP030?S1
SP0300000039cU80000000<000000P3e_i<00`000000mkj=0?NnS@04000000<0m[b<0P0000000`3g
_Xd000000?_4R@030?_4R@030000003j`8L0000000@0n<2;00<000000?[2RP3j`XX00`3j`XX00`00
0000oLJ200000002000000030?NmRP000000mk^800L000000`3i_XH00`000000o<:20?c2PP020?c2
PP<0000000<0oKa]0000003g^hP00P3g^hP00`000000]:8B000000020?RlQP030000003k`840nl21
00<0nl2100X000000?k;K@00000000000?RlQP000000n[j30000003i_H@00000103j_X@010000000
nKf50?VmQ@0000020?NnR`80000000@0o/Em0000003naWl000000P3caj43000000030??9Y@000000
00000080oooo00@000000?ooo`3oool000000`3j_Gl01@000000o;ik0?bnN`3l_W/0000000@0o;mk
0P0000020?ZmP@060000003oa780olAb0000003n`WD000000P3k_Gh00`000000o/A/000000020?oo
o`030000003m_gP0oKmh0080oKmh0P0000040?k1L@<000001@3n_W000`000000S=3n08c@oP0208c@
oP<00000103n_W020000000308c@oP00000000000080o[i`00<000000=fUVP0000000P2NYm`00`00
0000oKia0?fnL@0200000080o[i`00<000000?jnL03n_W000P3n_W001@000000o[m`0?joL03n_g00
000000@0o[i`00L000000?jnL03n_W00o[i`0000003l`7d0000000@0oKie00<000000>nZP0000000
0`0000020?k1L@80000000<0o;mk0000002GT<T00P0000040?joK@030000003oool0oooo00<0oooo
00<000000?g0M`000000103l_WX00`000000oKmj0000000;0?ooo`800000103oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00P0oooo000Y0?ooo`<00000G03oool500000080kKVL0`00
00000`3]^Yd000000=ck/0020=ck/080000000D0omF?0000003_^9L000000:9LN`03000000050?G;
XP000000l;nN0?2oWP0000001`3d^Xl01P00000000150000A@000000l[^D00000080l[VB0P000006
0?6iTPD0000000<0olZ00000000000000P3M^[H00`000000l[ZC000000020>fjW080000000<0oLb=
0000000000000P000000103O]Jd000000000000000050?FnTP030000003c_9@0lkbD008000001@3e
`IL01P000000m;fB000000000000n[n6000000<0m[n@0`0000050?C5W@8000001@3f_i000`000000
m[n@0?JoT0040?JoT0030000003h`Hh0n<6>00<0n<6>00@000000<W>DP000000l/FP0`0000020?Fo
T`070000003g_Xd000000?RoS0000000mkj;000000020?JlS080000000<0mkj=0000003ka8T00P3k
a8T01@000000n/270?[0Q`3j`8L0000000<0n<2;00<000000?[2RP3j`XX00`3j`XX00`000000oLJ2
00000005000000D0mk^80P0000030?VnQP050000003l`X80o<:20?c2PP0000000P3j_hH00`000000
oKa]000000030?NkR0030000002dXQ8000000080n;b600<000000?_0P@3k`8400`3k`8402P000000
o/]]000000000000n;b60000003j_X<000000?VmQ00000040?ZnQ0040000003i_HD0nKf500000080
mkj;0`0000020?k6O`8000000P3caj44000000H0oooo00D000000?ZmO`3j_Gl0n[eo000000030?bn
N`030000003l_g/0o;mk00<0o;mk0P0000001`3j_H4000000?o4LP3oa78000000?k2M@0000000P3k
_Gh00`000000o/A/000000030?ooo`040000003m_gP0oKmh0?foN0800000103n`G42000000030?oo
o`000000o[i`00<0o[i`00<0000008c@oP2<d?h00P2<d?h3000000@0o[i`0P0000000`2<d?h00000
000000020?jnL0040000003MYIX0000000000080WZOL00@000000?fnL@00000000000P3n_W000`00
0000o[i`0?jnL0020?jnL0050000003n_g00o[m`0?joL0000000103n_W001`000000o[i`0?jnL03n
_W0000000?c0O@000000103m_WD00`000000kjZ00000000300000080o/5a0`000000103l_g/00000
0000000000040?joK@030000003oool0oooo00@0oooo0P0000040?bnNP<000002`3oool2000000D0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`070?ooo`00:@3oool00`000000oooo
0?ooo`1O0?ooo`8000000`3]^I`400000080g?^`0`0000000`3oeHl000000>nhU`02000000030?71
W@000000mL^R0080mL^R00<000000?2oWP0000001`3d^Xl01P00000000150000A@000000l[^D0000
00<0l[VB00<000000?6iTP3a^I80103a^I8400000080olZ00P0000020=fj]P030000003b^Y<00000
0080kKZL1`0000000`3O]Jd00000000000060?FnTP80000000<0lkbD0000003e`9<00P0000030?G1
U`060000003d_I80m;fB0000003j_hH000000`3f_i04000000D0m<FM00<000000?JoT03f_i000`3f
_i000`000000m[n@0?JoT0040?JoT0030000003h`Hh0n<6>0080n<6>00@000000<W>DP0000000000
0P3baJ02000000<0mKnC0P0000020?RoS08000000P3f_8`2000000040?NnS@000000nlB90?_4R@80
0000103j`8L2000000030?S0R`000000n/::00L000000P3Xd;d2000000H0mk^80P0000030?VnQP04
0000003l`X80o<:20?c2PP<0000000<0n[n60000000000000`3g^hP01P000000]:8B0;BR4P000000
n;b6000000D0nl2100<000000?k;K@0000000`000000103j_X<000000?VmQ00000040?ZnQ0030000
003i_HD0nKf500<000000P3naGd01P000000o/Io000000000000mLJM00000080llNQ0`0000070?oo
o`040000003j_Gl0n[eo000000<0o;ik00<000000?boN`3l_g/00`3l_g/2000000030?ZmP@000000
olAb0080000000L0o/9e0000003k_Gh0nken0000003na6`0000000<0oooo00@000000?foN03m_gP0
oKmh0P0000040?k1L@8000000P3oool01@000000o[i`0?jnL03n_W00000000@0S=3n0`0000040?jn
L080000000<0S=3n0000000000000P3n_W0010000000gJFJ00000000000209jWg0040000003m_W40
000000000080o[i`00<000000?jnL03n_W000P3n_W001@000000o[m`0?joL03n_g00000000@0o[i`
00<000000?jnL03n_W000P3n_W02000000@0oKie00@000000>nZP0000000o/5^0`0000001@3n`G40
00000?ooo`000000o;mk00<00000103n_fd00`000000oooo0?ooo`040?ooo`800000103l_WX30000
00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00L0oooo000Y0?ooo`030000003oool0oooo0600oooo00H000000>fiW03]^I`0kKVL0000003ngI42
000000030=ck/0000000j?[70080000000<0omF?0000003_^9L010000000103ebj8000000000003o
ool2000000L0m;Z?00H000000000A@0004D000000?:kU00000030?:iTP030000003a^I80lKVB00@0
lKVB100000030?o:P080000000@0gKZf00000000000000000P3]^Y`7000000030=ne[@0000000000
00H0mKjB0P0000000`3c_9@000000?G0T`020?G0T`80000000H0mL6G0000003d_I80m;fB0000003j
_hH3000000030?JoT0000000000000<00000103daId3000000<0m[n@00<000000?JoT03f_i000`3f
_i000`000000n<6>0?S1SP030?S1SP0400000039cU800000000000<0l/FP0P0000020?FoT`800000
0P3h_h`200000080m[b<00@000000?RmR@00000000000P3ka8T2000000<0n/27200000040?g6PPD0
00001P3g^hP300000080nKj600@000000?c2PP3l`X80o<:20P000000103j`HT00000000000000003
0?NkR0060000002dXQ80]:8B0000003h_8H000001@3k`842000000080?G5V@00000000000000003j
_X<000000?VmQ00000050?ZnQ0030000003i_HD00000008000000P3naGd010000000o/Io0000003d
bZ<3000000030??7X@000000oooo00P0oooo00@000000?ZmO`3j_Gl000000`3l_W/00`000000o;mk
0?boN`030?boN`80000000<0n[f10000003oa7800P0000020?k2M@050000003k_Gh000000?k4K000
00000`3oool010000000oKmh0?foN03m_gP2000000@0o/5a0P0000030?ooo`80000000<0o[i`0000
002<d?h00`2<d?h3000000@0o[i`0P0000000`2<d?h00000000000030?jnL080000000D0S=3n0000
002NYm`000000?fnL@0200000080o[i`00<000000?jnL03n_W000P3n_W001@000000o[m`0?joL03n
_g00000000@0o[i`00<000000?jnL03n_W000P3n_W02000000@0oKie00D000000>nZP0000000o/5^
000000020?k0I080000000<0oooo0000003l_g/00`0000040?joK@030000003oool0oooo00D0oooo
0P0000030?bnNP<00000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0HP3oool01@000000kKVL0>fi
W0000000o]fA00X0000000<0XUak0000003oool00P0000050?ooo`030000003d^Xl0m;Z?00@0m;Z?
00H000000000A@0004D000000?:kU00000030?:iTP030000003a^I80lKVB00@0lKVB00<000000?o:
P00000000`3obX0010000000nLJC0000003M^[H2000000030?c=T@000000kKZL00X000001P3e_Y80
10000000o<Z?0000000000050?G0T`8000000P3d_I82000000030?BmTP000000omB500P0000000<0
m<FM0000003daYd00P3daYd010000000m[n@0?JoT00000050?JoT0030000003h`Hh0n<6>00<0n<6>
00<000000<W>DP0000001@3baJ02000000030?FoT`000000000000@000000P3f_8`01@000000n;f9
000000000000nlB900H000000P3j`8L01P000000nKj8000000000000nKj8000000@0oLJ21@000006
0?NkR0<000000P3i_XH010000000o<:20?c2PP3l`X8200000080n/6900<000000?flK@0000000P3g
^hP01P000000]:8B000000000000n;b6000000D0nl210P000000203eaIT00000000000000000n[j3
0000003i_H@000001@3j_X@00`000000nKf500000002000000030?k5O@000000000000L000002P3o
ool010000000n[eo0?ZmO`0000030?bnN`030000003l_g/0o;mk00<0o;mk0P0000000`3j_H400000
0?o4LP0200000080o/9e00D000000?^mOP000000o/A/000000030?ooo`8000000P3m_gP2000000@0
o/5a0P0000040?ooo`<000001@2<d?h2000000@0o[i`0P0000000`2<d?h00000000000030?jnL007
0000002<d?h0S=3n0000002NYm`000000?fnL@0200000080o[i`00<000000?jnL03n_W000P3n_W00
1@000000o[m`0?joL03n_g00000000@0o[i`00<000000?jnL03n_W000P3n_W02000000@0oKie00D0
00000>nZP0000000o/5^000000020?k0I080000000<0oooo0000003l_g/00`0000040?joK@030000
003oool0oooo00D0oooo0P0000030?bnNP<000005@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo0680oooo00D000000>fiW03]^I`00000
0?kMT@02000000040?ooo`000000oooo0?ooo`D000002@3oool00`000000m;Z?0?BjS`040?BjS`03
0000000004D000000080l[^D00D000000?:iTP3b^I80l[VB000000060?6iTP030000003obX000000
00<0olZ000<000000?W6T`3iaY<00`000000103lcI4000000000003kc9<2000000070?BnTP000000
00000?BnTP000000m;jB000000060?FnTP040000003lbXl00000000000D0mL2C0`0000001P3d_I80
00000000003d_I8000000?oDQ@80000000<0lLBR0000003a_i`00P0000000`3_`jD0000000000004
0?C6W@<000001@3f_i000`000000n<6>0?S1SP030?S1SP<000001P3baJ001@000000mKnC0000003^
Zh@000000080mKf@0P0000000`3f_8`0000000000004000000030?RmR@000000n/2700@0n/2700<0
00000?VnR03i_XP00P3i_XP00`000000oLJ20?g6PP020?g6PP060000003_bjh000000000003g_HX0
00001@3g^hP300000080nKj600<000000?c2PP3l`X800`0000020?[1R@030000003m_6d000000080
mk^800H000000;BR4P00000000000?RlQP0000050?_0P@H000000P3j_X<2000000D0n[j400<00000
0?VmQ@0000000P0000000`3naGd0000000000002000000050?ooo`000000oooo0?ooo`0000002P3o
ool010000000n[eo0?ZmO`0000040?bnN`030000003l_g/0o;mk0080o;mk0P0000000`3j_H400000
0?o4LP0200000080o/9e00D000000?^mOP000000o/A/000000040?ooo`030000003m_gP0oKmh0080
0000103n`G400`000000oooo0?ooo`030?ooo`<000001@2<d?h2000000@0o[i`0P0000000`2<d?h0
0000000000030?jnL0040000002<d?h0S=3n08c@oP80000000<0oKia0000000000000P3n_W000`00
0000o[i`0?jnL0020?jnL0030000003n_g00o[m`0080o[m`00D000000?jnL03n_W00o[i`00000004
0?jnL0800000103m_WD010000000kjZ00000000000030?k0I08000000P3oool4000000@0o[m]00<0
00000?ooo`3oool01@3oool2000000<0o;ij00<000000?ooo`0000005P3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo0680oooo00<00000
0>fiW03]^I`00P0000060?ooo`030000003oool0oooo008000002@3oool00`000000m;Z?0?BjS`04
0?BjS`030000000004D000000080l[^D00D000000?:iTP3b^I80l[VB000000060?6iTP030000003o
bX00olZ000<0olZ000D000000?W6T`3iaY<000000=fj]P05000000040?O3T`000000m;jB000000@0
m;jB00<000000?FnTP3e_Y800`3e_Y8010000000o<Z?0?c:S`3lbXl3000000<0mL2C0`000000203d
_I8000000?BmTP3d_I8000000?oDQ@000000jlbf0P0000020?6oW080000000<0kl>U0000003daYd0
1@3daYd00`000000m[n@0?JoT0030?JoT0030000003h`Hh0n<6>00<0n<6>1@0000040?;5X0/00000
0P3h_HT01@000000n;f90?RmR@3h_HT0000000D0n/2700<000000?VnR03i_XP00P3i_XP010000000
oLJ20?g6PP3maX8200000080kl^^00<000000?NmRP0000001@3g^hP00`000000001E000000020?Vn
QP030000003l`X80o<:20080000000H0oL>000000000000000000?flK@0000020?NkR0060000002d
XQ8000000000003h_8H000001@3k`84600000080n[j30P0000050?ZnQ0030000003i_HD0000000<0
000000@0o/Eo0000003na7/000003`3oool010000000n[eo0?ZmO`0000040?bnN`030000003l_g/0
o;mk0080o;mk0P0000000`3j_H4000000?o4LP0200000080o/9e00@000000?^mOP00000000001@3o
ool00`000000oKmh0?foN002000000@0o/5a00<000000?ooo`3oool00`3oool4000000@0S=3n0P00
00040?jnL080000000<0S=3n0000000000000`3n_W001P000000S=3n08c@oP2<d?h0000009jWg080
00000`3n_W000`000000o[i`0?jnL0020?jnL0030000003n_g00o[m`0080o[m`00D000000?jnL03n
_W00o[i`000000040?jnL0800000103m_WD010000000kjZ00000000000030?k0I0040000003oool0
oooo0?ooo`@00000103n_fd00`000000oooo0?ooo`060?ooo`070000003l_WX0o;ij0?bnNP000000
oooo0000000F0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool01`3oool002P0oooo
00<000000?ooo`3oool0H`3oool2000000030?kMT@000000oooo00D0oooo00<000000?ooo`3oool0
0P0000090?ooo`030000003d^Xl0m;Z?00@0m;Z?00<000000000A@0000000P3b^i@01@000000l[VB
0?:iTP3b^I80000000H0lKVB00<000000?o:P03obX000`3obX0010000000nLJC0?W6T`3iaY<30000
00050?O3T`00000000000000003d_i@00P0000040?BnTP030000003e_Y80mKjB00<0mKjB00@00000
0?c:S`3lbXl0o<Z?200000000`3a_9L00000000000020?BmTP060000003oe8D000000000003[c;H0
00000`3a_i`2000000030>o3Y@000000m<JM00@0m<JM0P0000040?JoT0030000003h`Hh0n<6>00<0
n<6>1P0000000`3baJ00000000000006000000050?FmT000000000000?JlS00000001P3h_HT00`00
0000n/270?[0Q`030?[0Q`030000003i_XP0nKj80080nKj800@000000?g6PP3maX80oLJ20`000000
103_bjh000000?NmRP0000050?NkR0060000000005D000000000003i_XH000000P3l`X82000000<0
oL>00`0000020?NkR0060000002dXQ8000000000003h_8H000001@3k`843000000030?ooo`000000
00000080n[j30P0000050?ZnQ0040000003i_HD000000?k5O`80000000<0o/Eo000000000000403o
ool010000000n[eo0?ZmO`0000040?bnN`030000003l_g/0o;mk0080o;mk0P0000000`3j_H400000
0?o4LP0200000080o/9e00@000000?^mOP00000000001@3oool2000000030?foN0000000000000@0
o/5a00<000000?ooo`3oool00`3oool5000000<0S=3n0P0000040?jnL080000000<0S=3n00000000
00000`3n_W001P000000S=3n08c@oP2<d?h0000009jWg08000000`3n_W000`000000o[i`0?jnL002
0?jnL0030000003n_g00o[m`0080o[m`00D000000?jnL03n_W00o[i`000000040?jnL0800000103m
_WD010000000kjZ00000000000030?k0I0040000003oool0oooo0?ooo`@000000`3n_fd00`000000
oooo0?ooo`070?ooo`050000003l_WX0o;ij0?bnNP0000006@3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo06<0oooo0`00000:0?ooo`03
0000003oool0oooo00P0oooo00<000000?BjS`3d^Xl0103d^Xl01@00000000150000003b^i@00000
00@0l[VB00<000000?6iTP3a^I80103a^I800`000000olZ00?o:P0030?o:P0040000003iaY<0nLJC
0?W6T`8000000P3g`i<2000000@0m;nD0P0000020?BnTP030000003e_Y80mKjB00<0mKjB00<00000
0?c:S`3lbXl00`0000001P3Wc[d000000>k1Y@3^`JD000000>o3Y@<000000P3d_I85000000030;37
j`000000lKnL0080lKnL0P0000000`3_`jD000000?C6W@030?C6W@030000003daYd0000000<0m[n@
00<000000?S1SP3h`Hh00`3h`Hh900000080ll6J100000001@3e_I0000000000003f_8`0000000H0
n;f900<000000?[0Q`3j`8L00P3j`8L00`000000nKj80?VnR0030?VnR0040000003maX80oLJ20?g6
PP@0000000<0kl^^0000000000001@3g^hP02P000000001E0000E@000000nKj60000003l`X800000
0?RmQ`0000040?g3P08000000P3g^hP01P000000]:8B000000000000n;b6000000D0nl210P000002
0?ooo`8000000P3j_X<2000000D0n[j400T000000?VmQ@000000o/Eo0000003naGl000000?k4N`00
0000403oool010000000n[eo0?ZmO`0000040?bnN`030000003l_g/0o;mk0080o;mk00D000000?g0
N000000000000?o4LP0200000080o/9e00@000000?^mOP00000000001@3oool2000000030?foN000
0000000000@0o/5a00<000000?ooo`3oool0103oool010000000o/In00000000000308c@oP800000
103n_W020000000308c@oP000000000000<0o[i`00<0000008c@oP2<d?h00P2<d?h3000000<0o[i`
00<000000?jnL03n_W000P3n_W000`000000o[m`0?joL0020?joL0050000003n_W00o[i`0?jnL000
0000103n_W02000000@0oKie00@000000>nZP000000000000`3n`6@010000000oooo0?ooo`3oool4
000000040?joK@0000000000000000T0oooo00D000000?bnNP3l_WX0o;ij0000000J0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool01`3oool002P0oooo1000001R0?ooo`<000002P3o
ool00`000000oooo0?ooo`080?ooo`030000003d^Xl0m;Z?00<0m;Z?00<000000000A@0004D00`00
00040?:iTP030000003a^I80lKVB00@0lKVB00<000000?o:P03obX000`3obX001@000000nLJC0?W6
T`000000m;nD00@000001`3d_i@3000000D0mKjB00<000000?c:S`3lbXl01P0000020>k1Y@D00000
00<0m;fB0000000000001@0000040?6oW080000000D0kl>U000000000000m<JM000000030?C6W@80
000000<0m[n@0000000000002P0000020??0V@030000003c`IX0ll6J0080ll6J1`0000050?RmR@03
0000003j`8L0n/2700<0n/2700<000000?VnR03i_XP00`3i_XP01P000000oLJ20?g6PP3maX800000
0?ooo`D000001@3g^hP02P000000001E0000E@000000nKj60000003l`X8000000?RmQ`0000040?g3
P08000000P3g^hP01P000000]:8B000000000000n;b6000000D0nl210P0000020?ooo`8000000P3j
_X<2000000D0n[j40`0000001P3naGl000000?k5O`000000o/Ak00000100oooo00@000000?ZmO`3j
_Gl00000103l_W/00`000000o;mk0?boN`020?boN`030000003m`7P000000080000000H0oL1h0000
003n`WD0o/9e0000003k_Gh2000000D0oooo0P0000000`3m_gP00000000000040?k1L@030000003o
ool0oooo00@0oooo00<000000?k6OP0000000P00000208c@oP800000103n_W020000000308c@oP00
0000000000@0o[i`00@0000008c@oP2<d?h0S=3n0`0000030?jnL0030000003n_W00o[i`0080o[i`
00<000000?joL03n_g000P3n_g001@000000o[i`0?jnL03n_W00000000@0o[i`00<000000?jnL000
00000`3m_WD010000000kjZ00000000000030?k0I0030000003oool0oooo0080oooo00D000000?oo
o`00000000000;^S`002000000X0oooo00@000000?bnNP3l_WX000006`3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0503oool00`000000m;Z?0?BjS`030?BjS`030000000004D0001500<00000103b^I80
0`000000lKVB0?6iTP040?6iTP030000003obX00olZ000<0olZ000H000000?W6T`3iaY<000000?Bo
U00000020?BoU0030000003d_i@0m;nD00D0m;nD00<000000?W6T@0000001@3e_Y800`000000o<Z?
000000020>W4[`D000000P3^`JD4000000040?BmTP00000000000?34Y0D000000`3a_i`400000003
08:_lP00000000000080m<JM1@0000001@3h`Hh00000000000000000mlBE00<0000000<0kL2T0000
000000000P3c`9T2000000@0ll6J1P0000050?RmR@030000003j`8L0n/2700<0n/2700<000000?Vn
R03i_XP00P3i_XP010000000oLJ20?g6PP3maX82000000<0oooo0`0000050?NkR00:0000000005D0
001E0000003i_XH000000?c2PP000000n;f7000000@0oL>00P000000103g^hP000000;BR4P2dXQ84
000000D0nl210P0000030?ooo`030000003j_X<0n[j3008000001@3j_X@300000080o/Eo00@00000
0?k4N`3na7/00000403oool010000000n[eo0?ZmO`0000040?bnN`030000003l_g/0o;mk0080o;mk
00<000000?g0N00000000P0000001P3m`7P000000?k2M@3n`WD000000?^mOP8000001@3oool20000
00030?foN0000000000000@0o/5a00<000000?ooo`3oool0103oool00`000000o/In000000030000
000308c@oP000000000000@0o[i`00<0000008c@oP2<d?h00P0000040?jnL08000000`2<d?h20000
00<0o[i`00<000000?jnL03n_W000P3n_W000`000000o[m`0?joL0020?joL0050000003n_W00o[i`
0?jnL0000000103n_W000`000000o[i`000000030?fnM@040000003_ZX000000000000<0o/1T00<0
00000?ooo`3oool00P3oool010000000oooo0000003oool3000000X0oooo00@000000?bnNP3l_WX0
0000703oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0503oool00`000000m;Z?0?BjS`030?BjS`030000
000004D0001500<00000103b^I800`000000lKVB0?6iTP040?6iTP030000003obX00olZ000<0olZ0
00<000000?W6T`0000001@3d_i@00`000000m;nD0?BoU0040?BoU0030000003iaY40nLJA00800000
103e_Y800`000000o<Z?00000002000000030>O9^@000000000000<0000000<0k/6U000000000000
30000000103a_i`000000?33X`3``j<7000000@0m<JM0P0000040?O4U@80000000<0oooo0000003]
`:@00P0000020??0V@8000000`3c`IX3000000030?35Y@000000000000D0n;f900<000000?[0Q`3j
`8L00`3j`8L00`000000nKj80?VnR0020?VnR0040000003maX80oLJ20?g6PP800000103oool20000
00D0mk^800@000000000E@0005D0001E0`0000020?RmQ`030000003m`h00oL>00080oL>00P000000
103g^hP000000;BR4P2dXQ84000000D0nl210P0000030?ooo`050000003j_X<0n[j30?ZnP`000000
1@3j_X@300000080o/Eo00<000000?k4N`0000004@3oool010000000n[eo0?ZmO`0000040?bnN`03
0000003l_g/0o;mk0080o;mk00<000000?g0N00000000P0000001P3m`7P000000?k2M@3n`WD00000
0?^mOP8000001P3oool4000000@0o/5a00<000000?ooo`3oool0103oool01@000000o/In00000000
0000o/1b0080000000<0o[i_0000000000000`3n_W000`000000S=3n08c@oP02000000@0o[i`00D0
00000?jnL0000000000008c@oP02000000<0o[i`00<000000?jnL03n_W000P3n_W000`000000o[m`
0?joL0020?joL0050000003n_W00o[i`0?jnL0000000103n_W000`000000o[i`000000030?fnM@04
0000003_ZX000000000000<0o/1T00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3
000000X0oooo00@000000?bnNP3l_WX000007@3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo00L0oooo000X0?ooo`030000003oool0oooo07/0oooo00<000000?BjS`3d^Xl00`3d^Xl0
1P00000000150000A@000000lKVC000000@0l[VB00<000000?6iTP3a^I800`3a^I800`000000olZ0
0?o:P0040?o:P0<000001@3d_i@00`000000m;nD0?BoU0040?BoU0030000003iaY40nLJA00<00000
0`3e_Y83000000040>c6[P000000ilVi0>O9^@<0000000@0kL:X000000000000kl:S1@0000000`3>
c]T000000>o7Z@0;0000000408:_lP0000000000000000@0m<JM00<000000?O4U@3ga9D00`3ga9D2
00000080oooo100000000`3c`9T00000000000020??1VP030000003oool0000000@000001@3h_HT0
0`000000n/270?[0Q`030?[0Q`030000003i_XP0nKj80080nKj800@000000?g6PP3maX80oLJ20P00
00040?ooo`8000001@3g^hP010000000001E0000E@0005D300000080n;f700<000000?g3P03m`h00
0P3m`h02000000040?NkR0000000]:8B0;BR4P@000001@3k`8400`000000oooo0?ooo`020?ooo`05
0000003j_X<0n[j30?ZnP`0000001@3j_X@3000000050?k5O`00000000000?k4N`0000004P3oool0
0`000000n[eo000000040?bnN`030000003l_g/0o;mk0080o;mk00<000000?g0N00000000P000000
103m`7P000000?k2M@3n`WD4000000H0oooo100000040?k1L@030000003oool0oooo00@0oooo0P00
00001@3naWh000000000003n`78000000080o[i_0P0000020?jnL0030000002<d?h0S=3n00800000
103n_W000`000000o[i`0?jnL0020000000308c@oP000000o[i`0080o[i`00<000000?jnL03n_W00
0P3n_W000`000000o[m`0?joL0020?joL0050000003n_W00o[i`0?jnL0000000103n_W000`000000
o[i`000000030?fnM@040000003_ZX000000000000<0o/1T00<000000?ooo`3oool01P3oool30000
00X0oooo00@000000?bnNP3l_WX000007P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00L0oooo000X0?ooo`030000003oool0oooo07/0oooo00<000000?BjS`3d^Xl00`3d^Xl01P00
000000150000A@000000lKVC000000@0l[VB00<000000?6iTP3a^I800`3a^I800`000000olZ00?o:
P0040?o:P0@00000103d_i@00`000000m;nD0?BoU0040?BoU0030000003iaY4000000080j<Vg0`00
00000`3e_Y80000000000002000000040>c6[P000000ilVi0>O9^@<0000000@0kL:X0000003_`Z<0
kl:S0`0000000`3ZaJl0000000000007000000<0l<>S0`0000001022[o8000000000000000020?C6
W@030000003ga9D0mlBE00<0mlBE0P0000030?ooo`P0000000<0ll6J0000003oool00P3oool30000
00D0n;f900<000000?[0Q`3j`8L00`3j`8L00`000000nKj80?VnR0020?VnR0040000003maX80oLJ2
0?g6PP800000103oool2000000D0mk^800@000000000E@0005D0001E0`0000020?RmQ`030000003m
`h00oL>00080oL>00P0000000`3g^hP000000;BR4P02000000030?ooo`000000000000D0nl2100<0
00000?ooo`3oool00P3oool01@000000n[j30?ZnP`3j_X<0000000D0n[j40`0000001@3naGl00000
0000003na7/000000180oooo00<000000?ZmO`000000103l_W/00`000000o;mk0?boN`020?boN`03
0000003m`7P000000080000000@0oL1h0000003n`WD0o/9e100000060?ooo`@00000103n`G400`00
0000oooo0?ooo`040?ooo`<0000000/0o/In000000000000o/1b0000003n_Vl0000008c@oP000000
o[i`0000000308c@oP030000003n_W00o[i`0080o[i`00@000000?jnL03n_W00o[i`0`0000030?jn
L0030000003n_W00o[i`0080o[i`00<000000?joL03n_g000P3n_g001@000000o[i`0?jnL03n_W00
000000@0o[i`00<000000?jnL00000000`3m_WD010000000kjZ00000000000030?k0I0030000003o
ool0oooo00H0oooo00<000000;^S`00000002P3oool010000000o;ij0?bnNP00000O0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0N`3o
ool00`000000m;Z?0?BjS`030?BjS`060000000004D000150000003a^I<00000103b^I800`000000
lKVB0?6iTP030?6iTP030000003obX00olZ000@0olZ01`0000000`3d_i@000000?BoU0050?BoU004
0000003iaY40000000000080j<Vg2P0000030>O9^@80000000<0kL:X000000000000100000000`3Z
aJl000000<k>f@03000000030>75_0000000000000@0l<>S0P0000000`22[o800000000000040000
00D0mlBE0P0000040?ooo`030000003oool0000000H00000103oool2000000D0n;f900<000000?[0
Q`3j`8L00`3j`8L00`000000nKj80?VnR0020?VnR0060000003maX80oLJ20000003oool000001@3o
ool00`000000mk^80?NkR0030?NkR0040000000005D0001E0000E@<000000P3h_HL00`000000oL>0
0?g3P0020?g3P080000000@0mk^80000002dXQ8000000P3oool2000000@0nl2100<000000?ooo`3o
ool00`3oool01@000000n[j30?ZnP`3j_X<0000000D0n[j410000000103l`Gh000000?k4N`00000B
0?ooo`030000003j_Gl0000000@0o;ik00<000000?boN`3l_g/00P3l_g/00`000000oL1h00000002
000000050?g0N0000000o/9e0000003oool00`0000060?ooo`040000003T/Z400000000000@0o/5a
00<000000?ooo`3oool01@3oool010000000oooo0000003naWh60000000308c@oP000000000000<0
S=3n00<000000?jnL03n_W000P3n_W000`000000o[i`0?jnL0020?jnL0030000003n_W00o[i`0080
o[i`00<000000?jnL03n_W000P3n_W000`000000o[m`0?joL0020?joL0050000003n_W00o[i`0?jn
L0000000103n_W0010000000o[i`0?jnL00000020?fnM@040000003_ZX000000000000<0o/1T00<0
00000?ooo`3oool01`3oool2000000/0oooo00<000000?bnNP000000803oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo07/0oooo00<00000
0?BjS`3d^Xl00`3d^Xl00`0000000015000000020?6iT`030000003b^I80l[VB0080l[VB00<00000
0?6iTP3a^I800`3a^I800`000000olZ00?o:P0040?o:P08000000P3Y`Jd2000000040=k4_`000000
0000000000D0m;nD0P000000103``Z4000000000000000020>S9]`80000000<0l<6P0000003Tb;/0
2@0000000`3]`ZP000000>o2X`020>o2X`80000000@0j/F_000000000000j/F_1@0000030?33X`<0
000000<0PZob000000000000100000040?O4U@8000001`3oool2000000040?ooo`000000oooo0000
00@0oooo0P0000050?RmR@030000003j`8L0n/2700<0n/2700<000000?VnR03i_XP00P3i_XP01000
0000oLJ20?g6PP0000070?ooo`030000003g^hP0mk^800<0mk^800@000000000E@0005D0001E0P00
00030?RmQ`030000003m`h00oL>00080oL>00P000000103g^hP000000;BR4P0000020?ooo`800000
0`3k`842000000H0oooo00D000000?ZnP`3j_X<0n[j3000000040?ZnQ0050000003l`Gh000000000
003l`Gh00P00000C0?ooo`030000003j_Gl0000000@0o;ik00<000000?boN`3l_g/00P3l_g/01000
0000oL1h0?g0N00000020?g0N0040000003n`WD000000?ooo`<000001P3oool01@000000i;:Q0000
003j_7l000000080o/5a00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`000000o/In00H0
000000<0S=3n0000002<d?h00P2<d?h00`000000o[i`0?jnL0020?jnL0030000003n_W00o[i`0080
o[i`00<000000?jnL03n_W000P3n_W000`000000o[i`0?jnL0020?jnL0030000003n_g00o[m`0080
o[m`00D000000?jnL03n_W00o[i`000000040?jnL0040000003n_W00o[i`00000080oKie00@00000
0>nZP000000000000`3n`6@00`000000oooo0?ooo`070?ooo`8000002`3oool00`000000o;ij0000
000P0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool01`3oool00140oooo10000004
0?ooo`@000002`3oool010000000oooo00000000001k0?ooo`030000003d^Xl0m;Z?0080m;Z?00<0
00000000A@0000000P3a^I<00`000000l[VB0?:iTP020?:iTP030000003a^I80lKVB00<0lKVB00<0
00000?o:P03obX00103obX001@000000k/>V000000000000`T400080000000<0g/Bo000000000000
100000000`3d_i@00000000000020?32X@d0000000@0oooo000000000000oooo0`0000030>o2X`@0
000000@0oooo0000003ZaJl0j/F_100000030?33X`030000003oool0000000D0000000H0oooo0000
0000000000000?O4U@00000C0?ooo`030000003h_HT0n;f900<0n;f900<000000?[0Q`3j`8L00`3j
`8L00`000000nKj80?VnR0020?VnR0040000003maX80oLJ2000000L0oooo00<000000?NkR03g^hP0
0`3g^hP010000000001E0000E@0005D2000000<0n;f700<000000?g3P03m`h000P3m`h0200000004
0?NkR0000000]:8B00000080oooo0P0000030?_0P@8000001P3oool01@000000n[j30?ZnP`3j_X<0
000000@0n[j400<000000?c1OP0000000P3l`Gh2000001<0oooo00<000000?ZmO`000000103l_W/0
0`000000o;mk0?boN`020?boN`040000003m`7P0oL1h00000080oL1h00@000000?k2M@000000oooo
0`0000060?ooo`050000003T/Z4000000?ZlO`0000000P3n`G400`000000oooo0?ooo`060?ooo`04
0000003oool0oooo0?ooo`D0000000<0o[mb000000000000102<d?h00`000000o[i`0?jnL0020?jn
L0030000003n_W00o[i`0080o[i`00<000000?jnL03n_W000P3n_W000`000000o[i`0?jnL0020?jn
L0030000003n_g00o[m`0080o[m`00D000000?jnL03n_W00o[i`000000040?jnL0040000003n_W00
o[i`000000<0oKie0`0000030?k0I0030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3o
ool00`000000o;ij0000000Q0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool01P3o
ool00100oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00L0oooo0`00001m0?ooo`030000003d^Xl0m;Z?0080m;Z?00<000000000A@0000000P3a
^I<00`000000l[VB0?:iTP020?:iTP030000003a^I80lKVB00<0lKVB00<000000?o:P03obX00103o
bX0400000080`T400P000000103Na;l000000>3<a03Pc<@4000000@0l<:Q2P0000040?ooo`030000
003oool0oooo00<0000000@0kl:S0000003oool0oooo0P0000020?ooo`80000000<0oooo00000000
00000`000000103``j<000000?ooo`3oool2000000030?ooo`000000000000@0oooo0P00000D0?oo
o`030000003h_HT0n;f90080n;f900<000000?[0Q`3j`8L00`3j`8L00`000000nKj80?VnR0020?Vn
R0040000003maX80oLJ2000000L0oooo0P0000040?NkR0050000000005D0001E0000E@0000000`3h
_HL00`000000oL>00?g3P0030?g3P0060000003oool000000000002dXQ8000000P3oool200000080
nl2100<000000?ooo`0000001P3oool01@000000n[j30?ZnP`3j_X<0000000@0n[j400<000000?c1
OP0000000P3l`Gh2000001<0oooo00<000000?ZmO`000000103l_W/00`000000o;mk0?boN`020?bo
N`040000003m`7P0oL1h00000080oL1h00@000000?k2M@000000oooo0`0000070?ooo`80000000D0
n[ao0000003n`G40o/5a000000080?ooo`030000003oool0oooo0080oooo00<000000?joLP3n_g80
0P3n_g82000000@0S=3n00<000000?jnL03n_W000P3n_W000`000000o[i`0?jnL0020?jnL0030000
003n_W00o[i`0080o[i`00<000000?jnL03n_W000P3n_W000`000000o[m`0?joL0020?joL0050000
003n_W00o[i`0?jnL0000000103n_W0010000000o[i`0?jnL00000030?fnM@<000000`3n`6@00`00
0000oooo0?ooo`0D0?ooo`030000003l_WX000000280oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`060?ooo`00403oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1m0?ooo`030000003d^Xl0m;Z?
0080m;Z?00<000000000A@0000000P3a^I<00`000000l[VB0?:iTP030?:iTP030000003a^I80lKVB
0080lKVB00<000000?o:P03obX000`3obX001@000000oooo0?ooo`000000k/>V0080000000<0`T40
0000000000000P0000020>3<a0L000000P3``Z4020000000oooo0?ooo`000000fLK70000003oool0
00002P3oool2000000L0oooo00H000000?ooo`000000hLFl0000003oool300000240oooo00<00000
0?RmR@3h_HT00P3h_HT00`000000n/270?[0Q`030?[0Q`030000003i_XP0nKj80080nKj800@00000
0?g6PP3maX8000001`3oool2000000@0mk^800D000000000E@0005D0001E000000030?RmQ`030000
003m`h00oL>000<0oL>000H000000?ooo`00000000000;BR4P0000030?ooo`060000003k`8400000
0000003oool000001P3oool00`000000n[j30?ZnP`020?ZnP`050000003j_X@0n[j40?ZnQ0000000
103l`Gh2000001<0oooo00<000000?ZmO`000000103l_W/00`000000o;mk0?boN`020?boN`040000
003m`7P0oL1h00000080oL1h00@000000?k2M@000000oooo0P0000080?ooo`040000003j_7l0n[ao
00000080o/5a00<000000?ooo`3oool0303oool01`000000o[mb0?joLP3n_g8000000?ooo`000000
0`2<d?h00`000000o[i`0?jnL0020?jnL0030000003n_W00o[i`0080o[i`00<000000?jnL03n_W00
0P3n_W000`000000o[i`0?jnL0020?jnL0030000003n_g00o[m`0080o[m`00D000000?jnL03n_W00
o[i`000000040?jnL0050000003n_W00o[i`0?jnL00000000P3m_WD2000000050?jnL0000000o/1T
0?k0I00000005P3oool00`000000o;ij0000000S0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool01P3oool00100oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0O@3oool00`000000m;Z?0?BjS`02
0?BjS`030000000004D000000080lKVC0P0000040?:iTP030000003a^I80lKVB0080lKVB00<00000
0?o:P03obX000`3obX0010000000oooo0?ooo`3oool2000000030>k3YP000000000000H0000000<0
kkbM0000003``Z401@3``Z401@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool0
203oool010000000oooo0?ooo`3oool200000240oooo00<000000?RmR@3h_HT00P3h_HT00`000000
n/270?[0Q`030?[0Q`030000003i_XP0nKj80080nKj800<000000?g6PP000000203oool2000000@0
mk^800D000000000E@0005D0001E000000030?RmQ`030000003m`h00oL>000<0oL>000H000000?oo
o`00000000000;BR4P0000030?ooo`@000002@3oool01@000000n[j30?ZnP`3j_X<0000000<0n[j4
00<000000?c1OP3l`Gh00P3l`Gh00`000000oooo0?ooo`0B0?ooo`030000003j_Gl0000000@0o;ik
00<000000?boN`3l_g/00P3l_g/00`000000oL1h0?g0N0030?g0N0040000003n`WD000000?ooo`80
0000203oool010000000n[ao0?ZlO`0000020?k1L@030000003oool0oooo00d0oooo00@000000?jo
LP3n_g8000000P3oool010000000S=3n08c@oP0000040?jnL0030000003n_W00o[i`0080o[i`00<0
00000?jnL03n_W000P3n_W000`000000o[i`0?jnL0020?jnL0030000003n_g00o[m`0080o[m`00D0
00000?jnL03n_W00o[i`000000040?jnL0050000003n_W00o[i`0?jnL00000000P3m_WD200000005
0?jnL0000000o/1T0?k0I00000005`3oool2000002@0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`060?ooo`00403oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1m0?ooo`030000003d^Xl0m;Z?
0080m;Z?00<000000000A@0000000P3a^I<2000000@0l[VB00<000000?6iTP3a^I800P3a^I800`00
0000olZ00?o:P0030?o:P0030000003oool0oooo00/0000000<0h<c40000000000000P0000040?32
X@030000003oool0oooo04<0oooo00D000000?RmR@3h_HT0n;f9000000050?[0Q`030000003i_XP0
nKj80080nKj800<000000?g6PP0000002@3oool00`000000mk^80?NkR0020?NkR0050000000005D0
001E0000E@0000000`3h_HL00`000000oL>00?g3P0020?g3P0030000003oool0oooo0080000000<0
]:8B0000003oool00P3oool2000000030?ooo`000000oooo00P0oooo00D000000?ZnP`3j_X<0n[j3
000000030?ZnQ0030000003l`Gh0o<5n0080o<5n00<000000?ooo`3oool04P3oool00`000000n[eo
000000040?bnN`030000003l_g/0o;mk0080o;mk00<000000?g0N03m`7P00`3m`7P00`000000o/9e
000000020?ooo`030000003oool0oooo00H0oooo00@000000?ZlO`3j_7l000000P3n`G400`000000
oooo0?ooo`0>0?ooo`030000003n_g80000000<0oooo00<0000008c@oP000000103n_W000`000000
o[i`0?jnL0020?jnL0030000003n_W00o[i`0080o[i`00<000000?jnL03n_W000P3n_W000`000000
o[m`0?joL0020?joL0050000003n_W00o[i`0?jnL0000000103n_W001@000000o[i`0?jnL03n_W00
00000080oKie0P0000001@3n_W0000000?k0I03n`6@0000001L0oooo0P00000U0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool01P3oool00140oooo100000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1m0?ooo`030000003d^Xl0
m;Z?0080m;Z?00<000000000A@0000000P3a^I<2000000@0l[VB00<000000?6iTP3a^I800P3a^I80
10000000olZ00?o:P03obX05000000@0oooo200000001@3Pc<@000000?ooo`3oool000000080l<:Q
00<000000?ooo`3oool0A03oool01@000000n;f90?RmR@3h_HT0000000D0n/2700<000000?VnR03i
_XP00P3i_XP00`000000oLJ2000000090?ooo`030000003g^hP0mk^80080mk^800<000000000E@00
05D00P0000030?RmQ`030000003m`h00oL>00080oL>000<000000?ooo`3oool00P0000000`2dXQ80
00000?ooo`020?ooo`040000003oool0oooo000000T0oooo00@000000?ZnP`3j_X<0n[j30P000002
0?ZnQ0030000003l`Gh0o<5n0080o<5n00<000000?ooo`3oool04P3oool00`000000n[eo00000004
0?bnN`030000003l_g/0o;mk0080o;mk00<000000?g0N03m`7P00`3m`7P2000000<0oooo00<00000
0?ooo`3oool01`3oool00`000000n[ao000000020?k1L@030000003oool0oooo00l0oooo0P000004
0?ooo`800000103n_W000`000000o[i`0?jnL0020?jnL0030000003n_W00o[i`00<0o[i`00D00000
0?jnL03n_W00o[i`000000040?joL0050000003n_W00o[i`0?jnL0000000103n_W001@000000o[i`
0?jnL03n_W0000000080oKie0P0000001@3n_W0000000?k0I03n`6@0000001L0oooo0P00000V0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00100oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0O@3oool00`000000m;Z?0?BjS`020?BjS`030000000004D000000080lKVC0P0000040?:i
TP030000003a^I80lKVB00H000000P3obX000`000000oooo0?ooo`060?ooo`030000003oool00000
00@00000103oool3000004H0oooo00D000000?RmR@3h_HT0n;f9000000050?[0Q`030000003i_XP0
nKj80080nKj800<000000?g6PP0000002@3oool00`000000mk^80?NkR0020?NkR0030000000005D0
001E008000000`3h_HL00`000000oL>00?g3P0020?g3P0030000003oool0oooo00<000004P3oool0
0`000000n[j30?ZnP`0200000080n[j400D000000?c1OP3l`Gh0o<5n0000000F0?ooo`800000103l
_W/00`000000o;mk0?boN`020?boN`030000003m`7P0oL1h00<0oL1h0P0000030?ooo`030000003o
ool0oooo00L0oooo00<000000?ZlO`0000000P3n`G400`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00<0oooo0P0000030?jnL0030000003n_W00o[i`0080o[i`00<000000?jnL03n_W000`3n
_W001@000000o[i`0?jnL03n_W00000000@0o[m`00D000000?jnL03n_W00o[i`000000040?jnL005
0000003n_W00o[i`0?jnL00000000P3m_WD2000000050?jnL0000000o/1T0?k0I00000005`3oool2
000002L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`060?ooo`00403oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1m0?ooo`030000003d^Xl0m;Z?0080m;Z?00P000000000A@000000lKVC0000
003h`Hl000000?:iTPH000000P3a^I800`000000olZ00?o:P0030?o:P0030000003oool0oooo00D0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`150?ooo`040000003h_HT0n;f90000
00D0n/2700<000000?VnR03i_XP00P3i_XP2000000X0oooo00<000000?NkR03g^hP00P3g^hP00`00
0000001E0000E@02000000<0n;f700<000000?g3P03m`h000P3m`h000`000000oooo0?ooo`030000
0180oooo00<000000?ZnP`3j_X<00P0000020?ZnQ0050000003l`Gh0o<5n0?c1OP0000005P3oool2
000000@0o;ik00<000000?boN`3l_g/00P3l_g/00`000000oL1h0?g0N0030?g0N08000000`3oool0
0`000000oooo0?ooo`070?ooo`030000003j_7l000000080o/5a00<000000?ooo`3oool05`3oool2
00000080o[i`00<000000?jnL03n_W000P3n_W000`000000o[i`0?jnL0030?jnL0050000003n_W00
o[i`0?jnL0000000103n_g001@000000o[i`0?jnL03n_W00000000@0o[i`00<000000?jnL03n_W00
0P3n_W000`000000oKie000000020?jnL0040000003n`6@0o/1T000001L0oooo0P00000W0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool01P3oool00100oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo0`00001m0?ooo`03
0000003d^Xl0m;Z?0080m;Z?00<000000000A@0000001@0000030?:iTP030000003a^I80lKVB0080
lKVB00<000000?o:P03obX000`3obX000`000000oooo0?ooo`050?ooo`030000003oool0oooo05<0
oooo00@000000?RmR@3h_HT000001@3j`8L00`000000nKj80?VnR0020?VnR08000002P3oool00`00
0000mk^80?NkR0020?NkR0030000000005D0001E008000000`3h_HL00`000000oL>00?g3P0020?g3
P0030000003oool0oooo00<000004P3oool00`000000n[j30?ZnP`0200000080n[j400@000000?c1
OP3l`Gh000005`3oool2000000@0o;ik00<000000?boN`3l_g/00P3l_g/00`000000oL1h0?g0N003
0?g0N08000000`3oool00`000000oooo0?ooo`070?ooo`030000003j_7l000000080o/5a00<00000
0?ooo`3oool0603oool2000000030?jnL0000000o[i`00<0o[i`00<000000?jnL03n_W000`3n_W00
1@000000o[i`0?jnL03n_W00000000@0o[m`00D000000?jnL03n_W00o[i`000000040?jnL0030000
003n_W00o[i`0080o[i`00<000000?fnM@0000000P3n_W000`000000o/1T0000000H0?ooo`800000
:03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00H0oooo000A0?ooo`@00000103o
ool4000000X0oooo00<000000?ooo`3oool0O@3oool:000000030?S1S`000000l[VB00<0l[VB00<0
00000?6iTP3a^I800P3a^I800`000000olZ00?o:P0030?o:P0030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0E03oool00`000000n;f9000000040?[0Q`030000003oool0000000<0nKj80P00
000:0?ooo`030000003g^hP0mk^80080mk^800H000000000E@0005D000000?ooo`0000020?RmQ`05
0000003m`h00oL>00?g3P00000000`3oool3000001<0oooo00<000000?ZnP`0000000P0000001@3j
_X@000000?c1OP3l`Gh0000001L0oooo0P0000040?bnN`030000003l_g/0o;mk0080o;mk00<00000
0?g0N03m`7P00`3m`7P2000000d0oooo00<000000?ZlO`0000000P3n`G400`000000oooo0?ooo`0I
0?ooo`<00000103n_W000`000000o[i`0?jnL0030?jnL0050000003n_W00o[i`0?jnL0000000103n
_g001@000000o[i`0?jnL03n_W00000000@0o[i`00<000000?jnL03n_W000P3n_W000`000000oKie
000000020?jnL0030000003n`6@0000001T0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00H0oooo000W0?ooo`030000003oool0oooo07T0oooo1@00
00040?BjS`D0000000<0n<6?0000003b^I800`3b^I800`000000lKVB0?6iTP020?6iTP030000003o
bX00olZ00080olZ000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1D0?ooo`030000003h
_HT0000000<0n/2700D000000?ooo`3oool0oooo000000020?VnR08000002P3oool00`000000mk^8
0?NkR0020?NkR0060000000005D0001E0000003oool000000P3h_HL01@000000oL>00?g3P03m`h00
000000<0oooo0`00000C0?ooo`030000003j_X<000000080000000@0n[j40000003l`Gh00000603o
ool2000000@0o;ik00<000000?boN`3l_g/00P3l_g/00`000000oL1h0?g0N0030?g0N08000003@3o
ool01@000000n[ao0000003n`G40000001d0oooo0P0000040?jnL0030000003n_W00o[i`00<0o[i`
00<000000?jnL03n_W000P3n_W001@000000o[m`0?joL03n_g00000000<0o[i`00<000000?jnL03n
_W000P3n_W000`000000o[i`0?jnL0020?jnL0030000003m_WD000000080o[i`00<000000?k0I000
00006@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool01P3oool002L0oooo00<000000?ooo`3oool0L`3oool6000000@0oooo00<000000?BjS`3d^Xl0
0P3d^Xl5000000030?S1S`000000l[VB00<0l[VB00<000000?6iTP3a^I800P3a^I800`000000olZ0
0?o:P0020?o:P0030000003oool0oooo00H0oooo00<000000?ooo`3oool0E03oool00`000000n;f9
000000030?[0Q`030000003oool0oooo0080oooo00<000000?VnR00000002`3oool00`000000mk^8
0?NkR0020?NkR0060000000005D0001E0000003oool000000P3h_HL01@000000oL>00?g3P03m`h00
000000<0oooo0`00000C0?ooo`030000003j_X<000000080000000@0n[j40000003l`Gh00000603o
ool2000000@0o;ik00<000000?boN`3l_g/00P3l_g/00`000000oL1h0?g0N0030?g0N08000003@3o
ool01@000000n[ao0000003n`G40000001h0oooo0P0000030?jnL0030000003n_W00o[i`00<0o[i`
00<000000?jnL03n_W000P3n_W001@000000o[m`0?joL03n_g00000000<0o[i`00<000000?jnL03n
_W000P3n_W000`000000o[i`0?jnL0020?jnL0030000003m_WD000000080o[i`00<000000?k0I000
00006@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool01P3oool002L0oooo00<000000?ooo`3oool0K@3oool6000000X0oooo00<000000?BjS`3d^Xl0
0P3d^Xl2000000050?ooo`00000000000?S1S`000000103b^I800`000000lKVB0?6iTP020?6iTP03
0000003obX00olZ00080olZ000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`80
00000P3j`8L00`000000oooo0?ooo`040?ooo`8000002`3oool00`000000mk^80?NkR0020?NkR006
0000000005D0001E0000003oool000000P3h_HL01@000000oL>00?g3P03m`h00000000<0oooo0`00
000C0?ooo`050000003j_X<000000000003oool00P0000000`3l`Gh000000?ooo`0G0?ooo`800000
103l_W/00`000000o;mk0?boN`020?boN`030000003m`7P0oL1h00<0oL1h0P00000=0?ooo`050000
003j_7l000000?k1L@0000007`3oool200000080o[i`00<000000?jnL03n_W000`3n_W000`000000
o[i`0?jnL0020?jnL0050000003n_g00o[m`0?joL0000000103n_W001@000000o[i`0?jnL03n_W00
000000@0o[i`0`0000020?jnL0030000003n`6@0000004H0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`060?ooo`009`3oool00`000000oooo0?ooo`1W0?ooo`H000004@3oool01000
0000m;Z?0?BjS`3d^Xl2000000050?ooo`00000000000?S1S`000000103b^I800`000000lKVB0?6i
TP020?6iTP030000003obX00olZ00080olZ000<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`1E0?ooo`80000000<0n/270000003oool01`3oool00`000000oooo0?ooo`0:0?ooo`050000003g
^hP0mk^80?NkR00000000P0005D00`000000oooo000000020?RmQ`050000003m`h00oL>00?g3P000
00000`3oool3000001@0oooo0`000000103oool0000000000000000I0?ooo`800000103l_W/00`00
0000o;mk0?boN`020?boN`030000003m`7P0oL1h00<0oL1h00<000000?ooo`3oool0303oool01@00
0000n[ao0000003n`G4000000200oooo0P0000000`3n_W0000000?jnL0040?jnL0030000003n_W00
o[i`0080o[i`00D000000?joL03n_g00o[m`000000040?jnL0050000003n_W00o[i`0?jnL0000000
103n_W0300000080o[i`00<000000?k0I0000000A`3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00H0oooo000V0?ooo`030000003oool0oooo0680oooo1P00000G0?ooo`070000003d
^Xl0m;Z?0000000004D000000?ooo`03000000030?ooo`000000l[VB0080l[VB00<000000?6iTP3a
^I800P3a^I800`000000olZ00?o:P0020?o:P0030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0E@3oool3000001H0oooo00D000000?NkR03g^hP0mk^8000000020000E@030000003oool00000
0080n;f700@000000?g3P03m`h0000001@3oool2000001@0oooo0P0000020?ooo`<000006@3oool2
000000@0o;ik00<000000?boN`3l_g/00P3l_g/00`000000oL1h0?g0N0030?g0N0030000003oool0
oooo00`0oooo00D000000?ZlO`000000o/5a0000000Q0?ooo`<000001@3n_W000`000000o[i`0?jn
L0020?jnL0050000003n_g00o[m`0?joL0000000103n_W001@000000o[i`0?jnL03n_W00000000@0
o[i`0`0000020?jnL0030000003n`6@0000004P0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`050?ooo`009P3oool00`000000oooo0?ooo`1L0?ooo`H000007@3oool01P000000m;Z?
0?BjS`000000001500000080oooo0P0000000`3oool000000?:iTP020?:iTP030000003a^I80lKVB
0080lKVB00<000000?o:P03obX000P3obX000`000000oooo0?ooo`060?ooo`030000003oool0oooo
05H0oooo0P00000F0?ooo`050000003g^hP0mk^80?NkR00000000P0005D01P000000oooo0?ooo`00
0000n;f700000080oL>000<000000?ooo`3oool00`3oool2000001@0oooo0P0000030?ooo`030000
003oool0oooo01P0oooo0P0000040?bnN`030000003l_g/0o;mk0080o;mk00<000000?g0N03m`7P0
0`3m`7P00`000000oooo0?ooo`0<0?ooo`050000003j_7l000000?k1L@0000008P3oool2000000D0
o[i`00<000000?jnL03n_W000P3n_W001@000000o[m`0?joL03n_g00000000@0o[i`00D000000?jn
L03n_W00o[i`000000040?jnL0<000000P3n_W000`000000o/1T000000190?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool01@3oool002H0oooo1000001F0?ooo`D000008`3oool01P00
0000m;Z?0?BjS`000000001500000080oooo0P0000000`3oool000000?:iTP020?:iTP030000003a
^I80lKVB0080lKVB00<000000?o:P03obX000P3obX000`000000oooo0?ooo`060?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05@3oool010000000mk^80?NkR00000020000E@070000
003oool0oooo0?ooo`000000n;f7000000020?g3P0030000003oool0oooo00<0oooo00<000000?oo
o`3oool0503oool01@000000oooo0?ooo`3oool0000001/0oooo00<000000?bnN`3l_W/00P3l_W/0
0`000000o;mk0?boN`030?boN`030000003m`7P0oL1h0080oL1h00<000000?ooo`3oool0303oool0
1@000000n[ao0000003n`G4000000280oooo100000030?jnL0030000003n_W00o[i`0080o[i`00<0
00000?joL03n_g000P3n_g001@000000o[i`0?jnL03n_W00000000<0o[i`00<000000?jnL03n_W00
0P3n_W000`000000o[i`000000020?jnL0030000003n`6@0000004T0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`050?ooo`009P3oool00`000000oooo0?ooo`1A0?ooo`H00000:03o
ool01P000000m;Z?0?BjS`000000001500000080oooo00@000000?ooo`3oool000000`3b^I800`00
0000lKVB0?6iTP020?6iTP050000003obX00olZ00?o:P00000002@3oool00`000000oooo0?ooo`1^
0?ooo`040000003g^hP0mk^800000080001E00L000000?ooo`3oool0oooo0000003h_HL000000080
oL>000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01d0
oooo00<000000?bnN`3l_W/00P3l_W/00`000000o;mk0?boN`030?boN`030000003m`7P0oL1h0080
oL1h00<000000?ooo`3oool0303oool01@000000n[ao0000003n`G4000000280oooo0P0000000`3o
ool00000000000020?jnL0030000003n_W00o[i`0080o[i`00<000000?joL03n_g000P3n_g001@00
0000o[i`0?jnL03n_W00000000@0o[i`00L000000?jnL03n_W00o[i`0000003n_W0000000080o[i`
00<000000?k0I0000000BP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0oooo
000V0?ooo`030000003oool0oooo04/0oooo1P00000^0?ooo`060000003d^Xl0m;Z?0000000004D0
00000P3oool010000000oooo0?ooo`0000030?:iTP050000003a^I80lKVB0?6iTP000000103obX00
0`000000oooo0?ooo`070?ooo`030000003oool0oooo06h0oooo00@000000?NkR03g^hP000000P00
05D01`000000oooo0?ooo`3oool000000?RmQ`0000000P3m`h000`000000oooo0?ooo`030?ooo`03
0000003oool0oooo03@0oooo00<000000?bnN`3l_W/00P3l_W/00`000000o;mk0?boN`030?boN`03
0000003m`7P0oL1h0080oL1h00<000000?ooo`3oool03@3oool2000000030?k1L@000000oooo0240
oooo0P0000020?ooo`@00000103n_W000`000000o[m`0?joL0020?joL0050000003n_W00o[i`0?jn
L0000000103n_W001`000000o[i`0?jnL03n_W0000000?jnL00000000P3n_W000`000000o/1T0000
001;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool002H0oooo00<00000
0?ooo`3oool0A@3oool6000003@0oooo00<000000?BjS`3d^Xl00P0000060?ooo`050000003b^I80
l[VB0?:iTP0000000`3a^I800`000000olZ00?o:P0020?o:P0030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0KP3oool010000000mk^80?NkR00000020000E@090000003oool0oooo0?ooo`00
0000n;f70000003m`h00000000H0oooo00<000000?ooo`3oool0=03oool00`000000o;ik0?bnN`02
0?bnN`030000003l_g/0o;mk00<0o;mk00D000000?g0N03m`7P0oL1h0000000@0?ooo`80000000<0
o/5a0000003oool08P3oool01`000000oooo0?ooo`3oool0000008c@oP000000103n_W000`000000
o[m`0?joL0020?joL0050000003n_W00o[i`0?jnL0000000103n_W001@000000o[i`0?jnL03n_W00
000000@0o[i`00<000000?k0I0000000C03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00D0oooo000V0?ooo`030000003oool0oooo03l0oooo1P00000j0?ooo`030000003d^Xl0m;Z?
008000001P3oool01@000000l[VB0?:iTP3b^I80000000<0lKVB00<000000?o:P03obX000P3obX00
0`000000oooo0?ooo`070?ooo`030000003oool0oooo06h0oooo00@000000?NkR03g^hP000000P00
05D02@000000oooo0?ooo`3oool000000?RmQ`000000oL>0000000060?ooo`030000003oool0oooo
03@0oooo00<000000?bnN`3l_W/00P3l_W/00`000000o;mk0?boN`030?boN`050000003m`7P0oL1h
0?g0N0000000403oool2000000030?k1L@000000oooo0280oooo00<000000?ooo`3oool00P3oool0
0`000000S=3n000000030?jnL0030000003n_g00o[m`0080o[m`00D000000?jnL03n_W00o[i`0000
00040?jnL0050000003n_W00o[i`0?jnL0000000103n_W000`000000o/1T0000001=0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool01@3oool002H0oooo00<000000?ooo`3oool0>P3o
ool500000400oooo00<000000?BjS`3d^Xl00P0000060?ooo`050000003b^I80l[VB0?:iTP000000
0`3a^I800`000000olZ00?o:P0020?o:P0030000003oool0oooo00L0oooo00<000000?ooo`3oool0
KP3oool010000000mk^80?NkR00000020000E@090000003oool0oooo0?ooo`000000n;f70000003m
`h00000003d0oooo00<000000?bnN`3l_W/00P3l_W/00`000000o;mk0?boN`030?boN`050000003m
`7P0oL1h0?g0N0000000403oool3000002X0oooo00<0000008c@oP0000000P3n_W000`000000o[m`
0?joL0020?joL0050000003n_W00o[i`0?jnL0000000103n_W001@000000o[i`0?jnL03n_W000000
00@0o[i`00<000000?k0I0000000CP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00D0oooo000V0?ooo`030000003oool0oooo03@0oooo1P0000150?ooo`030000003d^Xl0m;Z?0080
00001P3oool01@000000l[VB0?:iTP3b^I80000000<0lKVB00<000000?o:P03obX000P3obX000`00
0000oooo0?ooo`070?ooo`030000003oool0oooo06h0oooo00@000000?NkR03g^hP000000P0005D0
0`000000oooo0?ooo`020?ooo`80000000<0oL>00000003oool0?03oool00`000000o;ik0?bnN`02
0?bnN`030000003l_g/0o;mk00<0o;mk00D000000?g0N03m`7P0oL1h0000000@0?ooo`<00000:`3o
ool3000000030?jnL0000000o[m`00<0o[m`00D000000?jnL03n_W00o[i`000000040?jnL0050000
003n_W00o[i`0?jnL0000000103n_W000`000000o/1T0000001?0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool01@3oool002H0oooo00<000000?ooo`3oool0;P3oool6000004/0oooo
00<000000?BjS`3d^Xl00P0000060?ooo`050000003b^I80l[VB0?:iTP0000000`3a^I800`000000
olZ00?o:P0020?o:P0030000003oool0oooo00L0oooo00<000000?ooo`3oool0KP3oool010000000
mk^80?NkR00000020000E@030000003oool0oooo0080oooo0P0000000`3m`h0000000?ooo`0m0?oo
o`050000003l_W/0o;ik0?bnN`0000001@3l_g/01@000000oL1h0?g0N03m`7P000000100oooo0`00
000]0?ooo`<00000103n_g001@000000o[i`0?jnL03n_W00000000@0o[i`00D000000?jnL03n_W00
o[i`000000040?jnL0030000003n`6@000000500oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`050?ooo`009P3oool3000002P0oooo1P00001A0?ooo`030000003d^Xl0m;Z?00800000
1P3oool01@000000l[VB0?:iTP3b^I80000000<0lKVB00<000000?o:P03obX000P3obX000`000000
oooo0?ooo`070?ooo`030000003oool0oooo06l0oooo00<000000?NkR00000000P0005D00`000000
oooo0?ooo`020?ooo`<00000?`3oool01@000000o;ik0?bnN`3l_W/0000000D0o;mk00@000000?g0
N03m`7P000004@3oool3000002h0oooo0P0000040?joL0050000003n_W00o[i`0?jnL0000000103n
_W001@000000o[i`0?jnL03n_W00000000@0o[i`00<000000?k0I0000000D@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00D0oooo000V0?ooo`030000003oool0oooo0280oooo1P00
001G0?ooo`030000003d^Xl0m;Z?008000001`3oool010000000l[VB0?:iTP0000030?6iTP050000
003obX00olZ00?o:P00000002P3oool00`000000oooo0?ooo`1_0?ooo`030000003g^hP000000080
001E00<000000?ooo`3oool00P3oool3000003l0oooo00D000000?bnN`3l_W/0o;ik000000050?bo
N`040000003m`7P0oL1h00000140oooo0`00000_0?ooo`8000000`3n_g001@000000o[i`0?jnL03n
_W00000000@0o[i`00D000000?jnL03n_W00o[i`000000040?jnL0030000003n`6@000000540oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`009@3oool00`000000oooo0?oo
o`0M0?ooo`H00000GP3oool010000000m;Z?0000000000070?ooo`040000003b^I80l[VB000000<0
lKVB00D000000?o:P03obX00olZ00000000:0?ooo`030000003oool0oooo06l0oooo00D000000?Nk
R0000000001E000000050?ooo`<00000@03oool010000000o;ik0?bnN`0000050?boN`040000003m
`7P0oL1h00000140oooo0`00000`0?ooo`8000000P3n_g001@000000o[i`0?jnL03n_W00000000@0
o[i`00D000000?jnL03n_W00o[i`000000040?jnL0030000003n`6@000000580oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`050?ooo`009@3oool00`000000oooo0?ooo`0H0?ooo`D0
0000I03oool010000000m;Z?0000000000070?ooo`040000003b^I80l[VB000000<0lKVB00D00000
0?o:P03obX00olZ00000000:0?ooo`030000003oool0oooo06l0oooo00D000000?NkR0000000001E
000000050?ooo`<00000@03oool010000000o;ik0?bnN`0000050?boN`040000003m`7P0oL1h0000
0140oooo0`00000a0?ooo`80000000<0o[m`0000003n_W000P3n_W000`000000o[i`0?jnL0020?jn
L0050000003n_W00o[i`0?jnL0000000103n_W000`000000o/1T0000001C0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01@3oool002D0oooo00<000000?ooo`3oool04P3oool60000
06T0oooo00@000000?BjS`00000000001`3oool010000000l[VB0?:iTP0000030?6iTP050000003o
bX00olZ00?o:P00000002P3oool00`000000oooo0?ooo`1_0?ooo`050000003g^hP000000000E@00
00001P3oool200000400oooo00@000000?bnN`3l_W/000001@3l_g/010000000oL1h0?g0N000000A
0?ooo`<00000<P3oool3000000<0o[i`00<000000?jnL03n_W000P3n_W001@000000o[i`0?jnL03n
_W00000000@0o[i`00<000000?k0I0000000E03oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00D0oooo000U0?ooo`030000003oool0oooo00`0oooo1P00001_0?ooo`030000003d^Xl0
000000P0oooo00@000000?:iTP3b^I8000000`3a^I801@000000olZ00?o:P03obX00000000X0oooo
00<000000?ooo`3oool0K`3oool01@000000mk^80000000005D0000000H0oooo00<000000?ooo`3o
ool0@03oool00`000000o;ik000000050?boN`030000003m`7P000000180oooo0`00000c0?ooo`80
00000`3n_W000`000000o[i`0?jnL0020?jnL0030000003n_W00o[i`0080o[i`00L000000?jnL03n
_W00o[i`0000003n`6@0000005D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`04
0?ooo`009@3oool00`000000oooo0?ooo`060?ooo`H00000M@3oool00`000000m;Z?000000080?oo
o`040000003b^I80l[VB000000<0lKVB00D000000?o:P03obX00olZ00000000:0?ooo`030000003o
ool0oooo06l0oooo00D000000?NkR0000000001E000000060?ooo`030000003oool0oooo0400oooo
00<000000?bnN`0000001@3l_g/00`000000oL1h0000000B0?ooo`<00000=03oool200000080o[i`
00<000000?jnL03n_W000P3n_W000`000000o[i`0?jnL0020?jnL0070000003n_W00o[i`0?jnL000
0000o/1T0000001F0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool000T0
oooo00<000000?ooo`3oool00`3oool4000000@0oooo1000000:0?ooo`030000003oool0oooo00H0
0000N`3oool00`000000m;Z?000000080?ooo`030000003b^I80l[VB008000000P3a^I801@000000
olZ00?o:P03obX00000000X0oooo00<000000?ooo`3oool0K`3oool01@000000mk^80000000005D0
000000H0oooo00<000000?ooo`3oool0@03oool00`000000o;ik000000050?boN`030000003m`7P0
000001<0oooo0P00000e0?ooo`80000000<0o[i`0000003n_W000`3n_W000`000000o[i`0?jnL002
0?jnL0070000003n_W00o[i`0?jnL0000000o/1T0000001G0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0103oool000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool300000840oooo
00<000000?BjS`000000203oool00`000000l[VB0?:iTP0200000080lKVB00D000000?o:P03obX00
olZ00000000:0?ooo`030000003oool0oooo06l0oooo00D000000?NkR0000000001E0000001:0?oo
o`8000001@3l_g/00`000000oL1h0000000C0?ooo`030000003oool0oooo03D0oooo00<000000?jn
L0000000103n_W000`000000o[i`0?jnL0020?jnL0030000003n_W00o[i`0080o[i`0P00001H0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool000T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0203oool200000840oooo00<000000?BjS`000000203oool00`000000l[VB0?:iTP020000
0080lKVB00@000000?o:P03obX0000002`3oool00`000000oooo0?ooo`1_0?ooo`050000003g^hP0
00000000E@000000BP3oool2000000D0o;mk00<000000?g0N00000004`3oool00`000000oooo0?oo
o`0f0?ooo`800000103n_W000`000000o[i`0?jnL0020?jnL0030000003n_W00o[i`0080o[i`0P00
001I0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0103oool000T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool02P3oool2000000@0oooo00<000000?ooo`3oool0N03oool3000000P0oooo00<0
00000?:iTP3b^I800P0000020?6iTP040000003obX00olZ0000000/0oooo00<000000?ooo`3oool0
K`3oool01@000000mk^80000000005D0000004X0oooo0P0000050?boN`800000503oool00`000000
oooo0?ooo`0g0?ooo`030000003n_W00o[i`0080o[i`00<000000?jnL03n_W000P3n_W000`000000
o[i`0?jnL0020?jnL0030000003oool0oooo05P0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`040?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0<0?ooo`8000000P3oool00`000000
oooo0?ooo`1h0?ooo`<00000203oool00`000000l[VB0?:iTP0200000080lKVB00@000000?o:P03o
bX0000002`3oool00`000000oooo0?ooo`1_0?ooo`050000003g^hP000000000E@000000B`3oool0
0`000000o;mk0?boN`030?boN`800000503oool00`000000oooo0?ooo`0h0?ooo`050000003n_W00
o[i`0?jnL0000000103n_W000`000000o[i`0?jnL0020?jnL0030000003oool0oooo05T0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`002@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0>0?ooo`<00000NP3oool3000000T0oooo00@000000?:iTP00000000000P3a^I8010000000olZ0
0?o:P000000;0?ooo`030000003oool0oooo0700oooo0P0000000`0005D000000?ooo`1:0?ooo`03
0000003l_g/0o;mk00<0o;mk0P00000D0?ooo`030000003oool0oooo03T0oooo0P0000000`3n_W00
00000?jnL0030?jnL0030000003n_W00o[i`0080o[i`00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00090?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0N03oool3000000T0oooo00@000000?:iTP00000000000P3a^I801000
0000olZ00?o:P000000;0?ooo`030000003oool0oooo0700oooo0`00001<0?ooo`800000103l_g/2
000001@0oooo00<000000?ooo`3oool0>`3oool2000000@0o[i`00<000000?jnL03n_W000P3n_W00
0`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool0
00L0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool04@3oool2000007T0oooo0P0000090?ooo`040000003b^I80
000000000080lKVB00@000000?o:P03obX0000002`3oool00`000000oooo0?ooo`1`0?ooo`<00000
C03oool00`000000oooo000000030?boN`800000D`3oool00`000000o[i`0?jnL0020?jnL0030000
003n_W00o[i`0080o[i`00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00@0oooo00080?ooo`800000103oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool04`3oool2000000<0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`080?ooo`040000003b^I80000000000080lKVB00@000000?o:P03o
bX0000002`3oool00`000000oooo0?ooo`1`0?ooo`<00000C03oool00`000000oooo000000020000
00030?boN`000000oooo05@0oooo00D000000?jnL03n_W00o[i`000000040?jnL0030000003oool0
oooo05d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`002@3oool00`00
0000oooo0?ooo`030?ooo`@00000103oool4000001P0oooo0P0000000`3oool000000?ooo`1b0?oo
o`030000003oool0oooo00P0oooo00@000000?:iTP00000000000P3a^I800`000000olZ00000000;
0?ooo`030000003oool0oooo0740oooo0`00001<0?ooo`030000003oool000000080oooo0P00001E
0?ooo`8000000P3n_W000`000000o[i`0?jnL0020?jnL0030000003oool0oooo05h0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00=@3oool2000007<0oooo00<000000?oo
o`3oool0203oool2000000040?c6R0000000lKVB00000080olZ000<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`1a0?ooo`<00000C03oool00`000000oooo000000030?ooo`030000003oool0
oooo05@0oooo0P0000000`3n_W0000000?jnL0030?jnL0030000003oool0oooo05l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1`0?oo
o`030000003oool0oooo00P0oooo0P000000103laXP000000?6iTP0000020?o:P0030000003oool0
oooo00T0oooo00<000000?ooo`3oool0L@3oool300000:T0oooo100000040?jnL0030000003oool0
oooo0600oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00>03oool20000
00@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`080?ooo`80000000@0o<J80000
003a^I8000000P3obX000`000000oooo0?ooo`090?ooo`030000003oool0oooo0740oooo0`00002Y
0?ooo`040000003oool00000000000@0o[i`00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00<0oooo000j0?ooo`8000000P3oool00`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo00P0oooo100000001@3a^I8000000?o:P03obX00000000/0oooo00<0
00000?ooo`3oool0L@3oool300000:d0oooo00D000000?jnL03n_W00o[i`0000001S0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool003`0oooo0`00001f0?ooo`@0000000D0
lKVB0000003obX00olZ00000000;0?ooo`030000003oool0oooo0740oooo0`00002^0?ooo`800000
00<0o[i`0000003oool0H`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
000n0?ooo`8000001P3oool00`000000oooo0?ooo`1/0?ooo`@0000000D0lKVB0000003obX00olZ0
0000000;0?ooo`030000003oool0oooo0740oooo0`00002`0?ooo`800000I@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0K@3oool3000000050?6iTP000000olZ00?o:P00000002`3oool00`000000oooo
0?ooo`1a0?ooo`<00000/@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool00440oooo0P0000020?ooo`030000003oool0oooo06h0oooo0`00
0000103a^I8000000?o:P000000<0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0
o`3ooolI0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004<0oooo0`00
001`0?ooo`<0000000@0lKVB0000003obX000000303oool00`000000oooo0?ooo`1b0?ooo`030000
003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00150?ooo`800000K`3oool01`000000oooo0000003a^I8000000?o:P0000000303oool00`000000
oooo0?ooo`1b0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00<0oooo00170?ooo`800000K@3oool01`000000oooo0000003a^I8000000?o:
P0000000303oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0?l0oooo6`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00190?ooo`050000003oool0oooo0?oo
o`000000J03oool01`000000oooo0000003a^I8000000?o:P0000000303oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo001:0?ooo`80000000<0oooo0000003oool0J@3oool01@000000lKVB0000003o
bX00000000`0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3o0?oooad0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`00C03oool2000006X0oooo00D00000
0?6iTP000000olZ00000000<0?ooo`030000003oool0oooo0?l0ooooT`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo001>0?ooo`800000J03oool010000000lKVB00000000
000=0?ooo`030000003oool0oooo0?l0ooooU03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo001@0?ooo`8000000`3oool00`000000oooo0?ooo`1P0?ooo`040000003a^I80
0000000000d0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00580oooo00@000000?ooo`3oool00000HP3oool010000000lKVB0000
0000000=0?ooo`030000003oool0oooo0?l0ooooUP3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo001C0?ooo`<00000HP3oool010000000lKVB00000000000=0?ooo`030000
003oool0oooo0?l0ooooU`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
001E0?ooo`800000H@3oool010000000lKVB00000000000=0?ooo`030000003oool0oooo0?l0oooo
V03oool01@000000oooo0?ooo`3oool0000000@0oooo001G0?ooo`8000000`3oool00`000000oooo
0?ooo`1J0?ooo`<000003@3oool00`000000oooo0?ooo`3o0?oooiP0oooo00D000000?ooo`3oool0
oooo000000040?ooo`00F@3oool2000000030?ooo`000000oooo05/0oooo0`00000=0?ooo`030000
003oool0oooo0?l0ooooV@3oool010000000oooo0?ooo`0000040?ooo`00?@3oool6000000<0oooo
1000000A0?ooo`800000G03oool3000000d0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000
003oool0000000@0oooo000n0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0?0?ooo`800000F`3oool2000000h0oooo00<000000?ooo`3oool0o`3o
oonK0?ooo`800000103oool003l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0140oooo0P0000040?ooo`030000003oool0oooo0580oooo0P00000>
0?ooo`030000003oool0oooo0?l0ooooV@3oool4000000@0oooo00100?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`8000000P3oool00`00
0000oooo0?ooo`1B0?ooo`8000003P3oool00`000000oooo0?ooo`3o0?oooi80oooo1`0000080?oo
o`00@@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool05@3oool30000
05@0oooo0P00000>0?ooo`030000003oool0oooo0?l0ooooR`3oool7000000l0oooo00120?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo04/0oooo0P00000>0?ooo`030000003oool0oooo0?l0ooooP`3oool80000
01H0oooo00120?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0603oool20000
00@0oooo00<000000?ooo`3oool0B`3oool2000000h0oooo00<000000?ooo`3oool0o`3oooml0?oo
o`L000007P3oool003d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo01X0oooo0P0000020?ooo`030000003oool0oooo04/0oooo0P00000>0?oo
o`030000003oool0oooo0?l0ooooM@3oool7000002D0oooo000m0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0L0?ooo`<00000C@3oool20000
00h0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`L00000;03oool003h0oooo100000040?ooo`@0
00008@3oool2000004`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooofL0
oooo1`00000c0?ooo`00K@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooof00oooo1`00000j0?ooo`00KP3o
ool200000080oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0?l0ooooF@3oool800000440oooo001`0?ooo`<00000AP3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0?l0ooooDP3oool7000004T0oooo001b0?ooo`800000E03oool00`00
0000oooo0?ooo`3o0?oood/0oooo1`00001@0?ooo`00M03oool2000000<0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`3o0?oood@0oooo1`00001G0?ooo`00MP3oool010000000oooo
0?ooo`00001>0?ooo`030000003oool0oooo0?l0oooo?@3oool7000005h0oooo001g0?ooo`<00000
CP3oool00`000000oooo0?ooo`3o0?ooocH0oooo1`00001U0?ooo`00N@3oool2000004d0oooo00<0
00000?ooo`3oool0o`3oool^0?ooo`P00000K03oool007/0oooo0P0000030?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`L00000M03oool007d0oooo0P0000000`3o
ool000000?ooo`160?ooo`030000003oool0oooo0?l0oooo803oool7000007/0oooo001o0?ooo`80
0000A`3oool00`000000oooo0?ooo`3o0?oooaT0oooo1`0000220?ooo`00IP3oool00`000000oooo
0?ooo`030?ooo`@00000403oool2000004H0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`L00000
R@3oool006H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000180oooo
0P0000030?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3oool:0?ooo`P00000
T03oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0140oooo0P0000000`3oool000000?ooo`0o0?ooo`030000003oool0oooo0?l0oooo0`3o
ool7000009P0oooo001V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool2
000000H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3k0?ooo`L00000W`3oool0
06H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3d0?ooo`L00000YP3oool006H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0
oooo0P0000030?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0k@3oool700000:d0
oooo001V0?ooo`030000003oool0oooo0080oooo1@00000K0?ooo`80000000<0oooo0000003oool0
>03oool00`000000oooo0?ooo`3V0?ooo`L00000]03oool006@0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`0O0?ooo`800000>@3oool00`000000oooo0?ooo`3N0?ooo`P00000^`3o
ool006D0oooo0P0000050?ooo`030000003oool0oooo0200oooo0P00000g0?ooo`030000003oool0
oooo0=L0oooo1`0000330?ooo`00IP3oool00`000000oooo0?ooo`030?ooo`D00000803oool01000
0000oooo0?ooo`00000c0?ooo`030000003oool0oooo0=00oooo1`00003:0?ooo`00TP3oool30000
03<0oooo00<000000?ooo`3oool0b@3oool700000=40oooo002D0?ooo`800000<P3oool00`000000
oooo0?ooo`320?ooo`L00000f03oool009H0oooo0P0000030?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0^`3oool700000=l0oooo002H0?ooo`80000000<0oooo0000003oool0:`3o
ool00`000000oooo0?ooo`2c0?ooo`P00000iP3oool009X0oooo0P00000/0?ooo`030000003oool0
oooo0:`0oooo1`00003^0?ooo`00V`3oool2000002/0oooo00<000000?ooo`3oool0Y@3oool70000
0?D0oooo002M0?ooo`8000000`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo09h0
oooo1`00003l0?ooo`00W`3oool3000002H0oooo00<000000?ooo`3oool0U`3oool700000?l0oooo
103oool00:40oooo0P00000U0?ooo`030000003oool0oooo0900oooo1`00003o0?ooo`/0oooo002S
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0R03oool800000?l0oooo4P3oool0
08T0oooo00<000000?ooo`3oool00`3oool400000140oooo0P0000020?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0P@3oool700000?l0oooo6P3oool008T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo0`00000O0?ooo`03
0000003oool0oooo07X0oooo1`00003o0?ooob40oooo00290?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`800000103oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo07<0oooo1`00003o0?ooobP0oooo00290?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?ooo`8000000P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06d0oooo1`00003o0?ooobl0oooo0029
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool0IP3oool700000?l0oooo=P3oool0
08T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01L0oooo0P00000H0?ooo`030000003oool0oooo05h0oooo2000003o0?ooocd0oooo00290?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`80
00005P3oool00`000000oooo0?ooo`1G0?ooo`L00000o`3ooom50?ooo`00Q`3oool00`000000oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool200000080oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1@0?ooo`L00000o`3ooom<0?ooo`00R03o
ool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`8000004P3o
ool00`000000oooo0?ooo`190?ooo`L00000o`3ooomC0?ooo`00R@3oool00`000000oooo0?ooo`03
0?ooo`@000008@3oool200000140oooo00<000000?ooo`3oool0@P3oool700000?l0ooooFP3oool0
0;H0oooo0P0000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0>P3oool80000
0?l0ooooH@3oool00;P0oooo0P0000000`3oool000000?ooo`0:0?ooo`030000003oool0oooo03<0
oooo1`00003o0?ooofT0oooo002j0?ooo`8000002`3oool00`000000oooo0?ooo`0/0?ooo`L00000
o`3ooom`0?ooo`00_03oool2000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0U0?ooo`L00000o`3ooomg0?ooo`00_P3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo01h0oooo1`00003o0?ooogh0oooo002o0?ooo`<000001@3oool00`000000oooo0?ooo`0G
0?ooo`L00000o`3ooon50?ooo`00`@3oool2000000@0oooo00<000000?ooo`3oool03`3oool80000
0?l0ooooS03oool00<<0oooo0P0000020?ooo`030000003oool0oooo00P0oooo1`00003o0?oooi@0
oooo002/0?ooo`@000005@3oool3000000<0oooo1`00003o0?oooi/0oooo002[0?ooo`050000003o
ool0oooo0?ooo`0000005`3oool400000?l0ooooXP3oool00:/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3o0?oookX0oooo002`0?ooo`030000003oool0oooo0?l0oooo^P3oool0
0;00oooo00<000000?ooo`3oool0o`3ooonj0?ooo`00Z`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0?l0oooo^P3oool00:/0oooo1@00003o0?oookd0oooo002[0?ooo`030000003o
ool0oooo0?l0oooo_`3oool00:`0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`00[03oool50000
0?l0oooo_03oool00?l0ooooo`3ooom^0?ooo`00o`3ooooo0?ooofh0oooo003o0?ooool0ooooKP3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 619}, {361.938, 0}} -> {-0.0639125, 0.160152, \
0.0016849, 0.0016849}}]
}, Open  ]],

Cell[TextData[{
  "The warning from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " tells us that some prices are missing. We will ignore this message for \
the moment. It looks like there are a lot of  jumps in the hourly prices. \
Also it looks like there is a typical pattern over a day. To further explore \
this pattern over a day the mean for each hour is calculated and plotted."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Mean[hour]\ \), "\[IndentingNewLine]", 
    \(\(BarChart[% /. \ Null \[Rule] \ 0, 
        Frame \[Rule] {True, True, False, False}, 
        FrameLabel \[Rule] \ {"\<hour\>", "\<\>"}, AspectRatio \[Rule] \ 0.2, 
        Axes \[Rule] None];\)\)}], "Input"],

Cell[BoxData[
    \({16.333513909224024`, 14.251493411420208`, 
      1\/683\ \((\(\(8942.270000000002`\)\(\[InvisibleSpace]\)\) + 
            2\ Null)\), 12.575007320644218`, 12.77953147877014`, 
      14.0607906295754`, 16.684333821376274`, 22.23998535871158`, 
      25.388096632503693`, 27.321405563689606`, 30.017042459736494`, 
      36.64159590043923`, 29.76852122986822`, 27.55746705710104`, 
      24.838360175695453`, 23.074026354319187`, 23.933294289897553`, 
      27.751024890190312`, 29.127144948755507`, 25.620453879941415`, 
      22.99689604685215`, 20.685724743777445`, 20.547306002928266`, 
      17.823865300146416`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
-0.0165289 0.0413223 0.0047619 0.00519836 [
[.02479 -0.0125 -5.90625 -17.75 ]
[.02479 -0.0125 5.90625 0 ]
[.06612 -0.0125 -5.90625 -17.75 ]
[.06612 -0.0125 5.90625 0 ]
[.10744 -0.0125 -5.90625 -17.75 ]
[.10744 -0.0125 5.90625 0 ]
[.14876 -0.0125 -5.90625 -17.75 ]
[.14876 -0.0125 5.90625 0 ]
[.19008 -0.0125 -5.90625 -17.75 ]
[.19008 -0.0125 5.90625 0 ]
[.2314 -0.0125 -5.90625 -17.75 ]
[.2314 -0.0125 5.90625 0 ]
[.27273 -0.0125 -5.90625 -17.75 ]
[.27273 -0.0125 5.90625 0 ]
[.31405 -0.0125 -5.90625 -17.75 ]
[.31405 -0.0125 5.90625 0 ]
[.35537 -0.0125 -5.90625 -17.75 ]
[.35537 -0.0125 5.90625 0 ]
[.39669 -0.0125 -9.8125 -17.75 ]
[.39669 -0.0125 9.8125 0 ]
[.43802 -0.0125 -9.8125 -17.75 ]
[.43802 -0.0125 9.8125 0 ]
[.47934 -0.0125 -9.8125 -17.75 ]
[.47934 -0.0125 9.8125 0 ]
[.52066 -0.0125 -9.8125 -17.75 ]
[.52066 -0.0125 9.8125 0 ]
[.56198 -0.0125 -9.8125 -17.75 ]
[.56198 -0.0125 9.8125 0 ]
[.60331 -0.0125 -9.8125 -17.75 ]
[.60331 -0.0125 9.8125 0 ]
[.64463 -0.0125 -9.8125 -17.75 ]
[.64463 -0.0125 9.8125 0 ]
[.68595 -0.0125 -9.8125 -17.75 ]
[.68595 -0.0125 9.8125 0 ]
[.72727 -0.0125 -9.8125 -17.75 ]
[.72727 -0.0125 9.8125 0 ]
[.7686 -0.0125 -9.8125 -17.75 ]
[.7686 -0.0125 9.8125 0 ]
[.80992 -0.0125 -9.8125 -17.75 ]
[.80992 -0.0125 9.8125 0 ]
[.85124 -0.0125 -9.8125 -17.75 ]
[.85124 -0.0125 9.8125 0 ]
[.89256 -0.0125 -9.8125 -17.75 ]
[.89256 -0.0125 9.8125 0 ]
[.93388 -0.0125 -9.8125 -17.75 ]
[.93388 -0.0125 9.8125 0 ]
[.97521 -0.0125 -9.8125 -17.75 ]
[.97521 -0.0125 9.8125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -16.125 -35.5 ]
[.5 -0.0125 16.125 -17.75 ]
[-0.0125 .00476 -11.8125 -8.875 ]
[-0.0125 .00476 0 8.875 ]
[-0.0125 .03075 -11.8125 -8.875 ]
[-0.0125 .03075 0 8.875 ]
[-0.0125 .05675 -19.625 -8.875 ]
[-0.0125 .05675 0 8.875 ]
[-0.0125 .08274 -19.625 -8.875 ]
[-0.0125 .08274 0 8.875 ]
[-0.0125 .10873 -19.625 -8.875 ]
[-0.0125 .10873 0 8.875 ]
[-0.0125 .13472 -19.625 -8.875 ]
[-0.0125 .13472 0 8.875 ]
[-0.0125 .16071 -19.625 -8.875 ]
[-0.0125 .16071 0 8.875 ]
[-0.0125 .1867 -19.625 -8.875 ]
[-0.0125 .1867 0 8.875 ]
[ 0 0 -0.125 0 ]
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02479 0 m
.02479 .00625 L
s
gsave
.02479 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.06612 0 m
.06612 .00625 L
s
gsave
.06612 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.10744 0 m
.10744 .00625 L
s
gsave
.10744 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.14876 0 m
.14876 .00625 L
s
gsave
.14876 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.19008 0 m
.19008 .00625 L
s
gsave
.19008 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.2314 0 m
.2314 .00625 L
s
gsave
.2314 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.27273 0 m
.27273 .00625 L
s
gsave
.27273 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.31405 0 m
.31405 .00625 L
s
gsave
.31405 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.35537 0 m
.35537 .00625 L
s
gsave
.35537 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.39669 0 m
.39669 .00625 L
s
gsave
.39669 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.43802 0 m
.43802 .00625 L
s
gsave
.43802 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
1.000 setlinewidth
grestore
.47934 0 m
.47934 .00625 L
s
gsave
.47934 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.52066 0 m
.52066 .00625 L
s
gsave
.52066 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
1.000 setlinewidth
grestore
.56198 0 m
.56198 .00625 L
s
gsave
.56198 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
.60331 0 m
.60331 .00625 L
s
gsave
.60331 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.64463 0 m
.64463 .00625 L
s
gsave
.64463 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
.68595 0 m
.68595 .00625 L
s
gsave
.68595 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(17) show
1.000 setlinewidth
grestore
.72727 0 m
.72727 .00625 L
s
gsave
.72727 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
1.000 setlinewidth
grestore
.7686 0 m
.7686 .00625 L
s
gsave
.7686 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(19) show
1.000 setlinewidth
grestore
.80992 0 m
.80992 .00625 L
s
gsave
.80992 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.85124 0 m
.85124 .00625 L
s
gsave
.85124 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
1.000 setlinewidth
grestore
.89256 0 m
.89256 .00625 L
s
gsave
.89256 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
1.000 setlinewidth
grestore
.93388 0 m
.93388 .00625 L
s
gsave
.93388 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
1.000 setlinewidth
grestore
.97521 0 m
.97521 .00625 L
s
gsave
.97521 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -77.125 -39.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(hour) show
91.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00476 m
.00625 .00476 L
s
gsave
-0.0125 .00476 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .03075 m
.00625 .03075 L
s
gsave
-0.0125 .03075 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .05675 m
.00625 .05675 L
s
gsave
-0.0125 .05675 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .08274 m
.00625 .08274 L
s
gsave
-0.0125 .08274 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .10873 m
.00625 .10873 L
s
gsave
-0.0125 .10873 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .13472 m
.00625 .13472 L
s
gsave
-0.0125 .13472 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
0 .16071 m
.00625 .16071 L
s
gsave
-0.0125 .16071 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .1867 m
.00625 .1867 L
s
gsave
-0.0125 .1867 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(35) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .00996 m
.00375 .00996 L
s
0 .01516 m
.00375 .01516 L
s
0 .02036 m
.00375 .02036 L
s
0 .02556 m
.00375 .02556 L
s
0 .03595 m
.00375 .03595 L
s
0 .04115 m
.00375 .04115 L
s
0 .04635 m
.00375 .04635 L
s
0 .05155 m
.00375 .05155 L
s
0 .06194 m
.00375 .06194 L
s
0 .06714 m
.00375 .06714 L
s
0 .07234 m
.00375 .07234 L
s
0 .07754 m
.00375 .07754 L
s
0 .08794 m
.00375 .08794 L
s
0 .09313 m
.00375 .09313 L
s
0 .09833 m
.00375 .09833 L
s
0 .10353 m
.00375 .10353 L
s
0 .11393 m
.00375 .11393 L
s
0 .11913 m
.00375 .11913 L
s
0 .12432 m
.00375 .12432 L
s
0 .12952 m
.00375 .12952 L
s
0 .13992 m
.00375 .13992 L
s
0 .14512 m
.00375 .14512 L
s
0 .15032 m
.00375 .15032 L
s
0 .15551 m
.00375 .15551 L
s
0 .16591 m
.00375 .16591 L
s
0 .17111 m
.00375 .17111 L
s
0 .17631 m
.00375 .17631 L
s
0 .18151 m
.00375 .18151 L
s
0 .1919 m
.00375 .1919 L
s
0 .1971 m
.00375 .1971 L
s
.25 Mabswid
0 0 m
0 .2 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
1 0 0 r
.00826 .00476 m
.00826 .08967 L
.04132 .08967 L
.04132 .00476 L
F
0 g
.5 Mabswid
.00826 .00476 m
.00826 .08967 L
.04132 .08967 L
.04132 .00476 L
.00826 .00476 L
s
1 0 0 r
.04959 .00476 m
.04959 .07885 L
.08264 .07885 L
.08264 .00476 L
F
0 g
.04959 .00476 m
.04959 .07885 L
.08264 .07885 L
.08264 .00476 L
.04959 .00476 L
s
1 0 0 r
.09091 .00476 m
.09091 .07282 L
.12397 .07282 L
.12397 .00476 L
F
0 g
.09091 .00476 m
.09091 .07282 L
.12397 .07282 L
.12397 .00476 L
.09091 .00476 L
s
1 0 0 r
.13223 .00476 m
.13223 .07013 L
.16529 .07013 L
.16529 .00476 L
F
0 g
.13223 .00476 m
.13223 .07013 L
.16529 .07013 L
.16529 .00476 L
.13223 .00476 L
s
1 0 0 r
.17355 .00476 m
.17355 .07119 L
.20661 .07119 L
.20661 .00476 L
F
0 g
.17355 .00476 m
.17355 .07119 L
.20661 .07119 L
.20661 .00476 L
.17355 .00476 L
s
1 0 0 r
.21488 .00476 m
.21488 .07785 L
.24793 .07785 L
.24793 .00476 L
F
0 g
.21488 .00476 m
.21488 .07785 L
.24793 .07785 L
.24793 .00476 L
.21488 .00476 L
s
1 0 0 r
.2562 .00476 m
.2562 .09149 L
.28926 .09149 L
.28926 .00476 L
F
0 g
.2562 .00476 m
.2562 .09149 L
.28926 .09149 L
.28926 .00476 L
.2562 .00476 L
s
1 0 0 r
.29752 .00476 m
.29752 .12037 L
.33058 .12037 L
.33058 .00476 L
F
0 g
.29752 .00476 m
.29752 .12037 L
.33058 .12037 L
.33058 .00476 L
.29752 .00476 L
s
1 0 0 r
.33884 .00476 m
.33884 .13674 L
.3719 .13674 L
.3719 .00476 L
F
0 g
.33884 .00476 m
.33884 .13674 L
.3719 .13674 L
.3719 .00476 L
.33884 .00476 L
s
1 0 0 r
.38017 .00476 m
.38017 .14679 L
.41322 .14679 L
.41322 .00476 L
F
0 g
.38017 .00476 m
.38017 .14679 L
.41322 .14679 L
.41322 .00476 L
.38017 .00476 L
s
1 0 0 r
.42149 .00476 m
.42149 .1608 L
.45455 .1608 L
.45455 .00476 L
F
0 g
.42149 .00476 m
.42149 .1608 L
.45455 .1608 L
.45455 .00476 L
.42149 .00476 L
s
1 0 0 r
.46281 .00476 m
.46281 .19524 L
.49587 .19524 L
.49587 .00476 L
F
0 g
.46281 .00476 m
.46281 .19524 L
.49587 .19524 L
.49587 .00476 L
.46281 .00476 L
s
1 0 0 r
.50413 .00476 m
.50413 .15951 L
.53719 .15951 L
.53719 .00476 L
F
0 g
.50413 .00476 m
.50413 .15951 L
.53719 .15951 L
.53719 .00476 L
.50413 .00476 L
s
1 0 0 r
.54545 .00476 m
.54545 .14802 L
.57851 .14802 L
.57851 .00476 L
F
0 g
.54545 .00476 m
.54545 .14802 L
.57851 .14802 L
.57851 .00476 L
.54545 .00476 L
s
1 0 0 r
.58678 .00476 m
.58678 .13388 L
.61983 .13388 L
.61983 .00476 L
F
0 g
.58678 .00476 m
.58678 .13388 L
.61983 .13388 L
.61983 .00476 L
.58678 .00476 L
s
1 0 0 r
.6281 .00476 m
.6281 .12471 L
.66116 .12471 L
.66116 .00476 L
F
0 g
.6281 .00476 m
.6281 .12471 L
.66116 .12471 L
.66116 .00476 L
.6281 .00476 L
s
1 0 0 r
.66942 .00476 m
.66942 .12918 L
.70248 .12918 L
.70248 .00476 L
F
0 g
.66942 .00476 m
.66942 .12918 L
.70248 .12918 L
.70248 .00476 L
.66942 .00476 L
s
1 0 0 r
.71074 .00476 m
.71074 .14902 L
.7438 .14902 L
.7438 .00476 L
F
0 g
.71074 .00476 m
.71074 .14902 L
.7438 .14902 L
.7438 .00476 L
.71074 .00476 L
s
1 0 0 r
.75207 .00476 m
.75207 .15618 L
.78512 .15618 L
.78512 .00476 L
F
0 g
.75207 .00476 m
.75207 .15618 L
.78512 .15618 L
.78512 .00476 L
.75207 .00476 L
s
1 0 0 r
.79339 .00476 m
.79339 .13795 L
.82645 .13795 L
.82645 .00476 L
F
0 g
.79339 .00476 m
.79339 .13795 L
.82645 .13795 L
.82645 .00476 L
.79339 .00476 L
s
1 0 0 r
.83471 .00476 m
.83471 .12431 L
.86777 .12431 L
.86777 .00476 L
F
0 g
.83471 .00476 m
.83471 .12431 L
.86777 .12431 L
.86777 .00476 L
.83471 .00476 L
s
1 0 0 r
.87603 .00476 m
.87603 .11229 L
.90909 .11229 L
.90909 .00476 L
F
0 g
.87603 .00476 m
.87603 .11229 L
.90909 .11229 L
.90909 .00476 L
.87603 .00476 L
s
1 0 0 r
.91736 .00476 m
.91736 .11157 L
.95041 .11157 L
.95041 .00476 L
F
0 g
.91736 .00476 m
.91736 .11157 L
.95041 .11157 L
.95041 .00476 L
.91736 .00476 L
s
1 0 0 r
.95868 .00476 m
.95868 .09742 L
.99174 .09742 L
.99174 .00476 L
F
0 g
.95868 .00476 m
.95868 .09742 L
.99174 .09742 L
.99174 .00476 L
.95868 .00476 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{712, 142.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;80000SR000`400?l00000o`00003oo`3ooooo
0?ooolX0oooo003o0?ooool0oooobP3oool00?l0ooooo`3oooo:0?ooo`00o`3ooooo0?ooolX0oooo
003o0?ooool0oooobP3oool00?l0ooooI03oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo0?ooo`@00000103oool3000000050?ooo`000000oooo0?ooo`000000o`3ooom=0?ooo`00o`3o
oomT0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000030?ooo`8000000P3oool00`000000oooo0?ooo`3o0?oood/0oooo003o0?ooof@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000o`3ooom=0?ooo`00o`3ooomT0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo00000?l0ooooC@3oool00?l0ooooI03oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00003o0?oo
odd0oooo003o0?ooof@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000o`3ooom=0?ooo`00o`3ooomT
0?ooo`8000000`3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P00003o0?oood`0oooo003o0?ooof@0oooo00<000000?ooo`0000000P00
00040?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool0
0P00003o0?ooodX0oooo003o0?ooof@0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`00o`3ooomT
0?ooo`030000003oool0oooo0?l0ooooH`3oool00?l0ooooo`3oooo:0?ooo`00o`3ooooo0?ooolX0
oooo003o0?ooool0oooobP3oool00?l0ooooo`3oooo:0?ooo`00o`3ooooo0?ooolX0oooo003o0?oo
ool0oooobP3oool00?l0ooooo`3oooo:0?ooo`00o`3ooooo0?ooolX0oooo00290?ooo`030000003o
ool0oooo00h0oooo1P00000?0?ooo`@000004`3oool00`000000oooo0?ooo`0>0?ooo`@00000403o
ool400000140oooo00<000000?ooo`3oool04@3oool400000100oooo0`00000?0?ooo`030000003o
ool0oooo00<0oooo1000000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`H000002@3oool00`000000oooo0?ooo`030?ooo`@000002P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool4000000X0oooo00<000000?ooo`3oool00`3oool4000000X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo1000000:0?ooo`030000003o
ool0oooo00<0oooo0`0000080?ooo`H000000`3oool4000000L0oooo1P0000050?ooo`030000003o
ool0oooo00H0oooo1P0000020?ooo`H000001P3oool6000000<0oooo100000070?ooo`H000001P3o
ool00`000000oooo0?ooo`1Y0?ooo`00R@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00d0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000080?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1Y0?oo
o`00R@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`L000003P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`3oool70000
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo1`00001Z0?ooo`00R@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0J@3oool0
08T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00`0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool0oooo00`0oooo0P000003
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo0`0000000`3oool000000?ooo`0<0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`<0000000<0oooo0000003oool02@3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool0J@3oool008T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0>0?ooo`<00000
403oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0303oool00`000000oooo0000000200000180oooo00<000000?ooo`3oool0403oool4000000l0
oooo00@000000?ooo`3oool0oooo0P00000=0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0103oool3000000X0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P00000:0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`@000002P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000002`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`020?ooo`<00000303oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0J@3oool008T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00d0oooo00@000000?ooo`3oool000003`3oool5000000l0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo1@00000:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`1Y0?ooo`00Q`3oool0
0`000000oooo0000000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000003`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0000000D0oooo00<000000?ooo`0000002@3oool0
0`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo000000060?ooo`030000003oool0000000P0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo000000080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000203oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000J`3oool008P0oooo0P00000@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00l0oooo0P00000@0?ooo`030000003oool0oooo0140oooo00D000000?oo
o`3oool0oooo0000000C0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool2
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`8000001P3oool2
000000X0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool2
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`8000001`3oool2
000000T0oooo0P0000050?ooo`030000003oool0oooo00X0oooo0P0000050?ooo`050000003oool0
oooo0?ooo`000000203oool2000000T0oooo00<000000?ooo`3oool01`3oool2000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`800000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`800000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo0P00001[0?ooo`00R@3oool00`000000oooo0?ooo`0?0?ooo`@00000403oool4000001<0
oooo00<000000?ooo`3oool03P3oool500000100oooo0`00000?0?ooo`H00000403oool400000100
oooo1000000>0?ooo`030000003oool0oooo00<0oooo1000000:0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`@000002P3oool00`000000
oooo0?ooo`030?ooo`@000002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool5000000T0oooo00<000000?ooo`3oool0103oool3000000X0
oooo00<000000?ooo`3oool00P3oool6000000X0oooo00<000000?ooo`3oool00`3oool4000000X0
oooo00<000000?ooo`3oool00`3oool4000000P0oooo100000040?ooo`@00000203oool4000000H0
oooo00<000000?ooo`3oool01`3oool4000000@0oooo100000080?ooo`@00000103oool4000000P0
oooo100000070?ooo`030000003oool0oooo06T0oooo003o0?ooool0oooobP3oool00?l0ooooo`3o
ooo:0?ooo`00o`3ooooo0?ooolX0oooo003o0?ooool0oooobP3oool00?l0ooooo`3oooo:0?ooo`00
o`3ooooo0?ooolX0oooo003o0?ooool0oooobP3oool006l0oooo1000003o0?ooool0ooooE`3oool0
06h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooool0ooooE03oool006h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooool00000j000001T0?ooo`00
KP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
KP3oool006h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oooaD000000`3o
oolA000000<0oooo4@0000030?oooa4000000`3ooolA000000<0oooo4@0000030?oooa4000000`3o
oolA000000<0oooo4P0000030?oooa4000000`3ooolA000000<0oooo4@0000030?oooa4000000`3o
oolA000000<0oooo4@0000030?oooa4000000`3ooolA000000<0oooo4@0000030?oooa8000000`3o
oolA000000<0oooo4@0000030?oooa4000000`3ooolA000000<0oooo4@00001X0?ooo`00KP3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o0000
1@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000
003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?oo
o`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?oo
o`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o0000
1@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000
003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?oo
o`3oool0IP3oool006h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`05
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000403o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000030000003oool0oooo06H0oooo001^0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool3000000030?ooo`000000o`0000h0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
0100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`1V0?ooo`00KP3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0
IP3oool006l0oooo1000000:0?ooo`<0000000<0oooo0000003o00003P3o00001@000000oooo0?oo
o`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o0000
1@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000
003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?oo
o`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?oo
o`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000?0?l000030000003oool0oooo06H0oooo001m0?ooo`05
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000403o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000030000003oool0oooo06H0oooo001m0?ooo`050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000030000003oool0
oooo06H0oooo001m0?ooo`<0000000<0oooo0000003o00003P3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000030000003oool0oooo06H0oooo001_0?ooo`@000002P3o
ool01@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00000`000000oooo0?ooo`1V0?ooo`00KP3oool01@000000oooo0?ooo`3oool0
000000X0oooo0`0000000`3oool000000?l0000>0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0IP3oool006h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000030000003oool0oooo06H0oooo001c
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0IP3oool007<0
oooo00<000000?ooo`3oool01`3oool5000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00000`000000oooo0?ooo`1V0?ooo`00KP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0IP3oool006h0
oooo1@00000:0?ooo`<0000000<0oooo0000003o00003P3o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000403o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000030000003oool0oooo06H0oooo001^0?ooo`030000003oool0
oooo00`0oooo00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0IP3oool006l0oooo00<000000?ooo`3o
ool02`3oool01@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`1V0?ooo`00K`3oool5000000T0oooo0`00
00000`3oool000000?l0000>0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
0100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000<000000?ooo`3oool0IP3oool007d0oooo00D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0
IP3oool007d0oooo0`0000000`3oool000000?l0000>0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0IP3oool007d0oooo00D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00<000000?ooo`3oool0IP3oool006T0oooo00<000000?ooo`3oool00`3oool4000000X0oooo00D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
00000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000<000000?ooo`3oool0IP3oool006T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0`0000000`3oool000000?l0000>0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0
IP3oool006T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0IP3oool006T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo1@00000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0
IP3oool006T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0IP3oool006T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00D000000?oo
o`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?oo
o`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100
o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o0000
1@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000
003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?oo
o`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?oo
o`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0
o`0000<000000?ooo`3oool0IP3oool006T0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo0`0000000`3oool000000?l0000>0?l000050000
003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?oo
o`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?oo
o`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o0000
1@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000
003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?oo
o`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?oo
o`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0IP3oool0
06L0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0IP3oool006P0oooo0P0000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool3000000030?ooo`000000o`0000h0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000403o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`1V
0?ooo`00J@3oool00`000000oooo0?ooo`030?ooo`@000002P3oool01@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000403o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`000000
oooo0?ooo`1V0?ooo`00O@3oool01@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o000010000000oooo0?ooo`3o
oolA000000<0oooo4@0000030?ooo`030000003o0000o`0000d0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
0100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000<000000?ooo`3oool0IP3oool007d0oooo0`0000000`3oool000000?l0000>0?l00005
0000003oool0oooo0?ooo`0000003`3o000010000000oooo0?ooo`3ooolA000002/0oooo00<00000
0?l0003o00003@3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`1V0?ooo`00
J@3oool00`000000oooo0?ooo`030?ooo`@000002P3oool01@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000?0?l000030000003oool0oooo03d0oooo00<000000?l0
003o00003@3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o0000
1@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000
003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?oo
o`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?oo
o`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`1V0?ooo`00J@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000030000003oool0oooo
03d0oooo00<000000?l0003o00003@3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000403o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`000000oooo
0?ooo`1V0?ooo`00J@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool3000000030?ooo`000000o`0000h0o`0000@000000?ooo`3oool0oooo
4@00000o0?oooa4000000`3oool00`000000o`000?l0000=0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0IP3oool006T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?oo
o`0000003`3o00000`000000oooo0?ooo`1U0?ooo`030000003o0000o`0000d0o`0000D000000?oo
o`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000403o00001@000000oooo0?oo
o`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o0000
1@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000
003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?oo
o`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?oo
o`1V0?ooo`00J@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo1@00000?
0?l000030000003oool0oooo06D0oooo00<000000?l0003o00003@3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000030000003oool0oooo06H0oooo
001Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`070?ooo`050000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`1U0?ooo`030000
003o0000o`0000d0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o0000
1@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000
003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?oo
o`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?oo
o`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`0000003`3o00000`000000oooo0?ooo`1V0?ooo`00J@3oool00`000000oooo0?ooo`020?ooo`D0
00002P3oool01@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0I@3oool00`00
0000o`000?l0000=0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000<000000?ooo`3oool0IP3oool006L0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`0<0?ooo`<0000000<0oooo0000000000003`00001W0?ooo`030000003o0000
o`0000d0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00000`000000oooo0?ooo`1V0?ooo`00J03oool2000000D0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1i0?oooa4000000`3oool00`000000o`000?l0000=0?l000050000003o
ool0oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`1V0?ooo`00J@3oool00`000000oooo0?oo
o`030?ooo`D000002@3oool3000008d0oooo00<000000?l0003o00003@3o00001@000000oooo0?oo
o`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o0000
1@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000
003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?oo
o`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?oo
o`3oool0000000l0o`0000<000000?ooo`3oool0IP3oool007d0oooo00<000000?ooo`3oool0S@3o
ool00`000000o`000?l0000=0?l000050000003oool0oooo0?ooo`000000403o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`000000oooo
0?ooo`1V0?ooo`00O@3oool00`000000oooo0?ooo`2=0?ooo`030000003o0000o`0000d0o`0000D0
00000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000@0
00000?ooo`3oool0oooo4@00001X0?ooo`00O@3oool3000008d0oooo00<000000?l0003o00003@3o
00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00000`000000oooo0?ooo`1j0?ooo`00IP3oool6000000<0oooo1000000:0?ooo`030000003oool0
oooo08d0oooo00<000000?l0003o00003@3o00001@000000oooo0?ooo`3oool000000100o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`1j0?ooo`00I`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool30000
08d0oooo00<000000?l0003o00003@3o00001@000000oooo0?ooo`3oool000000100o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo
0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`1j0?ooo`00J03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`2=0?ooo`030000003o0000o`0000d0o`0000D000000?ooo`3oool0oooo0000000@0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0NP3oool006T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0S@3oool00`000000o`000?l0000=0?l000050000003oool0oooo0?ooo`00
0000403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000030000003oool0oooo07X0oooo
001Z0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`@00000
S03oool00`000000o`000?l0000=0?l000050000003oool0oooo0?ooo`000000403o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000030000003oool0oooo07X0oooo001[0?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2=0?ooo`030000
003o0000o`0000d0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o0000
1@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000
003oool0oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?oo
o`3oool0oooo0000000?0?l000040000003oool0oooo0?oooa4000000`3ooolA000007`0oooo001[
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool3000008d0oooo00<0
00000?l0003o00003@3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0XP3oool006H0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0S@3oool00`000000o`000?l0000=0?l000050000003oool0oooo0?ooo`000000403o0000
1@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000
003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?oo
o`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?oo
o`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`2R0?ooo`00IP3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2=0?ooo`030000003o0000o`0000d0o`0000D000000?ooo`3oool0
oooo0000000@0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0
000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000
3`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D0
00000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000403o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000030000003oool0
oooo0:80oooo001W0?ooo`@00000103oool4000000X0oooo0`00002=0?oooa4000000`3oool00`00
0000o`000?l0000>0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`000000403o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000030000003o
ool0oooo0:80oooo001m0?ooo`030000003oool0oooo0:40oooo00<000000?l0003o00003P3o0000
1@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000
003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?oo
o`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?oo
o`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`2R0?ooo`00O@3o
ool300000:40oooo00<000000?l0003o00003P3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o000010000000oooo0?ooo`3ooolA000000<0oooo00<000000?l0003o
00003@3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000@
0?l000050000003oool0oooo0?ooo`0000003`3o000010000000oooo0?ooo`3ooolA00000:@0oooo
001m0?ooo`030000003oool0oooo0:40oooo00<000000?l0003o00003P3o00001@000000oooo0?oo
o`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`0E0?ooo`030000
003o0000o`0000d0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?oo
o`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0]P3oool0
06H0oooo1P0000030?ooo`@000002P3oool00`000000oooo0?ooo`2Q0?ooo`030000003o0000o`00
00h0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l00005
0000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000<00000
0?ooo`3oool05@3oool00`000000o`000?l0000=0?l000050000003oool0oooo0?ooo`0000003`3o
00001@000000oooo0?ooo`3oool000000100o`0000D000000?ooo`3oool0oooo0000000?0?l00003
0000003oool0oooo0;H0oooo001W0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`<00000X@3oool00`000000o`000?l0000>0?l000050000003oool0oooo0?oo
o`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000
000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000?0?l000030000003oool0oooo01D0oooo4@0000030?oo
o`030000003o0000o`0000d0o`0000D000000?ooo`3oool0oooo0000000@0?l000050000003oool0
oooo0?ooo`0000003`3o00000`000000oooo0?ooo`2f0?ooo`00J03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2Q
0?ooo`030000003o0000o`0000h0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003o
ool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3o
ool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000<000000?ooo`3oool0:@3oool00`000000o`000?l0000=0?l000050000003o
ool0oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3o
ool0]P3oool006T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`@00000
X03oool00`000000o`000?l0000>0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000
oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000@000000?ooo`3oool0
oooo4@00000[0?ooo`030000003o0000o`0000d0o`0000D000000?ooo`3oool0oooo0000000@0?l0
00050000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`2f0?ooo`00JP3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0X@3ooolB0000
00<0oooo00<000000?l0003o00003@3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo
0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0?@3oool00`000000o`000?l0000=0?l00005
0000003oool0oooo0?ooo`000000403o00001@000000oooo0?ooo`3oool0000000l0o`0000<00000
0?ooo`3oool0]P3oool006/0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0;H0oooo00<000000?l0003o00003@3o00001@000000oooo0?ooo`3o
ool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`00
00003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000<000000?ooo`3oool0?@3oool00`00
0000o`000?l0000=0?l000050000003oool0oooo0?ooo`000000403o000010000000oooo0?ooo`3o
oolA00000;P0oooo001[0?ooo`030000003oool0oooo00D000002P3oool300000;H0oooo00<00000
0?l0003o00003@3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo
0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool00000
00l0o`0000<000000?ooo`3oool0?@3oool00`000000o`000?l0000=0?l000050000003oool0oooo
0?ooo`000000403o00000`000000oooo0?ooo`3:0?ooo`00IP3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0]P3oool00`000000o`000?l0000=
0?l000050000003oool0oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`00
00D000000?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`00
0000oooo0?ooo`0m0?ooo`030000003o0000o`0000d0o`0000D000000?ooo`3oool0oooo0000000@
0?l000030000003oool0oooo0<X0oooo001V0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo0000000=0?ooo`<00000]P3oool00`000000o`000?l0000=0?l000050000003oool0
oooo0?ooo`0000003`3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0
oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`000000oooo0?ooo`0m0?oo
o`030000003o0000o`0000d0o`0000D000000?ooo`3oool0oooo0000000@0?l000030000003oool0
oooo0<X0oooo001W0?ooo`@00000103oool5000000T0oooo00<000000?ooo`3oool0]P3ooolA0000
00<0oooo00<000000?l0003o00003@3o00001@000000oooo0?ooo`3oool0000000l0o`0000D00000
0?ooo`3oool0oooo0000000?0?l000050000003oool0oooo0?ooo`0000003`3o00000`000000oooo
0?ooo`0m0?ooo`030000003o0000o`0000d0o`0000D000000?ooo`3oool0oooo0000000@0?l00003
0000003oool0oooo0<X0oooo001m0?ooo`030000003oool0oooo0<X0oooo00<000000?l0003o0000
3@3o00001@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l0
00040000003oool0oooo0?oooa400000?`3ooolA000000<0oooo00<000000?l0003o00003P3o0000
0`000000oooo0?ooo`3:0?ooo`00O@3oool300000<X0oooo00<000000?l0003o00003@3o00001@00
0000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000030000003o
ool0oooo06D0oooo00<000000?l0003o00003P3o00000`000000oooo0?ooo`3:0?ooo`00I`3oool4
000000@0oooo1000000:0?ooo`030000003oool0oooo0<X0oooo00<000000?l0003o00003@3o0000
1@000000oooo0?ooo`3oool0000000l0o`0000D000000?ooo`3oool0oooo0000000?0?l000030000
003oool0oooo06D0oooo00<000000?l0003o00003P3o00000`000000oooo0?ooo`3:0?ooo`00IP3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
1`3oool300000<X0oooo00<000000?l0003o00003@3o00001@000000oooo0?ooo`3oool0000000l0
o`0000D000000?ooo`3oool0oooo0000000?0?l000030000003oool0oooo06D0oooo00<000000?l0
003o00003P3o00000`000000oooo0?ooo`3:0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3:0?oo
o`030000003o0000o`0000d0o`0000D000000?ooo`3oool0oooo0000000?0?l000050000003oool0
oooo0?ooo`0000003`3o00000`000000oooo0?ooo`1U0?oooa800000c03oool006/0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0<X0oooo00<0
00000?l0003o00003@3o00001@000000oooo0?ooo`3oool0000000l0o`0000@000000?ooo`3oool0
oooo4@00003o0?ooodH0oooo001[0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool01`3oool400000<T0oooo4@0000030?ooo`030000003o0000o`0000d0o`0000<000000?ooo`3o
ool0o`3ooomH0?ooo`00J03oool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0=h0oooo00<000000?l0003o00003@3o00000`000000oooo
0?ooo`3o0?oooeP0oooo001[0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3N0?ooo`030000003o0000o`0000d0o`0000<000000?ooo`3oool0
o`3ooomH0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool01`3oool300000=h0oooo00<000000?l0003o00003@3o00000`000000oooo
0?ooo`3o0?oooeP0oooo001V0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=h0oooo00<000000?l0003o0000
3@3o00000`000000oooo0?ooo`3o0?oooeP0oooo001W0?ooo`@00000103oool4000000X0oooo0`00
003N0?ooo`030000003o0000o`0000d0o`0000<000000?ooo`3oool0o`3ooomH0?ooo`00O@3oool0
0`000000oooo0?ooo`3N0?ooo`030000003o0000o`0000d0o`0000<000000?ooo`3oool0o`3ooomH
0?ooo`00O@3oool00`000000oooo0?ooo`3N0?ooo`030000003o0000o`0000d0o`0000<000000?oo
o`3oool0o`3ooomH0?ooo`00O@3oool300000=h0oooo00<000000?l0003o00003@3o00000`000000
oooo0?ooo`3o0?oooeP0oooo001W0?ooo`@00000103oool4000000X0oooo00<000000?ooo`3oool0
gP3oool00`000000o`000?l0000=0?l000030000003oool0oooo0?l0ooooF03oool006H0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo
0`00003N0?ooo`030000003o0000o`0000d0o`0000<000000?ooo`3oool0o`3ooomH0?ooo`00IP3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3N0?ooo`030000003o0000o`0000d0o`0000<000000?ooo`3oool0
o`3ooomH0?ooo`00J`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0gP3oool00`000000o`000?l0000=0?l000030000003oool0oooo0?l0ooooF03o
ool006/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`@00000g@3oool0
0`000000o`000?l0000=0?l000030000003oool0oooo0?l0ooooF03oool006P0oooo0`0000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3N0?oo
o`030000003o0000o`0000d0o`0000<000000?ooo`3oool0o`3ooomH0?ooo`00J`3oool00`000000
oooo0?ooo`05000000X0oooo0`00003N0?ooo`030000003o0000o`0000d0o`0000<000000?ooo`3o
ool0o`3ooomH0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000h0
oooo00<000000?ooo`3oool0gP3oool00`000000o`000?l0000=0?l000030000003oool0oooo0?l0
ooooF03oool006H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000d0
oooo00<000000?ooo`3oool0gP3ooolA00000?l0ooooFP3oool006L0oooo100000040?ooo`D00000
2@3oool300000?l0ooooo`3ooom:0?ooo`00O@3oool00`000000oooo0?ooo`3o0?ooool0ooooBP3o
ool00?l0ooooo`3oooo:0?ooo`00o`3ooooo0?ooolX0oooo0000\
\>"],
  ImageRangeCache->{{{0, 711}, {141.25, 0}} -> {-5.82991, -17.3633, 0.049762, \
0.395563}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparing base and peak load prices", "Subsection"],

Cell["\<\
To further explore the seemingly similarity of the peak and base load prices \
both time series are plotted in one graph together with the differnces \
between them. As expected the prices of the peak load are higher then the \
base load in most cases.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[Show[plbase, plpeak, PlotRange \[Rule] {0, 100}], 
        BarChart[peak - base, AspectRatio \[Rule] \ 0.2, 
          Ticks \[Rule] {ticks, Automatic}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0238095 0.00139359 3.46945e-018 0.002 [
[.0252 -0.0125 -33.7813 -17.75 ]
[.0252 -0.0125 33.7813 0 ]
[.16456 -0.0125 -33.7813 -17.75 ]
[.16456 -0.0125 33.7813 0 ]
[.30392 -0.0125 -29.875 -17.75 ]
[.30392 -0.0125 29.875 0 ]
[.44328 -0.0125 -33.7813 -17.75 ]
[.44328 -0.0125 33.7813 0 ]
[.58264 -0.0125 -33.7813 -17.75 ]
[.58264 -0.0125 33.7813 0 ]
[.722 -0.0125 -37.6875 -17.75 ]
[.722 -0.0125 37.6875 0 ]
[.86136 -0.0125 -29.875 -17.75 ]
[.86136 -0.0125 29.875 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04 -19.625 -8.875 ]
[-0.0125 .04 0 8.875 ]
[-0.0125 .08 -19.625 -8.875 ]
[-0.0125 .08 0 8.875 ]
[-0.0125 .12 -19.625 -8.875 ]
[-0.0125 .12 0 8.875 ]
[-0.0125 .16 -19.625 -8.875 ]
[-0.0125 .16 0 8.875 ]
[-0.0125 .2 -27.4375 -8.875 ]
[-0.0125 .2 0 8.875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .1 -45.1875 -24.8125 ]
[-0.01875 .1 -27.4375 24.8125 ]
[ 0 .2 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0252 0 m
.0252 .00625 L
s
gsave
.0252 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16456 0 m
.16456 .00625 L
s
gsave
.16456 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.30392 0 m
.30392 .00625 L
s
gsave
.30392 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.44328 0 m
.44328 .00625 L
s
gsave
.44328 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.58264 0 m
.58264 .00625 L
s
gsave
.58264 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.722 0 m
.722 .00625 L
s
gsave
.722 -0.0125 -98.6875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.688 17.625 moveto
(\\220) show
103.125 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
134.375 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86136 0 m
.86136 .00625 L
s
gsave
.86136 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2002) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .04 m
.00625 .04 L
s
gsave
-0.0125 .04 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .08 m
.00625 .08 L
s
gsave
-0.0125 .08 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .12 m
.00625 .12 L
s
gsave
-0.0125 .12 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
0 .16 m
.00625 .16 L
s
gsave
-0.0125 .16 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -88.4375 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01 m
.00375 .01 L
s
0 .02 m
.00375 .02 L
s
0 .03 m
.00375 .03 L
s
0 .05 m
.00375 .05 L
s
0 .06 m
.00375 .06 L
s
0 .07 m
.00375 .07 L
s
0 .09 m
.00375 .09 L
s
0 .1 m
.00375 .1 L
s
0 .11 m
.00375 .11 L
s
0 .13 m
.00375 .13 L
s
0 .14 m
.00375 .14 L
s
0 .15 m
.00375 .15 L
s
0 .17 m
.00375 .17 L
s
0 .18 m
.00375 .18 L
s
0 .19 m
.00375 .19 L
s
.25 Mabswid
0 0 m
0 .2 L
s
gsave
-0.01875 .1 -122.125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.8125 12.875 translate
90 rotate
-85.8125 -12.875 translate
0 25.75 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
%%BeginResource: font Arial-MISO
%%BeginFont: Arial-MISO
/Arial /Arial-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
currentpoint currentpoint
newpath
 moveto
 0.813 0.000 rmoveto
 0 -10.063 rlineto
 6.688 0 rlineto
 0 10.063 rlineto
 -6.688 0 rlineto
closepath
fill moveto
8.313 0.000 rmoveto
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.313 17.625 moveto
(\\220) show
75.750 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MWh) show
108.625 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
1 .2 L
s
1 0 m
1 .2 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.0252 .03426 m
.0266 .0266 L
.02799 .0228 L
.02938 .03534 L
.03078 .03672 L
.03217 .03588 L
.03356 .02712 L
.03496 .02878 L
.03635 .02516 L
.03775 .02218 L
.03914 .03734 L
.04053 .03234 L
.04193 .03358 L
.04332 .03718 L
.04471 .03164 L
.04611 .02228 L
.0475 .02002 L
.04889 .03222 L
.05029 .0357 L
.05168 .03468 L
.05307 .0359 L
.05447 .03324 L
.05586 .0252 L
.05726 .01972 L
.05865 .0338 L
.06004 .03794 L
.06144 .03584 L
.06283 .03292 L
.06422 .0301 L
.06562 .02356 L
.06701 .0206 L
.0684 .031 L
.0698 .02978 L
.07119 .03008 L
.07259 .03016 L
.07398 .03248 L
.07537 .02696 L
.07677 .02112 L
.07816 .031 L
.07955 .03058 L
.08095 .03174 L
.08234 .02978 L
.08373 .03032 L
.08513 .02468 L
.08652 .022 L
.08791 .03102 L
.08931 .03008 L
.0907 .02876 L
.0921 .03108 L
.09349 .03204 L
Mistroke
.09488 .02528 L
.09628 .02036 L
.09767 .02764 L
.09906 .0296 L
.10046 .02896 L
.10185 .03088 L
.10324 .02966 L
.10464 .02526 L
.10603 .02044 L
.10743 .03092 L
.10882 .02874 L
.11021 .03456 L
.11161 .0353 L
.113 .03404 L
.11439 .02872 L
.11579 .02194 L
.11718 .0365 L
.11857 .04328 L
.11997 .03306 L
.12136 .04112 L
.12275 .037 L
.12415 .02472 L
.12554 .01746 L
.12694 .03758 L
.12833 .03932 L
.12972 .04508 L
.13112 .04094 L
.13251 .04448 L
.1339 .03078 L
.1353 .02616 L
.13669 .04124 L
.13808 .0522 L
.13948 .04608 L
.14087 .04848 L
.14226 .04924 L
.14366 .02852 L
.14505 .02296 L
.14645 .04422 L
.14784 .04984 L
.14923 .05198 L
.15063 .06064 L
.15202 .04554 L
.15341 .0317 L
.15481 .02486 L
.1562 .04444 L
.15759 .0451 L
.15899 .04548 L
.16038 .05728 L
.16178 .04404 L
.16317 .03268 L
Mistroke
.16456 .02452 L
.16596 .04378 L
.16735 .04576 L
.16874 .04448 L
.17014 .0455 L
.17153 .04354 L
.17292 .03198 L
.17432 .02092 L
.17571 .0359 L
.1771 .03032 L
.1785 .04042 L
.17989 .03806 L
.18129 .037 L
.18268 .03112 L
.18407 .02196 L
.18547 .04206 L
.18686 .0427 L
.18825 .05022 L
.18965 .04308 L
.19104 .04084 L
.19243 .0225 L
.19383 .01548 L
.19522 .03218 L
.19661 .04192 L
.19801 .03884 L
.1994 .03906 L
.2008 .03844 L
.20219 .0292 L
.20358 .02256 L
.20498 .0441 L
.20637 .04506 L
.20776 .04206 L
.20916 .04356 L
.21055 .04348 L
.21194 .03434 L
.21334 .0254 L
.21473 .05198 L
.21613 .04572 L
.21752 .03904 L
.21891 .05746 L
.22031 .03952 L
.2217 .03804 L
.22309 .0266 L
.22449 .04252 L
.22588 .04626 L
.22727 .04456 L
.22867 .03696 L
.23006 .04186 L
.23145 .03164 L
.23285 .026 L
Mistroke
.23424 .0467 L
.23564 .04764 L
.23703 .05198 L
.23842 .04912 L
.23982 .0502 L
.24121 .03754 L
.2426 .03384 L
.244 .05034 L
.24539 .0483 L
.24678 .05372 L
.24818 .05238 L
.24957 .04922 L
.25097 .04448 L
.25236 .03018 L
.25375 .05562 L
.25515 .05088 L
.25654 .052 L
.25793 .05864 L
.25933 .0463 L
.26072 .03334 L
.26211 .03366 L
.26351 .05322 L
.2649 .04958 L
.26629 .05932 L
.26769 .0523 L
.26908 .0375 L
.27048 .03936 L
.27187 .03358 L
.27326 .05036 L
.27466 .0504 L
.27605 .04246 L
.27744 .04686 L
.27884 .05052 L
.28023 .03742 L
.28162 .03252 L
.28302 .06038 L
.28441 .0716 L
.2858 .0656 L
.2872 .05214 L
.28859 .04556 L
.28999 .03926 L
.29138 .03328 L
.29277 .03012 L
.29417 .03024 L
.29556 .03998 L
.29695 .03824 L
.29835 .03584 L
.29974 .03648 L
.30113 .03292 L
.30253 .02528 L
Mistroke
.30392 .04044 L
.30532 .03842 L
.30671 .0422 L
.3081 .04228 L
.3095 .03318 L
.31089 .03066 L
.31228 .04722 L
.31368 .049 L
.31507 .05044 L
.31646 .0502 L
.31786 .04794 L
.31925 .04404 L
.32064 .04176 L
.32204 .0583 L
.32343 .05924 L
.32483 .06034 L
.32622 .05478 L
.32761 .05984 L
.32901 .04502 L
.3304 .03656 L
.33179 .05756 L
.33319 .05108 L
.33458 .0415 L
.33597 .05142 L
.33737 .04788 L
.33876 .03564 L
.34015 .0313 L
.34155 .0478 L
.34294 .05272 L
.34434 .05024 L
.34573 .04986 L
.34712 .05662 L
.34852 .04418 L
.34991 .03654 L
.3513 .0527 L
.3527 .04212 L
.35409 .04662 L
.35548 .04476 L
.35688 .04442 L
.35827 .03898 L
.35967 .03212 L
.36106 .04414 L
.36245 .04296 L
.36385 .04388 L
.36524 .05274 L
.36663 .04582 L
.36803 .04026 L
.36942 .03168 L
.37081 .04242 L
.37221 .04316 L
Mistroke
.3736 .04346 L
.37499 .0439 L
.37639 .05004 L
.37778 .04608 L
.37918 .03562 L
.38057 .05374 L
.38196 .06264 L
.38336 .05852 L
.38475 .07964 L
.38614 .05528 L
.38754 .05026 L
.38893 .03656 L
.39032 .05262 L
.39172 .06276 L
.39311 .05272 L
.39451 .05088 L
.3959 .04296 L
.39729 .03968 L
.39869 .03136 L
.40008 .0459 L
.40147 .036 L
.40287 .04406 L
.40426 .04452 L
.40565 .0431 L
.40705 .03752 L
.40844 .02808 L
.40983 .03552 L
.41123 .0441 L
.41262 .04054 L
.41402 .0415 L
.41541 .03974 L
.4168 .03412 L
.4182 .01788 L
.41959 .0363 L
.42098 .04442 L
.42238 .03654 L
.42377 .04206 L
.42516 .04462 L
.42656 .03674 L
.42795 .03208 L
.42934 .05054 L
.43074 .0511 L
.43213 .041 L
.43353 .04506 L
.43492 .04754 L
.43631 .04238 L
.43771 .0353 L
.4391 .04506 L
.44049 .0541 L
.44189 .05004 L
Mistroke
.44328 .0419 L
.44467 .03344 L
.44607 .03984 L
.44746 .02956 L
.44886 .02416 L
.45025 .05424 L
.45164 .05128 L
.45304 .0833 L
.45443 .0525 L
.45582 .04394 L
.45722 .04024 L
.45861 .06622 L
.46 .0599 L
.4614 .05108 L
.46279 .04972 L
.46418 .06372 L
.46558 .0434 L
.46697 .03582 L
.46837 .04604 L
.46976 .03114 L
.47115 .0602 L
.47255 .0433 L
.47394 .04246 L
.47533 .03946 L
.47673 .0341 L
.47812 .0497 L
.47951 .04772 L
.48091 .04276 L
.4823 .04734 L
.48369 .03604 L
.48509 .03662 L
.48648 .02742 L
.48788 .0477 L
.48927 .05044 L
.49066 .05062 L
.49206 .04424 L
.49345 .04618 L
.49484 .03512 L
.49624 .0323 L
.49763 .054 L
.49902 .05596 L
.50042 .0478 L
.50181 .02814 L
.50321 .03184 L
.5046 .02916 L
.50599 .02094 L
.50739 .0459 L
.50878 .04378 L
.51017 .04702 L
.51157 .04952 L
Mistroke
.51296 .0375 L
.51435 .02678 L
.51575 .01662 L
.51714 .01966 L
.51853 .043 L
.51993 .05654 L
.52132 .03958 L
.52272 .04102 L
.52411 .04042 L
.5255 .02712 L
.5269 .0418 L
.52829 .04766 L
.52968 .06036 L
.53108 .03662 L
.53247 .03766 L
.53386 .03718 L
.53526 .02568 L
.53665 .05364 L
.53805 .0481 L
.53944 .05324 L
.54083 .0442 L
.54223 .03808 L
.54362 .03126 L
.54501 .02156 L
.54641 .049 L
.5478 .06132 L
.54919 .04896 L
.55059 .06106 L
.55198 .05116 L
.55337 .0312 L
.55477 .01952 L
.55616 .05974 L
.55756 .05296 L
.55895 .05314 L
.56034 .05992 L
.56174 .05048 L
.56313 .04074 L
.56452 .0207 L
.56592 .0536 L
.56731 .04868 L
.5687 .04812 L
.5701 .04306 L
.57149 .04264 L
.57288 .03004 L
.57428 .01928 L
.57567 .04798 L
.57707 .04488 L
.57846 .03576 L
.57985 .04062 L
.58125 .04 L
Mistroke
.58264 .02446 L
.58403 .01784 L
.58543 .03346 L
.58682 .03846 L
.58821 .0305 L
.58961 .0382 L
.591 .033 L
.5924 .02814 L
.59379 .01746 L
.59518 .03564 L
.59658 .04318 L
.59797 .03614 L
.59936 .03936 L
.60076 .03698 L
.60215 .02508 L
.60354 .0166 L
.60494 .03922 L
.60633 .03822 L
.60772 .04046 L
.60912 .03402 L
.61051 .04176 L
.61191 .01718 L
.6133 .0106 L
.61469 .02892 L
.61609 .0407 L
.61748 .03406 L
.61887 .05062 L
.62027 .04952 L
.62166 .03358 L
.62305 .02354 L
.62445 .04294 L
.62584 .05642 L
.62723 .04716 L
.62863 .05778 L
.63002 .0507 L
.63142 .04326 L
.63281 .03142 L
.6342 .05156 L
.6356 .05136 L
.63699 .08894 L
.63838 .05316 L
.63978 .0448 L
.64117 .03826 L
.64256 .0282 L
.64396 .05886 L
.64535 .04896 L
.64675 .04678 L
.64814 .05138 L
.64953 .0446 L
.65093 .03486 L
Mistroke
.65232 .0276 L
.65371 .0469 L
.65511 .04628 L
.6565 .05596 L
.65789 .0499 L
.65929 .0587 L
.66068 .03618 L
.66207 .02806 L
.66347 .04714 L
.66486 .05152 L
.66626 .05086 L
.66765 .05152 L
.66904 .04976 L
.67044 .04152 L
.67183 .03472 L
.67322 .05228 L
.67462 .05172 L
.67601 .05392 L
.6774 .0485 L
.6788 .04762 L
.68019 .04106 L
.68159 .03374 L
.68298 .06156 L
.68437 .04904 L
.68577 .0384 L
.68716 .04274 L
.68855 .04514 L
.68995 .03672 L
.69134 .02652 L
.69273 .04202 L
.69413 .04218 L
.69552 .04382 L
.69691 .04886 L
.69831 .04094 L
.6997 .03444 L
.7011 .03184 L
.70249 .04722 L
.70388 .04734 L
.70528 .05062 L
.70667 .04808 L
.70806 .0486 L
.70946 .04098 L
.71085 .03668 L
.71224 .04782 L
.71364 .0554 L
.71503 .05574 L
.71642 .05754 L
.71782 .04628 L
.71921 .04008 L
.72061 .03042 L
Mistroke
.722 .06428 L
.72339 .05092 L
.72479 .04198 L
.72618 .03506 L
.72757 .04572 L
.72897 .04272 L
.73036 .03386 L
.73175 .0549 L
.73315 .0509 L
.73454 .05626 L
.73594 .05334 L
.73733 .0606 L
.73872 .04776 L
.74012 .03856 L
.74151 .05522 L
.7429 .09124 L
.7443 .0832 L
.74569 .07204 L
.74708 .08026 L
.74848 .06702 L
.74987 .04852 L
.75126 .07094 L
.75266 .07562 L
.75405 .0719 L
.75545 .06494 L
.75684 .0743 L
.75823 .05078 L
.75963 .03508 L
.76102 .06856 L
.76241 .06618 L
.76381 .06284 L
.7652 .06202 L
.76659 .0533 L
.76799 .033 L
.76938 .0314 L
.77077 .07422 L
.77217 .064 L
.77356 .05554 L
.77496 .05256 L
.77635 .05844 L
.77774 .05198 L
.77914 .04146 L
.78053 .12722 L
.78192 .09006 L
.78332 .11562 L
.78471 .11034 L
.7861 .11614 L
.7875 .07298 L
.78889 .05102 L
Mfstroke
.78889 .05102 m
.78938 .2 L
s
.79245 .2 m
.79307 .08322 L
.79447 .1078 L
.79586 .05962 L
.79725 .0601 L
.79865 .04692 L
.80004 .04396 L
.80143 .03098 L
.80283 .0355 L
.80422 .0556 L
.80561 .0293 L
.80701 .03768 L
.8084 .03498 L
.8098 .04414 L
.81119 .02986 L
.81258 .0575 L
.81398 .06254 L
.81537 .06842 L
.81676 .05506 L
.81816 .04128 L
.81955 .0949 L
.82094 .122 L
.82234 .10396 L
.82373 .10012 L
.82513 .08538 L
.82652 .0656 L
.82791 .05284 L
.82931 .0758 L
.8307 .0681 L
.83209 .06784 L
.83349 .06886 L
.83488 .06334 L
.83627 .03306 L
.83767 .03222 L
.83906 .05526 L
.84045 .0565 L
.84185 .04816 L
.84324 .05082 L
.84464 .04942 L
.84603 .03648 L
.84742 .03162 L
.84882 .04904 L
.85021 .0358 L
.8516 .04678 L
.853 .04198 L
.85439 .04186 L
.85578 .03044 L
.85718 .02292 L
.85857 .04226 L
.85996 .04228 L
Mistroke
.86136 .0419 L
.86275 .04114 L
.86415 .03784 L
.86554 .0344 L
.86693 .02752 L
.86833 .03772 L
.86972 .03304 L
.87111 .0444 L
.87251 .04806 L
.8739 .03724 L
.87529 .04568 L
.87669 .0366 L
.87808 .04596 L
.87948 .04414 L
.88087 .04582 L
.88226 .0514 L
.88366 .04352 L
.88505 .03778 L
.88644 .0378 L
.88784 .04808 L
.88923 .04518 L
.89062 .03996 L
.89202 .04594 L
.89341 .05566 L
.8948 .03712 L
.8962 .03014 L
.89759 .0474 L
.89899 .04948 L
.90038 .04558 L
.90177 .04294 L
.90317 .0414 L
.90456 .04246 L
.90595 .03432 L
.90735 .04432 L
.90874 .0443 L
.91013 .03992 L
.91153 .04338 L
.91292 .03656 L
.91431 .03506 L
.91571 .02844 L
.9171 .04154 L
.9185 .03836 L
.91989 .0398 L
.92128 .03718 L
.92268 .0383 L
.92407 .02974 L
.92546 .02272 L
.92686 .0423 L
.92825 .04884 L
.92964 .04796 L
Mistroke
.93104 .04456 L
.93243 .03254 L
.93383 .02978 L
.93522 .01804 L
.93661 .01588 L
.93801 .04028 L
.9394 .0379 L
.94079 .04118 L
.94219 .03832 L
.94358 .0388 L
.94497 .03062 L
.94637 .05598 L
.94776 .05004 L
.94915 .05142 L
.95055 .05806 L
.95194 .05486 L
.95334 .03584 L
.95473 .03102 L
.95612 .05474 L
.95752 .06108 L
.95891 .0608 L
.9603 .05578 L
.9617 .0515 L
.96309 .04568 L
.96448 .0309 L
.96588 .04836 L
.96727 .05352 L
.96867 .05594 L
.97006 .0487 L
.97145 .03948 L
.97285 .02912 L
.97424 .02304 L
.97563 .04272 L
Mfstroke
1 0 0 r
.0252 .04101 m
.0266 .03036 L
.02799 .02516 L
.02938 .04384 L
.03078 .04571 L
.03217 .04469 L
.03356 .02964 L
.03496 .03392 L
.03635 .02789 L
.03775 .02425 L
.03914 .04503 L
.04053 .03947 L
.04193 .03911 L
.04332 .04501 L
.04471 .03779 L
.04611 .02773 L
.0475 .02465 L
.04889 .0407 L
.05029 .04406 L
.05168 .04167 L
.05307 .04486 L
.05447 .0415 L
.05586 .02885 L
.05726 .02246 L
.05865 .04356 L
.06004 .0456 L
.06144 .04525 L
.06283 .04016 L
.06422 .03669 L
.06562 .02709 L
.06701 .0227 L
.0684 .03757 L
.0698 .03481 L
.07119 .03501 L
.07259 .03529 L
.07398 .03862 L
.07537 .03048 L
.07677 .02343 L
.07816 .0375 L
.07955 .03455 L
.08095 .03916 L
.08234 .03519 L
.08373 .03564 L
.08513 .02827 L
.08652 .0246 L
.08791 .0379 L
.08931 .03569 L
.0907 .03325 L
.0921 .03753 L
.09349 .03791 L
Mistroke
.09488 .02974 L
.09628 .02299 L
.09767 .03218 L
.09906 .0347 L
.10046 .03301 L
.10185 .03546 L
.10324 .0333 L
.10464 .02952 L
.10603 .0231 L
.10743 .03645 L
.10882 .03189 L
.11021 .04041 L
.11161 .04109 L
.113 .03854 L
.11439 .03359 L
.11579 .02567 L
.11718 .04751 L
.11857 .05699 L
.11997 .03972 L
.12136 .05179 L
.12275 .04573 L
.12415 .02903 L
.12554 .02104 L
.12694 .04903 L
.12833 .05119 L
.12972 .06023 L
.13112 .05154 L
.13251 .05701 L
.1339 .0353 L
.1353 .0292 L
.13669 .05513 L
.13808 .06276 L
.13948 .05974 L
.14087 .06197 L
.14226 .06351 L
.14366 .03363 L
.14505 .0243 L
.14645 .05754 L
.14784 .0636 L
.14923 .06426 L
.15063 .07986 L
.15202 .05492 L
.15341 .03769 L
.15481 .02837 L
.1562 .05531 L
.15759 .05635 L
.15899 .05906 L
.16038 .07724 L
.16178 .05527 L
.16317 .03978 L
Mistroke
.16456 .02834 L
.16596 .05434 L
.16735 .0563 L
.16874 .05376 L
.17014 .05648 L
.17153 .05227 L
.17292 .04032 L
.17432 .02381 L
.17571 .04718 L
.1771 .03976 L
.1785 .05414 L
.17989 .04678 L
.18129 .04522 L
.18268 .03766 L
.18407 .02461 L
.18547 .05675 L
.18686 .05018 L
.18825 .06749 L
.18965 .05795 L
.19104 .05262 L
.19243 .02756 L
.19383 .02037 L
.19522 .04083 L
.19661 .05516 L
.19801 .04725 L
.1994 .04856 L
.2008 .04614 L
.20219 .03313 L
.20358 .02367 L
.20498 .05677 L
.20637 .05557 L
.20776 .05192 L
.20916 .05435 L
.21055 .0548 L
.21194 .0401 L
.21334 .02826 L
.21473 .06609 L
.21613 .05886 L
.21752 .04636 L
.21891 .08184 L
.22031 .04495 L
.2217 .04294 L
.22309 .02844 L
.22449 .05876 L
.22588 .06051 L
.22727 .05913 L
.22867 .04493 L
.23006 .05017 L
.23145 .03573 L
.23285 .02939 L
Mistroke
.23424 .06181 L
.23564 .05703 L
.23703 .06408 L
.23842 .06292 L
.23982 .0633 L
.24121 .04251 L
.2426 .04054 L
.244 .06437 L
.24539 .06053 L
.24678 .06509 L
.24818 .0665 L
.24957 .0573 L
.25097 .05222 L
.25236 .03226 L
.25375 .06799 L
.25515 .06174 L
.25654 .06302 L
.25793 .07547 L
.25933 .05805 L
.26072 .03836 L
.26211 .03868 L
.26351 .0705 L
.2649 .05816 L
.26629 .07592 L
.26769 .06303 L
.26908 .03815 L
.27048 .04672 L
.27187 .03791 L
.27326 .0626 L
.27466 .06299 L
.27605 .05032 L
.27744 .0573 L
.27884 .0631 L
.28023 .04258 L
.28162 .03636 L
.28302 .07976 L
.28441 .0934 L
.2858 .08446 L
.2872 .06371 L
.28859 .0511 L
.28999 .04181 L
.29138 .03581 L
.29277 .03137 L
.29417 .03123 L
.29556 .04857 L
.29695 .04326 L
.29835 .04041 L
.29974 .04097 L
.30113 .03721 L
.30253 .02357 L
Mistroke
.30392 .04356 L
.30532 .04099 L
.30671 .04877 L
.3081 .04773 L
.3095 .03659 L
.31089 .03467 L
.31228 .05936 L
.31368 .06048 L
.31507 .06354 L
.31646 .06231 L
.31786 .05639 L
.31925 .04888 L
.32064 .04396 L
.32204 .07389 L
.32343 .06959 L
.32483 .07537 L
.32622 .0641 L
.32761 .07281 L
.32901 .04933 L
.3304 .03878 L
.33179 .07502 L
.33319 .06181 L
.33458 .04656 L
.33597 .06265 L
.33737 .05615 L
.33876 .03791 L
.34015 .03425 L
.34155 .05766 L
.34294 .06504 L
.34434 .05996 L
.34573 .05683 L
.34712 .07175 L
.34852 .0492 L
.34991 .0414 L
.3513 .06797 L
.3527 .05049 L
.35409 .05635 L
.35548 .05406 L
.35688 .0531 L
.35827 .04465 L
.35967 .03539 L
.36106 .05221 L
.36245 .0487 L
.36385 .04877 L
.36524 .06194 L
.36663 .0519 L
.36803 .04228 L
.36942 .03595 L
.37081 .04983 L
.37221 .05066 L
Mistroke
.3736 .04915 L
.37499 .04887 L
.37639 .05852 L
.37778 .05136 L
.37918 .03753 L
.38057 .0643 L
.38196 .07801 L
.38336 .06928 L
.38475 .10097 L
.38614 .0625 L
.38754 .05507 L
.38893 .03913 L
.39032 .06683 L
.39172 .08087 L
.39311 .06509 L
.39451 .06041 L
.3959 .04464 L
.39729 .04195 L
.39869 .03458 L
.40008 .05313 L
.40147 .03746 L
.40287 .04835 L
.40426 .04929 L
.40565 .04664 L
.40705 .04024 L
.40844 .03214 L
.40983 .04091 L
.41123 .05051 L
.41262 .04203 L
.41402 .04802 L
.41541 .04285 L
.4168 .0385 L
.4182 .01795 L
.41959 .04413 L
.42098 .04961 L
.42238 .03922 L
.42377 .04608 L
.42516 .05071 L
.42656 .0379 L
.42795 .03396 L
.42934 .06309 L
.43074 .05701 L
.43213 .04368 L
.43353 .05205 L
.43492 .05468 L
.43631 .04509 L
.43771 .03539 L
.4391 .05087 L
.44049 .06001 L
.44189 .05998 L
Mistroke
.44328 .0446 L
.44467 .03297 L
.44607 .04343 L
.44746 .03284 L
.44886 .02501 L
.45025 .06705 L
.45164 .06322 L
.45304 .10455 L
.45443 .06523 L
.45582 .04715 L
.45722 .0419 L
.45861 .09237 L
.46 .07327 L
.4614 .05972 L
.46279 .05892 L
.46418 .07838 L
.46558 .04595 L
.46697 .03828 L
.46837 .052 L
.46976 .02917 L
.47115 .08264 L
.47255 .05023 L
.47394 .04978 L
.47533 .04122 L
.47673 .03773 L
.47812 .06353 L
.47951 .05529 L
.48091 .04888 L
.4823 .0582 L
.48369 .0432 L
.48509 .0433 L
.48648 .03128 L
.48788 .06254 L
.48927 .06141 L
.49066 .06541 L
.49206 .05272 L
.49345 .05649 L
.49484 .03868 L
.49624 .03516 L
.49763 .07647 L
.49902 .07357 L
.50042 .05772 L
.50181 .0311 L
.50321 .03801 L
.5046 .03377 L
.50599 .02461 L
.50739 .06136 L
.50878 .05961 L
.51017 .06335 L
.51157 .07004 L
Mistroke
.51296 .04414 L
.51435 .03167 L
.51575 .01965 L
.51714 .02531 L
.51853 .06152 L
.51993 .07743 L
.52132 .04921 L
.52272 .05472 L
.52411 .05283 L
.5255 .03241 L
.5269 .05627 L
.52829 .0618 L
.52968 .0843 L
.53108 .0465 L
.53247 .04513 L
.53386 .04815 L
.53526 .0299 L
.53665 .07424 L
.53805 .06287 L
.53944 .07262 L
.54083 .0605 L
.54223 .05048 L
.54362 .03633 L
.54501 .0268 L
.54641 .06506 L
.5478 .08071 L
.54919 .06445 L
.55059 .08615 L
.55198 .06741 L
.55337 .03929 L
.55477 .0237 L
.55616 .09163 L
.55756 .07071 L
.55895 .07023 L
.56034 .0849 L
.56174 .06776 L
.56313 .05188 L
.56452 .02501 L
.56592 .07693 L
.56731 .06488 L
.5687 .06459 L
.5701 .05624 L
.57149 .05608 L
.57288 .03428 L
.57428 .02604 L
.57567 .06826 L
.57707 .05451 L
.57846 .04711 L
.57985 .05424 L
.58125 .05324 L
Mistroke
.58264 .03096 L
.58403 .02218 L
.58543 .04766 L
.58682 .04926 L
.58821 .04152 L
.58961 .05128 L
.591 .04177 L
.5924 .03247 L
.59379 .02246 L
.59518 .05055 L
.59658 .05314 L
.59797 .04245 L
.59936 .04869 L
.60076 .04585 L
.60215 .03491 L
.60354 .02224 L
.60494 .05747 L
.60633 .04848 L
.60772 .05124 L
.60912 .04324 L
.61051 .05407 L
.61191 .02192 L
.6133 .01362 L
.61469 .04217 L
.61609 .04581 L
.61748 .04098 L
.61887 .06339 L
.62027 .06466 L
.62166 .04064 L
.62305 .0265 L
.62445 .05994 L
.62584 .074 L
.62723 .06076 L
.62863 .07532 L
.63002 .0654 L
.63142 .04734 L
.63281 .03625 L
.6342 .06894 L
.6356 .06404 L
.63699 .13636 L
.63838 .06631 L
.63978 .05439 L
.64117 .04281 L
.64256 .03424 L
.64396 .07873 L
.64535 .05951 L
.64675 .05677 L
.64814 .06031 L
.64953 .05339 L
.65093 .04045 L
Mistroke
.65232 .03165 L
.65371 .05843 L
.65511 .0594 L
.6565 .07163 L
.65789 .05979 L
.65929 .07459 L
.66068 .04003 L
.66207 .03305 L
.66347 .06 L
.66486 .06358 L
.66626 .06328 L
.66765 .06104 L
.66904 .06252 L
.67044 .04536 L
.67183 .04015 L
.67322 .0635 L
.67462 .06361 L
.67601 .06585 L
.6774 .05738 L
.6788 .05756 L
.68019 .04344 L
.68159 .03886 L
.68298 .08705 L
.68437 .06073 L
.68577 .04645 L
.68716 .05522 L
.68855 .05146 L
.68995 .04267 L
.69134 .03133 L
.69273 .05338 L
.69413 .05239 L
.69552 .05476 L
.69691 .06434 L
.69831 .04626 L
.6997 .03856 L
.7011 .03758 L
.70249 .05736 L
.70388 .05817 L
.70528 .06014 L
.70667 .05788 L
.70806 .05824 L
.70946 .04575 L
.71085 .04253 L
.71224 .06211 L
.71364 .06618 L
.71503 .06904 L
.71642 .07101 L
.71782 .05623 L
.71921 .05098 L
.72061 .03844 L
Mistroke
.722 .08716 L
.72339 .07034 L
.72479 .05674 L
.72618 .04068 L
.72757 .05904 L
.72897 .0512 L
.73036 .04074 L
.73175 .0722 L
.73315 .06664 L
.73454 .06942 L
.73594 .06878 L
.73733 .07457 L
.73872 .0531 L
.74012 .04017 L
.74151 .0724 L
.7429 .13018 L
.7443 .11299 L
.74569 .09044 L
.74708 .10078 L
.74848 .07506 L
.74987 .05628 L
.75126 .0913 L
.75266 .09602 L
.75405 .09104 L
.75545 .08141 L
.75684 .09401 L
.75823 .0585 L
.75963 .03874 L
.76102 .09122 L
.76241 .08499 L
.76381 .08195 L
.7652 .07876 L
.76659 .06674 L
.76799 .04304 L
.76938 .03769 L
.77077 .10986 L
.77217 .08759 L
.77356 .07051 L
.77496 .06726 L
.77635 .07281 L
.77774 .05888 L
.77914 .04663 L
Mfstroke
.77914 .04663 m
.78048 .2 L
s
.78064 .2 m
.78192 .12702 L
.78332 .16756 L
.78471 .15837 L
.7861 .16179 L
.7875 .08285 L
.78889 .05511 L
s
.78889 .05511 m
.78913 .2 L
s
.79277 .2 m
.79307 .10424 L
.79447 .14406 L
.79586 .06972 L
.79725 .06964 L
.79865 .05141 L
.80004 .05405 L
.80143 .03433 L
.80283 .04043 L
.80422 .07566 L
.80561 .03597 L
.80701 .04391 L
.8084 .03847 L
.8098 .05556 L
.81119 .0295 L
.81258 .07504 L
.81398 .07995 L
.81537 .07688 L
.81676 .06224 L
.81816 .04629 L
.81955 .13299 L
.82094 .15935 L
.82234 .14097 L
.82373 .13136 L
.82513 .09996 L
.82652 .07948 L
.82791 .06173 L
.82931 .10107 L
.8307 .07705 L
.83209 .08487 L
.83349 .08086 L
.83488 .07622 L
.83627 .03686 L
.83767 .03834 L
.83906 .0711 L
.84045 .06836 L
.84185 .06426 L
.84324 .06442 L
.84464 .0594 L
.84603 .04435 L
.84742 .03797 L
.84882 .06384 L
.85021 .04749 L
.8516 .05859 L
.853 .05136 L
.85439 .04949 L
.85578 .03538 L
.85718 .03088 L
.85857 .05277 L
.85996 .0522 L
Mistroke
.86136 .04933 L
.86275 .04798 L
.86415 .04418 L
.86554 .03961 L
.86693 .03388 L
.86833 .04559 L
.86972 .03765 L
.87111 .05272 L
.87251 .05631 L
.8739 .04036 L
.87529 .05301 L
.87669 .03985 L
.87808 .05614 L
.87948 .05209 L
.88087 .05504 L
.88226 .06317 L
.88366 .04842 L
.88505 .04125 L
.88644 .0407 L
.88784 .0573 L
.88923 .054 L
.89062 .04793 L
.89202 .05359 L
.89341 .06781 L
.8948 .04216 L
.8962 .0356 L
.89759 .05634 L
.89899 .05942 L
.90038 .05402 L
.90177 .05082 L
.90317 .04747 L
.90456 .04532 L
.90595 .03851 L
.90735 .05026 L
.90874 .05148 L
.91013 .04484 L
.91153 .04934 L
.91292 .04159 L
.91431 .03877 L
.91571 .03271 L
.9171 .04911 L
.9185 .0481 L
.91989 .05019 L
.92128 .04687 L
.92268 .04595 L
.92407 .03359 L
.92546 .02583 L
.92686 .05273 L
.92825 .0545 L
.92964 .05752 L
Mistroke
.93104 .05406 L
.93243 .0318 L
.93383 .03493 L
.93522 .01966 L
.93661 .01411 L
.93801 .04945 L
.9394 .04285 L
.94079 .0468 L
.94219 .0403 L
.94358 .04 L
.94497 .03094 L
.94637 .06677 L
.94776 .0583 L
.94915 .05845 L
.95055 .06858 L
.95194 .06157 L
.95334 .04384 L
.95473 .03342 L
.95612 .06751 L
.95752 .07871 L
.95891 .06989 L
.9603 .06693 L
.9617 .05831 L
.96309 .05105 L
.96448 .03123 L
.96588 .05858 L
.96727 .06531 L
.96867 .074 L
.97006 .05578 L
.97145 .05006 L
.97285 .03488 L
.97424 .02762 L
.97563 .05233 L
Mfstroke
.02465 0 m
.02465 .00675 L
.02576 .00675 L
.02576 0 L
F
0 g
.02465 0 m
.02465 .00675 L
.02576 .00675 L
.02576 0 L
.02465 0 L
s
1 0 0 r
.02604 0 m
.02604 .00376 L
.02715 .00376 L
.02715 0 L
F
0 g
.02604 0 m
.02604 .00376 L
.02715 .00376 L
.02715 0 L
.02604 0 L
s
1 0 0 r
.02743 0 m
.02743 .00236 L
.02855 .00236 L
.02855 0 L
F
0 g
.02743 0 m
.02743 .00236 L
.02855 .00236 L
.02855 0 L
.02743 0 L
s
1 0 0 r
.02883 0 m
.02883 .0085 L
.02994 .0085 L
.02994 0 L
F
0 g
.02883 0 m
.02883 .0085 L
.02994 .0085 L
.02994 0 L
.02883 0 L
s
1 0 0 r
.03022 0 m
.03022 .00899 L
.03133 .00899 L
.03133 0 L
F
0 g
.03022 0 m
.03022 .00899 L
.03133 .00899 L
.03133 0 L
.03022 0 L
s
1 0 0 r
.03161 0 m
.03161 .00881 L
.03273 .00881 L
.03273 0 L
F
0 g
.03161 0 m
.03161 .00881 L
.03273 .00881 L
.03273 0 L
.03161 0 L
s
1 0 0 r
.03301 0 m
.03301 .00252 L
.03412 .00252 L
.03412 0 L
F
0 g
.03301 0 m
.03301 .00252 L
.03412 .00252 L
.03412 0 L
.03301 0 L
s
1 0 0 r
.0344 0 m
.0344 .00514 L
.03552 .00514 L
.03552 0 L
F
0 g
.0344 0 m
.0344 .00514 L
.03552 .00514 L
.03552 0 L
.0344 0 L
s
1 0 0 r
.03579 0 m
.03579 .00273 L
.03691 .00273 L
.03691 0 L
F
0 g
.03579 0 m
.03579 .00273 L
.03691 .00273 L
.03691 0 L
.03579 0 L
s
1 0 0 r
.03719 0 m
.03719 .00207 L
.0383 .00207 L
.0383 0 L
F
0 g
.03719 0 m
.03719 .00207 L
.0383 .00207 L
.0383 0 L
.03719 0 L
s
1 0 0 r
.03858 0 m
.03858 .00769 L
.0397 .00769 L
.0397 0 L
F
0 g
.03858 0 m
.03858 .00769 L
.0397 .00769 L
.0397 0 L
.03858 0 L
s
1 0 0 r
.03998 0 m
.03998 .00713 L
.04109 .00713 L
.04109 0 L
F
0 g
.03998 0 m
.03998 .00713 L
.04109 .00713 L
.04109 0 L
.03998 0 L
s
1 0 0 r
.04137 0 m
.04137 .00553 L
.04248 .00553 L
.04248 0 L
F
0 g
.04137 0 m
.04137 .00553 L
.04248 .00553 L
.04248 0 L
.04137 0 L
s
1 0 0 r
.04276 0 m
.04276 .00783 L
.04388 .00783 L
.04388 0 L
F
0 g
.04276 0 m
.04276 .00783 L
.04388 .00783 L
.04388 0 L
.04276 0 L
s
1 0 0 r
.04416 0 m
.04416 .00615 L
.04527 .00615 L
.04527 0 L
F
0 g
.04416 0 m
.04416 .00615 L
.04527 .00615 L
.04527 0 L
.04416 0 L
s
1 0 0 r
.04555 0 m
.04555 .00545 L
.04666 .00545 L
.04666 0 L
F
0 g
.04555 0 m
.04555 .00545 L
.04666 .00545 L
.04666 0 L
.04555 0 L
s
1 0 0 r
.04694 0 m
.04694 .00463 L
.04806 .00463 L
.04806 0 L
F
0 g
.04694 0 m
.04694 .00463 L
.04806 .00463 L
.04806 0 L
.04694 0 L
s
1 0 0 r
.04834 0 m
.04834 .00848 L
.04945 .00848 L
.04945 0 L
F
0 g
.04834 0 m
.04834 .00848 L
.04945 .00848 L
.04945 0 L
.04834 0 L
s
1 0 0 r
.04973 0 m
.04973 .00836 L
.05085 .00836 L
.05085 0 L
F
0 g
.04973 0 m
.04973 .00836 L
.05085 .00836 L
.05085 0 L
.04973 0 L
s
1 0 0 r
.05112 0 m
.05112 .00699 L
.05224 .00699 L
.05224 0 L
F
0 g
.05112 0 m
.05112 .00699 L
.05224 .00699 L
.05224 0 L
.05112 0 L
s
1 0 0 r
.05252 0 m
.05252 .00896 L
.05363 .00896 L
.05363 0 L
F
0 g
.05252 0 m
.05252 .00896 L
.05363 .00896 L
.05363 0 L
.05252 0 L
s
1 0 0 r
.05391 0 m
.05391 .00826 L
.05503 .00826 L
.05503 0 L
F
0 g
.05391 0 m
.05391 .00826 L
.05503 .00826 L
.05503 0 L
.05391 0 L
s
1 0 0 r
.0553 0 m
.0553 .00365 L
.05642 .00365 L
.05642 0 L
F
0 g
.0553 0 m
.0553 .00365 L
.05642 .00365 L
.05642 0 L
.0553 0 L
s
1 0 0 r
.0567 0 m
.0567 .00274 L
.05781 .00274 L
.05781 0 L
F
0 g
.0567 0 m
.0567 .00274 L
.05781 .00274 L
.05781 0 L
.0567 0 L
s
1 0 0 r
.05809 0 m
.05809 .00976 L
.05921 .00976 L
.05921 0 L
F
0 g
.05809 0 m
.05809 .00976 L
.05921 .00976 L
.05921 0 L
.05809 0 L
s
1 0 0 r
.05949 0 m
.05949 .00766 L
.0606 .00766 L
.0606 0 L
F
0 g
.05949 0 m
.05949 .00766 L
.0606 .00766 L
.0606 0 L
.05949 0 L
s
1 0 0 r
.06088 0 m
.06088 .00941 L
.06199 .00941 L
.06199 0 L
F
0 g
.06088 0 m
.06088 .00941 L
.06199 .00941 L
.06199 0 L
.06088 0 L
s
1 0 0 r
.06227 0 m
.06227 .00724 L
.06339 .00724 L
.06339 0 L
F
0 g
.06227 0 m
.06227 .00724 L
.06339 .00724 L
.06339 0 L
.06227 0 L
s
1 0 0 r
.06367 0 m
.06367 .00659 L
.06478 .00659 L
.06478 0 L
F
0 g
.06367 0 m
.06367 .00659 L
.06478 .00659 L
.06478 0 L
.06367 0 L
s
1 0 0 r
.06506 0 m
.06506 .00353 L
.06617 .00353 L
.06617 0 L
F
0 g
.06506 0 m
.06506 .00353 L
.06617 .00353 L
.06617 0 L
.06506 0 L
s
1 0 0 r
.06645 0 m
.06645 .0021 L
.06757 .0021 L
.06757 0 L
F
0 g
.06645 0 m
.06645 .0021 L
.06757 .0021 L
.06757 0 L
.06645 0 L
s
1 0 0 r
.06785 0 m
.06785 .00657 L
.06896 .00657 L
.06896 0 L
F
0 g
.06785 0 m
.06785 .00657 L
.06896 .00657 L
.06896 0 L
.06785 0 L
s
1 0 0 r
.06924 0 m
.06924 .00503 L
.07036 .00503 L
.07036 0 L
F
0 g
.06924 0 m
.06924 .00503 L
.07036 .00503 L
.07036 0 L
.06924 0 L
s
1 0 0 r
.07063 0 m
.07063 .00493 L
.07175 .00493 L
.07175 0 L
F
0 g
.07063 0 m
.07063 .00493 L
.07175 .00493 L
.07175 0 L
.07063 0 L
s
1 0 0 r
.07203 0 m
.07203 .00513 L
.07314 .00513 L
.07314 0 L
F
0 g
.07203 0 m
.07203 .00513 L
.07314 .00513 L
.07314 0 L
.07203 0 L
s
1 0 0 r
.07342 0 m
.07342 .00614 L
.07454 .00614 L
.07454 0 L
F
0 g
.07342 0 m
.07342 .00614 L
.07454 .00614 L
.07454 0 L
.07342 0 L
s
1 0 0 r
.07482 0 m
.07482 .00352 L
.07593 .00352 L
.07593 0 L
F
0 g
.07482 0 m
.07482 .00352 L
.07593 .00352 L
.07593 0 L
.07482 0 L
s
1 0 0 r
.07621 0 m
.07621 .00231 L
.07732 .00231 L
.07732 0 L
F
0 g
.07621 0 m
.07621 .00231 L
.07732 .00231 L
.07732 0 L
.07621 0 L
s
1 0 0 r
.0776 0 m
.0776 .0065 L
.07872 .0065 L
.07872 0 L
F
0 g
.0776 0 m
.0776 .0065 L
.07872 .0065 L
.07872 0 L
.0776 0 L
s
1 0 0 r
.079 0 m
.079 .00397 L
.08011 .00397 L
.08011 0 L
F
0 g
.079 0 m
.079 .00397 L
.08011 .00397 L
.08011 0 L
.079 0 L
s
1 0 0 r
.08039 0 m
.08039 .00742 L
.0815 .00742 L
.0815 0 L
F
0 g
.08039 0 m
.08039 .00742 L
.0815 .00742 L
.0815 0 L
.08039 0 L
s
1 0 0 r
.08178 0 m
.08178 .00541 L
.0829 .00541 L
.0829 0 L
F
0 g
.08178 0 m
.08178 .00541 L
.0829 .00541 L
.0829 0 L
.08178 0 L
s
1 0 0 r
.08318 0 m
.08318 .00532 L
.08429 .00532 L
.08429 0 L
F
0 g
.08318 0 m
.08318 .00532 L
.08429 .00532 L
.08429 0 L
.08318 0 L
s
1 0 0 r
.08457 0 m
.08457 .00359 L
.08569 .00359 L
.08569 0 L
F
0 g
.08457 0 m
.08457 .00359 L
.08569 .00359 L
.08569 0 L
.08457 0 L
s
1 0 0 r
.08596 0 m
.08596 .0026 L
.08708 .0026 L
.08708 0 L
F
0 g
.08596 0 m
.08596 .0026 L
.08708 .0026 L
.08708 0 L
.08596 0 L
s
1 0 0 r
.08736 0 m
.08736 .00688 L
.08847 .00688 L
.08847 0 L
F
0 g
.08736 0 m
.08736 .00688 L
.08847 .00688 L
.08847 0 L
.08736 0 L
s
1 0 0 r
.08875 0 m
.08875 .00561 L
.08987 .00561 L
.08987 0 L
F
0 g
.08875 0 m
.08875 .00561 L
.08987 .00561 L
.08987 0 L
.08875 0 L
s
1 0 0 r
.09014 0 m
.09014 .00448 L
.09126 .00448 L
.09126 0 L
F
0 g
.09014 0 m
.09014 .00448 L
.09126 .00448 L
.09126 0 L
.09014 0 L
s
1 0 0 r
.09154 0 m
.09154 .00645 L
.09265 .00645 L
.09265 0 L
F
0 g
.09154 0 m
.09154 .00645 L
.09265 .00645 L
.09265 0 L
.09154 0 L
s
1 0 0 r
.09293 0 m
.09293 .00587 L
.09405 .00587 L
.09405 0 L
F
0 g
.09293 0 m
.09293 .00587 L
.09405 .00587 L
.09405 0 L
.09293 0 L
s
1 0 0 r
.09433 0 m
.09433 .00446 L
.09544 .00446 L
.09544 0 L
F
0 g
.09433 0 m
.09433 .00446 L
.09544 .00446 L
.09544 0 L
.09433 0 L
s
1 0 0 r
.09572 0 m
.09572 .00263 L
.09683 .00263 L
.09683 0 L
F
0 g
.09572 0 m
.09572 .00263 L
.09683 .00263 L
.09683 0 L
.09572 0 L
s
1 0 0 r
.09711 0 m
.09711 .00454 L
.09823 .00454 L
.09823 0 L
F
0 g
.09711 0 m
.09711 .00454 L
.09823 .00454 L
.09823 0 L
.09711 0 L
s
1 0 0 r
.09851 0 m
.09851 .0051 L
.09962 .0051 L
.09962 0 L
F
0 g
.09851 0 m
.09851 .0051 L
.09962 .0051 L
.09962 0 L
.09851 0 L
s
1 0 0 r
.0999 0 m
.0999 .00405 L
.10101 .00405 L
.10101 0 L
F
0 g
.0999 0 m
.0999 .00405 L
.10101 .00405 L
.10101 0 L
.0999 0 L
s
1 0 0 r
.10129 0 m
.10129 .00458 L
.10241 .00458 L
.10241 0 L
F
0 g
.10129 0 m
.10129 .00458 L
.10241 .00458 L
.10241 0 L
.10129 0 L
s
1 0 0 r
.10269 0 m
.10269 .00364 L
.1038 .00364 L
.1038 0 L
F
0 g
.10269 0 m
.10269 .00364 L
.1038 .00364 L
.1038 0 L
.10269 0 L
s
1 0 0 r
.10408 0 m
.10408 .00426 L
.1052 .00426 L
.1052 0 L
F
0 g
.10408 0 m
.10408 .00426 L
.1052 .00426 L
.1052 0 L
.10408 0 L
s
1 0 0 r
.10547 0 m
.10547 .00266 L
.10659 .00266 L
.10659 0 L
F
0 g
.10547 0 m
.10547 .00266 L
.10659 .00266 L
.10659 0 L
.10547 0 L
s
1 0 0 r
.10687 0 m
.10687 .00553 L
.10798 .00553 L
.10798 0 L
F
0 g
.10687 0 m
.10687 .00553 L
.10798 .00553 L
.10798 0 L
.10687 0 L
s
1 0 0 r
.10826 0 m
.10826 .00315 L
.10938 .00315 L
.10938 0 L
F
0 g
.10826 0 m
.10826 .00315 L
.10938 .00315 L
.10938 0 L
.10826 0 L
s
1 0 0 r
.10965 0 m
.10965 .00585 L
.11077 .00585 L
.11077 0 L
F
0 g
.10965 0 m
.10965 .00585 L
.11077 .00585 L
.11077 0 L
.10965 0 L
s
1 0 0 r
.11105 0 m
.11105 .00579 L
.11216 .00579 L
.11216 0 L
F
0 g
.11105 0 m
.11105 .00579 L
.11216 .00579 L
.11216 0 L
.11105 0 L
s
1 0 0 r
.11244 0 m
.11244 .0045 L
.11356 .0045 L
.11356 0 L
F
0 g
.11244 0 m
.11244 .0045 L
.11356 .0045 L
.11356 0 L
.11244 0 L
s
1 0 0 r
.11384 0 m
.11384 .00487 L
.11495 .00487 L
.11495 0 L
F
0 g
.11384 0 m
.11384 .00487 L
.11495 .00487 L
.11495 0 L
.11384 0 L
s
1 0 0 r
.11523 0 m
.11523 .00373 L
.11634 .00373 L
.11634 0 L
F
0 g
.11523 0 m
.11523 .00373 L
.11634 .00373 L
.11634 0 L
.11523 0 L
s
1 0 0 r
.11662 0 m
.11662 .01101 L
.11774 .01101 L
.11774 0 L
F
0 g
.11662 0 m
.11662 .01101 L
.11774 .01101 L
.11774 0 L
.11662 0 L
s
1 0 0 r
.11802 0 m
.11802 .01371 L
.11913 .01371 L
.11913 0 L
F
0 g
.11802 0 m
.11802 .01371 L
.11913 .01371 L
.11913 0 L
.11802 0 L
s
1 0 0 r
.11941 0 m
.11941 .00666 L
.12052 .00666 L
.12052 0 L
F
0 g
.11941 0 m
.11941 .00666 L
.12052 .00666 L
.12052 0 L
.11941 0 L
s
1 0 0 r
.1208 0 m
.1208 .01067 L
.12192 .01067 L
.12192 0 L
F
0 g
.1208 0 m
.1208 .01067 L
.12192 .01067 L
.12192 0 L
.1208 0 L
s
1 0 0 r
.1222 0 m
.1222 .00873 L
.12331 .00873 L
.12331 0 L
F
0 g
.1222 0 m
.1222 .00873 L
.12331 .00873 L
.12331 0 L
.1222 0 L
s
1 0 0 r
.12359 0 m
.12359 .00431 L
.12471 .00431 L
.12471 0 L
F
0 g
.12359 0 m
.12359 .00431 L
.12471 .00431 L
.12471 0 L
.12359 0 L
s
1 0 0 r
.12498 0 m
.12498 .00358 L
.1261 .00358 L
.1261 0 L
F
0 g
.12498 0 m
.12498 .00358 L
.1261 .00358 L
.1261 0 L
.12498 0 L
s
1 0 0 r
.12638 0 m
.12638 .01145 L
.12749 .01145 L
.12749 0 L
F
0 g
.12638 0 m
.12638 .01145 L
.12749 .01145 L
.12749 0 L
.12638 0 L
s
1 0 0 r
.12777 0 m
.12777 .01187 L
.12889 .01187 L
.12889 0 L
F
0 g
.12777 0 m
.12777 .01187 L
.12889 .01187 L
.12889 0 L
.12777 0 L
s
1 0 0 r
.12917 0 m
.12917 .01515 L
.13028 .01515 L
.13028 0 L
F
0 g
.12917 0 m
.12917 .01515 L
.13028 .01515 L
.13028 0 L
.12917 0 L
s
1 0 0 r
.13056 0 m
.13056 .0106 L
.13167 .0106 L
.13167 0 L
F
0 g
.13056 0 m
.13056 .0106 L
.13167 .0106 L
.13167 0 L
.13056 0 L
s
1 0 0 r
.13195 0 m
.13195 .01253 L
.13307 .01253 L
.13307 0 L
F
0 g
.13195 0 m
.13195 .01253 L
.13307 .01253 L
.13307 0 L
.13195 0 L
s
1 0 0 r
.13335 0 m
.13335 .00452 L
.13446 .00452 L
.13446 0 L
F
0 g
.13335 0 m
.13335 .00452 L
.13446 .00452 L
.13446 0 L
.13335 0 L
s
1 0 0 r
.13474 0 m
.13474 .00304 L
.13585 .00304 L
.13585 0 L
F
0 g
.13474 0 m
.13474 .00304 L
.13585 .00304 L
.13585 0 L
.13474 0 L
s
1 0 0 r
.13613 0 m
.13613 .01389 L
.13725 .01389 L
.13725 0 L
F
0 g
.13613 0 m
.13613 .01389 L
.13725 .01389 L
.13725 0 L
.13613 0 L
s
1 0 0 r
.13753 0 m
.13753 .01056 L
.13864 .01056 L
.13864 0 L
F
0 g
.13753 0 m
.13753 .01056 L
.13864 .01056 L
.13864 0 L
.13753 0 L
s
1 0 0 r
.13892 0 m
.13892 .01366 L
.14004 .01366 L
.14004 0 L
F
0 g
.13892 0 m
.13892 .01366 L
.14004 .01366 L
.14004 0 L
.13892 0 L
s
1 0 0 r
.14031 0 m
.14031 .01349 L
.14143 .01349 L
.14143 0 L
F
0 g
.14031 0 m
.14031 .01349 L
.14143 .01349 L
.14143 0 L
.14031 0 L
s
1 0 0 r
.14171 0 m
.14171 .01427 L
.14282 .01427 L
.14282 0 L
F
0 g
.14171 0 m
.14171 .01427 L
.14282 .01427 L
.14282 0 L
.14171 0 L
s
1 0 0 r
.1431 0 m
.1431 .00511 L
.14422 .00511 L
.14422 0 L
F
0 g
.1431 0 m
.1431 .00511 L
.14422 .00511 L
.14422 0 L
.1431 0 L
s
1 0 0 r
.14449 0 m
.14449 .00134 L
.14561 .00134 L
.14561 0 L
F
0 g
.14449 0 m
.14449 .00134 L
.14561 .00134 L
.14561 0 L
.14449 0 L
s
1 0 0 r
.14589 0 m
.14589 .01332 L
.147 .01332 L
.147 0 L
F
0 g
.14589 0 m
.14589 .01332 L
.147 .01332 L
.147 0 L
.14589 0 L
s
1 0 0 r
.14728 0 m
.14728 .01376 L
.1484 .01376 L
.1484 0 L
F
0 g
.14728 0 m
.14728 .01376 L
.1484 .01376 L
.1484 0 L
.14728 0 L
s
1 0 0 r
.14868 0 m
.14868 .01228 L
.14979 .01228 L
.14979 0 L
F
0 g
.14868 0 m
.14868 .01228 L
.14979 .01228 L
.14979 0 L
.14868 0 L
s
1 0 0 r
.15007 0 m
.15007 .01922 L
.15118 .01922 L
.15118 0 L
F
0 g
.15007 0 m
.15007 .01922 L
.15118 .01922 L
.15118 0 L
.15007 0 L
s
1 0 0 r
.15146 0 m
.15146 .00938 L
.15258 .00938 L
.15258 0 L
F
0 g
.15146 0 m
.15146 .00938 L
.15258 .00938 L
.15258 0 L
.15146 0 L
s
1 0 0 r
.15286 0 m
.15286 .00599 L
.15397 .00599 L
.15397 0 L
F
0 g
.15286 0 m
.15286 .00599 L
.15397 .00599 L
.15397 0 L
.15286 0 L
s
1 0 0 r
.15425 0 m
.15425 .00351 L
.15536 .00351 L
.15536 0 L
F
0 g
.15425 0 m
.15425 .00351 L
.15536 .00351 L
.15536 0 L
.15425 0 L
s
1 0 0 r
.15564 0 m
.15564 .01087 L
.15676 .01087 L
.15676 0 L
F
0 g
.15564 0 m
.15564 .01087 L
.15676 .01087 L
.15676 0 L
.15564 0 L
s
1 0 0 r
.15704 0 m
.15704 .01125 L
.15815 .01125 L
.15815 0 L
F
0 g
.15704 0 m
.15704 .01125 L
.15815 .01125 L
.15815 0 L
.15704 0 L
s
1 0 0 r
.15843 0 m
.15843 .01358 L
.15955 .01358 L
.15955 0 L
F
0 g
.15843 0 m
.15843 .01358 L
.15955 .01358 L
.15955 0 L
.15843 0 L
s
1 0 0 r
.15982 0 m
.15982 .01996 L
.16094 .01996 L
.16094 0 L
F
0 g
.15982 0 m
.15982 .01996 L
.16094 .01996 L
.16094 0 L
.15982 0 L
s
1 0 0 r
.16122 0 m
.16122 .01123 L
.16233 .01123 L
.16233 0 L
F
0 g
.16122 0 m
.16122 .01123 L
.16233 .01123 L
.16233 0 L
.16122 0 L
s
1 0 0 r
.16261 0 m
.16261 .0071 L
.16373 .0071 L
.16373 0 L
F
0 g
.16261 0 m
.16261 .0071 L
.16373 .0071 L
.16373 0 L
.16261 0 L
s
1 0 0 r
.164 0 m
.164 .00382 L
.16512 .00382 L
.16512 0 L
F
0 g
.164 0 m
.164 .00382 L
.16512 .00382 L
.16512 0 L
.164 0 L
s
1 0 0 r
.1654 0 m
.1654 .01056 L
.16651 .01056 L
.16651 0 L
F
0 g
.1654 0 m
.1654 .01056 L
.16651 .01056 L
.16651 0 L
.1654 0 L
s
1 0 0 r
.16679 0 m
.16679 .01054 L
.16791 .01054 L
.16791 0 L
F
0 g
.16679 0 m
.16679 .01054 L
.16791 .01054 L
.16791 0 L
.16679 0 L
s
1 0 0 r
.16819 0 m
.16819 .00928 L
.1693 .00928 L
.1693 0 L
F
0 g
.16819 0 m
.16819 .00928 L
.1693 .00928 L
.1693 0 L
.16819 0 L
s
1 0 0 r
.16958 0 m
.16958 .01098 L
.17069 .01098 L
.17069 0 L
F
0 g
.16958 0 m
.16958 .01098 L
.17069 .01098 L
.17069 0 L
.16958 0 L
s
1 0 0 r
.17097 0 m
.17097 .00873 L
.17209 .00873 L
.17209 0 L
F
0 g
.17097 0 m
.17097 .00873 L
.17209 .00873 L
.17209 0 L
.17097 0 L
s
1 0 0 r
.17237 0 m
.17237 .00834 L
.17348 .00834 L
.17348 0 L
F
0 g
.17237 0 m
.17237 .00834 L
.17348 .00834 L
.17348 0 L
.17237 0 L
s
1 0 0 r
.17376 0 m
.17376 .00289 L
.17487 .00289 L
.17487 0 L
F
0 g
.17376 0 m
.17376 .00289 L
.17487 .00289 L
.17487 0 L
.17376 0 L
s
1 0 0 r
.17515 0 m
.17515 .01128 L
.17627 .01128 L
.17627 0 L
F
0 g
.17515 0 m
.17515 .01128 L
.17627 .01128 L
.17627 0 L
.17515 0 L
s
1 0 0 r
.17655 0 m
.17655 .00944 L
.17766 .00944 L
.17766 0 L
F
0 g
.17655 0 m
.17655 .00944 L
.17766 .00944 L
.17766 0 L
.17655 0 L
s
1 0 0 r
.17794 0 m
.17794 .01372 L
.17906 .01372 L
.17906 0 L
F
0 g
.17794 0 m
.17794 .01372 L
.17906 .01372 L
.17906 0 L
.17794 0 L
s
1 0 0 r
.17933 0 m
.17933 .00872 L
.18045 .00872 L
.18045 0 L
F
0 g
.17933 0 m
.17933 .00872 L
.18045 .00872 L
.18045 0 L
.17933 0 L
s
1 0 0 r
.18073 0 m
.18073 .00822 L
.18184 .00822 L
.18184 0 L
F
0 g
.18073 0 m
.18073 .00822 L
.18184 .00822 L
.18184 0 L
.18073 0 L
s
1 0 0 r
.18212 0 m
.18212 .00654 L
.18324 .00654 L
.18324 0 L
F
0 g
.18212 0 m
.18212 .00654 L
.18324 .00654 L
.18324 0 L
.18212 0 L
s
1 0 0 r
.18352 0 m
.18352 .00265 L
.18463 .00265 L
.18463 0 L
F
0 g
.18352 0 m
.18352 .00265 L
.18463 .00265 L
.18463 0 L
.18352 0 L
s
1 0 0 r
.18491 0 m
.18491 .01469 L
.18602 .01469 L
.18602 0 L
F
0 g
.18491 0 m
.18491 .01469 L
.18602 .01469 L
.18602 0 L
.18491 0 L
s
1 0 0 r
.1863 0 m
.1863 .00748 L
.18742 .00748 L
.18742 0 L
F
0 g
.1863 0 m
.1863 .00748 L
.18742 .00748 L
.18742 0 L
.1863 0 L
s
1 0 0 r
.1877 0 m
.1877 .01727 L
.18881 .01727 L
.18881 0 L
F
0 g
.1877 0 m
.1877 .01727 L
.18881 .01727 L
.18881 0 L
.1877 0 L
s
1 0 0 r
.18909 0 m
.18909 .01487 L
.1902 .01487 L
.1902 0 L
F
0 g
.18909 0 m
.18909 .01487 L
.1902 .01487 L
.1902 0 L
.18909 0 L
s
1 0 0 r
.19048 0 m
.19048 .01178 L
.1916 .01178 L
.1916 0 L
F
0 g
.19048 0 m
.19048 .01178 L
.1916 .01178 L
.1916 0 L
.19048 0 L
s
1 0 0 r
.19188 0 m
.19188 .00506 L
.19299 .00506 L
.19299 0 L
F
0 g
.19188 0 m
.19188 .00506 L
.19299 .00506 L
.19299 0 L
.19188 0 L
s
1 0 0 r
.19327 0 m
.19327 .00489 L
.19439 .00489 L
.19439 0 L
F
0 g
.19327 0 m
.19327 .00489 L
.19439 .00489 L
.19439 0 L
.19327 0 L
s
1 0 0 r
.19466 0 m
.19466 .00865 L
.19578 .00865 L
.19578 0 L
F
0 g
.19466 0 m
.19466 .00865 L
.19578 .00865 L
.19578 0 L
.19466 0 L
s
1 0 0 r
.19606 0 m
.19606 .01324 L
.19717 .01324 L
.19717 0 L
F
0 g
.19606 0 m
.19606 .01324 L
.19717 .01324 L
.19717 0 L
.19606 0 L
s
1 0 0 r
.19745 0 m
.19745 .00841 L
.19857 .00841 L
.19857 0 L
F
0 g
.19745 0 m
.19745 .00841 L
.19857 .00841 L
.19857 0 L
.19745 0 L
s
1 0 0 r
.19884 0 m
.19884 .0095 L
.19996 .0095 L
.19996 0 L
F
0 g
.19884 0 m
.19884 .0095 L
.19996 .0095 L
.19996 0 L
.19884 0 L
s
1 0 0 r
.20024 0 m
.20024 .0077 L
.20135 .0077 L
.20135 0 L
F
0 g
.20024 0 m
.20024 .0077 L
.20135 .0077 L
.20135 0 L
.20024 0 L
s
1 0 0 r
.20163 0 m
.20163 .00393 L
.20275 .00393 L
.20275 0 L
F
0 g
.20163 0 m
.20163 .00393 L
.20275 .00393 L
.20275 0 L
.20163 0 L
s
1 0 0 r
.20303 0 m
.20303 .00111 L
.20414 .00111 L
.20414 0 L
F
0 g
.20303 0 m
.20303 .00111 L
.20414 .00111 L
.20414 0 L
.20303 0 L
s
1 0 0 r
.20442 0 m
.20442 .01267 L
.20553 .01267 L
.20553 0 L
F
0 g
.20442 0 m
.20442 .01267 L
.20553 .01267 L
.20553 0 L
.20442 0 L
s
1 0 0 r
.20581 0 m
.20581 .01051 L
.20693 .01051 L
.20693 0 L
F
0 g
.20581 0 m
.20581 .01051 L
.20693 .01051 L
.20693 0 L
.20581 0 L
s
1 0 0 r
.20721 0 m
.20721 .00986 L
.20832 .00986 L
.20832 0 L
F
0 g
.20721 0 m
.20721 .00986 L
.20832 .00986 L
.20832 0 L
.20721 0 L
s
1 0 0 r
.2086 0 m
.2086 .01079 L
.20971 .01079 L
.20971 0 L
F
0 g
.2086 0 m
.2086 .01079 L
.20971 .01079 L
.20971 0 L
.2086 0 L
s
1 0 0 r
.20999 0 m
.20999 .01132 L
.21111 .01132 L
.21111 0 L
F
0 g
.20999 0 m
.20999 .01132 L
.21111 .01132 L
.21111 0 L
.20999 0 L
s
1 0 0 r
.21139 0 m
.21139 .00576 L
.2125 .00576 L
.2125 0 L
F
0 g
.21139 0 m
.21139 .00576 L
.2125 .00576 L
.2125 0 L
.21139 0 L
s
1 0 0 r
.21278 0 m
.21278 .00286 L
.2139 .00286 L
.2139 0 L
F
0 g
.21278 0 m
.21278 .00286 L
.2139 .00286 L
.2139 0 L
.21278 0 L
s
1 0 0 r
.21417 0 m
.21417 .01411 L
.21529 .01411 L
.21529 0 L
F
0 g
.21417 0 m
.21417 .01411 L
.21529 .01411 L
.21529 0 L
.21417 0 L
s
1 0 0 r
.21557 0 m
.21557 .01314 L
.21668 .01314 L
.21668 0 L
F
0 g
.21557 0 m
.21557 .01314 L
.21668 .01314 L
.21668 0 L
.21557 0 L
s
1 0 0 r
.21696 0 m
.21696 .00732 L
.21808 .00732 L
.21808 0 L
F
0 g
.21696 0 m
.21696 .00732 L
.21808 .00732 L
.21808 0 L
.21696 0 L
s
1 0 0 r
.21836 0 m
.21836 .02438 L
.21947 .02438 L
.21947 0 L
F
0 g
.21836 0 m
.21836 .02438 L
.21947 .02438 L
.21947 0 L
.21836 0 L
s
1 0 0 r
.21975 0 m
.21975 .00543 L
.22086 .00543 L
.22086 0 L
F
0 g
.21975 0 m
.21975 .00543 L
.22086 .00543 L
.22086 0 L
.21975 0 L
s
1 0 0 r
.22114 0 m
.22114 .0049 L
.22226 .0049 L
.22226 0 L
F
0 g
.22114 0 m
.22114 .0049 L
.22226 .0049 L
.22226 0 L
.22114 0 L
s
1 0 0 r
.22254 0 m
.22254 .00184 L
.22365 .00184 L
.22365 0 L
F
0 g
.22254 0 m
.22254 .00184 L
.22365 .00184 L
.22365 0 L
.22254 0 L
s
1 0 0 r
.22393 0 m
.22393 .01624 L
.22504 .01624 L
.22504 0 L
F
0 g
.22393 0 m
.22393 .01624 L
.22504 .01624 L
.22504 0 L
.22393 0 L
s
1 0 0 r
.22532 0 m
.22532 .01425 L
.22644 .01425 L
.22644 0 L
F
0 g
.22532 0 m
.22532 .01425 L
.22644 .01425 L
.22644 0 L
.22532 0 L
s
1 0 0 r
.22672 0 m
.22672 .01457 L
.22783 .01457 L
.22783 0 L
F
0 g
.22672 0 m
.22672 .01457 L
.22783 .01457 L
.22783 0 L
.22672 0 L
s
1 0 0 r
.22811 0 m
.22811 .00797 L
.22923 .00797 L
.22923 0 L
F
0 g
.22811 0 m
.22811 .00797 L
.22923 .00797 L
.22923 0 L
.22811 0 L
s
1 0 0 r
.2295 0 m
.2295 .00831 L
.23062 .00831 L
.23062 0 L
F
0 g
.2295 0 m
.2295 .00831 L
.23062 .00831 L
.23062 0 L
.2295 0 L
s
1 0 0 r
.2309 0 m
.2309 .00409 L
.23201 .00409 L
.23201 0 L
F
0 g
.2309 0 m
.2309 .00409 L
.23201 .00409 L
.23201 0 L
.2309 0 L
s
1 0 0 r
.23229 0 m
.23229 .00339 L
.23341 .00339 L
.23341 0 L
F
0 g
.23229 0 m
.23229 .00339 L
.23341 .00339 L
.23341 0 L
.23229 0 L
s
1 0 0 r
.23368 0 m
.23368 .01511 L
.2348 .01511 L
.2348 0 L
F
0 g
.23368 0 m
.23368 .01511 L
.2348 .01511 L
.2348 0 L
.23368 0 L
s
1 0 0 r
.23508 0 m
.23508 .00939 L
.23619 .00939 L
.23619 0 L
F
0 g
.23508 0 m
.23508 .00939 L
.23619 .00939 L
.23619 0 L
.23508 0 L
s
1 0 0 r
.23647 0 m
.23647 .0121 L
.23759 .0121 L
.23759 0 L
F
0 g
.23647 0 m
.23647 .0121 L
.23759 .0121 L
.23759 0 L
.23647 0 L
s
1 0 0 r
.23787 0 m
.23787 .0138 L
.23898 .0138 L
.23898 0 L
F
0 g
.23787 0 m
.23787 .0138 L
.23898 .0138 L
.23898 0 L
.23787 0 L
s
1 0 0 r
.23926 0 m
.23926 .0131 L
.24037 .0131 L
.24037 0 L
F
0 g
.23926 0 m
.23926 .0131 L
.24037 .0131 L
.24037 0 L
.23926 0 L
s
1 0 0 r
.24065 0 m
.24065 .00497 L
.24177 .00497 L
.24177 0 L
F
0 g
.24065 0 m
.24065 .00497 L
.24177 .00497 L
.24177 0 L
.24065 0 L
s
1 0 0 r
.24205 0 m
.24205 .0067 L
.24316 .0067 L
.24316 0 L
F
0 g
.24205 0 m
.24205 .0067 L
.24316 .0067 L
.24316 0 L
.24205 0 L
s
1 0 0 r
.24344 0 m
.24344 .01403 L
.24455 .01403 L
.24455 0 L
F
0 g
.24344 0 m
.24344 .01403 L
.24455 .01403 L
.24455 0 L
.24344 0 L
s
1 0 0 r
.24483 0 m
.24483 .01223 L
.24595 .01223 L
.24595 0 L
F
0 g
.24483 0 m
.24483 .01223 L
.24595 .01223 L
.24595 0 L
.24483 0 L
s
1 0 0 r
.24623 0 m
.24623 .01137 L
.24734 .01137 L
.24734 0 L
F
0 g
.24623 0 m
.24623 .01137 L
.24734 .01137 L
.24734 0 L
.24623 0 L
s
1 0 0 r
.24762 0 m
.24762 .01412 L
.24874 .01412 L
.24874 0 L
F
0 g
.24762 0 m
.24762 .01412 L
.24874 .01412 L
.24874 0 L
.24762 0 L
s
1 0 0 r
.24901 0 m
.24901 .00808 L
.25013 .00808 L
.25013 0 L
F
0 g
.24901 0 m
.24901 .00808 L
.25013 .00808 L
.25013 0 L
.24901 0 L
s
1 0 0 r
.25041 0 m
.25041 .00774 L
.25152 .00774 L
.25152 0 L
F
0 g
.25041 0 m
.25041 .00774 L
.25152 .00774 L
.25152 0 L
.25041 0 L
s
1 0 0 r
.2518 0 m
.2518 .00208 L
.25292 .00208 L
.25292 0 L
F
0 g
.2518 0 m
.2518 .00208 L
.25292 .00208 L
.25292 0 L
.2518 0 L
s
1 0 0 r
.25319 0 m
.25319 .01237 L
.25431 .01237 L
.25431 0 L
F
0 g
.25319 0 m
.25319 .01237 L
.25431 .01237 L
.25431 0 L
.25319 0 L
s
1 0 0 r
.25459 0 m
.25459 .01086 L
.2557 .01086 L
.2557 0 L
F
0 g
.25459 0 m
.25459 .01086 L
.2557 .01086 L
.2557 0 L
.25459 0 L
s
1 0 0 r
.25598 0 m
.25598 .01102 L
.2571 .01102 L
.2571 0 L
F
0 g
.25598 0 m
.25598 .01102 L
.2571 .01102 L
.2571 0 L
.25598 0 L
s
1 0 0 r
.25738 0 m
.25738 .01683 L
.25849 .01683 L
.25849 0 L
F
0 g
.25738 0 m
.25738 .01683 L
.25849 .01683 L
.25849 0 L
.25738 0 L
s
1 0 0 r
.25877 0 m
.25877 .01175 L
.25988 .01175 L
.25988 0 L
F
0 g
.25877 0 m
.25877 .01175 L
.25988 .01175 L
.25988 0 L
.25877 0 L
s
1 0 0 r
.26016 0 m
.26016 .00502 L
.26128 .00502 L
.26128 0 L
F
0 g
.26016 0 m
.26016 .00502 L
.26128 .00502 L
.26128 0 L
.26016 0 L
s
1 0 0 r
.26156 0 m
.26156 .00502 L
.26267 .00502 L
.26267 0 L
F
0 g
.26156 0 m
.26156 .00502 L
.26267 .00502 L
.26267 0 L
.26156 0 L
s
1 0 0 r
.26295 0 m
.26295 .01728 L
.26406 .01728 L
.26406 0 L
F
0 g
.26295 0 m
.26295 .01728 L
.26406 .01728 L
.26406 0 L
.26295 0 L
s
1 0 0 r
.26434 0 m
.26434 .00858 L
.26546 .00858 L
.26546 0 L
F
0 g
.26434 0 m
.26434 .00858 L
.26546 .00858 L
.26546 0 L
.26434 0 L
s
1 0 0 r
.26574 0 m
.26574 .0166 L
.26685 .0166 L
.26685 0 L
F
0 g
.26574 0 m
.26574 .0166 L
.26685 .0166 L
.26685 0 L
.26574 0 L
s
1 0 0 r
.26713 0 m
.26713 .01073 L
.26825 .01073 L
.26825 0 L
F
0 g
.26713 0 m
.26713 .01073 L
.26825 .01073 L
.26825 0 L
.26713 0 L
s
1 0 0 r
.26852 0 m
.26852 .00065 L
.26964 .00065 L
.26964 0 L
F
0 g
.26852 0 m
.26852 .00065 L
.26964 .00065 L
.26964 0 L
.26852 0 L
s
1 0 0 r
.26992 0 m
.26992 .00736 L
.27103 .00736 L
.27103 0 L
F
0 g
.26992 0 m
.26992 .00736 L
.27103 .00736 L
.27103 0 L
.26992 0 L
s
1 0 0 r
.27131 0 m
.27131 .00433 L
.27243 .00433 L
.27243 0 L
F
0 g
.27131 0 m
.27131 .00433 L
.27243 .00433 L
.27243 0 L
.27131 0 L
s
1 0 0 r
.27271 0 m
.27271 .01224 L
.27382 .01224 L
.27382 0 L
F
0 g
.27271 0 m
.27271 .01224 L
.27382 .01224 L
.27382 0 L
.27271 0 L
s
1 0 0 r
.2741 0 m
.2741 .01259 L
.27521 .01259 L
.27521 0 L
F
0 g
.2741 0 m
.2741 .01259 L
.27521 .01259 L
.27521 0 L
.2741 0 L
s
1 0 0 r
.27549 0 m
.27549 .00786 L
.27661 .00786 L
.27661 0 L
F
0 g
.27549 0 m
.27549 .00786 L
.27661 .00786 L
.27661 0 L
.27549 0 L
s
1 0 0 r
.27689 0 m
.27689 .01044 L
.278 .01044 L
.278 0 L
F
0 g
.27689 0 m
.27689 .01044 L
.278 .01044 L
.278 0 L
.27689 0 L
s
1 0 0 r
.27828 0 m
.27828 .01258 L
.27939 .01258 L
.27939 0 L
F
0 g
.27828 0 m
.27828 .01258 L
.27939 .01258 L
.27939 0 L
.27828 0 L
s
1 0 0 r
.27967 0 m
.27967 .00516 L
.28079 .00516 L
.28079 0 L
F
0 g
.27967 0 m
.27967 .00516 L
.28079 .00516 L
.28079 0 L
.27967 0 L
s
1 0 0 r
.28107 0 m
.28107 .00384 L
.28218 .00384 L
.28218 0 L
F
0 g
.28107 0 m
.28107 .00384 L
.28218 .00384 L
.28218 0 L
.28107 0 L
s
1 0 0 r
.28246 0 m
.28246 .01938 L
.28358 .01938 L
.28358 0 L
F
0 g
.28246 0 m
.28246 .01938 L
.28358 .01938 L
.28358 0 L
.28246 0 L
s
1 0 0 r
.28385 0 m
.28385 .0218 L
.28497 .0218 L
.28497 0 L
F
0 g
.28385 0 m
.28385 .0218 L
.28497 .0218 L
.28497 0 L
.28385 0 L
s
1 0 0 r
.28525 0 m
.28525 .01886 L
.28636 .01886 L
.28636 0 L
F
0 g
.28525 0 m
.28525 .01886 L
.28636 .01886 L
.28636 0 L
.28525 0 L
s
1 0 0 r
.28664 0 m
.28664 .01157 L
.28776 .01157 L
.28776 0 L
F
0 g
.28664 0 m
.28664 .01157 L
.28776 .01157 L
.28776 0 L
.28664 0 L
s
1 0 0 r
.28803 0 m
.28803 .00554 L
.28915 .00554 L
.28915 0 L
F
0 g
.28803 0 m
.28803 .00554 L
.28915 .00554 L
.28915 0 L
.28803 0 L
s
1 0 0 r
.28943 0 m
.28943 .00255 L
.29054 .00255 L
.29054 0 L
F
0 g
.28943 0 m
.28943 .00255 L
.29054 .00255 L
.29054 0 L
.28943 0 L
s
1 0 0 r
.29082 0 m
.29082 .00253 L
.29194 .00253 L
.29194 0 L
F
0 g
.29082 0 m
.29082 .00253 L
.29194 .00253 L
.29194 0 L
.29082 0 L
s
1 0 0 r
.29222 0 m
.29222 .00125 L
.29333 .00125 L
.29333 0 L
F
0 g
.29222 0 m
.29222 .00125 L
.29333 .00125 L
.29333 0 L
.29222 0 L
s
1 0 0 r
.29361 0 m
.29361 .00099 L
.29472 .00099 L
.29472 0 L
F
0 g
.29361 0 m
.29361 .00099 L
.29472 .00099 L
.29472 0 L
.29361 0 L
s
1 0 0 r
.295 0 m
.295 .00859 L
.29612 .00859 L
.29612 0 L
F
0 g
.295 0 m
.295 .00859 L
.29612 .00859 L
.29612 0 L
.295 0 L
s
1 0 0 r
.2964 0 m
.2964 .00502 L
.29751 .00502 L
.29751 0 L
F
0 g
.2964 0 m
.2964 .00502 L
.29751 .00502 L
.29751 0 L
.2964 0 L
s
1 0 0 r
.29779 0 m
.29779 .00457 L
.2989 .00457 L
.2989 0 L
F
0 g
.29779 0 m
.29779 .00457 L
.2989 .00457 L
.2989 0 L
.29779 0 L
s
1 0 0 r
.29918 0 m
.29918 .00449 L
.3003 .00449 L
.3003 0 L
F
0 g
.29918 0 m
.29918 .00449 L
.3003 .00449 L
.3003 0 L
.29918 0 L
s
1 0 0 r
.30058 0 m
.30058 .00429 L
.30169 .00429 L
.30169 0 L
F
0 g
.30058 0 m
.30058 .00429 L
.30169 .00429 L
.30169 0 L
.30058 0 L
s
1 0 0 r
.30197 0 m
.30197 -0.00171 L
.30309 -0.00171 L
.30309 0 L
F
0 g
.30197 0 m
0 0 rlineto s
.30309 0 m
.30197 0 L
s
1 0 0 r
.30336 0 m
.30336 .00312 L
.30448 .00312 L
.30448 0 L
F
0 g
.30336 0 m
.30336 .00312 L
.30448 .00312 L
.30448 0 L
.30336 0 L
s
1 0 0 r
.30476 0 m
.30476 .00257 L
.30587 .00257 L
.30587 0 L
F
0 g
.30476 0 m
.30476 .00257 L
.30587 .00257 L
.30587 0 L
.30476 0 L
s
1 0 0 r
.30615 0 m
.30615 .00657 L
.30727 .00657 L
.30727 0 L
F
0 g
.30615 0 m
.30615 .00657 L
.30727 .00657 L
.30727 0 L
.30615 0 L
s
1 0 0 r
.30754 0 m
.30754 .00545 L
.30866 .00545 L
.30866 0 L
F
0 g
.30754 0 m
.30754 .00545 L
.30866 .00545 L
.30866 0 L
.30754 0 L
s
1 0 0 r
.30894 0 m
.30894 .00341 L
.31005 .00341 L
.31005 0 L
F
0 g
.30894 0 m
.30894 .00341 L
.31005 .00341 L
.31005 0 L
.30894 0 L
s
1 0 0 r
.31033 0 m
.31033 .00401 L
.31145 .00401 L
.31145 0 L
F
0 g
.31033 0 m
.31033 .00401 L
.31145 .00401 L
.31145 0 L
.31033 0 L
s
1 0 0 r
.31173 0 m
.31173 .01214 L
.31284 .01214 L
.31284 0 L
F
0 g
.31173 0 m
.31173 .01214 L
.31284 .01214 L
.31284 0 L
.31173 0 L
s
1 0 0 r
.31312 0 m
.31312 .01148 L
.31423 .01148 L
.31423 0 L
F
0 g
.31312 0 m
.31312 .01148 L
.31423 .01148 L
.31423 0 L
.31312 0 L
s
1 0 0 r
.31451 0 m
.31451 .0131 L
.31563 .0131 L
.31563 0 L
F
0 g
.31451 0 m
.31451 .0131 L
.31563 .0131 L
.31563 0 L
.31451 0 L
s
1 0 0 r
.31591 0 m
.31591 .01211 L
.31702 .01211 L
.31702 0 L
F
0 g
.31591 0 m
.31591 .01211 L
.31702 .01211 L
.31702 0 L
.31591 0 L
s
1 0 0 r
.3173 0 m
.3173 .00845 L
.31841 .00845 L
.31841 0 L
F
0 g
.3173 0 m
.3173 .00845 L
.31841 .00845 L
.31841 0 L
.3173 0 L
s
1 0 0 r
.31869 0 m
.31869 .00484 L
.31981 .00484 L
.31981 0 L
F
0 g
.31869 0 m
.31869 .00484 L
.31981 .00484 L
.31981 0 L
.31869 0 L
s
1 0 0 r
.32009 0 m
.32009 .0022 L
.3212 .0022 L
.3212 0 L
F
0 g
.32009 0 m
.32009 .0022 L
.3212 .0022 L
.3212 0 L
.32009 0 L
s
1 0 0 r
.32148 0 m
.32148 .01559 L
.3226 .01559 L
.3226 0 L
F
0 g
.32148 0 m
.32148 .01559 L
.3226 .01559 L
.3226 0 L
.32148 0 L
s
1 0 0 r
.32287 0 m
.32287 .01035 L
.32399 .01035 L
.32399 0 L
F
0 g
.32287 0 m
.32287 .01035 L
.32399 .01035 L
.32399 0 L
.32287 0 L
s
1 0 0 r
.32427 0 m
.32427 .01502 L
.32538 .01502 L
.32538 0 L
F
0 g
.32427 0 m
.32427 .01502 L
.32538 .01502 L
.32538 0 L
.32427 0 L
s
1 0 0 r
.32566 0 m
.32566 .00932 L
.32678 .00932 L
.32678 0 L
F
0 g
.32566 0 m
.32566 .00932 L
.32678 .00932 L
.32678 0 L
.32566 0 L
s
1 0 0 r
.32706 0 m
.32706 .01297 L
.32817 .01297 L
.32817 0 L
F
0 g
.32706 0 m
.32706 .01297 L
.32817 .01297 L
.32817 0 L
.32706 0 L
s
1 0 0 r
.32845 0 m
.32845 .00431 L
.32956 .00431 L
.32956 0 L
F
0 g
.32845 0 m
.32845 .00431 L
.32956 .00431 L
.32956 0 L
.32845 0 L
s
1 0 0 r
.32984 0 m
.32984 .00222 L
.33096 .00222 L
.33096 0 L
F
0 g
.32984 0 m
.32984 .00222 L
.33096 .00222 L
.33096 0 L
.32984 0 L
s
1 0 0 r
.33124 0 m
.33124 .01746 L
.33235 .01746 L
.33235 0 L
F
0 g
.33124 0 m
.33124 .01746 L
.33235 .01746 L
.33235 0 L
.33124 0 L
s
1 0 0 r
.33263 0 m
.33263 .01073 L
.33374 .01073 L
.33374 0 L
F
0 g
.33263 0 m
.33263 .01073 L
.33374 .01073 L
.33374 0 L
.33263 0 L
s
1 0 0 r
.33402 0 m
.33402 .00506 L
.33514 .00506 L
.33514 0 L
F
0 g
.33402 0 m
.33402 .00506 L
.33514 .00506 L
.33514 0 L
.33402 0 L
s
1 0 0 r
.33542 0 m
.33542 .01123 L
.33653 .01123 L
.33653 0 L
F
0 g
.33542 0 m
.33542 .01123 L
.33653 .01123 L
.33653 0 L
.33542 0 L
s
1 0 0 r
.33681 0 m
.33681 .00827 L
.33793 .00827 L
.33793 0 L
F
0 g
.33681 0 m
.33681 .00827 L
.33793 .00827 L
.33793 0 L
.33681 0 L
s
1 0 0 r
.3382 0 m
.3382 .00227 L
.33932 .00227 L
.33932 0 L
F
0 g
.3382 0 m
.3382 .00227 L
.33932 .00227 L
.33932 0 L
.3382 0 L
s
1 0 0 r
.3396 0 m
.3396 .00295 L
.34071 .00295 L
.34071 0 L
F
0 g
.3396 0 m
.3396 .00295 L
.34071 .00295 L
.34071 0 L
.3396 0 L
s
1 0 0 r
.34099 0 m
.34099 .00986 L
.34211 .00986 L
.34211 0 L
F
0 g
.34099 0 m
.34099 .00986 L
.34211 .00986 L
.34211 0 L
.34099 0 L
s
1 0 0 r
.34238 0 m
.34238 .01232 L
.3435 .01232 L
.3435 0 L
F
0 g
.34238 0 m
.34238 .01232 L
.3435 .01232 L
.3435 0 L
.34238 0 L
s
1 0 0 r
.34378 0 m
.34378 .00972 L
.34489 .00972 L
.34489 0 L
F
0 g
.34378 0 m
.34378 .00972 L
.34489 .00972 L
.34489 0 L
.34378 0 L
s
1 0 0 r
.34517 0 m
.34517 .00697 L
.34629 .00697 L
.34629 0 L
F
0 g
.34517 0 m
.34517 .00697 L
.34629 .00697 L
.34629 0 L
.34517 0 L
s
1 0 0 r
.34657 0 m
.34657 .01513 L
.34768 .01513 L
.34768 0 L
F
0 g
.34657 0 m
.34657 .01513 L
.34768 .01513 L
.34768 0 L
.34657 0 L
s
1 0 0 r
.34796 0 m
.34796 .00502 L
.34907 .00502 L
.34907 0 L
F
0 g
.34796 0 m
.34796 .00502 L
.34907 .00502 L
.34907 0 L
.34796 0 L
s
1 0 0 r
.34935 0 m
.34935 .00486 L
.35047 .00486 L
.35047 0 L
F
0 g
.34935 0 m
.34935 .00486 L
.35047 .00486 L
.35047 0 L
.34935 0 L
s
1 0 0 r
.35075 0 m
.35075 .01527 L
.35186 .01527 L
.35186 0 L
F
0 g
.35075 0 m
.35075 .01527 L
.35186 .01527 L
.35186 0 L
.35075 0 L
s
1 0 0 r
.35214 0 m
.35214 .00837 L
.35325 .00837 L
.35325 0 L
F
0 g
.35214 0 m
.35214 .00837 L
.35325 .00837 L
.35325 0 L
.35214 0 L
s
1 0 0 r
.35353 0 m
.35353 .00973 L
.35465 .00973 L
.35465 0 L
F
0 g
.35353 0 m
.35353 .00973 L
.35465 .00973 L
.35465 0 L
.35353 0 L
s
1 0 0 r
.35493 0 m
.35493 .0093 L
.35604 .0093 L
.35604 0 L
F
0 g
.35493 0 m
.35493 .0093 L
.35604 .0093 L
.35604 0 L
.35493 0 L
s
1 0 0 r
.35632 0 m
.35632 .00868 L
.35744 .00868 L
.35744 0 L
F
0 g
.35632 0 m
.35632 .00868 L
.35744 .00868 L
.35744 0 L
.35632 0 L
s
1 0 0 r
.35771 0 m
.35771 .00567 L
.35883 .00567 L
.35883 0 L
F
0 g
.35771 0 m
.35771 .00567 L
.35883 .00567 L
.35883 0 L
.35771 0 L
s
1 0 0 r
.35911 0 m
.35911 .00327 L
.36022 .00327 L
.36022 0 L
F
0 g
.35911 0 m
.35911 .00327 L
.36022 .00327 L
.36022 0 L
.35911 0 L
s
1 0 0 r
.3605 0 m
.3605 .00807 L
.36162 .00807 L
.36162 0 L
F
0 g
.3605 0 m
.3605 .00807 L
.36162 .00807 L
.36162 0 L
.3605 0 L
s
1 0 0 r
.3619 0 m
.3619 .00574 L
.36301 .00574 L
.36301 0 L
F
0 g
.3619 0 m
.3619 .00574 L
.36301 .00574 L
.36301 0 L
.3619 0 L
s
1 0 0 r
.36329 0 m
.36329 .00489 L
.3644 .00489 L
.3644 0 L
F
0 g
.36329 0 m
.36329 .00489 L
.3644 .00489 L
.3644 0 L
.36329 0 L
s
1 0 0 r
.36468 0 m
.36468 .0092 L
.3658 .0092 L
.3658 0 L
F
0 g
.36468 0 m
.36468 .0092 L
.3658 .0092 L
.3658 0 L
.36468 0 L
s
1 0 0 r
.36608 0 m
.36608 .00608 L
.36719 .00608 L
.36719 0 L
F
0 g
.36608 0 m
.36608 .00608 L
.36719 .00608 L
.36719 0 L
.36608 0 L
s
1 0 0 r
.36747 0 m
.36747 .00202 L
.36858 .00202 L
.36858 0 L
F
0 g
.36747 0 m
.36747 .00202 L
.36858 .00202 L
.36858 0 L
.36747 0 L
s
1 0 0 r
.36886 0 m
.36886 .00427 L
.36998 .00427 L
.36998 0 L
F
0 g
.36886 0 m
.36886 .00427 L
.36998 .00427 L
.36998 0 L
.36886 0 L
s
1 0 0 r
.37026 0 m
.37026 .00741 L
.37137 .00741 L
.37137 0 L
F
0 g
.37026 0 m
.37026 .00741 L
.37137 .00741 L
.37137 0 L
.37026 0 L
s
1 0 0 r
.37165 0 m
.37165 .0075 L
.37277 .0075 L
.37277 0 L
F
0 g
.37165 0 m
.37165 .0075 L
.37277 .0075 L
.37277 0 L
.37165 0 L
s
1 0 0 r
.37304 0 m
.37304 .00569 L
.37416 .00569 L
.37416 0 L
F
0 g
.37304 0 m
.37304 .00569 L
.37416 .00569 L
.37416 0 L
.37304 0 L
s
1 0 0 r
.37444 0 m
.37444 .00497 L
.37555 .00497 L
.37555 0 L
F
0 g
.37444 0 m
.37444 .00497 L
.37555 .00497 L
.37555 0 L
.37444 0 L
s
1 0 0 r
.37583 0 m
.37583 .00848 L
.37695 .00848 L
.37695 0 L
F
0 g
.37583 0 m
.37583 .00848 L
.37695 .00848 L
.37695 0 L
.37583 0 L
s
1 0 0 r
.37722 0 m
.37722 .00528 L
.37834 .00528 L
.37834 0 L
F
0 g
.37722 0 m
.37722 .00528 L
.37834 .00528 L
.37834 0 L
.37722 0 L
s
1 0 0 r
.37862 0 m
.37862 .00191 L
.37973 .00191 L
.37973 0 L
F
0 g
.37862 0 m
.37862 .00191 L
.37973 .00191 L
.37973 0 L
.37862 0 L
s
1 0 0 r
.38001 0 m
.38001 .01056 L
.38113 .01056 L
.38113 0 L
F
0 g
.38001 0 m
.38001 .01056 L
.38113 .01056 L
.38113 0 L
.38001 0 L
s
1 0 0 r
.38141 0 m
.38141 .01537 L
.38252 .01537 L
.38252 0 L
F
0 g
.38141 0 m
.38141 .01537 L
.38252 .01537 L
.38252 0 L
.38141 0 L
s
1 0 0 r
.3828 0 m
.3828 .01076 L
.38391 .01076 L
.38391 0 L
F
0 g
.3828 0 m
.3828 .01076 L
.38391 .01076 L
.38391 0 L
.3828 0 L
s
1 0 0 r
.38419 0 m
.38419 .02133 L
.38531 .02133 L
.38531 0 L
F
0 g
.38419 0 m
.38419 .02133 L
.38531 .02133 L
.38531 0 L
.38419 0 L
s
1 0 0 r
.38559 0 m
.38559 .00722 L
.3867 .00722 L
.3867 0 L
F
0 g
.38559 0 m
.38559 .00722 L
.3867 .00722 L
.3867 0 L
.38559 0 L
s
1 0 0 r
.38698 0 m
.38698 .00481 L
.38809 .00481 L
.38809 0 L
F
0 g
.38698 0 m
.38698 .00481 L
.38809 .00481 L
.38809 0 L
.38698 0 L
s
1 0 0 r
.38837 0 m
.38837 .00257 L
.38949 .00257 L
.38949 0 L
F
0 g
.38837 0 m
.38837 .00257 L
.38949 .00257 L
.38949 0 L
.38837 0 L
s
1 0 0 r
.38977 0 m
.38977 .01421 L
.39088 .01421 L
.39088 0 L
F
0 g
.38977 0 m
.38977 .01421 L
.39088 .01421 L
.39088 0 L
.38977 0 L
s
1 0 0 r
.39116 0 m
.39116 .01811 L
.39228 .01811 L
.39228 0 L
F
0 g
.39116 0 m
.39116 .01811 L
.39228 .01811 L
.39228 0 L
.39116 0 L
s
1 0 0 r
.39255 0 m
.39255 .01237 L
.39367 .01237 L
.39367 0 L
F
0 g
.39255 0 m
.39255 .01237 L
.39367 .01237 L
.39367 0 L
.39255 0 L
s
1 0 0 r
.39395 0 m
.39395 .00953 L
.39506 .00953 L
.39506 0 L
F
0 g
.39395 0 m
.39395 .00953 L
.39506 .00953 L
.39506 0 L
.39395 0 L
s
1 0 0 r
.39534 0 m
.39534 .00168 L
.39646 .00168 L
.39646 0 L
F
0 g
.39534 0 m
.39534 .00168 L
.39646 .00168 L
.39646 0 L
.39534 0 L
s
1 0 0 r
.39673 0 m
.39673 .00227 L
.39785 .00227 L
.39785 0 L
F
0 g
.39673 0 m
.39673 .00227 L
.39785 .00227 L
.39785 0 L
.39673 0 L
s
1 0 0 r
.39813 0 m
.39813 .00322 L
.39924 .00322 L
.39924 0 L
F
0 g
.39813 0 m
.39813 .00322 L
.39924 .00322 L
.39924 0 L
.39813 0 L
s
1 0 0 r
.39952 0 m
.39952 .00723 L
.40064 .00723 L
.40064 0 L
F
0 g
.39952 0 m
.39952 .00723 L
.40064 .00723 L
.40064 0 L
.39952 0 L
s
1 0 0 r
.40092 0 m
.40092 .00146 L
.40203 .00146 L
.40203 0 L
F
0 g
.40092 0 m
.40092 .00146 L
.40203 .00146 L
.40203 0 L
.40092 0 L
s
1 0 0 r
.40231 0 m
.40231 .00429 L
.40342 .00429 L
.40342 0 L
F
0 g
.40231 0 m
.40231 .00429 L
.40342 .00429 L
.40342 0 L
.40231 0 L
s
1 0 0 r
.4037 0 m
.4037 .00476 L
.40482 .00476 L
.40482 0 L
F
0 g
.4037 0 m
.4037 .00476 L
.40482 .00476 L
.40482 0 L
.4037 0 L
s
1 0 0 r
.4051 0 m
.4051 .00354 L
.40621 .00354 L
.40621 0 L
F
0 g
.4051 0 m
.4051 .00354 L
.40621 .00354 L
.40621 0 L
.4051 0 L
s
1 0 0 r
.40649 0 m
.40649 .00272 L
.4076 .00272 L
.4076 0 L
F
0 g
.40649 0 m
.40649 .00272 L
.4076 .00272 L
.4076 0 L
.40649 0 L
s
1 0 0 r
.40788 0 m
.40788 .00406 L
.409 .00406 L
.409 0 L
F
0 g
.40788 0 m
.40788 .00406 L
.409 .00406 L
.409 0 L
.40788 0 L
s
1 0 0 r
.40928 0 m
.40928 .00539 L
.41039 .00539 L
.41039 0 L
F
0 g
.40928 0 m
.40928 .00539 L
.41039 .00539 L
.41039 0 L
.40928 0 L
s
1 0 0 r
.41067 0 m
.41067 .00641 L
.41179 .00641 L
.41179 0 L
F
0 g
.41067 0 m
.41067 .00641 L
.41179 .00641 L
.41179 0 L
.41067 0 L
s
1 0 0 r
.41206 0 m
.41206 .00149 L
.41318 .00149 L
.41318 0 L
F
0 g
.41206 0 m
.41206 .00149 L
.41318 .00149 L
.41318 0 L
.41206 0 L
s
1 0 0 r
.41346 0 m
.41346 .00652 L
.41457 .00652 L
.41457 0 L
F
0 g
.41346 0 m
.41346 .00652 L
.41457 .00652 L
.41457 0 L
.41346 0 L
s
1 0 0 r
.41485 0 m
.41485 .00311 L
.41597 .00311 L
.41597 0 L
F
0 g
.41485 0 m
.41485 .00311 L
.41597 .00311 L
.41597 0 L
.41485 0 L
s
1 0 0 r
.41625 0 m
.41625 .00438 L
.41736 .00438 L
.41736 0 L
F
0 g
.41625 0 m
.41625 .00438 L
.41736 .00438 L
.41736 0 L
.41625 0 L
s
1 0 0 r
.41764 0 m
.41764 7e-005 L
.41875 7e-005 L
.41875 0 L
F
0 g
.41764 0 m
.41764 7e-005 L
.41875 7e-005 L
.41875 0 L
.41764 0 L
s
1 0 0 r
.41903 0 m
.41903 .00783 L
.42015 .00783 L
.42015 0 L
F
0 g
.41903 0 m
.41903 .00783 L
.42015 .00783 L
.42015 0 L
.41903 0 L
s
1 0 0 r
.42043 0 m
.42043 .00519 L
.42154 .00519 L
.42154 0 L
F
0 g
.42043 0 m
.42043 .00519 L
.42154 .00519 L
.42154 0 L
.42043 0 L
s
1 0 0 r
.42182 0 m
.42182 .00268 L
.42293 .00268 L
.42293 0 L
F
0 g
.42182 0 m
.42182 .00268 L
.42293 .00268 L
.42293 0 L
.42182 0 L
s
1 0 0 r
.42321 0 m
.42321 .00402 L
.42433 .00402 L
.42433 0 L
F
0 g
.42321 0 m
.42321 .00402 L
.42433 .00402 L
.42433 0 L
.42321 0 L
s
1 0 0 r
.42461 0 m
.42461 .00609 L
.42572 .00609 L
.42572 0 L
F
0 g
.42461 0 m
.42461 .00609 L
.42572 .00609 L
.42572 0 L
.42461 0 L
s
1 0 0 r
.426 0 m
.426 .00116 L
.42712 .00116 L
.42712 0 L
F
0 g
.426 0 m
.426 .00116 L
.42712 .00116 L
.42712 0 L
.426 0 L
s
1 0 0 r
.42739 0 m
.42739 .00188 L
.42851 .00188 L
.42851 0 L
F
0 g
.42739 0 m
.42739 .00188 L
.42851 .00188 L
.42851 0 L
.42739 0 L
s
1 0 0 r
.42879 0 m
.42879 .01255 L
.4299 .01255 L
.4299 0 L
F
0 g
.42879 0 m
.42879 .01255 L
.4299 .01255 L
.4299 0 L
.42879 0 L
s
1 0 0 r
.43018 0 m
.43018 .00591 L
.4313 .00591 L
.4313 0 L
F
0 g
.43018 0 m
.43018 .00591 L
.4313 .00591 L
.4313 0 L
.43018 0 L
s
1 0 0 r
.43157 0 m
.43157 .00268 L
.43269 .00268 L
.43269 0 L
F
0 g
.43157 0 m
.43157 .00268 L
.43269 .00268 L
.43269 0 L
.43157 0 L
s
1 0 0 r
.43297 0 m
.43297 .00699 L
.43408 .00699 L
.43408 0 L
F
0 g
.43297 0 m
.43297 .00699 L
.43408 .00699 L
.43408 0 L
.43297 0 L
s
1 0 0 r
.43436 0 m
.43436 .00714 L
.43548 .00714 L
.43548 0 L
F
0 g
.43436 0 m
.43436 .00714 L
.43548 .00714 L
.43548 0 L
.43436 0 L
s
1 0 0 r
.43576 0 m
.43576 .00271 L
.43687 .00271 L
.43687 0 L
F
0 g
.43576 0 m
.43576 .00271 L
.43687 .00271 L
.43687 0 L
.43576 0 L
s
1 0 0 r
.43715 0 m
.43715 9e-005 L
.43826 9e-005 L
.43826 0 L
F
0 g
.43715 0 m
.43715 9e-005 L
.43826 9e-005 L
.43826 0 L
.43715 0 L
s
1 0 0 r
.43854 0 m
.43854 .00581 L
.43966 .00581 L
.43966 0 L
F
0 g
.43854 0 m
.43854 .00581 L
.43966 .00581 L
.43966 0 L
.43854 0 L
s
1 0 0 r
.43994 0 m
.43994 .00591 L
.44105 .00591 L
.44105 0 L
F
0 g
.43994 0 m
.43994 .00591 L
.44105 .00591 L
.44105 0 L
.43994 0 L
s
1 0 0 r
.44133 0 m
.44133 .00994 L
.44244 .00994 L
.44244 0 L
F
0 g
.44133 0 m
.44133 .00994 L
.44244 .00994 L
.44244 0 L
.44133 0 L
s
1 0 0 r
.44272 0 m
.44272 .0027 L
.44384 .0027 L
.44384 0 L
F
0 g
.44272 0 m
.44272 .0027 L
.44384 .0027 L
.44384 0 L
.44272 0 L
s
1 0 0 r
.44412 0 m
.44412 -0.00047 L
.44523 -0.00047 L
.44523 0 L
F
0 g
.44412 0 m
0 0 rlineto s
.44523 0 m
.44412 0 L
s
1 0 0 r
.44551 0 m
.44551 .00358 L
.44663 .00358 L
.44663 0 L
F
0 g
.44551 0 m
.44551 .00358 L
.44663 .00358 L
.44663 0 L
.44551 0 L
s
1 0 0 r
.4469 0 m
.4469 .00328 L
.44802 .00328 L
.44802 0 L
F
0 g
.4469 0 m
.4469 .00328 L
.44802 .00328 L
.44802 0 L
.4469 0 L
s
1 0 0 r
.4483 0 m
.4483 .00085 L
.44941 .00085 L
.44941 0 L
F
0 g
.4483 0 m
.4483 .00085 L
.44941 .00085 L
.44941 0 L
.4483 0 L
s
1 0 0 r
.44969 0 m
.44969 .01281 L
.45081 .01281 L
.45081 0 L
F
0 g
.44969 0 m
.44969 .01281 L
.45081 .01281 L
.45081 0 L
.44969 0 L
s
1 0 0 r
.45108 0 m
.45108 .01194 L
.4522 .01194 L
.4522 0 L
F
0 g
.45108 0 m
.45108 .01194 L
.4522 .01194 L
.4522 0 L
.45108 0 L
s
1 0 0 r
.45248 0 m
.45248 .02125 L
.45359 .02125 L
.45359 0 L
F
0 g
.45248 0 m
.45248 .02125 L
.45359 .02125 L
.45359 0 L
.45248 0 L
s
1 0 0 r
.45387 0 m
.45387 .01273 L
.45499 .01273 L
.45499 0 L
F
0 g
.45387 0 m
.45387 .01273 L
.45499 .01273 L
.45499 0 L
.45387 0 L
s
1 0 0 r
.45527 0 m
.45527 .00321 L
.45638 .00321 L
.45638 0 L
F
0 g
.45527 0 m
.45527 .00321 L
.45638 .00321 L
.45638 0 L
.45527 0 L
s
1 0 0 r
.45666 0 m
.45666 .00166 L
.45777 .00166 L
.45777 0 L
F
0 g
.45666 0 m
.45666 .00166 L
.45777 .00166 L
.45777 0 L
.45666 0 L
s
1 0 0 r
.45805 0 m
.45805 .02615 L
.45917 .02615 L
.45917 0 L
F
0 g
.45805 0 m
.45805 .02615 L
.45917 .02615 L
.45917 0 L
.45805 0 L
s
1 0 0 r
.45945 0 m
.45945 .01337 L
.46056 .01337 L
.46056 0 L
F
0 g
.45945 0 m
.45945 .01337 L
.46056 .01337 L
.46056 0 L
.45945 0 L
s
1 0 0 r
.46084 0 m
.46084 .00864 L
.46195 .00864 L
.46195 0 L
F
0 g
.46084 0 m
.46084 .00864 L
.46195 .00864 L
.46195 0 L
.46084 0 L
s
1 0 0 r
.46223 0 m
.46223 .0092 L
.46335 .0092 L
.46335 0 L
F
0 g
.46223 0 m
.46223 .0092 L
.46335 .0092 L
.46335 0 L
.46223 0 L
s
1 0 0 r
.46363 0 m
.46363 .01466 L
.46474 .01466 L
.46474 0 L
F
0 g
.46363 0 m
.46363 .01466 L
.46474 .01466 L
.46474 0 L
.46363 0 L
s
1 0 0 r
.46502 0 m
.46502 .00255 L
.46614 .00255 L
.46614 0 L
F
0 g
.46502 0 m
.46502 .00255 L
.46614 .00255 L
.46614 0 L
.46502 0 L
s
1 0 0 r
.46641 0 m
.46641 .00246 L
.46753 .00246 L
.46753 0 L
F
0 g
.46641 0 m
.46641 .00246 L
.46753 .00246 L
.46753 0 L
.46641 0 L
s
1 0 0 r
.46781 0 m
.46781 .00596 L
.46892 .00596 L
.46892 0 L
F
0 g
.46781 0 m
.46781 .00596 L
.46892 .00596 L
.46892 0 L
.46781 0 L
s
1 0 0 r
.4692 0 m
.4692 -0.00197 L
.47032 -0.00197 L
.47032 0 L
F
0 g
.4692 0 m
0 0 rlineto s
.47032 0 m
.4692 0 L
s
1 0 0 r
.4706 0 m
.4706 .02244 L
.47171 .02244 L
.47171 0 L
F
0 g
.4706 0 m
.4706 .02244 L
.47171 .02244 L
.47171 0 L
.4706 0 L
s
1 0 0 r
.47199 0 m
.47199 .00693 L
.4731 .00693 L
.4731 0 L
F
0 g
.47199 0 m
.47199 .00693 L
.4731 .00693 L
.4731 0 L
.47199 0 L
s
1 0 0 r
.47338 0 m
.47338 .00732 L
.4745 .00732 L
.4745 0 L
F
0 g
.47338 0 m
.47338 .00732 L
.4745 .00732 L
.4745 0 L
.47338 0 L
s
1 0 0 r
.47478 0 m
.47478 .00176 L
.47589 .00176 L
.47589 0 L
F
0 g
.47478 0 m
.47478 .00176 L
.47589 .00176 L
.47589 0 L
.47478 0 L
s
1 0 0 r
.47617 0 m
.47617 .00363 L
.47728 .00363 L
.47728 0 L
F
0 g
.47617 0 m
.47617 .00363 L
.47728 .00363 L
.47728 0 L
.47617 0 L
s
1 0 0 r
.47756 0 m
.47756 .01383 L
.47868 .01383 L
.47868 0 L
F
0 g
.47756 0 m
.47756 .01383 L
.47868 .01383 L
.47868 0 L
.47756 0 L
s
1 0 0 r
.47896 0 m
.47896 .00757 L
.48007 .00757 L
.48007 0 L
F
0 g
.47896 0 m
.47896 .00757 L
.48007 .00757 L
.48007 0 L
.47896 0 L
s
1 0 0 r
.48035 0 m
.48035 .00612 L
.48147 .00612 L
.48147 0 L
F
0 g
.48035 0 m
.48035 .00612 L
.48147 .00612 L
.48147 0 L
.48035 0 L
s
1 0 0 r
.48174 0 m
.48174 .01086 L
.48286 .01086 L
.48286 0 L
F
0 g
.48174 0 m
.48174 .01086 L
.48286 .01086 L
.48286 0 L
.48174 0 L
s
1 0 0 r
.48314 0 m
.48314 .00716 L
.48425 .00716 L
.48425 0 L
F
0 g
.48314 0 m
.48314 .00716 L
.48425 .00716 L
.48425 0 L
.48314 0 L
s
1 0 0 r
.48453 0 m
.48453 .00668 L
.48565 .00668 L
.48565 0 L
F
0 g
.48453 0 m
.48453 .00668 L
.48565 .00668 L
.48565 0 L
.48453 0 L
s
1 0 0 r
.48592 0 m
.48592 .00386 L
.48704 .00386 L
.48704 0 L
F
0 g
.48592 0 m
.48592 .00386 L
.48704 .00386 L
.48704 0 L
.48592 0 L
s
1 0 0 r
.48732 0 m
.48732 .01484 L
.48843 .01484 L
.48843 0 L
F
0 g
.48732 0 m
.48732 .01484 L
.48843 .01484 L
.48843 0 L
.48732 0 L
s
1 0 0 r
.48871 0 m
.48871 .01097 L
.48983 .01097 L
.48983 0 L
F
0 g
.48871 0 m
.48871 .01097 L
.48983 .01097 L
.48983 0 L
.48871 0 L
s
1 0 0 r
.49011 0 m
.49011 .01479 L
.49122 .01479 L
.49122 0 L
F
0 g
.49011 0 m
.49011 .01479 L
.49122 .01479 L
.49122 0 L
.49011 0 L
s
1 0 0 r
.4915 0 m
.4915 .00848 L
.49261 .00848 L
.49261 0 L
F
0 g
.4915 0 m
.4915 .00848 L
.49261 .00848 L
.49261 0 L
.4915 0 L
s
1 0 0 r
.49289 0 m
.49289 .01031 L
.49401 .01031 L
.49401 0 L
F
0 g
.49289 0 m
.49289 .01031 L
.49401 .01031 L
.49401 0 L
.49289 0 L
s
1 0 0 r
.49429 0 m
.49429 .00356 L
.4954 .00356 L
.4954 0 L
F
0 g
.49429 0 m
.49429 .00356 L
.4954 .00356 L
.4954 0 L
.49429 0 L
s
1 0 0 r
.49568 0 m
.49568 .00286 L
.49679 .00286 L
.49679 0 L
F
0 g
.49568 0 m
.49568 .00286 L
.49679 .00286 L
.49679 0 L
.49568 0 L
s
1 0 0 r
.49707 0 m
.49707 .02247 L
.49819 .02247 L
.49819 0 L
F
0 g
.49707 0 m
.49707 .02247 L
.49819 .02247 L
.49819 0 L
.49707 0 L
s
1 0 0 r
.49847 0 m
.49847 .01761 L
.49958 .01761 L
.49958 0 L
F
0 g
.49847 0 m
.49847 .01761 L
.49958 .01761 L
.49958 0 L
.49847 0 L
s
1 0 0 r
.49986 0 m
.49986 .00992 L
.50098 .00992 L
.50098 0 L
F
0 g
.49986 0 m
.49986 .00992 L
.50098 .00992 L
.50098 0 L
.49986 0 L
s
1 0 0 r
.50125 0 m
.50125 .00296 L
.50237 .00296 L
.50237 0 L
F
0 g
.50125 0 m
.50125 .00296 L
.50237 .00296 L
.50237 0 L
.50125 0 L
s
1 0 0 r
.50265 0 m
.50265 .00617 L
.50376 .00617 L
.50376 0 L
F
0 g
.50265 0 m
.50265 .00617 L
.50376 .00617 L
.50376 0 L
.50265 0 L
s
1 0 0 r
.50404 0 m
.50404 .00461 L
.50516 .00461 L
.50516 0 L
F
0 g
.50404 0 m
.50404 .00461 L
.50516 .00461 L
.50516 0 L
.50404 0 L
s
1 0 0 r
.50544 0 m
.50544 .00367 L
.50655 .00367 L
.50655 0 L
F
0 g
.50544 0 m
.50544 .00367 L
.50655 .00367 L
.50655 0 L
.50544 0 L
s
1 0 0 r
.50683 0 m
.50683 .01546 L
.50794 .01546 L
.50794 0 L
F
0 g
.50683 0 m
.50683 .01546 L
.50794 .01546 L
.50794 0 L
.50683 0 L
s
1 0 0 r
.50822 0 m
.50822 .01583 L
.50934 .01583 L
.50934 0 L
F
0 g
.50822 0 m
.50822 .01583 L
.50934 .01583 L
.50934 0 L
.50822 0 L
s
1 0 0 r
.50962 0 m
.50962 .01633 L
.51073 .01633 L
.51073 0 L
F
0 g
.50962 0 m
.50962 .01633 L
.51073 .01633 L
.51073 0 L
.50962 0 L
s
1 0 0 r
.51101 0 m
.51101 .02052 L
.51212 .02052 L
.51212 0 L
F
0 g
.51101 0 m
.51101 .02052 L
.51212 .02052 L
.51212 0 L
.51101 0 L
s
1 0 0 r
.5124 0 m
.5124 .00664 L
.51352 .00664 L
.51352 0 L
F
0 g
.5124 0 m
.5124 .00664 L
.51352 .00664 L
.51352 0 L
.5124 0 L
s
1 0 0 r
.5138 0 m
.5138 .00489 L
.51491 .00489 L
.51491 0 L
F
0 g
.5138 0 m
.5138 .00489 L
.51491 .00489 L
.51491 0 L
.5138 0 L
s
1 0 0 r
.51519 0 m
.51519 .00303 L
.51631 .00303 L
.51631 0 L
F
0 g
.51519 0 m
.51519 .00303 L
.51631 .00303 L
.51631 0 L
.51519 0 L
s
1 0 0 r
.51658 0 m
.51658 .00565 L
.5177 .00565 L
.5177 0 L
F
0 g
.51658 0 m
.51658 .00565 L
.5177 .00565 L
.5177 0 L
.51658 0 L
s
1 0 0 r
.51798 0 m
.51798 .01852 L
.51909 .01852 L
.51909 0 L
F
0 g
.51798 0 m
.51798 .01852 L
.51909 .01852 L
.51909 0 L
.51798 0 L
s
1 0 0 r
.51937 0 m
.51937 .02089 L
.52049 .02089 L
.52049 0 L
F
0 g
.51937 0 m
.51937 .02089 L
.52049 .02089 L
.52049 0 L
.51937 0 L
s
1 0 0 r
.52076 0 m
.52076 .00963 L
.52188 .00963 L
.52188 0 L
F
0 g
.52076 0 m
.52076 .00963 L
.52188 .00963 L
.52188 0 L
.52076 0 L
s
1 0 0 r
.52216 0 m
.52216 .0137 L
.52327 .0137 L
.52327 0 L
F
0 g
.52216 0 m
.52216 .0137 L
.52327 .0137 L
.52327 0 L
.52216 0 L
s
1 0 0 r
.52355 0 m
.52355 .01241 L
.52467 .01241 L
.52467 0 L
F
0 g
.52355 0 m
.52355 .01241 L
.52467 .01241 L
.52467 0 L
.52355 0 L
s
1 0 0 r
.52495 0 m
.52495 .00529 L
.52606 .00529 L
.52606 0 L
F
0 g
.52495 0 m
.52495 .00529 L
.52606 .00529 L
.52606 0 L
.52495 0 L
s
1 0 0 r
.52634 0 m
.52634 .01447 L
.52745 .01447 L
.52745 0 L
F
0 g
.52634 0 m
.52634 .01447 L
.52745 .01447 L
.52745 0 L
.52634 0 L
s
1 0 0 r
.52773 0 m
.52773 .01414 L
.52885 .01414 L
.52885 0 L
F
0 g
.52773 0 m
.52773 .01414 L
.52885 .01414 L
.52885 0 L
.52773 0 L
s
1 0 0 r
.52913 0 m
.52913 .02394 L
.53024 .02394 L
.53024 0 L
F
0 g
.52913 0 m
.52913 .02394 L
.53024 .02394 L
.53024 0 L
.52913 0 L
s
1 0 0 r
.53052 0 m
.53052 .00988 L
.53163 .00988 L
.53163 0 L
F
0 g
.53052 0 m
.53052 .00988 L
.53163 .00988 L
.53163 0 L
.53052 0 L
s
1 0 0 r
.53191 0 m
.53191 .00747 L
.53303 .00747 L
.53303 0 L
F
0 g
.53191 0 m
.53191 .00747 L
.53303 .00747 L
.53303 0 L
.53191 0 L
s
1 0 0 r
.53331 0 m
.53331 .01097 L
.53442 .01097 L
.53442 0 L
F
0 g
.53331 0 m
.53331 .01097 L
.53442 .01097 L
.53442 0 L
.53331 0 L
s
1 0 0 r
.5347 0 m
.5347 .00422 L
.53582 .00422 L
.53582 0 L
F
0 g
.5347 0 m
.5347 .00422 L
.53582 .00422 L
.53582 0 L
.5347 0 L
s
1 0 0 r
.53609 0 m
.53609 .0206 L
.53721 .0206 L
.53721 0 L
F
0 g
.53609 0 m
.53609 .0206 L
.53721 .0206 L
.53721 0 L
.53609 0 L
s
1 0 0 r
.53749 0 m
.53749 .01477 L
.5386 .01477 L
.5386 0 L
F
0 g
.53749 0 m
.53749 .01477 L
.5386 .01477 L
.5386 0 L
.53749 0 L
s
1 0 0 r
.53888 0 m
.53888 .01938 L
.54 .01938 L
.54 0 L
F
0 g
.53888 0 m
.53888 .01938 L
.54 .01938 L
.54 0 L
.53888 0 L
s
1 0 0 r
.54027 0 m
.54027 .0163 L
.54139 .0163 L
.54139 0 L
F
0 g
.54027 0 m
.54027 .0163 L
.54139 .0163 L
.54139 0 L
.54027 0 L
s
1 0 0 r
.54167 0 m
.54167 .0124 L
.54278 .0124 L
.54278 0 L
F
0 g
.54167 0 m
.54167 .0124 L
.54278 .0124 L
.54278 0 L
.54167 0 L
s
1 0 0 r
.54306 0 m
.54306 .00507 L
.54418 .00507 L
.54418 0 L
F
0 g
.54306 0 m
.54306 .00507 L
.54418 .00507 L
.54418 0 L
.54306 0 L
s
1 0 0 r
.54446 0 m
.54446 .00524 L
.54557 .00524 L
.54557 0 L
F
0 g
.54446 0 m
.54446 .00524 L
.54557 .00524 L
.54557 0 L
.54446 0 L
s
1 0 0 r
.54585 0 m
.54585 .01606 L
.54696 .01606 L
.54696 0 L
F
0 g
.54585 0 m
.54585 .01606 L
.54696 .01606 L
.54696 0 L
.54585 0 L
s
1 0 0 r
.54724 0 m
.54724 .01939 L
.54836 .01939 L
.54836 0 L
F
0 g
.54724 0 m
.54724 .01939 L
.54836 .01939 L
.54836 0 L
.54724 0 L
s
1 0 0 r
.54864 0 m
.54864 .01549 L
.54975 .01549 L
.54975 0 L
F
0 g
.54864 0 m
.54864 .01549 L
.54975 .01549 L
.54975 0 L
.54864 0 L
s
1 0 0 r
.55003 0 m
.55003 .02509 L
.55114 .02509 L
.55114 0 L
F
0 g
.55003 0 m
.55003 .02509 L
.55114 .02509 L
.55114 0 L
.55003 0 L
s
1 0 0 r
.55142 0 m
.55142 .01625 L
.55254 .01625 L
.55254 0 L
F
0 g
.55142 0 m
.55142 .01625 L
.55254 .01625 L
.55254 0 L
.55142 0 L
s
1 0 0 r
.55282 0 m
.55282 .00809 L
.55393 .00809 L
.55393 0 L
F
0 g
.55282 0 m
.55282 .00809 L
.55393 .00809 L
.55393 0 L
.55282 0 L
s
1 0 0 r
.55421 0 m
.55421 .00418 L
.55533 .00418 L
.55533 0 L
F
0 g
.55421 0 m
.55421 .00418 L
.55533 .00418 L
.55533 0 L
.55421 0 L
s
1 0 0 r
.5556 0 m
.5556 .03189 L
.55672 .03189 L
.55672 0 L
F
0 g
.5556 0 m
.5556 .03189 L
.55672 .03189 L
.55672 0 L
.5556 0 L
s
1 0 0 r
.557 0 m
.557 .01775 L
.55811 .01775 L
.55811 0 L
F
0 g
.557 0 m
.557 .01775 L
.55811 .01775 L
.55811 0 L
.557 0 L
s
1 0 0 r
.55839 0 m
.55839 .01709 L
.55951 .01709 L
.55951 0 L
F
0 g
.55839 0 m
.55839 .01709 L
.55951 .01709 L
.55951 0 L
.55839 0 L
s
1 0 0 r
.55979 0 m
.55979 .02498 L
.5609 .02498 L
.5609 0 L
F
0 g
.55979 0 m
.55979 .02498 L
.5609 .02498 L
.5609 0 L
.55979 0 L
s
1 0 0 r
.56118 0 m
.56118 .01728 L
.56229 .01728 L
.56229 0 L
F
0 g
.56118 0 m
.56118 .01728 L
.56229 .01728 L
.56229 0 L
.56118 0 L
s
1 0 0 r
.56257 0 m
.56257 .01114 L
.56369 .01114 L
.56369 0 L
F
0 g
.56257 0 m
.56257 .01114 L
.56369 .01114 L
.56369 0 L
.56257 0 L
s
1 0 0 r
.56397 0 m
.56397 .00431 L
.56508 .00431 L
.56508 0 L
F
0 g
.56397 0 m
.56397 .00431 L
.56508 .00431 L
.56508 0 L
.56397 0 L
s
1 0 0 r
.56536 0 m
.56536 .02333 L
.56647 .02333 L
.56647 0 L
F
0 g
.56536 0 m
.56536 .02333 L
.56647 .02333 L
.56647 0 L
.56536 0 L
s
1 0 0 r
.56675 0 m
.56675 .0162 L
.56787 .0162 L
.56787 0 L
F
0 g
.56675 0 m
.56675 .0162 L
.56787 .0162 L
.56787 0 L
.56675 0 L
s
1 0 0 r
.56815 0 m
.56815 .01647 L
.56926 .01647 L
.56926 0 L
F
0 g
.56815 0 m
.56815 .01647 L
.56926 .01647 L
.56926 0 L
.56815 0 L
s
1 0 0 r
.56954 0 m
.56954 .01318 L
.57066 .01318 L
.57066 0 L
F
0 g
.56954 0 m
.56954 .01318 L
.57066 .01318 L
.57066 0 L
.56954 0 L
s
1 0 0 r
.57093 0 m
.57093 .01344 L
.57205 .01344 L
.57205 0 L
F
0 g
.57093 0 m
.57093 .01344 L
.57205 .01344 L
.57205 0 L
.57093 0 L
s
1 0 0 r
.57233 0 m
.57233 .00424 L
.57344 .00424 L
.57344 0 L
F
0 g
.57233 0 m
.57233 .00424 L
.57344 .00424 L
.57344 0 L
.57233 0 L
s
1 0 0 r
.57372 0 m
.57372 .00676 L
.57484 .00676 L
.57484 0 L
F
0 g
.57372 0 m
.57372 .00676 L
.57484 .00676 L
.57484 0 L
.57372 0 L
s
1 0 0 r
.57511 0 m
.57511 .02028 L
.57623 .02028 L
.57623 0 L
F
0 g
.57511 0 m
.57511 .02028 L
.57623 .02028 L
.57623 0 L
.57511 0 L
s
1 0 0 r
.57651 0 m
.57651 .00963 L
.57762 .00963 L
.57762 0 L
F
0 g
.57651 0 m
.57651 .00963 L
.57762 .00963 L
.57762 0 L
.57651 0 L
s
1 0 0 r
.5779 0 m
.5779 .01135 L
.57902 .01135 L
.57902 0 L
F
0 g
.5779 0 m
.5779 .01135 L
.57902 .01135 L
.57902 0 L
.5779 0 L
s
1 0 0 r
.5793 0 m
.5793 .01362 L
.58041 .01362 L
.58041 0 L
F
0 g
.5793 0 m
.5793 .01362 L
.58041 .01362 L
.58041 0 L
.5793 0 L
s
1 0 0 r
.58069 0 m
.58069 .01324 L
.5818 .01324 L
.5818 0 L
F
0 g
.58069 0 m
.58069 .01324 L
.5818 .01324 L
.5818 0 L
.58069 0 L
s
1 0 0 r
.58208 0 m
.58208 .0065 L
.5832 .0065 L
.5832 0 L
F
0 g
.58208 0 m
.58208 .0065 L
.5832 .0065 L
.5832 0 L
.58208 0 L
s
1 0 0 r
.58348 0 m
.58348 .00434 L
.58459 .00434 L
.58459 0 L
F
0 g
.58348 0 m
.58348 .00434 L
.58459 .00434 L
.58459 0 L
.58348 0 L
s
1 0 0 r
.58487 0 m
.58487 .0142 L
.58598 .0142 L
.58598 0 L
F
0 g
.58487 0 m
.58487 .0142 L
.58598 .0142 L
.58598 0 L
.58487 0 L
s
1 0 0 r
.58626 0 m
.58626 .0108 L
.58738 .0108 L
.58738 0 L
F
0 g
.58626 0 m
.58626 .0108 L
.58738 .0108 L
.58738 0 L
.58626 0 L
s
1 0 0 r
.58766 0 m
.58766 .01102 L
.58877 .01102 L
.58877 0 L
F
0 g
.58766 0 m
.58766 .01102 L
.58877 .01102 L
.58877 0 L
.58766 0 L
s
1 0 0 r
.58905 0 m
.58905 .01308 L
.59017 .01308 L
.59017 0 L
F
0 g
.58905 0 m
.58905 .01308 L
.59017 .01308 L
.59017 0 L
.58905 0 L
s
1 0 0 r
.59044 0 m
.59044 .00877 L
.59156 .00877 L
.59156 0 L
F
0 g
.59044 0 m
.59044 .00877 L
.59156 .00877 L
.59156 0 L
.59044 0 L
s
1 0 0 r
.59184 0 m
.59184 .00433 L
.59295 .00433 L
.59295 0 L
F
0 g
.59184 0 m
.59184 .00433 L
.59295 .00433 L
.59295 0 L
.59184 0 L
s
1 0 0 r
.59323 0 m
.59323 .005 L
.59435 .005 L
.59435 0 L
F
0 g
.59323 0 m
.59323 .005 L
.59435 .005 L
.59435 0 L
.59323 0 L
s
1 0 0 r
.59462 0 m
.59462 .01491 L
.59574 .01491 L
.59574 0 L
F
0 g
.59462 0 m
.59462 .01491 L
.59574 .01491 L
.59574 0 L
.59462 0 L
s
1 0 0 r
.59602 0 m
.59602 .00996 L
.59713 .00996 L
.59713 0 L
F
0 g
.59602 0 m
.59602 .00996 L
.59713 .00996 L
.59713 0 L
.59602 0 L
s
1 0 0 r
.59741 0 m
.59741 .00631 L
.59853 .00631 L
.59853 0 L
F
0 g
.59741 0 m
.59741 .00631 L
.59853 .00631 L
.59853 0 L
.59741 0 L
s
1 0 0 r
.59881 0 m
.59881 .00933 L
.59992 .00933 L
.59992 0 L
F
0 g
.59881 0 m
.59881 .00933 L
.59992 .00933 L
.59992 0 L
.59881 0 L
s
1 0 0 r
.6002 0 m
.6002 .00887 L
.60131 .00887 L
.60131 0 L
F
0 g
.6002 0 m
.6002 .00887 L
.60131 .00887 L
.60131 0 L
.6002 0 L
s
1 0 0 r
.60159 0 m
.60159 .00983 L
.60271 .00983 L
.60271 0 L
F
0 g
.60159 0 m
.60159 .00983 L
.60271 .00983 L
.60271 0 L
.60159 0 L
s
1 0 0 r
.60299 0 m
.60299 .00564 L
.6041 .00564 L
.6041 0 L
F
0 g
.60299 0 m
.60299 .00564 L
.6041 .00564 L
.6041 0 L
.60299 0 L
s
1 0 0 r
.60438 0 m
.60438 .01825 L
.60549 .01825 L
.60549 0 L
F
0 g
.60438 0 m
.60438 .01825 L
.60549 .01825 L
.60549 0 L
.60438 0 L
s
1 0 0 r
.60577 0 m
.60577 .01026 L
.60689 .01026 L
.60689 0 L
F
0 g
.60577 0 m
.60577 .01026 L
.60689 .01026 L
.60689 0 L
.60577 0 L
s
1 0 0 r
.60717 0 m
.60717 .01078 L
.60828 .01078 L
.60828 0 L
F
0 g
.60717 0 m
.60717 .01078 L
.60828 .01078 L
.60828 0 L
.60717 0 L
s
1 0 0 r
.60856 0 m
.60856 .00922 L
.60968 .00922 L
.60968 0 L
F
0 g
.60856 0 m
.60856 .00922 L
.60968 .00922 L
.60968 0 L
.60856 0 L
s
1 0 0 r
.60995 0 m
.60995 .01231 L
.61107 .01231 L
.61107 0 L
F
0 g
.60995 0 m
.60995 .01231 L
.61107 .01231 L
.61107 0 L
.60995 0 L
s
1 0 0 r
.61135 0 m
.61135 .00474 L
.61246 .00474 L
.61246 0 L
F
0 g
.61135 0 m
.61135 .00474 L
.61246 .00474 L
.61246 0 L
.61135 0 L
s
1 0 0 r
.61274 0 m
.61274 .00302 L
.61386 .00302 L
.61386 0 L
F
0 g
.61274 0 m
.61274 .00302 L
.61386 .00302 L
.61386 0 L
.61274 0 L
s
1 0 0 r
.61414 0 m
.61414 .01325 L
.61525 .01325 L
.61525 0 L
F
0 g
.61414 0 m
.61414 .01325 L
.61525 .01325 L
.61525 0 L
.61414 0 L
s
1 0 0 r
.61553 0 m
.61553 .00511 L
.61664 .00511 L
.61664 0 L
F
0 g
.61553 0 m
.61553 .00511 L
.61664 .00511 L
.61664 0 L
.61553 0 L
s
1 0 0 r
.61692 0 m
.61692 .00692 L
.61804 .00692 L
.61804 0 L
F
0 g
.61692 0 m
.61692 .00692 L
.61804 .00692 L
.61804 0 L
.61692 0 L
s
1 0 0 r
.61832 0 m
.61832 .01277 L
.61943 .01277 L
.61943 0 L
F
0 g
.61832 0 m
.61832 .01277 L
.61943 .01277 L
.61943 0 L
.61832 0 L
s
1 0 0 r
.61971 0 m
.61971 .01514 L
.62082 .01514 L
.62082 0 L
F
0 g
.61971 0 m
.61971 .01514 L
.62082 .01514 L
.62082 0 L
.61971 0 L
s
1 0 0 r
.6211 0 m
.6211 .00706 L
.62222 .00706 L
.62222 0 L
F
0 g
.6211 0 m
.6211 .00706 L
.62222 .00706 L
.62222 0 L
.6211 0 L
s
1 0 0 r
.6225 0 m
.6225 .00296 L
.62361 .00296 L
.62361 0 L
F
0 g
.6225 0 m
.6225 .00296 L
.62361 .00296 L
.62361 0 L
.6225 0 L
s
1 0 0 r
.62389 0 m
.62389 .017 L
.62501 .017 L
.62501 0 L
F
0 g
.62389 0 m
.62389 .017 L
.62501 .017 L
.62501 0 L
.62389 0 L
s
1 0 0 r
.62528 0 m
.62528 .01758 L
.6264 .01758 L
.6264 0 L
F
0 g
.62528 0 m
.62528 .01758 L
.6264 .01758 L
.6264 0 L
.62528 0 L
s
1 0 0 r
.62668 0 m
.62668 .0136 L
.62779 .0136 L
.62779 0 L
F
0 g
.62668 0 m
.62668 .0136 L
.62779 .0136 L
.62779 0 L
.62668 0 L
s
1 0 0 r
.62807 0 m
.62807 .01754 L
.62919 .01754 L
.62919 0 L
F
0 g
.62807 0 m
.62807 .01754 L
.62919 .01754 L
.62919 0 L
.62807 0 L
s
1 0 0 r
.62946 0 m
.62946 .0147 L
.63058 .0147 L
.63058 0 L
F
0 g
.62946 0 m
.62946 .0147 L
.63058 .0147 L
.63058 0 L
.62946 0 L
s
1 0 0 r
.63086 0 m
.63086 .00408 L
.63197 .00408 L
.63197 0 L
F
0 g
.63086 0 m
.63086 .00408 L
.63197 .00408 L
.63197 0 L
.63086 0 L
s
1 0 0 r
.63225 0 m
.63225 .00483 L
.63337 .00483 L
.63337 0 L
F
0 g
.63225 0 m
.63225 .00483 L
.63337 .00483 L
.63337 0 L
.63225 0 L
s
1 0 0 r
.63365 0 m
.63365 .01738 L
.63476 .01738 L
.63476 0 L
F
0 g
.63365 0 m
.63365 .01738 L
.63476 .01738 L
.63476 0 L
.63365 0 L
s
1 0 0 r
.63504 0 m
.63504 .01268 L
.63615 .01268 L
.63615 0 L
F
0 g
.63504 0 m
.63504 .01268 L
.63615 .01268 L
.63615 0 L
.63504 0 L
s
1 0 0 r
.63643 0 m
.63643 .04742 L
.63755 .04742 L
.63755 0 L
F
0 g
.63643 0 m
.63643 .04742 L
.63755 .04742 L
.63755 0 L
.63643 0 L
s
1 0 0 r
.63783 0 m
.63783 .01315 L
.63894 .01315 L
.63894 0 L
F
0 g
.63783 0 m
.63783 .01315 L
.63894 .01315 L
.63894 0 L
.63783 0 L
s
1 0 0 r
.63922 0 m
.63922 .00959 L
.64033 .00959 L
.64033 0 L
F
0 g
.63922 0 m
.63922 .00959 L
.64033 .00959 L
.64033 0 L
.63922 0 L
s
1 0 0 r
.64061 0 m
.64061 .00455 L
.64173 .00455 L
.64173 0 L
F
0 g
.64061 0 m
.64061 .00455 L
.64173 .00455 L
.64173 0 L
.64061 0 L
s
1 0 0 r
.64201 0 m
.64201 .00604 L
.64312 .00604 L
.64312 0 L
F
0 g
.64201 0 m
.64201 .00604 L
.64312 .00604 L
.64312 0 L
.64201 0 L
s
1 0 0 r
.6434 0 m
.6434 .01987 L
.64452 .01987 L
.64452 0 L
F
0 g
.6434 0 m
.6434 .01987 L
.64452 .01987 L
.64452 0 L
.6434 0 L
s
1 0 0 r
.64479 0 m
.64479 .01055 L
.64591 .01055 L
.64591 0 L
F
0 g
.64479 0 m
.64479 .01055 L
.64591 .01055 L
.64591 0 L
.64479 0 L
s
1 0 0 r
.64619 0 m
.64619 .00999 L
.6473 .00999 L
.6473 0 L
F
0 g
.64619 0 m
.64619 .00999 L
.6473 .00999 L
.6473 0 L
.64619 0 L
s
1 0 0 r
.64758 0 m
.64758 .00893 L
.6487 .00893 L
.6487 0 L
F
0 g
.64758 0 m
.64758 .00893 L
.6487 .00893 L
.6487 0 L
.64758 0 L
s
1 0 0 r
.64898 0 m
.64898 .00879 L
.65009 .00879 L
.65009 0 L
F
0 g
.64898 0 m
.64898 .00879 L
.65009 .00879 L
.65009 0 L
.64898 0 L
s
1 0 0 r
.65037 0 m
.65037 .00559 L
.65148 .00559 L
.65148 0 L
F
0 g
.65037 0 m
.65037 .00559 L
.65148 .00559 L
.65148 0 L
.65037 0 L
s
1 0 0 r
.65176 0 m
.65176 .00405 L
.65288 .00405 L
.65288 0 L
F
0 g
.65176 0 m
.65176 .00405 L
.65288 .00405 L
.65288 0 L
.65176 0 L
s
1 0 0 r
.65316 0 m
.65316 .01153 L
.65427 .01153 L
.65427 0 L
F
0 g
.65316 0 m
.65316 .01153 L
.65427 .01153 L
.65427 0 L
.65316 0 L
s
1 0 0 r
.65455 0 m
.65455 .01312 L
.65566 .01312 L
.65566 0 L
F
0 g
.65455 0 m
.65455 .01312 L
.65566 .01312 L
.65566 0 L
.65455 0 L
s
1 0 0 r
.65594 0 m
.65594 .01567 L
.65706 .01567 L
.65706 0 L
F
0 g
.65594 0 m
.65594 .01567 L
.65706 .01567 L
.65706 0 L
.65594 0 L
s
1 0 0 r
.65734 0 m
.65734 .00989 L
.65845 .00989 L
.65845 0 L
F
0 g
.65734 0 m
.65734 .00989 L
.65845 .00989 L
.65845 0 L
.65734 0 L
s
1 0 0 r
.65873 0 m
.65873 .01589 L
.65985 .01589 L
.65985 0 L
F
0 g
.65873 0 m
.65873 .01589 L
.65985 .01589 L
.65985 0 L
.65873 0 L
s
1 0 0 r
.66012 0 m
.66012 .00385 L
.66124 .00385 L
.66124 0 L
F
0 g
.66012 0 m
.66012 .00385 L
.66124 .00385 L
.66124 0 L
.66012 0 L
s
1 0 0 r
.66152 0 m
.66152 .00499 L
.66263 .00499 L
.66263 0 L
F
0 g
.66152 0 m
.66152 .00499 L
.66263 .00499 L
.66263 0 L
.66152 0 L
s
1 0 0 r
.66291 0 m
.66291 .01286 L
.66403 .01286 L
.66403 0 L
F
0 g
.66291 0 m
.66291 .01286 L
.66403 .01286 L
.66403 0 L
.66291 0 L
s
1 0 0 r
.6643 0 m
.6643 .01206 L
.66542 .01206 L
.66542 0 L
F
0 g
.6643 0 m
.6643 .01206 L
.66542 .01206 L
.66542 0 L
.6643 0 L
s
1 0 0 r
.6657 0 m
.6657 .01242 L
.66681 .01242 L
.66681 0 L
F
0 g
.6657 0 m
.6657 .01242 L
.66681 .01242 L
.66681 0 L
.6657 0 L
s
1 0 0 r
.66709 0 m
.66709 .00952 L
.66821 .00952 L
.66821 0 L
F
0 g
.66709 0 m
.66709 .00952 L
.66821 .00952 L
.66821 0 L
.66709 0 L
s
1 0 0 r
.66849 0 m
.66849 .01276 L
.6696 .01276 L
.6696 0 L
F
0 g
.66849 0 m
.66849 .01276 L
.6696 .01276 L
.6696 0 L
.66849 0 L
s
1 0 0 r
.66988 0 m
.66988 .00384 L
.67099 .00384 L
.67099 0 L
F
0 g
.66988 0 m
.66988 .00384 L
.67099 .00384 L
.67099 0 L
.66988 0 L
s
1 0 0 r
.67127 0 m
.67127 .00543 L
.67239 .00543 L
.67239 0 L
F
0 g
.67127 0 m
.67127 .00543 L
.67239 .00543 L
.67239 0 L
.67127 0 L
s
1 0 0 r
.67267 0 m
.67267 .01122 L
.67378 .01122 L
.67378 0 L
F
0 g
.67267 0 m
.67267 .01122 L
.67378 .01122 L
.67378 0 L
.67267 0 L
s
1 0 0 r
.67406 0 m
.67406 .01189 L
.67517 .01189 L
.67517 0 L
F
0 g
.67406 0 m
.67406 .01189 L
.67517 .01189 L
.67517 0 L
.67406 0 L
s
1 0 0 r
.67545 0 m
.67545 .01193 L
.67657 .01193 L
.67657 0 L
F
0 g
.67545 0 m
.67545 .01193 L
.67657 .01193 L
.67657 0 L
.67545 0 L
s
1 0 0 r
.67685 0 m
.67685 .00888 L
.67796 .00888 L
.67796 0 L
F
0 g
.67685 0 m
.67685 .00888 L
.67796 .00888 L
.67796 0 L
.67685 0 L
s
1 0 0 r
.67824 0 m
.67824 .00994 L
.67936 .00994 L
.67936 0 L
F
0 g
.67824 0 m
.67824 .00994 L
.67936 .00994 L
.67936 0 L
.67824 0 L
s
1 0 0 r
.67963 0 m
.67963 .00238 L
.68075 .00238 L
.68075 0 L
F
0 g
.67963 0 m
.67963 .00238 L
.68075 .00238 L
.68075 0 L
.67963 0 L
s
1 0 0 r
.68103 0 m
.68103 .00512 L
.68214 .00512 L
.68214 0 L
F
0 g
.68103 0 m
.68103 .00512 L
.68214 .00512 L
.68214 0 L
.68103 0 L
s
1 0 0 r
.68242 0 m
.68242 .02549 L
.68354 .02549 L
.68354 0 L
F
0 g
.68242 0 m
.68242 .02549 L
.68354 .02549 L
.68354 0 L
.68242 0 L
s
1 0 0 r
.68381 0 m
.68381 .01169 L
.68493 .01169 L
.68493 0 L
F
0 g
.68381 0 m
.68381 .01169 L
.68493 .01169 L
.68493 0 L
.68381 0 L
s
1 0 0 r
.68521 0 m
.68521 .00805 L
.68632 .00805 L
.68632 0 L
F
0 g
.68521 0 m
.68521 .00805 L
.68632 .00805 L
.68632 0 L
.68521 0 L
s
1 0 0 r
.6866 0 m
.6866 .01248 L
.68772 .01248 L
.68772 0 L
F
0 g
.6866 0 m
.6866 .01248 L
.68772 .01248 L
.68772 0 L
.6866 0 L
s
1 0 0 r
.688 0 m
.688 .00632 L
.68911 .00632 L
.68911 0 L
F
0 g
.688 0 m
.688 .00632 L
.68911 .00632 L
.68911 0 L
.688 0 L
s
1 0 0 r
.68939 0 m
.68939 .00595 L
.6905 .00595 L
.6905 0 L
F
0 g
.68939 0 m
.68939 .00595 L
.6905 .00595 L
.6905 0 L
.68939 0 L
s
1 0 0 r
.69078 0 m
.69078 .00481 L
.6919 .00481 L
.6919 0 L
F
0 g
.69078 0 m
.69078 .00481 L
.6919 .00481 L
.6919 0 L
.69078 0 L
s
1 0 0 r
.69218 0 m
.69218 .01136 L
.69329 .01136 L
.69329 0 L
F
0 g
.69218 0 m
.69218 .01136 L
.69329 .01136 L
.69329 0 L
.69218 0 L
s
1 0 0 r
.69357 0 m
.69357 .01021 L
.69468 .01021 L
.69468 0 L
F
0 g
.69357 0 m
.69357 .01021 L
.69468 .01021 L
.69468 0 L
.69357 0 L
s
1 0 0 r
.69496 0 m
.69496 .01094 L
.69608 .01094 L
.69608 0 L
F
0 g
.69496 0 m
.69496 .01094 L
.69608 .01094 L
.69608 0 L
.69496 0 L
s
1 0 0 r
.69636 0 m
.69636 .01548 L
.69747 .01548 L
.69747 0 L
F
0 g
.69636 0 m
.69636 .01548 L
.69747 .01548 L
.69747 0 L
.69636 0 L
s
1 0 0 r
.69775 0 m
.69775 .00532 L
.69887 .00532 L
.69887 0 L
F
0 g
.69775 0 m
.69775 .00532 L
.69887 .00532 L
.69887 0 L
.69775 0 L
s
1 0 0 r
.69914 0 m
.69914 .00412 L
.70026 .00412 L
.70026 0 L
F
0 g
.69914 0 m
.69914 .00412 L
.70026 .00412 L
.70026 0 L
.69914 0 L
s
1 0 0 r
.70054 0 m
.70054 .00574 L
.70165 .00574 L
.70165 0 L
F
0 g
.70054 0 m
.70054 .00574 L
.70165 .00574 L
.70165 0 L
.70054 0 L
s
1 0 0 r
.70193 0 m
.70193 .01014 L
.70305 .01014 L
.70305 0 L
F
0 g
.70193 0 m
.70193 .01014 L
.70305 .01014 L
.70305 0 L
.70193 0 L
s
1 0 0 r
.70333 0 m
.70333 .01083 L
.70444 .01083 L
.70444 0 L
F
0 g
.70333 0 m
.70333 .01083 L
.70444 .01083 L
.70444 0 L
.70333 0 L
s
1 0 0 r
.70472 0 m
.70472 .00952 L
.70583 .00952 L
.70583 0 L
F
0 g
.70472 0 m
.70472 .00952 L
.70583 .00952 L
.70583 0 L
.70472 0 L
s
1 0 0 r
.70611 0 m
.70611 .0098 L
.70723 .0098 L
.70723 0 L
F
0 g
.70611 0 m
.70611 .0098 L
.70723 .0098 L
.70723 0 L
.70611 0 L
s
1 0 0 r
.70751 0 m
.70751 .00964 L
.70862 .00964 L
.70862 0 L
F
0 g
.70751 0 m
.70751 .00964 L
.70862 .00964 L
.70862 0 L
.70751 0 L
s
1 0 0 r
.7089 0 m
.7089 .00477 L
.71001 .00477 L
.71001 0 L
F
0 g
.7089 0 m
.7089 .00477 L
.71001 .00477 L
.71001 0 L
.7089 0 L
s
1 0 0 r
.71029 0 m
.71029 .00585 L
.71141 .00585 L
.71141 0 L
F
0 g
.71029 0 m
.71029 .00585 L
.71141 .00585 L
.71141 0 L
.71029 0 L
s
1 0 0 r
.71169 0 m
.71169 .01429 L
.7128 .01429 L
.7128 0 L
F
0 g
.71169 0 m
.71169 .01429 L
.7128 .01429 L
.7128 0 L
.71169 0 L
s
1 0 0 r
.71308 0 m
.71308 .01078 L
.7142 .01078 L
.7142 0 L
F
0 g
.71308 0 m
.71308 .01078 L
.7142 .01078 L
.7142 0 L
.71308 0 L
s
1 0 0 r
.71447 0 m
.71447 .01329 L
.71559 .01329 L
.71559 0 L
F
0 g
.71447 0 m
.71447 .01329 L
.71559 .01329 L
.71559 0 L
.71447 0 L
s
1 0 0 r
.71587 0 m
.71587 .01347 L
.71698 .01347 L
.71698 0 L
F
0 g
.71587 0 m
.71587 .01347 L
.71698 .01347 L
.71698 0 L
.71587 0 L
s
1 0 0 r
.71726 0 m
.71726 .00995 L
.71838 .00995 L
.71838 0 L
F
0 g
.71726 0 m
.71726 .00995 L
.71838 .00995 L
.71838 0 L
.71726 0 L
s
1 0 0 r
.71865 0 m
.71865 .0109 L
.71977 .0109 L
.71977 0 L
F
0 g
.71865 0 m
.71865 .0109 L
.71977 .0109 L
.71977 0 L
.71865 0 L
s
1 0 0 r
.72005 0 m
.72005 .00802 L
.72116 .00802 L
.72116 0 L
F
0 g
.72005 0 m
.72005 .00802 L
.72116 .00802 L
.72116 0 L
.72005 0 L
s
1 0 0 r
.72144 0 m
.72144 .02288 L
.72256 .02288 L
.72256 0 L
F
0 g
.72144 0 m
.72144 .02288 L
.72256 .02288 L
.72256 0 L
.72144 0 L
s
1 0 0 r
.72284 0 m
.72284 .01942 L
.72395 .01942 L
.72395 0 L
F
0 g
.72284 0 m
.72284 .01942 L
.72395 .01942 L
.72395 0 L
.72284 0 L
s
1 0 0 r
.72423 0 m
.72423 .01476 L
.72534 .01476 L
.72534 0 L
F
0 g
.72423 0 m
.72423 .01476 L
.72534 .01476 L
.72534 0 L
.72423 0 L
s
1 0 0 r
.72562 0 m
.72562 .00562 L
.72674 .00562 L
.72674 0 L
F
0 g
.72562 0 m
.72562 .00562 L
.72674 .00562 L
.72674 0 L
.72562 0 L
s
1 0 0 r
.72702 0 m
.72702 .01332 L
.72813 .01332 L
.72813 0 L
F
0 g
.72702 0 m
.72702 .01332 L
.72813 .01332 L
.72813 0 L
.72702 0 L
s
1 0 0 r
.72841 0 m
.72841 .00848 L
.72952 .00848 L
.72952 0 L
F
0 g
.72841 0 m
.72841 .00848 L
.72952 .00848 L
.72952 0 L
.72841 0 L
s
1 0 0 r
.7298 0 m
.7298 .00688 L
.73092 .00688 L
.73092 0 L
F
0 g
.7298 0 m
.7298 .00688 L
.73092 .00688 L
.73092 0 L
.7298 0 L
s
1 0 0 r
.7312 0 m
.7312 .0173 L
.73231 .0173 L
.73231 0 L
F
0 g
.7312 0 m
.7312 .0173 L
.73231 .0173 L
.73231 0 L
.7312 0 L
s
1 0 0 r
.73259 0 m
.73259 .01574 L
.73371 .01574 L
.73371 0 L
F
0 g
.73259 0 m
.73259 .01574 L
.73371 .01574 L
.73371 0 L
.73259 0 L
s
1 0 0 r
.73398 0 m
.73398 .01316 L
.7351 .01316 L
.7351 0 L
F
0 g
.73398 0 m
.73398 .01316 L
.7351 .01316 L
.7351 0 L
.73398 0 L
s
1 0 0 r
.73538 0 m
.73538 .01544 L
.73649 .01544 L
.73649 0 L
F
0 g
.73538 0 m
.73538 .01544 L
.73649 .01544 L
.73649 0 L
.73538 0 L
s
1 0 0 r
.73677 0 m
.73677 .01397 L
.73789 .01397 L
.73789 0 L
F
0 g
.73677 0 m
.73677 .01397 L
.73789 .01397 L
.73789 0 L
.73677 0 L
s
1 0 0 r
.73816 0 m
.73816 .00534 L
.73928 .00534 L
.73928 0 L
F
0 g
.73816 0 m
.73816 .00534 L
.73928 .00534 L
.73928 0 L
.73816 0 L
s
1 0 0 r
.73956 0 m
.73956 .00161 L
.74067 .00161 L
.74067 0 L
F
0 g
.73956 0 m
.73956 .00161 L
.74067 .00161 L
.74067 0 L
.73956 0 L
s
1 0 0 r
.74095 0 m
.74095 .01718 L
.74207 .01718 L
.74207 0 L
F
0 g
.74095 0 m
.74095 .01718 L
.74207 .01718 L
.74207 0 L
.74095 0 L
s
1 0 0 r
.74235 0 m
.74235 .03894 L
.74346 .03894 L
.74346 0 L
F
0 g
.74235 0 m
.74235 .03894 L
.74346 .03894 L
.74346 0 L
.74235 0 L
s
1 0 0 r
.74374 0 m
.74374 .02979 L
.74485 .02979 L
.74485 0 L
F
0 g
.74374 0 m
.74374 .02979 L
.74485 .02979 L
.74485 0 L
.74374 0 L
s
1 0 0 r
.74513 0 m
.74513 .0184 L
.74625 .0184 L
.74625 0 L
F
0 g
.74513 0 m
.74513 .0184 L
.74625 .0184 L
.74625 0 L
.74513 0 L
s
1 0 0 r
.74653 0 m
.74653 .02052 L
.74764 .02052 L
.74764 0 L
F
0 g
.74653 0 m
.74653 .02052 L
.74764 .02052 L
.74764 0 L
.74653 0 L
s
1 0 0 r
.74792 0 m
.74792 .00804 L
.74903 .00804 L
.74903 0 L
F
0 g
.74792 0 m
.74792 .00804 L
.74903 .00804 L
.74903 0 L
.74792 0 L
s
1 0 0 r
.74931 0 m
.74931 .00776 L
.75043 .00776 L
.75043 0 L
F
0 g
.74931 0 m
.74931 .00776 L
.75043 .00776 L
.75043 0 L
.74931 0 L
s
1 0 0 r
.75071 0 m
.75071 .02036 L
.75182 .02036 L
.75182 0 L
F
0 g
.75071 0 m
.75071 .02036 L
.75182 .02036 L
.75182 0 L
.75071 0 L
s
1 0 0 r
.7521 0 m
.7521 .0204 L
.75322 .0204 L
.75322 0 L
F
0 g
.7521 0 m
.7521 .0204 L
.75322 .0204 L
.75322 0 L
.7521 0 L
s
1 0 0 r
.75349 0 m
.75349 .01914 L
.75461 .01914 L
.75461 0 L
F
0 g
.75349 0 m
.75349 .01914 L
.75461 .01914 L
.75461 0 L
.75349 0 L
s
1 0 0 r
.75489 0 m
.75489 .01647 L
.756 .01647 L
.756 0 L
F
0 g
.75489 0 m
.75489 .01647 L
.756 .01647 L
.756 0 L
.75489 0 L
s
1 0 0 r
.75628 0 m
.75628 .01971 L
.7574 .01971 L
.7574 0 L
F
0 g
.75628 0 m
.75628 .01971 L
.7574 .01971 L
.7574 0 L
.75628 0 L
s
1 0 0 r
.75768 0 m
.75768 .00772 L
.75879 .00772 L
.75879 0 L
F
0 g
.75768 0 m
.75768 .00772 L
.75879 .00772 L
.75879 0 L
.75768 0 L
s
1 0 0 r
.75907 0 m
.75907 .00366 L
.76018 .00366 L
.76018 0 L
F
0 g
.75907 0 m
.75907 .00366 L
.76018 .00366 L
.76018 0 L
.75907 0 L
s
1 0 0 r
.76046 0 m
.76046 .02266 L
.76158 .02266 L
.76158 0 L
F
0 g
.76046 0 m
.76046 .02266 L
.76158 .02266 L
.76158 0 L
.76046 0 L
s
1 0 0 r
.76186 0 m
.76186 .01881 L
.76297 .01881 L
.76297 0 L
F
0 g
.76186 0 m
.76186 .01881 L
.76297 .01881 L
.76297 0 L
.76186 0 L
s
1 0 0 r
.76325 0 m
.76325 .01911 L
.76436 .01911 L
.76436 0 L
F
0 g
.76325 0 m
.76325 .01911 L
.76436 .01911 L
.76436 0 L
.76325 0 L
s
1 0 0 r
.76464 0 m
.76464 .01673 L
.76576 .01673 L
.76576 0 L
F
0 g
.76464 0 m
.76464 .01673 L
.76576 .01673 L
.76576 0 L
.76464 0 L
s
1 0 0 r
.76604 0 m
.76604 .01344 L
.76715 .01344 L
.76715 0 L
F
0 g
.76604 0 m
.76604 .01344 L
.76715 .01344 L
.76715 0 L
.76604 0 L
s
1 0 0 r
.76743 0 m
.76743 .01004 L
.76855 .01004 L
.76855 0 L
F
0 g
.76743 0 m
.76743 .01004 L
.76855 .01004 L
.76855 0 L
.76743 0 L
s
1 0 0 r
.76882 0 m
.76882 .00629 L
.76994 .00629 L
.76994 0 L
F
0 g
.76882 0 m
.76882 .00629 L
.76994 .00629 L
.76994 0 L
.76882 0 L
s
1 0 0 r
.77022 0 m
.77022 .03564 L
.77133 .03564 L
.77133 0 L
F
0 g
.77022 0 m
.77022 .03564 L
.77133 .03564 L
.77133 0 L
.77022 0 L
s
1 0 0 r
.77161 0 m
.77161 .02359 L
.77273 .02359 L
.77273 0 L
F
0 g
.77161 0 m
.77161 .02359 L
.77273 .02359 L
.77273 0 L
.77161 0 L
s
1 0 0 r
.773 0 m
.773 .01497 L
.77412 .01497 L
.77412 0 L
F
0 g
.773 0 m
.773 .01497 L
.77412 .01497 L
.77412 0 L
.773 0 L
s
1 0 0 r
.7744 0 m
.7744 .0147 L
.77551 .0147 L
.77551 0 L
F
0 g
.7744 0 m
.7744 .0147 L
.77551 .0147 L
.77551 0 L
.7744 0 L
s
1 0 0 r
.77579 0 m
.77579 .01437 L
.77691 .01437 L
.77691 0 L
F
0 g
.77579 0 m
.77579 .01437 L
.77691 .01437 L
.77691 0 L
.77579 0 L
s
1 0 0 r
.77719 0 m
.77719 .0069 L
.7783 .0069 L
.7783 0 L
F
0 g
.77719 0 m
.77719 .0069 L
.7783 .0069 L
.7783 0 L
.77719 0 L
s
1 0 0 r
.77858 0 m
.77858 .00517 L
.77969 .00517 L
.77969 0 L
F
0 g
.77858 0 m
.77858 .00517 L
.77969 .00517 L
.77969 0 L
.77858 0 L
s
1 0 0 r
.77997 0 m
.77997 .07902 L
.78109 .07902 L
.78109 0 L
F
0 g
.77997 0 m
.77997 .07902 L
.78109 .07902 L
.78109 0 L
.77997 0 L
s
1 0 0 r
.78137 0 m
.78137 .03696 L
.78248 .03696 L
.78248 0 L
F
0 g
.78137 0 m
.78137 .03696 L
.78248 .03696 L
.78248 0 L
.78137 0 L
s
1 0 0 r
.78276 0 m
.78276 .05194 L
.78387 .05194 L
.78387 0 L
F
0 g
.78276 0 m
.78276 .05194 L
.78387 .05194 L
.78387 0 L
.78276 0 L
s
1 0 0 r
.78415 0 m
.78415 .04803 L
.78527 .04803 L
.78527 0 L
F
0 g
.78415 0 m
.78415 .04803 L
.78527 .04803 L
.78527 0 L
.78415 0 L
s
1 0 0 r
.78555 0 m
.78555 .04565 L
.78666 .04565 L
.78666 0 L
F
0 g
.78555 0 m
.78555 .04565 L
.78666 .04565 L
.78666 0 L
.78555 0 L
s
1 0 0 r
.78694 0 m
.78694 .00987 L
.78806 .00987 L
.78806 0 L
F
0 g
.78694 0 m
.78694 .00987 L
.78806 .00987 L
.78806 0 L
.78694 0 L
s
1 0 0 r
.78833 0 m
.78833 .00409 L
.78945 .00409 L
.78945 0 L
F
0 g
.78833 0 m
.78833 .00409 L
.78945 .00409 L
.78945 0 L
.78833 0 L
s
1 0 0 r
.78973 0 m
.78973 .40967 L
.79084 .40967 L
.79084 0 L
F
0 g
.78973 0 m
0 0 rlineto s
.78973 0 m
.78973 .2 L
s
.79084 .2 m
.79084 0 L
.78973 0 L
s
1 0 0 r
.79112 0 m
.79112 .20366 L
.79224 .20366 L
.79224 0 L
F
0 g
.79112 0 m
0 0 rlineto s
.79112 0 m
.79112 .2 L
s
.79224 .2 m
.79224 0 L
.79112 0 L
s
1 0 0 r
.79252 0 m
.79252 .02102 L
.79363 .02102 L
.79363 0 L
F
0 g
.79252 0 m
.79252 .02102 L
.79363 .02102 L
.79363 0 L
.79252 0 L
s
1 0 0 r
.79391 0 m
.79391 .03626 L
.79502 .03626 L
.79502 0 L
F
0 g
.79391 0 m
.79391 .03626 L
.79502 .03626 L
.79502 0 L
.79391 0 L
s
1 0 0 r
.7953 0 m
.7953 .0101 L
.79642 .0101 L
.79642 0 L
F
0 g
.7953 0 m
.7953 .0101 L
.79642 .0101 L
.79642 0 L
.7953 0 L
s
1 0 0 r
.7967 0 m
.7967 .00954 L
.79781 .00954 L
.79781 0 L
F
0 g
.7967 0 m
.7967 .00954 L
.79781 .00954 L
.79781 0 L
.7967 0 L
s
1 0 0 r
.79809 0 m
.79809 .00449 L
.7992 .00449 L
.7992 0 L
F
0 g
.79809 0 m
.79809 .00449 L
.7992 .00449 L
.7992 0 L
.79809 0 L
s
1 0 0 r
.79948 0 m
.79948 .01009 L
.8006 .01009 L
.8006 0 L
F
0 g
.79948 0 m
.79948 .01009 L
.8006 .01009 L
.8006 0 L
.79948 0 L
s
1 0 0 r
.80088 0 m
.80088 .00335 L
.80199 .00335 L
.80199 0 L
F
0 g
.80088 0 m
.80088 .00335 L
.80199 .00335 L
.80199 0 L
.80088 0 L
s
1 0 0 r
.80227 0 m
.80227 .00493 L
.80339 .00493 L
.80339 0 L
F
0 g
.80227 0 m
.80227 .00493 L
.80339 .00493 L
.80339 0 L
.80227 0 L
s
1 0 0 r
.80366 0 m
.80366 .02006 L
.80478 .02006 L
.80478 0 L
F
0 g
.80366 0 m
.80366 .02006 L
.80478 .02006 L
.80478 0 L
.80366 0 L
s
1 0 0 r
.80506 0 m
.80506 .00667 L
.80617 .00667 L
.80617 0 L
F
0 g
.80506 0 m
.80506 .00667 L
.80617 .00667 L
.80617 0 L
.80506 0 L
s
1 0 0 r
.80645 0 m
.80645 .00623 L
.80757 .00623 L
.80757 0 L
F
0 g
.80645 0 m
.80645 .00623 L
.80757 .00623 L
.80757 0 L
.80645 0 L
s
1 0 0 r
.80784 0 m
.80784 .00349 L
.80896 .00349 L
.80896 0 L
F
0 g
.80784 0 m
.80784 .00349 L
.80896 .00349 L
.80896 0 L
.80784 0 L
s
1 0 0 r
.80924 0 m
.80924 .01142 L
.81035 .01142 L
.81035 0 L
F
0 g
.80924 0 m
.80924 .01142 L
.81035 .01142 L
.81035 0 L
.80924 0 L
s
1 0 0 r
.81063 0 m
.81063 -0.00036 L
.81175 -0.00036 L
.81175 0 L
F
0 g
.81063 0 m
0 0 rlineto s
.81175 0 m
.81063 0 L
s
1 0 0 r
.81203 0 m
.81203 .01754 L
.81314 .01754 L
.81314 0 L
F
0 g
.81203 0 m
.81203 .01754 L
.81314 .01754 L
.81314 0 L
.81203 0 L
s
1 0 0 r
.81342 0 m
.81342 .01741 L
.81453 .01741 L
.81453 0 L
F
0 g
.81342 0 m
.81342 .01741 L
.81453 .01741 L
.81453 0 L
.81342 0 L
s
1 0 0 r
.81481 0 m
.81481 .00846 L
.81593 .00846 L
.81593 0 L
F
0 g
.81481 0 m
.81481 .00846 L
.81593 .00846 L
.81593 0 L
.81481 0 L
s
1 0 0 r
.81621 0 m
.81621 .00718 L
.81732 .00718 L
.81732 0 L
F
0 g
.81621 0 m
.81621 .00718 L
.81732 .00718 L
.81732 0 L
.81621 0 L
s
1 0 0 r
.8176 0 m
.8176 .005 L
.81871 .005 L
.81871 0 L
F
0 g
.8176 0 m
.8176 .005 L
.81871 .005 L
.81871 0 L
.8176 0 L
s
1 0 0 r
.81899 0 m
.81899 .03809 L
.82011 .03809 L
.82011 0 L
F
0 g
.81899 0 m
.81899 .03809 L
.82011 .03809 L
.82011 0 L
.81899 0 L
s
1 0 0 r
.82039 0 m
.82039 .03735 L
.8215 .03735 L
.8215 0 L
F
0 g
.82039 0 m
.82039 .03735 L
.8215 .03735 L
.8215 0 L
.82039 0 L
s
1 0 0 r
.82178 0 m
.82178 .03701 L
.8229 .03701 L
.8229 0 L
F
0 g
.82178 0 m
.82178 .03701 L
.8229 .03701 L
.8229 0 L
.82178 0 L
s
1 0 0 r
.82317 0 m
.82317 .03124 L
.82429 .03124 L
.82429 0 L
F
0 g
.82317 0 m
.82317 .03124 L
.82429 .03124 L
.82429 0 L
.82317 0 L
s
1 0 0 r
.82457 0 m
.82457 .01458 L
.82568 .01458 L
.82568 0 L
F
0 g
.82457 0 m
.82457 .01458 L
.82568 .01458 L
.82568 0 L
.82457 0 L
s
1 0 0 r
.82596 0 m
.82596 .01388 L
.82708 .01388 L
.82708 0 L
F
0 g
.82596 0 m
.82596 .01388 L
.82708 .01388 L
.82708 0 L
.82596 0 L
s
1 0 0 r
.82735 0 m
.82735 .00889 L
.82847 .00889 L
.82847 0 L
F
0 g
.82735 0 m
.82735 .00889 L
.82847 .00889 L
.82847 0 L
.82735 0 L
s
1 0 0 r
.82875 0 m
.82875 .02527 L
.82986 .02527 L
.82986 0 L
F
0 g
.82875 0 m
.82875 .02527 L
.82986 .02527 L
.82986 0 L
.82875 0 L
s
1 0 0 r
.83014 0 m
.83014 .00895 L
.83126 .00895 L
.83126 0 L
F
0 g
.83014 0 m
.83014 .00895 L
.83126 .00895 L
.83126 0 L
.83014 0 L
s
1 0 0 r
.83154 0 m
.83154 .01703 L
.83265 .01703 L
.83265 0 L
F
0 g
.83154 0 m
.83154 .01703 L
.83265 .01703 L
.83265 0 L
.83154 0 L
s
1 0 0 r
.83293 0 m
.83293 .012 L
.83404 .012 L
.83404 0 L
F
0 g
.83293 0 m
.83293 .012 L
.83404 .012 L
.83404 0 L
.83293 0 L
s
1 0 0 r
.83432 0 m
.83432 .01288 L
.83544 .01288 L
.83544 0 L
F
0 g
.83432 0 m
.83432 .01288 L
.83544 .01288 L
.83544 0 L
.83432 0 L
s
1 0 0 r
.83572 0 m
.83572 .0038 L
.83683 .0038 L
.83683 0 L
F
0 g
.83572 0 m
.83572 .0038 L
.83683 .0038 L
.83683 0 L
.83572 0 L
s
1 0 0 r
.83711 0 m
.83711 .00612 L
.83822 .00612 L
.83822 0 L
F
0 g
.83711 0 m
.83711 .00612 L
.83822 .00612 L
.83822 0 L
.83711 0 L
s
1 0 0 r
.8385 0 m
.8385 .01584 L
.83962 .01584 L
.83962 0 L
F
0 g
.8385 0 m
.8385 .01584 L
.83962 .01584 L
.83962 0 L
.8385 0 L
s
1 0 0 r
.8399 0 m
.8399 .01186 L
.84101 .01186 L
.84101 0 L
F
0 g
.8399 0 m
.8399 .01186 L
.84101 .01186 L
.84101 0 L
.8399 0 L
s
1 0 0 r
.84129 0 m
.84129 .0161 L
.84241 .0161 L
.84241 0 L
F
0 g
.84129 0 m
.84129 .0161 L
.84241 .0161 L
.84241 0 L
.84129 0 L
s
1 0 0 r
.84268 0 m
.84268 .0136 L
.8438 .0136 L
.8438 0 L
F
0 g
.84268 0 m
.84268 .0136 L
.8438 .0136 L
.8438 0 L
.84268 0 L
s
1 0 0 r
.84408 0 m
.84408 .00998 L
.84519 .00998 L
.84519 0 L
F
0 g
.84408 0 m
.84408 .00998 L
.84519 .00998 L
.84519 0 L
.84408 0 L
s
1 0 0 r
.84547 0 m
.84547 .00787 L
.84659 .00787 L
.84659 0 L
F
0 g
.84547 0 m
.84547 .00787 L
.84659 .00787 L
.84659 0 L
.84547 0 L
s
1 0 0 r
.84687 0 m
.84687 .00635 L
.84798 .00635 L
.84798 0 L
F
0 g
.84687 0 m
.84687 .00635 L
.84798 .00635 L
.84798 0 L
.84687 0 L
s
1 0 0 r
.84826 0 m
.84826 .0148 L
.84937 .0148 L
.84937 0 L
F
0 g
.84826 0 m
.84826 .0148 L
.84937 .0148 L
.84937 0 L
.84826 0 L
s
1 0 0 r
.84965 0 m
.84965 .01169 L
.85077 .01169 L
.85077 0 L
F
0 g
.84965 0 m
.84965 .01169 L
.85077 .01169 L
.85077 0 L
.84965 0 L
s
1 0 0 r
.85105 0 m
.85105 .01181 L
.85216 .01181 L
.85216 0 L
F
0 g
.85105 0 m
.85105 .01181 L
.85216 .01181 L
.85216 0 L
.85105 0 L
s
1 0 0 r
.85244 0 m
.85244 .00938 L
.85355 .00938 L
.85355 0 L
F
0 g
.85244 0 m
.85244 .00938 L
.85355 .00938 L
.85355 0 L
.85244 0 L
s
1 0 0 r
.85383 0 m
.85383 .00763 L
.85495 .00763 L
.85495 0 L
F
0 g
.85383 0 m
.85383 .00763 L
.85495 .00763 L
.85495 0 L
.85383 0 L
s
1 0 0 r
.85523 0 m
.85523 .00494 L
.85634 .00494 L
.85634 0 L
F
0 g
.85523 0 m
.85523 .00494 L
.85634 .00494 L
.85634 0 L
.85523 0 L
s
1 0 0 r
.85662 0 m
.85662 .00796 L
.85774 .00796 L
.85774 0 L
F
0 g
.85662 0 m
.85662 .00796 L
.85774 .00796 L
.85774 0 L
.85662 0 L
s
1 0 0 r
.85801 0 m
.85801 .01051 L
.85913 .01051 L
.85913 0 L
F
0 g
.85801 0 m
.85801 .01051 L
.85913 .01051 L
.85913 0 L
.85801 0 L
s
1 0 0 r
.85941 0 m
.85941 .00992 L
.86052 .00992 L
.86052 0 L
F
0 g
.85941 0 m
.85941 .00992 L
.86052 .00992 L
.86052 0 L
.85941 0 L
s
1 0 0 r
.8608 0 m
.8608 .00743 L
.86192 .00743 L
.86192 0 L
F
0 g
.8608 0 m
.8608 .00743 L
.86192 .00743 L
.86192 0 L
.8608 0 L
s
1 0 0 r
.86219 0 m
.86219 .00684 L
.86331 .00684 L
.86331 0 L
F
0 g
.86219 0 m
.86219 .00684 L
.86331 .00684 L
.86331 0 L
.86219 0 L
s
1 0 0 r
.86359 0 m
.86359 .00634 L
.8647 .00634 L
.8647 0 L
F
0 g
.86359 0 m
.86359 .00634 L
.8647 .00634 L
.8647 0 L
.86359 0 L
s
1 0 0 r
.86498 0 m
.86498 .00521 L
.8661 .00521 L
.8661 0 L
F
0 g
.86498 0 m
.86498 .00521 L
.8661 .00521 L
.8661 0 L
.86498 0 L
s
1 0 0 r
.86638 0 m
.86638 .00636 L
.86749 .00636 L
.86749 0 L
F
0 g
.86638 0 m
.86638 .00636 L
.86749 .00636 L
.86749 0 L
.86638 0 L
s
1 0 0 r
.86777 0 m
.86777 .00787 L
.86888 .00787 L
.86888 0 L
F
0 g
.86777 0 m
.86777 .00787 L
.86888 .00787 L
.86888 0 L
.86777 0 L
s
1 0 0 r
.86916 0 m
.86916 .00461 L
.87028 .00461 L
.87028 0 L
F
0 g
.86916 0 m
.86916 .00461 L
.87028 .00461 L
.87028 0 L
.86916 0 L
s
1 0 0 r
.87056 0 m
.87056 .00832 L
.87167 .00832 L
.87167 0 L
F
0 g
.87056 0 m
.87056 .00832 L
.87167 .00832 L
.87167 0 L
.87056 0 L
s
1 0 0 r
.87195 0 m
.87195 .00825 L
.87306 .00825 L
.87306 0 L
F
0 g
.87195 0 m
.87195 .00825 L
.87306 .00825 L
.87306 0 L
.87195 0 L
s
1 0 0 r
.87334 0 m
.87334 .00312 L
.87446 .00312 L
.87446 0 L
F
0 g
.87334 0 m
.87334 .00312 L
.87446 .00312 L
.87446 0 L
.87334 0 L
s
1 0 0 r
.87474 0 m
.87474 .00733 L
.87585 .00733 L
.87585 0 L
F
0 g
.87474 0 m
.87474 .00733 L
.87585 .00733 L
.87585 0 L
.87474 0 L
s
1 0 0 r
.87613 0 m
.87613 .00325 L
.87725 .00325 L
.87725 0 L
F
0 g
.87613 0 m
.87613 .00325 L
.87725 .00325 L
.87725 0 L
.87613 0 L
s
1 0 0 r
.87752 0 m
.87752 .01018 L
.87864 .01018 L
.87864 0 L
F
0 g
.87752 0 m
.87752 .01018 L
.87864 .01018 L
.87864 0 L
.87752 0 L
s
1 0 0 r
.87892 0 m
.87892 .00795 L
.88003 .00795 L
.88003 0 L
F
0 g
.87892 0 m
.87892 .00795 L
.88003 .00795 L
.88003 0 L
.87892 0 L
s
1 0 0 r
.88031 0 m
.88031 .00922 L
.88143 .00922 L
.88143 0 L
F
0 g
.88031 0 m
.88031 .00922 L
.88143 .00922 L
.88143 0 L
.88031 0 L
s
1 0 0 r
.8817 0 m
.8817 .01177 L
.88282 .01177 L
.88282 0 L
F
0 g
.8817 0 m
.8817 .01177 L
.88282 .01177 L
.88282 0 L
.8817 0 L
s
1 0 0 r
.8831 0 m
.8831 .0049 L
.88421 .0049 L
.88421 0 L
F
0 g
.8831 0 m
.8831 .0049 L
.88421 .0049 L
.88421 0 L
.8831 0 L
s
1 0 0 r
.88449 0 m
.88449 .00347 L
.88561 .00347 L
.88561 0 L
F
0 g
.88449 0 m
.88449 .00347 L
.88561 .00347 L
.88561 0 L
.88449 0 L
s
1 0 0 r
.88589 0 m
.88589 .0029 L
.887 .0029 L
.887 0 L
F
0 g
.88589 0 m
.88589 .0029 L
.887 .0029 L
.887 0 L
.88589 0 L
s
1 0 0 r
.88728 0 m
.88728 .00922 L
.88839 .00922 L
.88839 0 L
F
0 g
.88728 0 m
.88728 .00922 L
.88839 .00922 L
.88839 0 L
.88728 0 L
s
1 0 0 r
.88867 0 m
.88867 .00882 L
.88979 .00882 L
.88979 0 L
F
0 g
.88867 0 m
.88867 .00882 L
.88979 .00882 L
.88979 0 L
.88867 0 L
s
1 0 0 r
.89007 0 m
.89007 .00797 L
.89118 .00797 L
.89118 0 L
F
0 g
.89007 0 m
.89007 .00797 L
.89118 .00797 L
.89118 0 L
.89007 0 L
s
1 0 0 r
.89146 0 m
.89146 .00765 L
.89257 .00765 L
.89257 0 L
F
0 g
.89146 0 m
.89146 .00765 L
.89257 .00765 L
.89257 0 L
.89146 0 L
s
1 0 0 r
.89285 0 m
.89285 .01215 L
.89397 .01215 L
.89397 0 L
F
0 g
.89285 0 m
.89285 .01215 L
.89397 .01215 L
.89397 0 L
.89285 0 L
s
1 0 0 r
.89425 0 m
.89425 .00504 L
.89536 .00504 L
.89536 0 L
F
0 g
.89425 0 m
.89425 .00504 L
.89536 .00504 L
.89536 0 L
.89425 0 L
s
1 0 0 r
.89564 0 m
.89564 .00546 L
.89676 .00546 L
.89676 0 L
F
0 g
.89564 0 m
.89564 .00546 L
.89676 .00546 L
.89676 0 L
.89564 0 L
s
1 0 0 r
.89703 0 m
.89703 .00894 L
.89815 .00894 L
.89815 0 L
F
0 g
.89703 0 m
.89703 .00894 L
.89815 .00894 L
.89815 0 L
.89703 0 L
s
1 0 0 r
.89843 0 m
.89843 .00994 L
.89954 .00994 L
.89954 0 L
F
0 g
.89843 0 m
.89843 .00994 L
.89954 .00994 L
.89954 0 L
.89843 0 L
s
1 0 0 r
.89982 0 m
.89982 .00844 L
.90094 .00844 L
.90094 0 L
F
0 g
.89982 0 m
.89982 .00844 L
.90094 .00844 L
.90094 0 L
.89982 0 L
s
1 0 0 r
.90122 0 m
.90122 .00788 L
.90233 .00788 L
.90233 0 L
F
0 g
.90122 0 m
.90122 .00788 L
.90233 .00788 L
.90233 0 L
.90122 0 L
s
1 0 0 r
.90261 0 m
.90261 .00607 L
.90372 .00607 L
.90372 0 L
F
0 g
.90261 0 m
.90261 .00607 L
.90372 .00607 L
.90372 0 L
.90261 0 L
s
1 0 0 r
.904 0 m
.904 .00286 L
.90512 .00286 L
.90512 0 L
F
0 g
.904 0 m
.904 .00286 L
.90512 .00286 L
.90512 0 L
.904 0 L
s
1 0 0 r
.9054 0 m
.9054 .00419 L
.90651 .00419 L
.90651 0 L
F
0 g
.9054 0 m
.9054 .00419 L
.90651 .00419 L
.90651 0 L
.9054 0 L
s
1 0 0 r
.90679 0 m
.90679 .00594 L
.9079 .00594 L
.9079 0 L
F
0 g
.90679 0 m
.90679 .00594 L
.9079 .00594 L
.9079 0 L
.90679 0 L
s
1 0 0 r
.90818 0 m
.90818 .00718 L
.9093 .00718 L
.9093 0 L
F
0 g
.90818 0 m
.90818 .00718 L
.9093 .00718 L
.9093 0 L
.90818 0 L
s
1 0 0 r
.90958 0 m
.90958 .00492 L
.91069 .00492 L
.91069 0 L
F
0 g
.90958 0 m
.90958 .00492 L
.91069 .00492 L
.91069 0 L
.90958 0 L
s
1 0 0 r
.91097 0 m
.91097 .00596 L
.91209 .00596 L
.91209 0 L
F
0 g
.91097 0 m
.91097 .00596 L
.91209 .00596 L
.91209 0 L
.91097 0 L
s
1 0 0 r
.91236 0 m
.91236 .00503 L
.91348 .00503 L
.91348 0 L
F
0 g
.91236 0 m
.91236 .00503 L
.91348 .00503 L
.91348 0 L
.91236 0 L
s
1 0 0 r
.91376 0 m
.91376 .00371 L
.91487 .00371 L
.91487 0 L
F
0 g
.91376 0 m
.91376 .00371 L
.91487 .00371 L
.91487 0 L
.91376 0 L
s
1 0 0 r
.91515 0 m
.91515 .00427 L
.91627 .00427 L
.91627 0 L
F
0 g
.91515 0 m
.91515 .00427 L
.91627 .00427 L
.91627 0 L
.91515 0 L
s
1 0 0 r
.91654 0 m
.91654 .00757 L
.91766 .00757 L
.91766 0 L
F
0 g
.91654 0 m
.91654 .00757 L
.91766 .00757 L
.91766 0 L
.91654 0 L
s
1 0 0 r
.91794 0 m
.91794 .00974 L
.91905 .00974 L
.91905 0 L
F
0 g
.91794 0 m
.91794 .00974 L
.91905 .00974 L
.91905 0 L
.91794 0 L
s
1 0 0 r
.91933 0 m
.91933 .01039 L
.92045 .01039 L
.92045 0 L
F
0 g
.91933 0 m
.91933 .01039 L
.92045 .01039 L
.92045 0 L
.91933 0 L
s
1 0 0 r
.92073 0 m
.92073 .00969 L
.92184 .00969 L
.92184 0 L
F
0 g
.92073 0 m
.92073 .00969 L
.92184 .00969 L
.92184 0 L
.92073 0 L
s
1 0 0 r
.92212 0 m
.92212 .00765 L
.92323 .00765 L
.92323 0 L
F
0 g
.92212 0 m
.92212 .00765 L
.92323 .00765 L
.92323 0 L
.92212 0 L
s
1 0 0 r
.92351 0 m
.92351 .00385 L
.92463 .00385 L
.92463 0 L
F
0 g
.92351 0 m
.92351 .00385 L
.92463 .00385 L
.92463 0 L
.92351 0 L
s
1 0 0 r
.92491 0 m
.92491 .00311 L
.92602 .00311 L
.92602 0 L
F
0 g
.92491 0 m
.92491 .00311 L
.92602 .00311 L
.92602 0 L
.92491 0 L
s
1 0 0 r
.9263 0 m
.9263 .01043 L
.92741 .01043 L
.92741 0 L
F
0 g
.9263 0 m
.9263 .01043 L
.92741 .01043 L
.92741 0 L
.9263 0 L
s
1 0 0 r
.92769 0 m
.92769 .00565 L
.92881 .00565 L
.92881 0 L
F
0 g
.92769 0 m
.92769 .00565 L
.92881 .00565 L
.92881 0 L
.92769 0 L
s
1 0 0 r
.92909 0 m
.92909 .00956 L
.9302 .00956 L
.9302 0 L
F
0 g
.92909 0 m
.92909 .00956 L
.9302 .00956 L
.9302 0 L
.92909 0 L
s
1 0 0 r
.93048 0 m
.93048 .0095 L
.9316 .0095 L
.9316 0 L
F
0 g
.93048 0 m
.93048 .0095 L
.9316 .0095 L
.9316 0 L
.93048 0 L
s
1 0 0 r
.93187 0 m
.93187 -0.00074 L
.93299 -0.00074 L
.93299 0 L
F
0 g
.93187 0 m
0 0 rlineto s
.93299 0 m
.93187 0 L
s
1 0 0 r
.93327 0 m
.93327 .00515 L
.93438 .00515 L
.93438 0 L
F
0 g
.93327 0 m
.93327 .00515 L
.93438 .00515 L
.93438 0 L
.93327 0 L
s
1 0 0 r
.93466 0 m
.93466 .00162 L
.93578 .00162 L
.93578 0 L
F
0 g
.93466 0 m
.93466 .00162 L
.93578 .00162 L
.93578 0 L
.93466 0 L
s
1 0 0 r
.93606 0 m
.93606 -0.00177 L
.93717 -0.00177 L
.93717 0 L
F
0 g
.93606 0 m
0 0 rlineto s
.93717 0 m
.93606 0 L
s
1 0 0 r
.93745 0 m
.93745 .00917 L
.93856 .00917 L
.93856 0 L
F
0 g
.93745 0 m
.93745 .00917 L
.93856 .00917 L
.93856 0 L
.93745 0 L
s
1 0 0 r
.93884 0 m
.93884 .00495 L
.93996 .00495 L
.93996 0 L
F
0 g
.93884 0 m
.93884 .00495 L
.93996 .00495 L
.93996 0 L
.93884 0 L
s
1 0 0 r
.94024 0 m
.94024 .00562 L
.94135 .00562 L
.94135 0 L
F
0 g
.94024 0 m
.94024 .00562 L
.94135 .00562 L
.94135 0 L
.94024 0 L
s
1 0 0 r
.94163 0 m
.94163 .00198 L
.94274 .00198 L
.94274 0 L
F
0 g
.94163 0 m
.94163 .00198 L
.94274 .00198 L
.94274 0 L
.94163 0 L
s
1 0 0 r
.94302 0 m
.94302 .0012 L
.94414 .0012 L
.94414 0 L
F
0 g
.94302 0 m
.94302 .0012 L
.94414 .0012 L
.94414 0 L
.94302 0 L
s
1 0 0 r
.94442 0 m
.94442 .00032 L
.94553 .00032 L
.94553 0 L
F
0 g
.94442 0 m
.94442 .00032 L
.94553 .00032 L
.94553 0 L
.94442 0 L
s
1 0 0 r
.94581 0 m
.94581 .01079 L
.94693 .01079 L
.94693 0 L
F
0 g
.94581 0 m
.94581 .01079 L
.94693 .01079 L
.94693 0 L
.94581 0 L
s
1 0 0 r
.9472 0 m
.9472 .00826 L
.94832 .00826 L
.94832 0 L
F
0 g
.9472 0 m
.9472 .00826 L
.94832 .00826 L
.94832 0 L
.9472 0 L
s
1 0 0 r
.9486 0 m
.9486 .00703 L
.94971 .00703 L
.94971 0 L
F
0 g
.9486 0 m
.9486 .00703 L
.94971 .00703 L
.94971 0 L
.9486 0 L
s
1 0 0 r
.94999 0 m
.94999 .01052 L
.95111 .01052 L
.95111 0 L
F
0 g
.94999 0 m
.94999 .01052 L
.95111 .01052 L
.95111 0 L
.94999 0 L
s
1 0 0 r
.95138 0 m
.95138 .00671 L
.9525 .00671 L
.9525 0 L
F
0 g
.95138 0 m
.95138 .00671 L
.9525 .00671 L
.9525 0 L
.95138 0 L
s
1 0 0 r
.95278 0 m
.95278 .008 L
.95389 .008 L
.95389 0 L
F
0 g
.95278 0 m
.95278 .008 L
.95389 .008 L
.95389 0 L
.95278 0 L
s
1 0 0 r
.95417 0 m
.95417 .0024 L
.95529 .0024 L
.95529 0 L
F
0 g
.95417 0 m
.95417 .0024 L
.95529 .0024 L
.95529 0 L
.95417 0 L
s
1 0 0 r
.95557 0 m
.95557 .01277 L
.95668 .01277 L
.95668 0 L
F
0 g
.95557 0 m
.95557 .01277 L
.95668 .01277 L
.95668 0 L
.95557 0 L
s
1 0 0 r
.95696 0 m
.95696 .01763 L
.95807 .01763 L
.95807 0 L
F
0 g
.95696 0 m
.95696 .01763 L
.95807 .01763 L
.95807 0 L
.95696 0 L
s
1 0 0 r
.95835 0 m
.95835 .00909 L
.95947 .00909 L
.95947 0 L
F
0 g
.95835 0 m
.95835 .00909 L
.95947 .00909 L
.95947 0 L
.95835 0 L
s
1 0 0 r
.95975 0 m
.95975 .01115 L
.96086 .01115 L
.96086 0 L
F
0 g
.95975 0 m
.95975 .01115 L
.96086 .01115 L
.96086 0 L
.95975 0 L
s
1 0 0 r
.96114 0 m
.96114 .00681 L
.96225 .00681 L
.96225 0 L
F
0 g
.96114 0 m
.96114 .00681 L
.96225 .00681 L
.96225 0 L
.96114 0 L
s
1 0 0 r
.96253 0 m
.96253 .00537 L
.96365 .00537 L
.96365 0 L
F
0 g
.96253 0 m
.96253 .00537 L
.96365 .00537 L
.96365 0 L
.96253 0 L
s
1 0 0 r
.96393 0 m
.96393 .00033 L
.96504 .00033 L
.96504 0 L
F
0 g
.96393 0 m
.96393 .00033 L
.96504 .00033 L
.96504 0 L
.96393 0 L
s
1 0 0 r
.96532 0 m
.96532 .01022 L
.96644 .01022 L
.96644 0 L
F
0 g
.96532 0 m
.96532 .01022 L
.96644 .01022 L
.96644 0 L
.96532 0 L
s
1 0 0 r
.96671 0 m
.96671 .01179 L
.96783 .01179 L
.96783 0 L
F
0 g
.96671 0 m
.96671 .01179 L
.96783 .01179 L
.96783 0 L
.96671 0 L
s
1 0 0 r
.96811 0 m
.96811 .01806 L
.96922 .01806 L
.96922 0 L
F
0 g
.96811 0 m
.96811 .01806 L
.96922 .01806 L
.96922 0 L
.96811 0 L
s
1 0 0 r
.9695 0 m
.9695 .00707 L
.97062 .00707 L
.97062 0 L
F
0 g
.9695 0 m
.9695 .00707 L
.97062 .00707 L
.97062 0 L
.9695 0 L
s
1 0 0 r
.97089 0 m
.97089 .01058 L
.97201 .01058 L
.97201 0 L
F
0 g
.97089 0 m
.97089 .01058 L
.97201 .01058 L
.97201 0 L
.97089 0 L
s
1 0 0 r
.97229 0 m
.97229 .00576 L
.9734 .00576 L
.9734 0 L
F
0 g
.97229 0 m
.97229 .00576 L
.9734 .00576 L
.9734 0 L
.97229 0 L
s
1 0 0 r
.97368 0 m
.97368 .00458 L
.9748 .00458 L
.9748 0 L
F
0 g
.97368 0 m
.97368 .00458 L
.9748 .00458 L
.9748 0 L
.97368 0 L
s
1 0 0 r
.97508 0 m
.97508 .00961 L
.97619 .00961 L
.97619 0 L
F
0 g
.97508 0 m
.97508 .00961 L
.97619 .00961 L
.97619 0 L
.97508 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{706.25, 141.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;20000SB000`400?l00000o`00003oo`3ooooo
0?oool@0oooo003o0?ooool0ooooa03oool006h0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`2:0?ooo`00KP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08X0oooo
001^0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0RP3oool00680oooo00<00000
0?ooo`3oool00`3oool4000000<0oooo00<000000?ooo`3oool00P3oool4000000<0oooo00@00000
0?ooo`3oool0oooo1P0000030?ooo`@00000103oool4000000@0oooo1000000>0?ooo`H000001P3o
ool010000000oooo0?ooo`0000050?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`H00000
0`3oool4000000@0oooo100000040?ooo`@000004@3oool600000080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`H000000`3oool4000000@0
oooo100000060?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool600000003
0?ooo`000000oooo00L0oooo00@000000?ooo`3oool00000103oool6000000<0oooo100000040?oo
o`@000001P3oool00`000000oooo0?ooo`0<0?ooo`H000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool6
000000<0oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`090?ooo`H000000`3oool3
000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`@000000P3oool0
0`000000oooo0?ooo`020?ooo`H000000`3oool4000000@0oooo100000060?ooo`030000003oool0
oooo00d0oooo100000030?ooo`040000003oool0oooo0?ooo`H000000P3oool00`000000oooo0?oo
o`020?ooo`H000000`3oool4000000@0oooo100000030?ooo`H00000J@3oool00680oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000006d0oooo
001R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool7
000000030?ooo`000000oooo00P0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`L0000000<0oooo0000003oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1Z0?ooo`00HP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000080?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06T0oooo001R0?ooo`030000003o
ool0oooo0080oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000<0oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000103oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`<0
000000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`<0000000D0oooo0000003oool0oooo0000
00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000070?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool2000000<0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo06P0oooo001R0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000P0000040?ooo`050000003oool0oooo0000003oool00`0000040?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0?ooo`80
00000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01<0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000030?ooo`8000000P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`0000000P0000040?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo06L0oooo001R0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo000000090?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000
1`3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`00
00000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000070?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1W0?ooo`00H03oool00`000000oooo000000040?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`0000002@3oool00`000000oooo000000040?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P000000oooo
0?ooo`000000oooo000000H0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000001@0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo000000040?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`070000003oool0oooo0?ooo`00
0000oooo0000000>0?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`07
0000003oool0oooo0?ooo`000000oooo0000000;0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool0
1`000000oooo0?ooo`3oool000000?ooo`0000003P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo06L0oooo001Q0?ooo`8000001@3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`040000003oool0oooo000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool0oooo0P0000060?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P00000E0?ooo`80
0000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool20000
00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000/0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103o
ool2000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00P3oool2000000l0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo06L0oooo001R0?ooo`030000003oool0oooo00@0
oooo0`0000060?ooo`030000003oool0oooo00<000001P3oool00`000000oooo00000003000000@0
oooo100000040?ooo`@00000103oool4000000l0oooo100000070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0100000050?ooo`030000003oool0oooo00@00000103oool4000000@0
oooo100000040?ooo`@000004P3oool4000000H0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0000000<00000103oool4000000@0oooo100000060?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool00`3oool4000000D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@00000103oool4000000@0oooo100000060?oo
o`030000003oool0oooo00d0oooo100000060?ooo`030000003oool0oooo00D0oooo1`0000050?oo
o`030000003oool0000000<00000103oool4000000@0oooo100000060?ooo`030000003oool0oooo
00X0oooo100000040?ooo`@000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo100000050?ooo`030000003oool0oooo00@00000103oool4000000@0oooo100000060?oo
o`030000003oool0oooo00h0oooo0`0000060?ooo`030000003oool0000000<000001P3oool00`00
0000oooo0?ooo`04000000@0oooo100000040?ooo`@00000103oool4000006X0oooo003o0?ooool0
ooooa03oool00?l0ooooo`3oooo40?ooo`00o`3ooooo0?oool@0oooo003o0?ooool0ooooa03oool0
0?l0ooooo`3oooo40?ooo`00o`3ooooo0?oool@0oooo003o0?ooool0ooooa03oool00?l0ooooo`3o
ooo40?ooo`00o`3ooooo0?oool@0oooo003o0?oooa<0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0:T0oooo0P0000090?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`000000G03oool00700ooooo`00003o000001X00000>P3oool00700oooo
00<000000?ooo`3oool02`3ooon?000000030?ooo`00000000000?l00000FP0000000`3oool00000
0000000?000000`0oooo00<000000?ooo`3oool0>03oool00700oooo00<000000?ooo`3oool02`3o
ool6000000030?ooo`000000000008D000000P3ooolH000000030?ooo`000000000001`0000000<0
oooo0000000000003@0000000`3oool0000000000002000000070?ooo`00000000000000003oool0
00000?ooo`3o000000D0000000D0oooo00000000000000000?ooo`0A000000`0oooo00<000000?oo
o`3oool0>03oool00700oooo00<000000?ooo`3oool02`3oool00`000000oooo0000000200000080
oooo3`0000001P3oool000000?ooo`3oool000000?ooo`@0000000<0oooo0000000000000`000005
0?ooo`@000000P3oool4000000030?ooo`00000000000080000000<0oooo0000000000008P000000
0`3oool0000000000007000000030?ooo`00000000000180000000<0oooo0000000000003@000002
0?ooo`8000000`3oool3000000030?ooo`000000000000d0000000<0oooo0000000000000P000000
0`3oool000000000000B000000030?ooo`00000000000080000000<0oooo0000000000000`3oool4
000000040?ooo`00000000000?ooo`80000000<0oooo0000000000000P000000103oool000000000
000000030?ooo`h0000000<0oooo0000000000001`0000000`3oool0000000000008000000030?oo
o`00000000000340000000<0oooo0000000000001`0000000`3oool000000000000=000000030?oo
o`000000000004P0000000<0oooo000000000000:@0000020?ooo`h0000000<0oooo000000000000
0`000000103oool000000000000000030?ooo`<0000000<0oooo0000000000003`00000<0?ooo`03
0000003oool0oooo03P0oooo001`0?ooo`030000003oool0oooo00d0oooo0`0000020?ooo`@00000
00<0oooo0000000000001`0000080?ooo`8000004P3oool4000000030?ooo`000000000000800000
00<0oooo000000000000200000000`3oool0000000000002000000030?ooo`000000000001800000
00<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`000000000001800000
00<0oooo000000000000300000030?ooo`8000001`3oool?000000030?ooo`000000000000800000
00<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`000000000000<00000
00<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`000000000000P0oooo
0P0000040?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`T000000P3oool300000003
0?ooo`00000000000080000000<0oooo0000000000000P000000103oool000000000000000020?oo
o`@000000P3ooolN000000030?ooo`00000000000080000000<0oooo0000000000003@0000000`3o
ool000000?ooo`02000000030?ooo`00000000000080000000<0oooo000000000000200000000`3o
ool0000000000002000000030?ooo`00000000000080000000<0oooo0000000000001`0000000`3o
ool000000000000200000080oooo100000000`3oool000000000000=000000030?ooo`0000000000
01h0000000@0oooo000000000000oooo3`0000000`3oool000000000000;00000080oooo2@000002
0?ooo`@0000000<0oooo0000000000000P0000020?ooo`8000000P3oool5000000040?ooo`000000
0000000000<0oooo00@000000?ooo`3oool0oooo2@0000000`3oool0000000000003000000030?oo
o`000000oooo00/0oooo00<000000?ooo`3oool0>03oool00700oooo0`00000L0?ooo`<000007@3o
ool4000000030?ooo`00000000000080000000<0oooo000000000000200000000`3oool000000000
0002000000030?ooo`00000000000080000000@0oooo00000000000000000P3oool5000000040?oo
o`000000000000000080oooo100000000`3oool0000000000002000000040?ooo`00000000000000
0080oooo2@0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool00000000000070000
00`0oooo100000000`3oool000000000000700000080oooo100000000`3oool00000000000020000
00<0oooo0P0000070?ooo`<000000P3oool400000140oooo00<000000?ooo`3oool00`3oool20000
00<0oooo2@0000020?ooo`8000000P3oool01@000000oooo000000000000oooo00@0000000@0oooo
00000000000000000P3oool400000080oooo7P0000000`3oool0000000000002000000030?ooo`00
000000000080000000<0oooo000000000000200000000`00o`0000000?ooo`02000000030?ooo`00
000000000080000000<0oooo0000000000001P0000030?ooo`@0000000<0oooo0000000000000P00
00000`3oool0000000000007000000030?ooo`0000000000008000000P3oool4000000030?ooo`00
0000000000d0000000<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`00
0000000001@0000000@0oooo000000000000oooo100000000`3oool0000000000008000000030?oo
o`00000000000080000000<0oooo0000000000000P0000000`3oool00000000000090?ooo`<00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo0`0000020?ooo`<0
00000`3oool010000000oooo0?ooo`3oool4000000030?ooo`00000000000080000000<0oooo0000
000000000`0000000`3oool000000?ooo`0;0?ooo`030000003oool0oooo03P0oooo001`0?ooo`03
0000003oool0oooo03`0oooo0P0000030?ooo`@0000000<0oooo0000000000001`0000020?ooo`@0
00000`3oool2000000040?ooo`000000000000000080oooo1@0000000`3oool00000000000030?oo
o`050000003oool0oooo0000003oool010000000103oool000000000000000020?ooo`T000000P3o
ool4000000040?ooo`000000000000000080oooo0P0000000`3oool0000000000004000000`0oooo
100000000`3oool0000000000005000000040?ooo`000000oooo0?ooo`80000000@0oooo0000003o
ool000003`3oool300000080oooo0`00000B0?ooo`030000003oool0oooo00P0oooo2@0000020?oo
o`8000000P3oool00`000000oooo0?ooo`020?ooo`<000000P3oool2000000<0oooo100000020?oo
oah0000000<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`0000000000
00<0oooo0P0000001P3oool0000000000000o`0000000?ooo`80000000<0oooo0000000000000P00
00000`3oool0000000000002000000030?ooo`000000000000@0oooo100000000`3oool000000000
0002000000040?ooo`000000000000000080oooo100000000`3oool0000000000002000000L0oooo
3`0000000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo000000000000
3@000000103oool000000000000000040?ooo`80000000<0oooo0000000000000P0000000`3oool0
000000000008000000030?ooo`00000000000080000000@0oooo00000000000000003`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo100000020?ooo`<000003`3oool00`00
0000oooo0?ooo`0h0?ooo`00L03oool00`000000oooo0?ooo`0l0?ooo`800000103oool200000080
oooo2@0000030?ooo`800000203oool200000080oooo100000020?ooo`800000203oool400000004
0?ooo`000000000000000080oooo0P0000000`3oool0000000000002000000030?ooo`000000oooo
00<0oooo0P000000103oool000000000000000070?ooo`<000003P3oool200000080oooo1`000007
0?ooo`030000003oool0000000l0oooo0`0000020?ooo`8000007P3oool3000000030?ooo`000000
000000<000000P3oool200000080oooo00<000000?ooo`3oool00P3oool300000080oooo0P000003
0?ooo`@000000P3oool4000000040?ooo`000000000000000080oooo100000000`3oool000000000
0008000000030?ooo`00000000000080000000<0oooo0000003oool00P0000000`3oool000000000
0002000000030?ooo`000000000000<0oooo0P0000030?ooo`030?l000000000oooo0080000000<0
oooo0000000000000P0000000`3oool0000000000002000000030?ooo`000000000000@0oooo1000
00001@3oool000000?ooo`3oool0000000H0oooo0P0000060?ooo`030000003oool0oooo00D0oooo
100000000`3oool0000000000008000000030?ooo`00000000000080000000<0oooo000000000000
0P0000000`3oool000000000000=000000040?ooo`0000000000000000@0oooo0P0000030?ooo`80
000000<0oooo000000000000200000000`3oool0000000000002000000030?ooo`000000oooo02d0
oooo00<0o`000?ooo`3oool01`3oool3000000@0oooo0P00000?0?ooo`030000003oool0oooo03P0
oooo001`0?ooo`030000003oool0oooo0480oooo0P00000:0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool4000000030?ooo`00o`00oooo00/0oooo0P0000000`3oool00000
000000030?ooo`8000002`3oool2000000040?ooo`0000000000000000L0oooo0`00000B0?ooo`<0
00000P3oool2000000L0oooo00<000000?ooo`0000003`3oool300000080oooo0P00000O0?ooo`80
000000@0oooo000000000000oooo0P0000020?ooo`8000001`3oool300000080oooo0P0000030?oo
o`@000000P3oool3000000<0oooo0P0000020?ooo`@0000000<0oooo00000000000020000000103o
ool000000000000000020?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`8000000`3oool0
1P3o0000oooo0?ooo`3oool000000?ooo`@0000000@0oooo00000000000000000P3oool2000000D0
oooo0`00000;0?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`<000000P3oool400000080
oooo100000000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo00000000
00000P0000000`3oool0000000000003000000040?ooo`0000000000000000@0oooo0P0000030?oo
o`80000000<0oooo0000000000000P0000000`3oool000000000000200000080oooo0`0000020?oo
o`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool0203oool2000000@0oooo0P00000?0?oo
o`030000003oool0oooo03P0oooo001`0?ooo`030000003oool0oooo0400oooo00<00?l00?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3o
ool00?l0303oool2000001<0oooo0P000000103oool000000000000000070?ooo`<000005`3oool2
000001/0oooo00<000000?ooo`3oool00P00000=0?ooo`030?l0003oool0oooo00l0oooo0P000000
0`3oool00000000000050?ooo`800000303oool2000000H0oooo00<000000?ooo`00o`000`000003
0?ooo`8000000P3oool3000000<0oooo0`0000000`3oool0000000000003000000030?ooo`000000
oooo00<0oooo00<000000?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0
oooo0080oooo0P0000030?ooo`030?l0003oool0oooo00<0oooo10000000103oool0000000000000
00020?ooo`8000004`3oool2000001<0oooo0P0000030?ooo`800000103oool4000000030?ooo`00
000000000080000000<0oooo0000000000000P0000000`3oool00000000000030?ooo`D0000000@0
oooo0000000000000000103oool2000000<0oooo0P0000000`3oool0000000000002000000030?oo
o`000000000000800000=@3oool20?l000X0oooo0P0000040?ooo`8000003`3oool00`000000oooo
0?ooo`0h0?ooo`00L03oool3000001L0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?oo
o`0Q0?ooo`03003o003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0>0?ooo`800?l0303oool200000200oooo0`00000d0?ooo`030000003oool0oooo00l0oooo00<0
o`000?ooo`3oool03`3oool2000000030?ooo`000000000000D0oooo0P00000<0?ooo`8000001P3o
ool00`000000oooo0?l00003000000<0oooo0P0000020?ooo`<000000`3oool3000000050?ooo`00
000000000?ooo`0000000P3oool01P000000oooo0?ooo`3oool00?l0000000@0oooo00<00?l00?oo
o`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0o`000?oo
o`3oool02P3oool00`000000oooo0?ooo`02000001<0oooo0P00000C0?ooo`8000002@3oool40000
00030?ooo`00000000000080000000@0oooo00000000000000000P3oool2000000<0oooo1@000000
103oool000000000000000040?ooo`8000001P3oool4000000030?ooo`000000000003L0oooo0P3o
000Q0?ooo`030000003oool0oooo03P0oooo001`0?ooo`030000003oool0oooo01H0oooo0P00o`04
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`03
0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`02
0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0603oool00`00o`00oooo0?ooo`02
0?ooo`06003o003oool0oooo0?ooo`00o`00o`00303oool200000240oooo0P00000d0?ooo`030000
003oool0oooo00l0oooo00<0o`000?ooo`3oool03`3oool2000000030?ooo`000000000000D0oooo
0P00000<0?ooo`8000000`3oool01`00o`00oooo0?ooo`000000oooo0?l00000o`000P0000030?oo
o`8000000P3oool2000000<0oooo00D00?l00?ooo`00000000000?ooo`02000000050?ooo`000000
oooo003o000000000`3oool00`00o`0000000?ooo`020?ooo`800?l0103oool01000o`00oooo0?oo
o`3oool2003o00@0oooo00<0o`00003o003oool02P3oool00`000000oooo0?ooo`0E0?ooo`800000
4`3oool2000000T0oooo100000000`3oool00000000000030?ooo`8000000`3oool2000000<0oooo
1@000000103oool0000000000000000<0?ooo`@0000000<0oooo000000000000=`3oool20?l00240
oooo00<000000?ooo`3oool0>03oool00700oooo00<000000?ooo`3oool0303oool00`00o`00oooo
0?ooo`030?ooo`04003o003oool0oooo0?ooo`800?l00`3oool00`00o`00o`000?ooo`020?ooo`03
003o003o0000oooo00<0oooo00<0o`000?ooo`3oool00P3oool2003o00<0oooo00<00?l00?l0003o
ool00P3oool00`00o`00o`000?ooo`030?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3o
ool0203oool00`00o`00oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00H00?l00?ooo`3o
ool0oooo003o003o00040?ooo`030?l0003oool0oooo00D0oooo0P00000[0?ooo`030?l0003oool0
oooo03/0oooo00<0o`000?ooo`3oool04P3oool2000000D0oooo0P00000<0?ooo`8000000`3oool0
1@00o`00oooo0?ooo`3oool00?l00080o`001@3oool2000000L0oooo00D00?l00?ooo`0000000000
0?ooo`02000000050?ooo`000000oooo003o000000000`3oool00`00o`00oooo0?ooo`020?ooo`03
003o003o0000oooo0080oooo00<00?l00?l0003oool00P3oool00`00o`00o`000?ooo`030?ooo`03
0?l00000o`00oooo0080oooo00<00?l00?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`80
00004`3oool2000000T0oooo0`0000070?ooo`8000000`3oool2000000<0oooo1@000000103oool0
000000000000000<0?ooo`@0000000<0oooo0000000000003P3oool00`00o`00oooo0?ooo`0Q0?oo
o`03003o003oool0oooo0080oooo0P3o000C0?ooo`03003o003oool0oooo00/0oooo00<000000?oo
o`3oool0>03oool00700oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`020?ooo`03
003o003o0000oooo0080oooo00<00?l00?l0003oool00P3oool00`00o`00o`000?ooo`020?ooo`80
o`00103oool00`3o0000oooo0?ooo`020?ooo`03003o003o0000oooo0080oooo00<00?l00?l00000
o`000P3oool00`00o`00o`000?ooo`020?ooo`03003o003o0000oooo00<0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?ooo`80o`0000D00?l00?oo
o`3oool0oooo0?l000040?ooo`03003o003oool0oooo00800000:`3oool00`3o0000oooo0?ooo`0k
0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool2000001L0oooo00<00?l0
0?l0003oool00P3oool00`00o`00o`000?l000090?ooo`03003o003oool0oooo0080oooo00D00?l0
0?ooo`0000000000003o0002000000040?ooo`000000oooo0?l000@0oooo00<00?l00?ooo`3oool0
0P3oool00`00o`00o`000?ooo`020?ooo`03003o003o0000oooo0080oooo00<00?l00?l0003oool0
0`3oool00`3o00000?l00?ooo`020?ooo`03003o003oool0oooo00D0oooo00<000000?ooo`3oool0
5@3oool2000001h0oooo0`00000<0?ooo`8000000`3oool5000000040?ooo`0000000000000000`0
oooo100000000`3oool000000000000>0?ooo`03003o003oool0oooo0240oooo00<0o`000?ooo`3o
ool00P3oool20?l001<0oooo00<00?l00?ooo`3oool02`3oool00`000000oooo0?ooo`0h0?ooo`00
L03oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00800?l00P3o00030?ooo`80o`00
0`3oool20?l000<0oooo0P3o00001P00o`00oooo0?ooo`3oool0o`00003o00<0oooo0P3o00030?oo
o`80o`0000<00?l00?ooo`3oool00P3o00001@00o`00oooo0?ooo`00o`00o`0000@0oooo00<0o`00
0?ooo`3oool00`3oool01P00o`00oooo0?ooo`3oool00?l00?l000@0oooo00<00?l00?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`020?ooo`03003o003o0000oooo0080oooo00<00?l00?l0003oool0
0P3oool20?l00005003o003oool0oooo003o003o0000103oool00`00o`00oooo0?ooo`030?ooo`03
003o003oool0oooo0080oooo00<00?l00?ooo`3oool08P3oool00`3o0000oooo0?ooo`0j0?ooo`03
003o003o0000oooo00h0oooo00<0o`000?ooo`3oool00P3oool2000000d0oooo00<00?l00?ooo`3o
ool01`3oool00`00o`00o`000?ooo`020?ooo`030?l0003oool0o`0000<0oooo00<00?l00?ooo`3o
ool00`3oool01P00o`00oooo0?ooo`3oool00?l00?l000<0oooo00<00?l00000000000000`3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo0P3o00030?ooo`03003o003o0000
oooo0080oooo00<00?l00?l0003oool00`3oool00`3o00000?l00?ooo`020?ooo`030?l0003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0B0?ooo`03003o003oool0
oooo01P0oooo0`00000<0?ooo`8000000`3oool5000000040?ooo`0000000000000000`0oooo1000
000@0?ooo`800?l0103oool00`00o`00oooo0?ooo`0K0?ooo`03003o003o0000oooo00<0oooo0P3o
000C0?ooo`030?l0003oool0oooo00/0oooo00<000000?ooo`3oool0>03oool00700oooo00<00000
0?ooo`3oool0303oool00`3o0000oooo0?ooo`02003o0080o`000P3oool00`00o`00o`000?l00002
0?ooo`04003o003o0000o`00003o0080oooo0P3o00001P00o`00oooo0?ooo`3oool0o`00003o0080
oooo00@00?l00?l0003o0000oooo0P00o`001@3o0000oooo0?l00000o`00oooo0080o`000P00o`00
0`3oool00?l00?l000040?ooo`030?l00000o`00oooo0080oooo00<00?l00?l0003oool00P3oool0
0`00o`00o`000?ooo`020?ooo`03003o003o0000oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
0`00o`00o`000?ooo`020?ooo`03003o003o0000oooo0080oooo0P3o00000`00o`00oooo0?ooo`02
0?l000@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo0240oooo00<00?l00?l0003oool0=`3oool01000o`00oooo0?ooo`3oool20?l00003003o003o
ool0oooo00`0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`03003o003o
ool0oooo00H0oooo0P00o`001`3o0000oooo0?ooo`3oool0o`000?ooo`3o00000`3oool00`00o`00
oooo0?ooo`030?ooo`06003o003oool0oooo0?ooo`00o`00o`000`3oool00`00o`00000000000003
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool20?l000<0oooo0P3o0000
0`00o`00oooo0?ooo`020?l000@0oooo0P3o00030?ooo`030?l0003oool0oooo00D0oooo00@00000
0?ooo`3oool00?l0103oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00d0oooo00<0
0?l00?ooo`3oool0603oool3000000`0oooo0P0000030?ooo`D0000000@0oooo0000000000000000
1@3oool01000o`00oooo0?ooo`3o00030?ooo`@00000403oool2003o00@0oooo00<00?l00?ooo`3o
ool05`3oool01P00o`00oooo0?ooo`3oool00?l00?l000@0oooo0P3o00000`00o`00oooo0?ooo`0@
0?ooo`030?l0003oool0oooo00/0oooo00<000000?ooo`3oool0>03oool00700oooo0`00000;0?oo
o`06003o003o00000?l00?ooo`3o0000oooo0P3o00020?ooo`03003o003o0000o`000080oooo00@0
0?l00?l0003o00000?l00P3oool20?l000@00?l000<0o`00003o0000o`000P00o`020?l0000=003o
003oool00?l00?l0003oool0o`000?ooo`00o`00o`000?ooo`3o00000?l00?ooo`020?l00006003o
003oool0oooo003o003o00000?l00`3oool00`00o`00o`000?ooo`020?ooo`80o`000`3oool00`00
o`00o`000?ooo`030?ooo`030?l0003oool0oooo0080oooo00<00?l00?l00000o`000P3oool00`00
o`00o`000?ooo`020?ooo`80o`0000<00?l00?ooo`3oool00P3o00040?ooo`030?l0003oool0oooo
00<0oooo00H0o`000?ooo`3oool0oooo003o003o00090?ooo`03003o003oool0oooo01<0oooo0P3o
00020?ooo`80o`00103oool00`00o`00oooo0?ooo`0<0?ooo`03003o003oool0oooo01d0oooo00<0
0?l00?ooo`3oool00P3oool01000o`00oooo0?ooo`3oool20?l00003003o003oool0oooo00`0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
0`3o00030?ooo`030?l0003oool0o`0000<0oooo00<00?l00?ooo`3oool00`3oool01P3o0000oooo
0?ooo`3oool00?l00?l000<0oooo00<00?l00000000000000P3oool00`00o`00o`000?ooo`030?oo
o`030?l0003oool0oooo0080oooo0P3o00000`3oool00?l0003o00020?l00003003o003oool0oooo
0080o`0000@00?l00?ooo`3oool00?l00P3o00030?ooo`030?l0003oool0oooo00<0oooo00<00?l0
0?ooo`0000000P3oool01000o`00oooo0?ooo`3oool2003o00@0oooo00<00?l00?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo00P0oooo0`00000<0?ooo`8000000`3o
ool5000000040?ooo`0000000000000000<0oooo00<00?l00?ooo`00o`000P3oool0103o0000oooo
0?ooo`3oool400000100oooo00<00?l00?l0003oool00P3oool2003o00l0oooo00<00?l00?ooo`3o
ool01`3oool01000o`00oooo0?ooo`3oool20?l000@0oooo0P3o00001@00o`00oooo0?ooo`3oool0
o`0000@0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo00/0oooo00<000000?ooo`3oool0>03oool005T0oooo1P0000030?ooo`@000002P3oool00`00
0000oooo0?ooo`0;0?ooo`04003o003o00000?l00?ooo`80o`0000D0oooo0?l00000o`00oooo003o
00020?l00080oooo00T00?l00?l0003o00000?l00?ooo`00o`00o`000?ooo`3o00000P3oool03@00
o`00o`000?l0003oool00?l00?l0003oool0o`000?ooo`3o00000?l00?l0003oool00P3o00000`3o
ool0o`000?ooo`020?l000030?ooo`3o0000o`0000800?l000@0oooo003o003o00000?l00`3oool2
0?l000<0oooo0P3o00030?ooo`03003o003o0000oooo00<0oooo00<0o`000?ooo`3oool00P3oool2
0?l00003003o003oool0oooo0080o`000P3oool01000o`00o`000?ooo`3o00020?ooo`80o`00103o
ool00`3o0000oooo0?ooo`020?ooo`03003o003o0000oooo0080oooo0P3o00090?ooo`030?l0003o
ool0oooo00d0oooo00<00?l00?ooo`3oool00P3oool00`00o`00o`000?l000020?ooo`80o`000`3o
ool2003o00h0oooo00<00?l00?ooo`3oool0203oool00`00o`00oooo0?ooo`020?ooo`03003o003o
ool0oooo00d0oooo00<00?l00?ooo`3oool00P3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o
00000`3oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0o`0000/0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00<0o`000`3oool0103o0000
oooo0?l00000o`020?ooo`030?l0003oool0oooo0080oooo00<00?l00?l0003oool00P3oool20?l0
00<0oooo00<0o`000000000000000P3oool00`00o`00o`000?ooo`030?ooo`050?l0003oool0oooo
0?ooo`00o`000P3o00000`3oool00?l0003o00020?l00003003o003oool0oooo0080o`0000@00?l0
0?ooo`3oool00?l00P3o00030?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`0000000P3o
ool01P00o`00oooo0?ooo`3oool00?l00?l000@0oooo00<0o`000?ooo`3oool0303oool00`00o`00
o`000?ooo`030?ooo`03003o003oool0oooo00P0oooo00<00?l00?ooo`3oool0203oool2000000`0
oooo00<00?l00000000000000`3oool5000000040?ooo`0000000000000000<0oooo00<00?l00?oo
o`00o`000P3oool0103o0000oooo0?ooo`3oool3000000H0oooo0P00o`040?ooo`03003o003oool0
oooo0080oooo00<00?l00?l0003oool00P3oool3003o00h0oooo00<00?l00?ooo`3oool01P3oool0
0`00o`00o`000?ooo`020?ooo`80o`000`3oool20?l000030?ooo`3o0000oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool02`3oool00`000000oooo0?ooo`0h0?ooo`00FP3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?oo
o`04003o003o00000?l00?ooo`80o`0000P0oooo0?l00000o`000?l00?l0003oool0o`000?ooo`80
0?l000L0o`000?ooo`3o00000?l00?ooo`3o0000oooo0080o`0000<0oooo0?l0003oool0103o0000
0`3oool0o`000?l000020?l00080oooo0`3o00020?ooo`80o`0000<0oooo0?l0003o00000P00o`00
103oool00?l00?l00000o`030?ooo`80o`000`3oool20?l00003003o003oool0oooo0080o`00103o
ool00`3o0000oooo0?ooo`020?ooo`80o`0000<00?l00?ooo`00o`000P3o00020?ooo`04003o003o
0000oooo0?l00080oooo0P3o00001@00o`00oooo0?ooo`3oool0o`0000@0oooo00<00?l00?l0003o
ool00P3oool20?l000@0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
003o003oool0oooo00<0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`03
0?l0003oool0o`000080oooo00<0o`000?ooo`3o00000P3oool00`00o`00o`000?ooo`0<0?ooo`03
003o003o0000oooo00T0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`0=0?ooo`06
0?l0003oool0oooo0?ooo`00o`00o`000`3oool00`3o0000oooo0?l000020?ooo`03003o003o0000
oooo00L0oooo00<0o`00003o003o00002`3oool0103o0000oooo0?ooo`00o`040?ooo`030?l0003o
ool0oooo0080oooo00@00?l00?l0003oool0oooo0`3o00001`00o`00oooo0?ooo`3o0000oooo0?l0
0000o`000P3oool00`3o0000oooo0?ooo`020?ooo`05003o003o0000oooo0?ooo`00o`000P3o0003
0?ooo`80o`000`3oool00`00o`00o`000?ooo`030?ooo`050?l00000o`00oooo0?ooo`00o`000P3o
0003003o0080o`0000<00?l00?ooo`3oool00P3o00001000o`00oooo003o0000o`020?l00005003o
003oool0oooo0?l00000o`00103oool01P00o`00oooo0000003oool00?l00?l000<0oooo00<00?l0
0?l0003oool00`3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo00H00?l0
0?ooo`3oool0oooo003o003o00030?ooo`800?l02P3oool01P00o`00oooo0?ooo`00o`00oooo003o
00D0oooo0P0000070?ooo`03003o003oool0oooo0080oooo00<00?l00000000000000`3oool50000
00040?ooo`0000000000000000<0oooo00<0o`00003o0000o`000P00o`00103o0000oooo0?ooo`3o
ool3000000H0oooo0P00o`040?ooo`03003o003oool0oooo0080oooo0P3o00030?ooo`03003o003o
00000?l000d0oooo0P00o`040?ooo`06003o003oool0oooo0?ooo`00o`00o`000`3oool20?l00003
003o003oool0oooo0080o`0000H0oooo0?l0003oool0oooo003o003o00030?ooo`03003o003o0000
oooo00<0oooo00L0o`000?ooo`3oool0oooo003o003o00000?l000`0oooo00<000000?ooo`3oool0
>03oool005/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02`3oool01@3o0000oooo0?l00000o`00o`000080oooo
00T0o`000?ooo`00o`00o`000?ooo`3o00000?l00?ooo`3o00000P3oool01`3o00000?l00?ooo`3o
0000oooo0?l0003oool00P3o00000`3oool0o`000?l000020?l000050?ooo`3o0000o`000?ooo`3o
0000103oool00`3o0000oooo0?ooo`020?l00003003o003o0000o`0000800?l000@0oooo003o003o
0000o`000`3oool20?l000<0oooo0P3o00000`00o`00oooo0?ooo`020?l00006003o003oool0oooo
0?ooo`3o00000?l00`3oool20?l000030?ooo`00o`000?l00080o`000P3oool01000o`00o`000?oo
o`3o00020?ooo`80o`0000D00?l00?ooo`3oool0oooo0?l000040?ooo`80o`000P3oool00`00o`00
o`000?l000030?ooo`800?l0103oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00<0
oooo00H00?l00?ooo`3oool0oooo003o003o00030?ooo`09003o003o0000oooo0?l0003oool00?l0
0?l0003oool0o`000080oooo0P3o00090?ooo`04003o003oool0oooo0?ooo`80o`00103oool00`00
o`00oooo0?ooo`020?ooo`03003o003o0000oooo0080oooo00<00?l00?l0003oool00`3oool00`00
o`00oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?l00?l00000o`000P3oool20?l0
00<0oooo00D0o`000?ooo`3o00000?l00?ooo`020?l000@0oooo00L0o`000?ooo`3oool0oooo0?l0
0000o`00o`0000T0oooo00<00?l00?ooo`3o00000P3oool01P00o`00oooo0?ooo`3oool00?l00?l0
00@0oooo0P3o00020?ooo`040?l0003oool0o`00003o0080oooo00@0o`000?ooo`3o00000?l00P3o
ool01`3o00000?l00?ooo`00o`00oooo003o003o00000P3oool00`00o`00o`000?l000030?ooo`80
o`000`3oool00`00o`00o`000?ooo`020?ooo`04003o003o00000?l00?ooo`800?l00P3o00000`00
o`00oooo003o00020?l000800?l000D0oooo0?l0003o00000?l00?ooo`02003o0080o`0000D00?l0
0?ooo`3oool0o`00003o00040?ooo`060?l0003oool000000?ooo`00o`00o`000`3oool20?l000@0
oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`04003o003oool0oooo0?oo
o`80o`0000<00?l00?ooo`3oool00P00o`040?ooo`03003o003oool0oooo0080oooo0P00o`020?oo
o`03003o003oool00?l000D0oooo0P0000070?ooo`03003o003oool0oooo0080oooo00<00?l00000
000000000`3oool5000000040?ooo`0000000000000000<0oooo00<0o`00003o003o00000P00o`00
103o0000oooo0?ooo`3oool3000000H0oooo00<0o`00003o003oool00`3oool01@00o`00oooo003o
003oool00?l00080o`000P3oool01000o`00oooo0?l00000o`030?ooo`03003o003oool0oooo00L0
oooo00<00?l00?l0003oool00`3oool01000o`00oooo0?ooo`00o`020?l00003003o003oool0oooo
0080o`0000@00?l00?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`020?l000<0oooo00<00?l0
0?l0003oool00`3oool01`3o0000oooo0?ooo`3oool00?l00?l00000o`00303oool00`000000oooo
0?ooo`0h0?ooo`00G03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`050?l0003oool0o`000?ooo`3o0000
0P3oool01P3o0000oooo003o003o0000oooo0?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`3o
00020?ooo`080?l0003oool0oooo0?l0003oool0o`000?ooo`3o00020?ooo`040?l0003oool0oooo
0?l000P0oooo00D0o`000?ooo`3o0000oooo0?l00002003o00030?l0003oool0o`000080oooo00<0
0?l00?l0003o00000`3oool20?l00003003o003oool0oooo0080o`0000H00?l00?ooo`3oool00?l0
0?l00000o`020?ooo`04003o003o0000o`000?ooo`800?l00P3o00020?ooo`06003o003o0000oooo
0?l00000o`00oooo0P3o00001@00o`00oooo0?ooo`3oool0o`0000@0oooo0P3o00020?ooo`04003o
003o0000o`00003o0080oooo0P00o`040?ooo`030?l0003oool0oooo0080oooo00L0o`000?ooo`3o
ool0oooo0?l00000o`00o`0000<0oooo00<00?l00?l0003oool00P3oool02@00o`00o`000?ooo`3o
00000?l00?ooo`3o0000oooo0?l00002003o0080o`002@3oool0103o0000oooo0?ooo`3oool20?l0
00@0oooo00<00?l00?ooo`3oool00P3oool00`00o`00o`000?ooo`020?ooo`03003o003o00000?l0
00<0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`020?ooo`<0o`000P3oool20?l0
0080oooo00H00?l00?l0003oool0o`00003o003oool20?l000@0oooo00@0o`000?ooo`3oool00?l0
0`3o00090?ooo`060?l00000o`00o`000?ooo`00o`00o`000`3oool00`00o`00o`00003o00030?oo
o`80o`0000H0oooo003o003o0000oooo0?l00000o`020?ooo`040?l0003oool0o`00003o0080oooo
00<0o`00003o003oool00`00o`00103o0000oooo0?ooo`00o`020?l000<0oooo0P3o00030?ooo`80
o`0000L00?l00?ooo`3oool00?l00?l00000o`00oooo00800?l00P3o00000`00o`00oooo0?l00002
0?ooo`030?l00000o`000?l00080o`000`00o`00103o0000oooo0?l00000o`020?ooo`030?l00000
o`00oooo0080oooo00L00?l00?l0003oool000000?ooo`00o`00o`0000<0oooo0P3o00001@00o`00
oooo0?ooo`3oool0o`0000@0oooo0P00o`030?ooo`05003o003o0000oooo003o003oool00P3o0000
0`00o`00oooo0?ooo`020?l000@0oooo00<00?l00?ooo`3oool00P3oool00`00o`00o`000?ooo`02
003o00030?ooo`00o`00oooo00<0oooo00<00?l00000000000001`3oool00`3o0000oooo0?ooo`02
0?ooo`03003o003o0000oooo00<0oooo1@0000000`3oool00000000000030?ooo`05003o003o0000
o`000?l00000o`000P3o00030?ooo`<000001P3oool20?l000@0oooo00D0o`000?ooo`00o`00oooo
003o00020?l00080oooo00@00?l00?l0003o0000o`000P3oool2003o00@0oooo00<00?l00?ooo`3o
ool00P3oool00`00o`00o`000?ooo`020?ooo`05003o003o0000oooo0?ooo`00o`000P3o00000`00
o`00oooo003o00020?l00004003o003oool0oooo0?l00080oooo00<0o`00003o0000o`000P3o0003
0?ooo`03003o003o0000oooo0080oooo00<00?l00?l0003oool00P3oool00`00o`00o`00003o000<
0?ooo`030000003oool0oooo03P0oooo001M0?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`070?ooo`D000002@3oool01@3o0000oooo0?l0003oool0o`000080oooo103o
00001@3oool0o`000?ooo`3oool0o`000080oooo00<0o`000?ooo`3o00002@3oool00`3o0000oooo
0?ooo`0<0?ooo`80o`000P3oool20?l00007003o003o0000oooo0?l00000o`00oooo003o00020?l0
0080oooo00@00?l00?l0003o00000?l00P3oool20?l00006003o003oool0oooo003o003o00000?l0
0P3oool01P00o`00o`000?l0003o00000?l00?ooo`80o`000P3oool01P3o0000oooo0?ooo`3o0000
oooo003o0080o`0000L00?l00?ooo`3oool00?l00?l00000o`00oooo00800?l00P3o00020?ooo`04
003o003o0000o`00003o0080oooo00<00?l00?l0003oool00`3oool01P3o0000oooo0?ooo`3oool0
0?l00?l000<0oooo00<0o`00003o003o00000`3oool20?l000<0oooo00D0o`000?ooo`3oool0o`00
0?ooo`020?l000040?ooo`3o00000?l0003o0080o`002@3oool0103o0000oooo0?ooo`3oool20?l0
0005003o003oool0oooo0?ooo`00o`00103oool00`00o`00o`000?ooo`020?ooo`80o`0000D00?l0
0?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0oooo0080oooo0`3o00020?ooo`80o`0000D0
oooo003o0000o`00o`000?ooo`020?l00003003o003o0000o`0000@0oooo00D0o`000?ooo`3oool0
o`000?ooo`020?l000@0oooo00D00?l00?ooo`3oool0oooo003o00030?l000030?ooo`3o0000o`00
00<0oooo00<00?l00?l00000o`000P3oool02@00o`00o`000?l0003oool00?l00?l0003oool0o`00
003o00020?ooo`030?l0003oool0o`0000800?l000H0oooo0?l00000o`00oooo003o003oool20?l0
0080oooo00<00?l00?l0003o00000`3oool20?l000<0oooo0P3o00001`00o`00oooo0?ooo`00o`00
o`00003o003oool00P00o`020?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`00o`020?l00080
0?l000D0oooo0?l0003oool0o`00003o00020?ooo`030?l00000o`00oooo0080oooo00D00?l00?l0
003oool000000?ooo`020?l000<0oooo0P3o00001P00o`00oooo0?ooo`3oool0o`00003o00<0oooo
00<00?l00?l0003oool00P3oool01@00o`00o`000?ooo`00o`00oooo0080o`0000<00?l00?ooo`3o
ool00P3o00040?ooo`03003o003oool0oooo0080oooo00L00?l00?l0003oool00?l00?l00000o`00
o`0000@0oooo00<0o`000000000000001`3oool00`3o0000oooo0?ooo`020?ooo`03003o003o0000
oooo00<0oooo1@0000000`3oool00000000000030?ooo`05003o003o0000o`000?l0003oool00P3o
000<0?ooo`80o`00103oool01@3o0000oooo003o003oool00?l00080o`000P3oool01P00o`00o`00
0?l0003o00000?l00?ooo`80o`00103oool01@3o0000oooo0?ooo`00o`00oooo0080o`000`3oool0
1`00o`00o`000?ooo`00o`00o`000?ooo`3o00000P00o`001`3oool0o`000?ooo`3o0000oooo003o
003o00000P3oool00`3o00000?l00?l000020?l000<0oooo0P3o00030?ooo`03003o003o0000oooo
0080oooo00<00?l00?l00000o`00303oool00`000000oooo0?ooo`0h0?ooo`00GP3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool01@3o
0000oooo0?l0003oool0o`000080oooo0`3o00020?ooo`040?l0003oool0o`000?l00080oooo00<0
o`000?ooo`3o00006@3oool00`3o0000oooo0?ooo`020?l00004003o003o0000oooo0?l000<00?l0
0P3o00020?ooo`04003o003o0000oooo0?l00080oooo0P3o00001P00o`00oooo0?ooo`00o`00o`00
003o0080oooo00P00?l00?l0003o0000o`000?ooo`3o0000oooo0?l00080oooo00@0o`000?ooo`3o
ool0o`000P3oool02@3o0000oooo0?l00000o`00oooo003o003o00000?l00?ooo`02003o0080o`00
00<0oooo003o0000o`000P3o00000`00o`00oooo0?ooo`020?l000@0oooo00H0o`000?ooo`3oool0
oooo003o003o00030?ooo`060?l0003oool0o`000?ooo`00o`00oooo0P3o00030?ooo`030?l0003o
ool0oooo0080o`0000<0oooo0?l0003oool00`3o00000`3oool0o`000?ooo`030?ooo`09003o003o
ool0oooo0?ooo`00o`00o`000?ooo`00o`00oooo0080o`0000T00?l00?ooo`3oool0oooo0?l0003o
ool00?l00?ooo`00o`000P3o00030?ooo`80o`0000D00?l00?ooo`3oool00?l00?l000040?ooo`05
0?l0003oool0oooo0?ooo`00o`000`3o0002003o0080o`0000<00?l00?l0003o00000P3oool20?l0
0005003o003o0000o`000?ooo`00o`000P3oool01@3o00000?l00?ooo`3o0000oooo0080o`0000D0
0?l00?ooo`3oool00?l00?l000030?ooo`@0o`0000<0oooo0?l0003o00000P3oool01000o`00oooo
0?l00000o`020?ooo`09003o003o0000o`000?ooo`00o`00o`000?ooo`3o00000?l00080oooo00<0
o`000?ooo`3o00000`00o`001@3o00000?l00?ooo`00o`00oooo0080o`000P3oool00`00o`00o`00
0?l000020?ooo`04003o003o0000o`00003o0080oooo0P3o00001@00o`00oooo0?ooo`00o`00o`00
00800?l000D0oooo0?l0003oool0o`000?ooo`020?l00080oooo0P3o0000103oool0o`000?ooo`3o
00020?ooo`080?l0003oool0o`000?l0003oool00?l00?l00000o`030?ooo`80o`0000<0oooo0000
0000o`000P3o00030?ooo`80o`0000H00?l00?ooo`3oool0oooo0?l00000o`030?ooo`03003o003o
0000oooo0080oooo0P3o00000`3oool00?l0003o00020?l00003003o003oool0oooo0080o`0000D0
0?l00?ooo`3oool0oooo0?l000040?ooo`07003o003o0000oooo003o003o00000?l00?l000040?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo1@0000000`3o
ool00000000000030?ooo`03003o003o0000o`0000@0o`000`3oool00`00o`00oooo0?ooo`060?oo
o`80o`00103oool00`3o00000?l0003o0002003o0080o`000P00o`001P3o0000oooo0?ooo`3o0000
0?l00?ooo`80o`0000D00?l00?ooo`3oool00?l00?l000020?ooo`04003o003oool0o`000?l00080
oooo00<00?l00?l0003o00000P00o`00103o0000oooo0?ooo`3o00020?ooo`060?l0003oool0o`00
0?ooo`00o`00o`000P3oool01@3o00000?l00?l0003oool0o`0000<0oooo0P3o00030?ooo`80o`00
00H00?l00?ooo`3oool0o`000?ooo`3o000<0?ooo`030000003oool0oooo03P0oooo001N0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`030?l0003oool0o`000080oooo00<0o`000?ooo`3o00000`3oool30?l00080oooo0P3o000M0?oo
o`80o`0000D0oooo0?l0003oool0o`000?ooo`02003o0080o`000P3oool01000o`00o`000?ooo`3o
00020?ooo`030?l0003oool0o`000080oooo00@00?l00?l0003o0000oooo0P00o`030?l000070?oo
o`3o0000oooo0?l00000o`00oooo0?l000020?ooo`060?l0003oool0oooo0?l0003oool0o`000`00
o`000`3o00000?l0003o0002003o0080o`0000H0oooo003o003o0000oooo0?l00000o`020?ooo`80
o`0000H00?l00?ooo`3oool0oooo0?l00000o`020?ooo`03003o003o0000oooo0080oooo0`3o0000
0`3oool00?l00?ooo`020?l000<0oooo00<0o`000?ooo`3oool00P3o00030?ooo`<0o`0000<0oooo
0?l0003oool00P3oool00`00o`00o`000?ooo`020?ooo`80o`0000<0oooo003o003oool00P3o0000
2@00o`00oooo0?ooo`3oool0o`000?ooo`00o`00oooo003o00020?l000<00?l000<0o`000?ooo`3o
00000`00o`000`3o0000oooo0?ooo`020?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0P3o0000
1@00o`00o`000?ooo`3o00000?l00080o`000P3oool50?l00009003o003o0000oooo0?ooo`3o0000
0?l00?ooo`3o0000oooo0080o`0000D00?l00?ooo`3oool00?l00?l000030?ooo`@0o`0000<00?l0
0?l0003o00000`00o`020?l00004003o003oool00?l0003o0080o`0000<0oooo003o003o00000P3o
ool01P3o0000oooo003o003o0000oooo0?l000800?l000H0oooo0?l00000o`00oooo003o003oool2
0?l00080oooo00<0o`000?ooo`3o00000P3oool01000o`00o`000?l00000o`020?ooo`80o`0000D0
0?l00?ooo`00o`00oooo0?l00002003o00050?ooo`3o0000oooo0?l0003oool00P3o00020?ooo`80
o`0000D0oooo0?l0003oool0o`000?ooo`020?l000030?ooo`3o0000o`0000800?l000<0o`00003o
003oool00P3oool20?l000030?ooo`0000000?l00080o`000`3oool20?l00006003o003oool0oooo
0?ooo`3o00000?l00`3oool20?l000<0oooo0P3o00002000o`00oooo003o003o0000oooo0?l00000
o`00oooo0P3o00001P00o`00oooo0?ooo`3oool0o`00003o0080oooo00P00?l00?ooo`3o0000oooo
003o003o00000?l00?l000<0oooo00<00?l00?l0003oool0203oool01@3o0000oooo0?ooo`3oool0
0?l00080o`00103oool5000000030?ooo`000000000000<0oooo00<00?l00?l0003o0000103o0003
0?ooo`03003o003oool0oooo00H0oooo0P3o00030?ooo`08003o003o00000?l00?ooo`00o`00o`00
0?ooo`3o00020?ooo`040?l0003oool0oooo0?l000800?l00P3o0002003o00030?ooo`00o`00o`00
00<00?l000H0oooo0?l0003o0000oooo003o003oool20?l00003003o003oool0o`000080oooo00P0
o`000?ooo`3oool0o`000?ooo`3o0000oooo0?l000<0oooo0P3o00020?ooo`040?l0003oool0oooo
0?ooo`80o`0000<00?l00?ooo`3oool00P3o00001P00o`00oooo0?ooo`3o0000oooo0?l000`0oooo
00<000000?ooo`3oool0>03oool005T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool20?l00080oooo
00<0o`000?ooo`3o00001@3oool00`3o0000oooo0?ooo`020?l001d0oooo0P3o00001`3oool0o`00
0?ooo`3o0000oooo003o003oool00P3o00001P3oool00?l0003o003o0000oooo0?l00080oooo00H0
o`000?ooo`3o00000?l00?ooo`00o`020?l000800?l000/0oooo0?l0003o0000o`000?ooo`3o0000
oooo0?l00000o`00oooo0?l000020?ooo`070?l0003oool0oooo0?l0003oool0o`00003o00020?oo
o`030?l00000o`000?l00080o`0000P0oooo0?l00000o`000?l00?l0003oool0o`00003o0080oooo
0P3o00001P00o`00oooo0?ooo`3oool0o`00003o0080oooo00D00?l00?l00000o`00oooo003o0003
0?l000030?ooo`00o`000?l00080o`000`3oool00`3o0000oooo0?ooo`020?l000@0oooo0P3o0000
1`3oool0o`000?ooo`3oool00?l00?ooo`3o00000`3oool20?l000030?ooo`00o`00oooo0080o`00
00D00?l00?ooo`3oool0oooo0?l00003003o00040?ooo`3o0000o`000?ooo`800?l000D0o`000?oo
o`3o0000oooo003o00020?l00006003o003oool0oooo0?ooo`3o00000?l00P3oool0103o0000oooo
0?l0003oool20?l000030?ooo`3o0000oooo0080o`000P3oool00`3o0000oooo0?l000020?l00004
003o003o00000?l0003o0080o`0000H0oooo0?l0003oool0oooo0?l00000o`020?ooo`80o`000`3o
ool01@3o0000oooo0?l0003o00000?l00080o`000`00o`020?l00004003o003oool00?l0003o0080
o`0000<0oooo0?l0003oool00P3oool0103o0000oooo003o003o00020?ooo`030?l00000o`00oooo
0080o`000P00o`030?l00080oooo00<0o`000?ooo`3o00000P3oool01000o`00o`000?l00000o`02
0?ooo`80o`000P00o`000`3oool0o`000?l00002003o00030?ooo`3o0000oooo00@0o`000P3oool2
0?l000050?ooo`3o0000oooo0?l0003oool00P3o00020?ooo`030?l00000o`000?l00080o`000`3o
ool20?l000030?ooo`0000000?l00080o`0000<00?l00?ooo`3oool00P3o0002003o0080oooo00D0
o`00003o003oool0oooo003o00020?l00080oooo00T00?l00?l0003o00000?l00?ooo`00o`00o`00
0?ooo`3o00000P00o`020?l00006003o003oool0oooo003o003o00000?l00P3oool01@00o`00o`00
0?l0003oool00?l000<0o`0000D00?l00?ooo`3oool00?l00?l000090?ooo`050?l0003oool0oooo
0?ooo`00o`000P3o00040?ooo`D0000000<0oooo0000000000000P3oool00`00o`00o`000?ooo`02
0?l000040?ooo`3o0000o`00003o0080oooo00<0o`000?ooo`3oool01P3oool20?l0000;003o003o
ool0oooo003o003o00000?l00?ooo`00o`00o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o
0002003o0080o`000P00o`000`3oool0o`000?l00003003o00060?ooo`3o0000o`000?ooo`00o`00
oooo0P3o00000`3oool0o`000?l000020?ooo`080?l0003oool0oooo0?l0003oool0o`000?ooo`3o
00030?ooo`80o`000P3oool0103o0000oooo0?ooo`00o`020?l0000;003o003oool0oooo0?l0003o
ool0o`000?ooo`00o`00o`000?ooo`3o0000303oool00`000000oooo0?ooo`0h0?ooo`00F@3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0l0?ooo`@0o`0000P0oooo0?l0003oool0oooo0?l0003oool0o`000?oo
o`800?l000<0o`000?ooo`3o00000P3oool0203o0000oooo0?l00000o`00oooo0?l0003oool0o`00
0P3oool0203o0000oooo0?l0003o0000oooo0?l0003oool0o`000P00o`000`3o0000oooo0?ooo`03
0?l00080oooo00<0o`000?ooo`3oool00P3o0002003o0080o`0000D0oooo0?l0003oool0oooo0?l0
00020?ooo`030?l0003oool0oooo0080o`0000H00?l00?ooo`3oool00?l00?l00000o`020?ooo`05
003o003o00000?l00?ooo`00o`000`3o00000`00o`00oooo003o00020?l00004003o003oool0oooo
0?l00080oooo00<0o`000?ooo`3oool00`3oool20?l000050?ooo`3o0000oooo0?ooo`00o`000P3o
00030?ooo`80o`0000H00?l00?l00000o`00o`000?ooo`3o00030?ooo`050?l00000o`00oooo003o
003oool00P3o00000`3oool00?l00?l000020?ooo`030?l0003oool0oooo0080o`0000`00?l00?oo
o`3oool0oooo0?l00000o`00oooo003o003o0000oooo0?l0003oool20?l00080oooo00<0o`000?oo
o`3o00000P3oool00`3o0000oooo0?l000020?l00004003o003o0000oooo003o0080o`0000<0oooo
0?l0003oool00P3oool00`3o0000oooo0?ooo`020?l000<0oooo00D0o`000?ooo`3o0000o`00003o
00020?l000<00?l000X0o`000?ooo`3o0000oooo003o003o0000oooo0?l0003oool0o`000`3oool0
103o00000?l0003o003o00020?ooo`030?l00000o`00oooo0080o`0000<00?l00?l0003oool00P3o
00001@00o`00oooo0?l0003oool0o`000080oooo00@00?l00?l0003o00000?l00P3oool20?l00080
0?l000D0oooo0?l0003o00000?l00?ooo`020?l000050?ooo`3o0000o`000?ooo`3o00000P3oool0
0`3o0000oooo0?l000020?ooo`@0o`000P3oool00`3o00000?l0003o00020?l000030?ooo`00o`00
0?l00080o`0000<0oooo00000000o`000P3o0002003o00070?ooo`3o0000oooo0?l00000o`00oooo
003o00020?l00080oooo00<00?l00?l0003o00000P3oool01000o`00o`000?l00000o`020?l00080
oooo00<0o`000?ooo`00o`000P3o0004003o00050?l00000o`00oooo0?ooo`00o`000P3o00000`00
o`00oooo0?l000020?l00003003o003oool0oooo0080o`0000<00?l00?ooo`3oool01P3oool01@3o
0000oooo0?ooo`3oool00?l00080o`000`3oool00`00o`0000000000000200000080oooo0P000002
0?ooo`03003o003o0000oooo0080o`0000@0oooo0?l0003o00000?l00P3oool00`3o0000oooo0?oo
o`060?ooo`80o`000P00o`002@3oool00?l00?l00000o`00o`00003o003o0000oooo0?l000020?oo
o`060?l0003oool0oooo0?ooo`3o00000?l00P3o00000`3oool00?l0003o00020?l00004003o003o
ool0o`00003o0080o`0000H00?l00?ooo`3o0000oooo0?l0003oool20?l00080oooo00<0o`000?oo
o`3o00000P3oool00`3o00000?l00?l000030?ooo`80o`000P3oool0103o0000oooo0?ooo`00o`02
0?l0000;003o003oool0oooo0?l0003oool0o`000?ooo`00o`00o`000?ooo`3o0000303oool00`00
0000oooo0?ooo`0h0?ooo`00FP3oool4000000@0oooo1000000:0?ooo`<00000?03oool30?l00080
oooo00T0o`000?ooo`3oool0o`000?ooo`3o00000?l00?ooo`3o00000P3oool02`3o0000oooo0?oo
o`3o0000oooo0?l00000o`00oooo0?l0003oool0o`000080oooo00@0o`000?ooo`3oool0oooo0P3o
00001@3oool0o`000?ooo`00o`00o`000080oooo0`3o00020?ooo`070?l0003oool0oooo0?l0003o
ool0o`000?ooo`020?l000050?ooo`3o0000oooo0?ooo`3o00000P3oool00`3o0000oooo003o0002
0?l000800?l000@0oooo003o003o00000?l00P3oool20?l000<00?l000H0o`000?ooo`3o00000?l0
0?ooo`00o`020?l00004003o003oool00?l00?l00080oooo00<0o`000?ooo`3oool00`3oool01`3o
0000oooo0?ooo`3o00000?l00?ooo`00o`000P3o00030?ooo`80o`0000/00?l00?l00000o`00o`00
0?ooo`3o0000oooo003o003oool0o`00003o00020?ooo`030?l0003oool0o`0000<0o`000P3oool5
0?l0000=003o003oool0oooo0?ooo`3o00000?l00?ooo`00o`00o`000?ooo`3o0000oooo0?l00003
0?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0o`000?ooo`030?l000050?ooo`3o
0000o`000?ooo`3o00000`3oool00`3o0000oooo003o00020?l00080oooo00<00?l00?l0003oool0
0P3o00004000o`00o`000?l00000o`00o`000?ooo`3o0000oooo0?l0003oool00?l00?l0003oool0
o`000?ooo`3o00030?ooo`040?l0003oool00?l00?l00080oooo0P3o00001@3oool0o`000?l00000
o`00o`000080oooo00L0o`00003o0000o`00o`000?ooo`3o0000oooo00800?l00P3o00000`00o`00
oooo0?ooo`020?l000800?l000D0oooo0?l0003oool0o`000?ooo`020?l00080oooo00<0o`000?oo
o`3o00000P3oool00`3o0000oooo0?l000020?ooo`@0o`000P3oool00`3o00000?l0003o00020?l0
00030?ooo`00o`000?l00080o`000P3oool00`3o0000oooo0?l00003003o00030?l0003oool0o`00
00<00?l00P3o00020?ooo`03003o003o0000o`000080oooo00@00?l00?l0003o00000?l00P3o0002
0?ooo`0;0?l0003oool00?l00?l0003oool0o`00003o003oool00?l00?l00000o`000P3oool01000
o`00o`000?l00000o`040?l00003003o003oool0oooo0080o`0000D00?l00?ooo`3oool0oooo003o
00040?ooo`050?l0003oool0oooo0?ooo`00o`000P3o00030?ooo`04003o000000000000000000<0
oooo0P0000020?ooo`03003o003o0000oooo0080o`0000L0oooo0?l0003o00000?l00?ooo`00o`00
o`0000P0oooo0P3o0002003o000;0?ooo`00o`00o`00003o003o0000oooo0?l0003oool0o`000?oo
o`3o0000103oool30?l0000:0?ooo`3o0000oooo003o003o0000oooo0?l0003oool0o`00003o0080
o`0000@00?l00?l0003oool0oooo0P3o0000103oool0o`000?ooo`3oool20?l000<0oooo00<0o`00
003o003o00000`3oool0203o0000oooo0?ooo`3oool0o`00003o003oool00?l00P3o00002`00o`00
oooo0?ooo`3o0000oooo0?l0003oool00?l00?l0003oool0o`0000`0oooo00<000000?ooo`3oool0
>03oool00700oooo00<000000?ooo`3oool0?03oool30?l000<0oooo0`3o00001@3oool0o`00003o
003oool0o`000080oooo00H0o`00003o003oool0o`000?ooo`3o0002003o00030?l0003oool0o`00
0080oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`80o`0000D00?l00?l0003oool0oooo0?l0
00040?ooo`80o`0000D0oooo0?l0003oool0o`000?ooo`020?l000050?ooo`3o0000oooo0?ooo`3o
00000P3oool00`3o00000?l00?ooo`020?l000<00?l000D0oooo0?l0003o00000?l00?ooo`020?l0
00800?l000L0o`000?ooo`3oool0o`00003o003o00000?l00080o`0000@00?l00?ooo`00o`00o`00
2`3oool0103o0000oooo003o0000o`020?l00003003o003oool0oooo0080o`0000H00?l00?l00000
o`00o`000?ooo`3o0003003o00080?l00000o`00o`000?ooo`3o0000oooo0?l0003oool20?l00080
oooo00<0o`000?ooo`3o00000P3o00002`00o`00oooo0?ooo`3oool0o`00003o003oool00?l00?l0
003oool0o`0000D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?l000030?l000040?oo
o`3o00000?l00?l000<0oooo00<0o`00003o0000o`000P3o00001@3oool00?l0003o003o0000oooo
00<0o`0000<0oooo0?l0003oool00P3o00020?ooo`080?l00000o`000?l00?l0003oool0o`000?oo
o`3o00030?ooo`040?l0003oool0oooo0?l00080oooo0P3o00001@3oool0o`000?l00000o`00o`00
0080oooo00L0o`000?ooo`00o`00o`000?ooo`3o0000oooo00800?l00P3o00000`00o`00oooo0?oo
o`020?l00005003o003oool0oooo0?l0003oool0103o00040?ooo`040?l0003oool0oooo0?l000@0
oooo0P3o00001`3oool0o`000?ooo`3oool0o`00003o003oool00P3o0003003o0080o`0000/00?l0
0?ooo`3o0000oooo0?l00000o`00oooo003o003o0000oooo0?l00003003o0080o`000P00o`002@3o
ool0o`000?l00000o`00oooo0?l0003oool0o`00003o00020?l00080oooo00L0o`000?ooo`3oool0
o`000?ooo`3o00000?l00080oooo00D0o`00003o003oool00?l00?ooo`020?l00003003o003o0000
o`000080o`0000<00?l00?ooo`3oool00P3o00001@00o`00oooo0?ooo`3oool00?l000@0oooo00D0
o`000?ooo`3oool0oooo003o00020?l000<0oooo00@00?l000000000000000000P3oool00`00o`00
0000000000020?ooo`80o`0000@0oooo0?l0003o0000oooo0P3o00001000o`00oooo003o003o0008
0?ooo`80o`000`00o`020?l000030?ooo`3o0000o`000080oooo0P3o00050?ooo`<0o`0000H0oooo
0?l0003oool00?l00?l0003oool30?l00005003o003o0000o`000?ooo`3o00000P3oool20?l000D0
oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`0000L0oooo00@0o`00003o0000o`000?l00P3o
00002`00o`00oooo0?ooo`3o0000oooo0?l0003oool00?l00?l0003oool0o`0000`0oooo00<00000
0?ooo`3oool0>03oool00700oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`020?oo
o`<0o`0000D0oooo0?l00000o`00oooo0?l000020?ooo`0<0?l00000o`000?l00?l0003oool0o`00
0?ooo`00o`00o`000?ooo`3o0000oooo0P3o00030?ooo`030?l0003oool0oooo0080o`0000D0oooo
0?l0003oool0oooo0?l000040?ooo`80o`0000<0oooo0?l0003oool0103o0000103oool0o`000?oo
o`3o00030?ooo`060?l0003oool0oooo0?l0003oool0o`000P00o`000`3oool0o`000?l00002003o
0080o`000P00o`001@3o0000oooo0?ooo`3o0000oooo0080o`0000H0oooo0?l00000o`00oooo003o
003o000;0?ooo`090?l0003oool0oooo0?l0003oool0o`00003o003oool00?l00080o`0000H00?l0
0?l0003oool0o`000?ooo`3o0003003o00080?l00000o`00o`000?ooo`3o0000oooo0?l0003oool2
0?l000@0oooo0P3o00002@3oool0o`000?ooo`3oool00?l00?l00000o`00oooo0?l000020?ooo`03
0?l0003oool0oooo00d0oooo103o0000103oool0o`00003o003o00030?ooo`030?l00000o`000?l0
0080o`0000@0oooo003o0000o`00o`000P3oool20?l00080oooo0`3o00020?ooo`080?l0003oool0
o`000?l0003oool0o`00003o003o00030?ooo`040?l0003oool0oooo0?l00080oooo1@3o00002`00
o`00o`000?ooo`3oool0o`000?ooo`00o`00o`000?ooo`3o0000oooo00800?l00P3o0002003o0004
0?ooo`3o0000oooo0?l00080oooo00<0o`000?ooo`3o00000`3o00070?ooo`030?l0003oool0oooo
0080oooo00@0o`000?ooo`3oool0o`000P3oool01@3o0000oooo0?l0003oool0o`0000<00?l00P3o
00001P00o`00oooo0?l0003oool0o`00003o0080oooo00<0o`000?ooo`3o00000`00o`020?l000<0
oooo0P3o0002003o00040?l0003oool0o`00003o0080o`000P3oool01P3o0000oooo0?ooo`3o0000
oooo0?l00080oooo00<0o`000?ooo`3o00000P00o`00103oool0o`000?l00000o`040?l00003003o
003oool00?l00080o`0000D00?l00?ooo`3oool0oooo003o00040?ooo`050?l00000o`00oooo0?oo
o`00o`000P3o00020?ooo`04003o003o00000000000000<0oooo00<00?l00000000000000P3oool2
0?l0000:0?ooo`3o0000o`000?ooo`3o0000oooo0?l0003oool00?l00?l000@0oooo00@00?l00?oo
o`3oool0oooo0P3o0002003o00030?ooo`3o0000oooo00<0o`000P3oool20?l000D0oooo0`3o0000
1P3oool0o`000?l0003oool0o`000?ooo`<0o`0000D00?l00?l0003o0000oooo0?l0000=0?ooo`03
0?l0003oool0o`0000L0oooo00@0o`000?ooo`00o`00o`000P3oool0203o0000oooo0?ooo`3o0000
oooo0?l00000o`00o`000P3oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo03P0oooo
001`0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool00P3oool30?l000050?ooo`3o
0000oooo0?ooo`3o00000P3oool02P3o00000?l0003o003o0000oooo0?l0003oool00?l00?l0003o
ool30?l000@0oooo00<0o`000?ooo`3oool00P3o00001@3oool0o`000?ooo`3oool0o`0000@0oooo
103o00000`3oool0o`000?l000020?l000040?ooo`3o0000oooo0?l000<0oooo00H0o`000?ooo`3o
ool0o`000?ooo`3o00020?ooo`030?l0003oool0o`0000800?l000D0o`000?ooo`3o0000oooo0?l0
00020?ooo`0:0?l0003oool0o`000?l0003oool0o`00003o003oool00?l00?l000/0oooo00T0o`00
0?ooo`3oool0o`000?ooo`3o00000?l00?ooo`00o`00103o0000103oool0o`000?ooo`3o00020?oo
o`03003o003o0000oooo0080o`00103oool20?l000D0oooo00<0o`000?ooo`3o00000P3oool01@00
o`00o`000?l0003oool0o`000180oooo0P3o00001P3oool0o`000?ooo`3o00000?l00?l000<0oooo
00<0o`00003o0000o`000P3o0003003o00030?l0003oool0oooo0080o`000P3oool30?l00080oooo
00P0o`000?ooo`3o0000o`000?ooo`3o00000?l00?l000<0oooo00@0o`000?ooo`3oool0o`000P3o
ool30?l000040?ooo`3o0000oooo0?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`3o0002003o
00030?l0003oool0o`0000800?l000@0oooo0?l0003oool0o`000P3oool00`3o0000oooo0?l00002
0?l000d0oooo00@0o`000?ooo`3oool0o`000`3oool20?l000050?ooo`3o00000?l0003o003oool0
0P3o00001P00o`00oooo0?l0003oool0o`00003o0080oooo00H0o`000?ooo`3o00000?l00?ooo`00
o`020?l00080oooo00L0o`000?ooo`3o0000oooo003o003o0000oooo0080o`0000<0oooo0?l0003o
ool00P3oool20?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`3o0002003o00040?l0003oool0
o`00003o0080o`0000<0oooo0?l00000o`000P00o`020?l00005003o003oool0oooo0?ooo`00o`00
103oool0203o00000?l00?ooo`3oool0o`000?ooo`3o0000oooo0P00o`000`3o0000000000000003
0?ooo`030?l00000000000000080oooo0P3o0000203oool0o`000?l0003oool0o`000?ooo`3o0000
oooo0P3o00040?ooo`04003o003oool0oooo0?ooo`80o`000P00o`000`3oool0o`000?ooo`030?l0
00T0oooo0P3o00020?ooo`80o`0000<0oooo0?l0003oool0103o0000103oool0o`000?ooo`3o000>
0?ooo`80o`001`3oool0103o0000oooo003o003o00020?ooo`080?l0003oool00?l00?l0003oool0
o`00003o003o000?0?ooo`030000003oool0oooo03P0oooo001`0?ooo`030000003oool0oooo03d0
oooo00<0o`000?ooo`3oool00`3oool20?l000050?ooo`3o0000oooo0?ooo`3o00000P3oool0103o
0000oooo003o003o00020?ooo`030?l00000o`00o`000080oooo0P3o00070?ooo`80o`0000<0oooo
0?l0003oool01P3oool00`3o0000oooo0?ooo`020?ooo`@0o`0000@0oooo0?l0003oool0o`000`3o
ool01P3o0000oooo0?ooo`3o0000oooo0?l00080oooo00X0o`000?ooo`3o0000oooo003o003o0000
oooo0?l0003oool0o`000P3oool20?l000080?ooo`3o0000oooo0?l00000o`00oooo003o003o000;
0?ooo`090?l0003oool0oooo0?l0003oool0o`00003o003oool00?l000<0o`0000P0oooo0?l0003o
0000oooo0?l0003oool0o`00003o00@0o`001@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0o`000080oooo00D00?l00?l0003o0000oooo0?l0000B0?ooo`80o`00103oool20?l000<0oooo
00T0o`00003o003o0000oooo0?l00000o`00oooo003o003o00000P3oool20?l00080oooo0`3o0002
0?ooo`080?l0003oool0o`000?l0003oool0o`00003o003o00030?ooo`030?l0003oool0o`0000<0
oooo0P3o00020?ooo`030?l0003oool0o`000080oooo00/0o`000?ooo`3oool0o`000?ooo`3o0000
0?l00?ooo`3o0000oooo0?l00003003o00040?l0003oool0o`000?ooo`80o`0000<0oooo0?l0003o
00003P3oool00`3o0000oooo0?ooo`040?ooo`80o`0000d0oooo0?l00000o`000?l00?l0003oool0
o`00003o003oool0o`000?ooo`3o00000?l00080o`000P3oool0103o00000?l00?ooo`00o`020?l0
0080oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?l0003o00050?ooo`80o`000P3oool0
303o0000oooo0?ooo`3o0000oooo0?l0003oool00?l00?l0003oool0o`00003o0080o`000P3oool0
1P3o00000?l0003o003o0000oooo0?l000<0oooo00<0o`000?ooo`3oool00P3oool0203o00000?l0
0?ooo`3oool0o`000?ooo`3o0000oooo0P00o`000`3o00000000000000030?ooo`030?l000000000
00000080oooo00@0o`000?ooo`3oool0o`00103oool0103o0000oooo0?l0003o00040?ooo`0>003o
003oool0oooo0?ooo`3o0000oooo0?l00000o`00oooo0?l0003oool0o`000?ooo`3o000:0?ooo`03
0?l0003oool0oooo00<0o`000P3oool01@3o0000oooo0?l0003o0000oooo0080o`003`3oool00`3o
0000oooo0?ooo`060?ooo`040?l0003oool0oooo0?l00080oooo00P0o`000?ooo`00o`00o`000?oo
o`3o00000?l00?l000l0oooo00<000000?ooo`3oool0>03oool00700oooo00<000000?ooo`3oool0
@`3oool0103o0000oooo0?ooo`3o00020?ooo`070?l0003oool0oooo0?l0003oool00?l00?l00002
0?ooo`030?l0003oool0o`0000`0oooo00<0o`000?ooo`3o0000303oool40?l000040?ooo`3o0000
oooo0?l000<0oooo00H0o`000?ooo`3oool0o`000?ooo`3o00020?ooo`070?l0003oool0o`000?oo
o`00o`00o`000?ooo`030?l00080oooo0P3o00001`3oool0o`000?ooo`3oool0o`000?ooo`3o0000
303oool01P3o0000oooo0?ooo`3o0000oooo0?l000<00?l000@0o`000?ooo`3o0000oooo0P3o0000
1@3oool0o`000?l0003o0000oooo00<0o`001P3oool00`3o0000oooo0?ooo`030?ooo`0:0?l0003o
ool0o`00003o003oool0o`000?ooo`3o00000?l00?l00180oooo0P3o00040?ooo`80o`000`3oool0
1`3o00000?l00?l0003oool0o`00003o003oool00P3o00020?ooo`80o`000P3oool30?l00080oooo
00<0o`000?ooo`3o00000P3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000<0oooo
0P3o00020?ooo`030?l0003oool0o`000080oooo00T0o`000?ooo`3oool0o`000?ooo`3o00000?l0
0?ooo`3o00000P3oool0203o0000oooo003o003o0000oooo0?l0003oool0o`000P3oool20?l001D0
oooo0P3o00002P3oool0o`000?ooo`00o`00o`000?ooo`3o00000?l00?ooo`3o00020?ooo`<0o`00
0P3oool20?l000040?ooo`3o0000oooo0?l00080oooo00<0o`000?ooo`3o00000P3oool0103o0000
oooo0?l0003o00050?ooo`80o`000`3oool30?l000080?ooo`3o0000oooo0?ooo`3o0000oooo0?l0
003oool20?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`3o00030?ooo`030?l0003oool0oooo
0080oooo00P0o`00003o003oool00?l00?l0003oool0o`000?ooo`800?l000<0o`00000000000000
0`3oool00`3o00000000000000020?ooo`040?l0003oool0oooo0?l000@0oooo00@0o`000?ooo`3o
0000o`00103oool01`00o`00oooo0?ooo`3oool0o`000?ooo`3o00000P3oool01@3o0000oooo0?l0
003oool0o`0000h0oooo0P3o00040?ooo`80o`000P3oool00`3o0000oooo0?ooo`0F0?ooo`@0o`00
0P3oool0203o00000?l00?ooo`3o0000oooo0?l0003oool0o`003`3oool00`000000oooo0?ooo`0h
0?ooo`00?@3oool:000002T0oooo0`0000130?ooo`040?l0003oool0oooo0?ooo`<0o`000P3oool0
103o0000oooo003o003o00020?ooo`030?l0003oool0o`0000d0oooo0P3o000<0?ooo`@0o`000P3o
ool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?l0003oool00P3o0000103oool0o`00
0?ooo`3o00020?ooo`030?l0003oool0o`000080o`000P3oool20?l000070?ooo`3o0000oooo0?oo
o`3o00000?l00?l0000=0?ooo`030?l0003oool0o`000080oooo00P0o`00003o0000o`00o`000?oo
o`3o0000oooo0?l00080oooo103o00000`3oool0o`000?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00P0o`00003o003oool0o`000?ooo`3o00000?l00?l00180oooo00<0o`000?ooo`3oool00`3o
ool20?l000<0oooo00H0o`00003o003o0000oooo0?l00000o`030?l00080oooo0P3o00020?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3o00000P3oool00`3o0000oooo0?l000030?ooo`03
0?l0003oool0o`0000<0oooo0P3o00030?ooo`80o`000P3oool02@3o0000oooo0?ooo`3o0000oooo
0?l00000o`00oooo0?l000020?ooo`050?l0003oool00?l00?l0003oool00P3o00030?ooo`80o`00
5@3oool20?l000030?ooo`3o0000oooo0080o`0000D0oooo0?l00000o`00oooo0?l000020?ooo`03
0?l0003oool0o`0000<0oooo0`3o00000`3oool0o`000?ooo`020?l000060?ooo`3o0000oooo0?oo
o`3o0000oooo0P3o00060?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0203o0000oooo0?oo
o`3o0000oooo0?l0003oool0o`000`3oool01P3o0000oooo0?ooo`3o0000oooo0?l000<0oooo00<0
o`000?ooo`3oool00P3oool0203o00000?l00?ooo`00o`00o`000?ooo`3o00000?l00P3oool00`3o
00000000000000030?ooo`060?l00000000000000?ooo`00o`00o`000P3oool00`3o0000oooo0?oo
o`020?ooo`040?l00000o`00o`000?l000<0oooo0P00o`030?ooo`030?l0003oool0o`000080oooo
00<0o`000?ooo`3o00004@3oool00`3o0000oooo0?ooo`020?ooo`80o`006`3oool40?l00080oooo
00P0o`00003o003oool0o`000?ooo`3o0000oooo0?l000l0oooo00<000000?ooo`3oool0>03oool0
03d0oooo2P00000Y0?ooo`030000003oool0oooo04L0oooo00<0o`000?ooo`3o00000P3oool0103o
0000oooo0?ooo`3o00020?ooo`030?l0003oool0o`0000d0oooo0P3o000<0?ooo`040?l0003oool0
o`000?l000L0oooo103o0000103oool0o`000?l0003o00020?ooo`80o`0000<0oooo0?l0003oool0
0`3o00020?ooo`80o`0000L0oooo0?l0003oool0oooo0?l00000o`00o`0000d0oooo00<0o`000?oo
o`3o00000P3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0o`0000<0oooo0`3o00000`3o
ool0o`000?ooo`060?ooo`030?l0003oool0oooo00D0oooo00P0o`00003o003oool0o`000?ooo`3o
00000?l00?l00180oooo00<0o`000?ooo`3oool0203oool30?l000030?ooo`3o00000?l000<0o`00
0P3oool20?l00080oooo00<0o`000?ooo`3oool00P3oool30?l00080oooo00<0o`000?ooo`3o0000
0`3oool00`3o0000oooo0?l000030?ooo`80o`000`3oool20?l00080oooo0P3o0000103oool0o`00
0?ooo`3o00020?ooo`040?l0003oool0oooo0?l00080oooo00@0o`000?ooo`3o0000o`000`3oool0
0`3o0000oooo0?ooo`0D0?ooo`80o`0000<0oooo0?l0003oool00P3o00001@3oool0o`00003o003o
ool0o`000080oooo00<0o`000?ooo`3oool00`3oool30?l000030?ooo`3o0000oooo0080o`0000@0
oooo0?l0003oool0o`000P3oool20?l000H0oooo00<0o`000?ooo`3oool01@3oool0203o0000oooo
0?ooo`3o0000oooo0?l0003oool0o`000`3oool01P3o0000oooo0?ooo`3o0000oooo0?l000<0oooo
00d0o`00003o003oool0oooo003o003o00000?l00?ooo`00o`00o`000?ooo`3o00000?l00080oooo
00<0o`000000000000000P3oool01`00o`00o`00000000000000oooo003o003o00000P3oool00`3o
0000oooo0?ooo`020?ooo`040?l00000o`00o`000?l000<0oooo00<00?l00?l0003oool00P3oool0
1@3o0000oooo0?l0003oool0o`000080oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo01T0oooo00@0o`000?ooo`3o0000o`000P3oool00`3o0000oooo
0?l000020?ooo`030?l0003oool0o`0000l0oooo00<000000?ooo`3oool0>03oool003d0oooo2P00
000Y0?ooo`030000003oool0oooo04T0oooo00<0o`000?ooo`3oool00P3o00001`3oool0o`000?oo
o`3oool0o`000?ooo`3o00003@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0o`0000T0
oooo00@0o`000?ooo`3o0000oooo0`3o00020?ooo`80o`0000<0oooo0?l0003oool00`3o00080?oo
o`030?l00000o`00o`0000h0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`000080oooo00<0
o`000?ooo`3oool00`3oool30?l000030?ooo`3o0000oooo00h0oooo00P0o`00003o003oool0o`00
0?ooo`3o0000oooo0?l001d0oooo0`3o00000`3oool0o`00003o00030?l00080oooo0P3o00020?oo
o`030?l0003oool0oooo00<0oooo0P3o00020?ooo`030?l0003oool0o`0000@0oooo0P3o00030?oo
o`030?l0003oool0oooo0080oooo0P3o00020?ooo`80o`0000D0oooo0?l0003oool0o`000?ooo`02
0?l00080oooo00D0o`000?ooo`3oool0o`000?ooo`020?l000<0oooo00<0o`000?ooo`3oool0503o
ool20?l000030?ooo`3o0000oooo0080o`0000D0oooo0?l0003o0000oooo0?l000020?ooo`030?l0
003oool0oooo00<0oooo0`3o00020?ooo`80o`000P3oool30?l000<0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0o`000080oooo0P3o00040?ooo`060?l0
003oool0oooo0?l0003oool0o`000`3oool00`3o00000?l00?ooo`02003o00080?l00000o`000?l0
0?ooo`3o0000oooo0?l00000o`020?ooo`030?l00000000000000080oooo00L00?l00?l000000000
00000?ooo`00o`00o`000080oooo00<0o`000?ooo`3oool00P3oool0103o00000?l00?l0003o0003
0?ooo`03003o003o0000oooo0080oooo00<0o`000?ooo`3o00000P3o00020?ooo`030?l0003oool0
oooo01D0oooo00<0o`000?ooo`3oool06@3oool0103o0000oooo0?ooo`3o00020?ooo`030?l0003o
ool0o`0000<0oooo0P3o000?0?ooo`030000003oool0oooo03P0oooo000m0?ooo`X00000:@3oool0
0`000000oooo0?ooo`1=0?ooo`030?l0003oool0o`000080oooo0P3o000>0?ooo`030?l0003oool0
oooo00/0oooo00<0o`000?ooo`3o00003`3oool00`3o0000oooo0?ooo`020?l000030?ooo`3o0000
oooo00<0o`00203oool00`3o00000?l00?l0000B0?ooo`030?l0003oool0o`000080oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?l0000?0?ooo`080?l00000o`00oooo0?l0003oool0o`00
0?ooo`3o000M0?ooo`<0o`0000<0oooo0?l00000o`000`3o00020?ooo`80o`002@3oool00`3o0000
oooo0?ooo`020?l000D0oooo0P3o00030?ooo`030?l0003oool0oooo0080oooo0P3o00020?ooo`80
o`0000D0oooo0?l0003oool0o`000?ooo`020?l00080oooo00D0o`000?ooo`3oool0o`000?ooo`02
0?l000<0oooo00<0o`000?ooo`3oool05`3oool01@3o0000oooo0?l0003o0000oooo0080o`0000D0
oooo0?l0003oool0oooo0?l000050?ooo`<0o`00203oool01@3o0000oooo0?ooo`3oool0o`0000l0
oooo0P3o00020?ooo`80o`00103oool01P3o0000oooo0?ooo`3o0000oooo0?l000<0oooo00<0o`00
003o003oool00P00o`020?l00009003o003oool0o`000?ooo`3o00000?l00?ooo`3o0000oooo0080
00000P3oool01`00o`00o`00000000000000oooo003o003o00000P3oool00`3o0000oooo0?ooo`02
0?ooo`040?l00000o`00o`000?l000<0oooo00<00?l00?l00000o`000P3oool0103o0000oooo0?l0
003o000K0?ooo`030?l0003oool0oooo01T0oooo00@0o`000?ooo`3oool0o`000P3oool00`3o0000
oooo0?l000030?ooo`030?l0003oool0oooo00h0oooo00<000000?ooo`3oool0>03oool003d0oooo
2P00000Y0?ooo`030000003oool0oooo04d0oooo0P3o00030?ooo`80o`003P3oool00`3o0000oooo
0?ooo`0=0?ooo`030?l0003oool0oooo0100oooo0`3o00020?ooo`030?l0003oool0o`0000P0oooo
00<0o`00003o003o00004P3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3o00003`3oool0203o00000?l0003o003o0000oooo0?l0003oool0o`007@3oool3
0?l00080oooo00@0o`000?ooo`3o0000o`000P3oool00`3o0000oooo0?ooo`0;0?ooo`80o`001P3o
ool01@3o0000oooo0?ooo`3oool0o`0000@0oooo0P3o00020?ooo`<0o`000P3oool0103o0000oooo
0?l0003o00020?ooo`050?l0003oool0oooo0?l0003oool00P3o00030?ooo`030?l0003oool0oooo
01P0oooo0`3o00001@3oool0o`000?l0003oool0o`000080oooo00<0o`000?ooo`3oool00`3oool3
0?l000`0oooo00<0o`000?ooo`3oool03@3oool20?l00080oooo0P3o00040?ooo`060?l0003oool0
o`000?l0003oool0o`000`3oool00`3o00000?l00?ooo`02003o0080o`000P3oool01`3o0000oooo
0?l00000o`00oooo0?l0003oool00P0000020?ooo`07003o003o000000000000003oool00?l00?l0
00020?ooo`030?l0003oool0oooo0080oooo00@0o`00003o003o0000o`000`3oool00`00o`00o`00
003o0002003o00040?l0003oool0o`000?l001/0oooo00<0o`000?ooo`3oool0703oool00`3o0000
oooo0?ooo`020?l000@0oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`0h0?ooo`00
?@3oool:000002T0oooo0`00001=0?ooo`80o`00103oool00`3o0000oooo0?ooo`0L0?ooo`030?l0
003oool0oooo0180oooo00H0o`000?ooo`3oool0o`000?ooo`3o00080?ooo`030?l0003oool0o`00
0180oooo0`3o00020?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool03`3oool20?l0
0006003o003o0000oooo0?l0003oool0o`007P3oool20?l00080oooo00@0o`000?ooo`3oool0o`00
0P3oool00`3o0000oooo0?ooo`0;0?ooo`80o`001P3oool01@3o0000oooo0?ooo`3oool0o`0000@0
oooo0P3o00020?ooo`030?l0003oool0o`000080oooo00@0o`000?ooo`3o0000o`000P3oool20?l0
00030?ooo`3o0000oooo0080o`007P3oool30?l000050?ooo`3o0000o`000?ooo`3o00000P3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0o`0000`0oooo00<0o`000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`020?l000@0oooo103o00000`3oool0o`000?ooo`020?ooo`030?l00000o`00
oooo00800?l00P3o00020?ooo`040?l0003oool0o`000?ooo`80o`0000<0oooo0000000000000P3o
ool20?l00080000000<0oooo0?l0003o00000P3oool00`3o0000oooo0?ooo`020?ooo`80o`0000<0
oooo0?l00000o`000P3oool02000o`00o`00003o003oool00?l00?l0003oool0o`00?P3oool20?l0
00@0oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`0h0?ooo`00?@3oool:000002T0
oooo00<000000?ooo`3oool0C@3oool20?l000@0oooo00<0o`000?ooo`3oool0703oool00`3o0000
oooo0?ooo`0B0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?l0000B0?ooo`<0o`000P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0100
oooo00L0o`00003o003o0000oooo0?l0003oool0o`0001h0oooo0P3o00020?ooo`040?l0003oool0
oooo0?l00080oooo00<0o`000?ooo`3oool02`3oool20?l000X0oooo00<0o`000?ooo`3oool00P3o
ool20?l00080oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?l0003o00020?ooo`80o`00
00@0oooo0?l0003oool0o`007`3oool20?l000<0oooo00<0o`00003o003o00000P3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0o`0000`0oooo00<0o`000?ooo`3oool03P3oool00`3o0000
oooo0?ooo`020?l000@0oooo00`0o`000?ooo`3o0000o`000?ooo`3o0000oooo003o003oool0o`00
003o003oool2003o0080o`000P3oool0103o0000oooo0?l0003oool20?l000030?ooo`0000000000
0080oooo0P3o0002000000030?ooo`3o0000oooo0080oooo00<0o`000?ooo`3oool00P3oool20?l0
00030?ooo`3o00000?l00080oooo0P3o00001P00o`00oooo0?ooo`3o0000oooo0?l003h0oooo0P3o
00040?ooo`030?l0003oool0oooo00h0oooo00<000000?ooo`3oool0>03oool005d0oooo00<00000
0?ooo`3oool00P3oool4000000X0oooo00<000000?ooo`3oool0CP3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o00004P3oool30?l00080oooo00<0o`00
0?ooo`3oool0603oool0103o00000?l00?l0003oool20?l001l0oooo0P3o00020?ooo`040?l0003o
ool0oooo0?l00080oooo00<0o`000?ooo`3oool02`3oool20?l000X0oooo00<0o`000?ooo`3oool0
0P3oool20?l00080oooo00<0o`000?ooo`3o00000`3oool30?l00080oooo0P3o0000103oool0o`00
0?ooo`3o000O0?ooo`80o`000`3oool00`3o00000?l00?l000020?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0A0?ooo`80o`001`3oool00`3o0000
oooo0?l00002003o00060?ooo`3o00000?l0003o003oool00?l00P3o00001P3oool0o`000?ooo`3o
ool0o`000?ooo`80o`0000<0oooo0000000000000P3oool20?l00080000000<0oooo0?l0003oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`80o`0000<0oooo0?l00000o`000P3oool20?l00004003o
003oool0oooo0?l00400oooo0P3o00040?ooo`030?l0003oool0oooo00h0oooo00<000000?ooo`3o
ool0>03oool004L0oooo0`00000C0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo04h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0L0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`060?ooo`80o`00503oool01@3o0000oooo0?ooo`3oool0o`0001X0oooo00<0o`00003o
003o00000P3oool00`3o0000oooo0?ooo`0M0?ooo`80o`000P3oool0103o0000oooo0?ooo`3o0002
0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00H0oooo0`3o00020?ooo`80o`0000@0oooo0?l0003oool0o`00803o
ool01`3o0000oooo0?ooo`3oool0o`00003o003o00000P3oool00`3o0000oooo0?ooo`050?ooo`03
0?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool04@3oool20?l000L0oooo00<0o`000?ooo`3o
00000`00o`020?l00003003o003oool0oooo0080o`0000L0oooo0?l0003oool0oooo0?l0003oool0
o`000080oooo0P0000020?ooo`80o`000P0000000`3oool0o`000?ooo`020?ooo`030?l0003oool0
oooo0080oooo0P3o00000`3oool0o`00003o00020?ooo`80o`0000@00?l00?ooo`3oool0o`00@03o
ool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo03P0oooo00140?ooo`<000004@3oool7
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo04h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0
oooo0200oooo0P3o000c0?ooo`030?l00000o`00o`000080oooo00<0o`000?ooo`3oool07@3oool2
0?l00080oooo00@0o`000?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0o`000080oooo0`3o00020?ooo`030?l0003oool0oooo0280oooo00<0o`00003o003o00000P3o
ool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo0140oooo0P3o00090?ooo`040?l00000
o`00oooo003o0080o`000P3oool01@3o0000oooo0?l0003oool0o`000080oooo00<0o`000?ooo`3o
00000P3oool200000080oooo0P3o0002000000030?ooo`3o0000oooo00L0oooo0P3o00000`3oool0
o`00003o00020?ooo`<0o`000P3oool00`3o0000oooo0?ooo`0n0?ooo`030?l0003oool0oooo01@0
oooo00<000000?ooo`3oool0>03oool00440oooo0`00000D0?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00L0oooo1@00001<0?ooo`03
0?l0003oool0oooo0240oooo00<0o`000?ooo`3oool0803oool20?l003<0oooo00<0o`00003o003o
00000P3oool00`3o0000oooo0?ooo`0M0?ooo`80o`000P3oool0103o0000oooo0?ooo`3o00020?oo
o`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?l000020?oo
o`030?l0003oool0o`0002L0oooo00<0o`00003o003o00000P3oool00`3o0000oooo0?ooo`0B0?oo
o`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0203oool0103o00000?l00?ooo`00o`02
0?l00080oooo00D0o`000?ooo`3o0000oooo0?l000020?ooo`80o`000`3oool200000080oooo0P3o
0002000000030?ooo`3o0000oooo00P0oooo00@0o`000?ooo`3o00000?l00P3oool30?l000030?oo
o`3o0000oooo0400oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`0h0?ooo`00?P3o
ool3000001P0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1b0?ooo`030?l0003oool0oooo0200oooo
0P3o000c0?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool07@3oool20?l00080oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3o00000P3oool00`3o0000oooo0?l0000W0?ooo`030?l00000o`00o`0001L0oooo
00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`080?ooo`040?l00000o`00oooo003o0080
o`0000L0oooo0?l0003o0000oooo0?l0003oool0o`000080oooo0P3o00030?ooo`040?l0003oool0
oooo0?ooo`80o`000P0000000`3oool0o`000?ooo`0:0?ooo`040?l00000o`00oooo0?ooo`<0o`00
00<0oooo0?l0003oool0E`3oool00`000000oooo0?ooo`0h0?ooo`00?@3oool00`000000oooo0?oo
o`0J0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo09D0oooo0P3o000c0?ooo`80o`008`3oool20?l00080oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo00P0oooo
00H0o`000?ooo`3oool0o`000?ooo`3o000W0?ooo`030?l00000o`00o`0001L0oooo00<0o`000?oo
o`3oool04@3oool00`3o0000oooo0?ooo`080?ooo`040?l00000o`00oooo0?ooo`80o`0000L0oooo
0?l0003o0000oooo0?l0003oool0o`000080oooo0P3o00030?ooo`040?l0003oool0oooo0?ooo`80
o`000P0000000`3oool0o`000?ooo`0:0?ooo`060?l00000o`00oooo0?ooo`3o0000oooo0P3o001I
0?ooo`030000003oool0oooo03P0oooo000m0?ooo`X000004`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2E
0?ooo`80o`00<`3oool20?l002@0oooo00@0o`000?ooo`3oool0o`009@3oool00`3o0000oooo0?oo
o`080?ooo`060?l0003oool0oooo0?l0003oool0o`009`3oool00`3o00000?l00?l0000G0?ooo`03
0?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0203oool0103o00000?l00?ooo`3oool20?l0
00040?ooo`3o0000o`000?ooo`80o`000`3oool20?l000<0oooo00@0o`000?ooo`3oool0oooo0P3o
000200000003003o003o0000oooo00X0oooo00H0o`00003o003oool0oooo0?l0003oool20?l005T0
oooo00<000000?ooo`3oool0>03oool003h0oooo0P00000K0?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo09D0oooo
0P3o000d0?ooo`030?l0003oool0oooo0280oooo00@0o`000?ooo`3oool0o`00<03oool0103o0000
oooo0?ooo`3o000Y0?ooo`030?l00000o`00o`0001L0oooo00<0o`000?ooo`3oool04@3oool00`3o
0000oooo0?ooo`080?ooo`040?l00000o`00oooo0?ooo`80o`0000@0oooo0?l0003o0000oooo0P3o
00030?ooo`80o`000`3oool0103o00000?l00?ooo`3oool20?l00080000000<00?l00?l0003oool0
2P3oool01`3o00000?l00?ooo`3oool0o`000?ooo`3o0000FP3oool00`000000oooo0?ooo`0h0?oo
o`00@03oool2000001X0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`2E0?ooo`80o`00=03oool00`3o0000oooo0?ooo`0R0?ooo`04
0?l0003oool0oooo0?l003<0oooo00<0o`000?ooo`3oool09`3oool00`3o00000?l00?l0000f0?oo
o`070?l00000o`00oooo0?l0003oool0o`000?ooo`020?l000030?ooo`3o0000oooo00<0oooo0P3o
00030?ooo`040?l00000o`00oooo0?ooo`80o`000P0000000`00o`00o`000?ooo`0:0?ooo`070?l0
0000o`00oooo0?ooo`3o0000oooo0?l0001J0?ooo`030000003oool0oooo03P0oooo00120?ooo`<0
0000603oool00`000000oooo0?ooo`020?ooo`@000002P3oool3000009D0oooo00<0o`000?ooo`3o
ool0<`3oool00`3o0000oooo0?ooo`0R0?ooo`040?l0003oool0oooo0?l003<0oooo00<0o`000?oo
o`3oool09`3oool00`3o0000oooo0?l0000f0?ooo`070?l00000o`00o`000?l0003oool0o`000?oo
o`020?l000030?ooo`3o0000oooo00<0oooo0P3o00030?ooo`040?l00000o`00oooo0?ooo`80o`00
0P0000000`00o`00o`000?ooo`0;0?ooo`060?l0003oool0oooo0?l0003oool0o`00FP3oool00`00
0000oooo0?ooo`0h0?ooo`00A@3oool2000002T0oooo00<000000?ooo`3oool0U@3oool00`3o0000
oooo0?ooo`0c0?ooo`030?l0003oool0oooo0280oooo00@0o`000?ooo`3oool0o`00<`3oool00`3o
0000oooo0?ooo`0W0?ooo`030?l0003oool0o`0003H0oooo00L0o`000?ooo`3o0000o`000?ooo`3o
0000oooo0080o`001P3oool20?l000<0oooo00@0o`00003o003oool0oooo0P3o000200000003003o
003o0000oooo00/0oooo00H0o`000?ooo`00o`00o`000?ooo`3o001J0?ooo`030000003oool0oooo
03P0oooo00120?ooo`<00000:`3oool00`000000oooo0?ooo`2E0?ooo`030?l0003oool0oooo03<0
oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`1N0?ooo`030?l0003oool0o`0003H0
oooo00D0o`000?ooo`3o0000o`000?ooo`020?l000030?ooo`3o0000oooo00D0oooo0P3o00030?oo
o`040?l00000o`00oooo0?ooo`80o`000P0000000`00o`00o`000?ooo`0;0?ooo`060?l0003oool0
0?l00?l0003oool0o`00FP3oool00`000000oooo0?ooo`0h0?ooo`00@03oool2000002h0oooo00<0
00000?ooo`3oool0b`3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo05h0oooo00<0
o`000?ooo`3o0000=P3oool0103o0000oooo0?l0003o00020?ooo`030?l0003oool0oooo00H0oooo
0P3o00030?ooo`040?l00000o`00oooo0?ooo`80o`000P0000000`00o`00o`000?ooo`0;0?ooo`06
0?l0003oool00?l00?l0003oool0o`00FP3oool00`000000oooo0?ooo`0h0?ooo`00?P3oool20000
0300oooo00<000000?ooo`3oool0b`3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo
05h0oooo00<0o`000?ooo`3o0000=P3oool0103o0000oooo0?l0003o000;0?ooo`80o`000`3oool0
103o00000?l00?ooo`3oool20?l00080000000<00?l00?l0003oool02`3oool01P3o0000oooo003o
003o0000oooo0?l005X0oooo00<000000?ooo`3oool0>03oool003d0oooo2P00000Y0?ooo`<00000
b`3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo05h0oooo00<0o`000?ooo`3o0000
=P3oool0103o0000oooo0?l0003o000;0?ooo`030?l0003oool0oooo0080oooo00@0o`00003o003o
ool0oooo0P3o000200000003003o003o0000oooo00/0oooo00H0o`000?ooo`00o`00o`000?ooo`3o
001J0?ooo`030000003oool0oooo03P0oooo001`0?ooo`030000003oool0oooo0</0oooo00<0o`00
0?ooo`3oool08P3oool00`3o0000oooo0?ooo`1O0?ooo`030?l0003oool0oooo03H0oooo00<0o`00
0?ooo`3o00002`3oool00`3o0000oooo0?ooo`020?ooo`040?l00000o`00oooo0?ooo`80o`000P00
00000`00o`00o`000?ooo`0;0?ooo`060?l00000o`00oooo0?l0003oool0o`00FP3oool00`000000
oooo0?ooo`0h0?ooo`00L03oool00`000000oooo0?ooo`3`0?ooo`030?l0003oool0oooo05l0oooo
00<0o`000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo
00@0o`00003o003oool0oooo0P3o000200000003003o003o0000oooo00/0oooo00@0o`00003o003o
ool0o`00G03oool00`000000oooo0?ooo`0h0?ooo`00?@3oool200000340oooo00<000000?ooo`3o
ool0l03oool00`3o0000oooo0?ooo`1O0?ooo`030?l0003oool0oooo03H0oooo00<0o`000?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`020?ooo`040?l00000o`000?l00?ooo`80o`000P0000000`00
o`00o`000?ooo`0;0?ooo`040?l00000o`00oooo0?l005`0oooo00<000000?ooo`3oool0>03oool0
03l0oooo0`00000^0?ooo`030000003oool0oooo0?l0ooooD`3oool00`3o0000oooo0?ooo`0f0?oo
o`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool0103o00000?l0003o003oool2
0?l00080000000<0o`000?ooo`3oool02`3oool0103o00000?l00?ooo`3o001L0?ooo`030000003o
ool0oooo03P0oooo00120?ooo`<00000:`3oool300000?l0ooooD`3oool00`3o0000oooo0?ooo`0f
0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool0103o00000?l0003o003o
ool20?l00080000000<0o`000?ooo`3oool02`3oool0103o00000?l00?ooo`3o001L0?ooo`030000
003oool0oooo03P0oooo00150?ooo`800000:@3oool00`000000oooo0?ooo`3o0?oooe<0oooo00<0
o`000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0@0?ooo`040?l00000o`000?l0003o0080o`00
0P0000000`3o0000oooo0?ooo`0;0?ooo`040?l00000o`00oooo0?l005`0oooo00<000000?ooo`3o
ool0>03oool00480oooo0`00000E0?ooo`@00000103oool4000000X0oooo00<000000?ooo`3oool0
o`3ooomC0?ooo`030?l0003oool0oooo03H0oooo00<0o`000?ooo`3oool0403oool0103o00000?l0
003o0000o`020?l00080000000<0o`000?ooo`3oool02`3oool0103o0000oooo0?ooo`3o001L0?oo
o`030000003oool0oooo03P0oooo000n0?ooo`@000005`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oo
oe<0oooo00<0o`000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0@0?ooo`040?l00000o`000?l0
0?ooo`80o`000P0000000`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?l005`0oooo00<0
00000?ooo`3oool0>03oool003d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3o0?oooe<0oooo00<0o`000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0@0?ooo`040?l00000
o`000?l00?ooo`80o`000P0000000`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0o`0005d0oooo
00<000000?ooo`3oool0>03oool003h0oooo1000000G0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo
D`3oool00`3o0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo0100oooo00@0o`00003o003oool0
oooo0P3o0002000000030?l0003oool0oooo00/0oooo00<0o`000?ooo`3o0000G@3oool00`000000
oooo0?ooo`0h0?ooo`00@P3oool3000001@0oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool01`3oool500000?l0ooooD@3oool00`3o0000oooo0?ooo`0f0?ooo`03
0?l0003oool0oooo0100oooo00@0o`00003o003oool0oooo0P3o0002000000030?l0003oool0oooo
00/0oooo00<0o`000?ooo`3o0000G@3oool00`000000oooo0?ooo`0h0?ooo`00A@3oool200000180
oooo00<000000?ooo`0000000P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`3o0?oooe<0oooo00<0o`000?ooo`3oool0=P3oool00`3o0000
oooo0?ooo`0@0?ooo`040?l00000o`00oooo0?ooo`80o`000P0000000`3o0000oooo0?ooo`0;0?oo
o`030?l0003oool0o`0005d0oooo00<000000?ooo`3oool0>03oool00480oooo0`00000D0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?l0ooooD`3oool00`3o0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo0100
oooo00@0o`00003o003oool0oooo0P3o0002000000030?l0003oool0oooo00/0oooo00<0o`000?oo
o`3o0000G@3oool00`000000oooo0?ooo`0h0?ooo`00?`3oool3000001L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0o`3ooomC0?ooo`030?l0003oool0oooo03H0oooo00<0o`000?ooo`3oool04@3oool00`3o0000
oooo0?ooo`020?l00080000000<0o`000?ooo`3oool02`3oool00`3o0000oooo0?l0001M0?ooo`03
0000003oool0oooo03P0oooo000m0?ooo`8000006`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0
ooooD`3oool00`3o0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3o
ool00P3o0002000000030?l0003oool0oooo00/0oooo00<0o`000?ooo`3o0000G@3oool00`000000
oooo0?ooo`0h0?ooo`00F`3oool3000000@0oooo1000000:0?ooo`<00000o`3ooomC0?ooo`030?l0
003oool0oooo03H0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`020?l000800000
00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?l0001M0?ooo`030000003oool0oooo03P0oooo
000m0?ooo`X00000:@3oool00`000000oooo0?ooo`3o0?oooe<0oooo00<0o`000?ooo`3oool0BP3o
ool00`3o0000oooo0?ooo`020?l00080000000<0o`000?ooo`3oool02`3oool00`3o0000oooo0?l0
001M0?ooo`030000003oool0oooo03P0oooo00100?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0o`3ooomC0?ooo`030?l0003oool0oooo04X0oooo00<0o`000?ooo`3oool00P3o0002
000000030?l0003oool0oooo00/0oooo00<0o`000?ooo`3o0000G@3oool00`000000oooo0?ooo`0h
0?ooo`00?`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooD`3oool00`3o
0000oooo0?ooo`1:0?ooo`030?l0003oool0oooo0080o`000P0000000`3o0000oooo0?ooo`0;0?oo
o`030?l0003oool0o`0005d0oooo00<000000?ooo`3oool0>03oool003l0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`3o0?oooe<0oooo00<0o`000?ooo`3oool0BP3oool00`3o0000
oooo0?ooo`020?l00080000000<0o`000?ooo`3oool02`3oool20?l005h0oooo00<000000?ooo`3o
ool0>03oool003l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooj00oooo
00<0o`000?ooo`3oool00P3o0002000000030?l0003oool0oooo00/0oooo0P3o001N0?ooo`030000
003oool0oooo03P0oooo00100?ooo`L00000:@3oool300000?l0ooooX03oool00`3o0000oooo0?oo
o`020?l00080000000<0o`000?ooo`3oool02`3oool20?l005h0oooo00<000000?ooo`3oool0>03o
ool00700oooo00<000000?ooo`3oool0o`3ooonP0?ooo`030?l0003oool0oooo0080o`000P000000
0`3o0000oooo0?ooo`0;0?ooo`80o`00GP3oool00`000000oooo0?ooo`0h0?ooo`00L03oool00`00
0000oooo0?ooo`3o0?oooj00oooo00<0o`000?ooo`3oool00P3o0002000000030?l0003oool0oooo
00/0oooo0P3o001N0?ooo`030000003oool0oooo03P0oooo001`0?ooo`030000003oool0oooo0?l0
ooooX03oool00`3o0000oooo0?ooo`020?l0008000003P3oool20?l005h0oooo00<000000?ooo`3o
ool0>03oool00700oooo00<000000?ooo`3oool0o`3ooonP0?ooo`80o`0000<0oooo0?l0003o0000
0P00000>0?ooo`80o`00GP3oool00`000000oooo0?ooo`0h0?ooo`00L03oool300000?l0ooooX03o
ool20?l000030?ooo`3o0000o`00008000003P3oool00`3o0000oooo0?ooo`1M0?ooo`030000003o
ool0oooo03P0oooo001J0?ooo`@00000103oool4000000X0oooo00<000000?ooo`3oool0o`3ooonP
0?ooo`80o`0000<0oooo0?l0003o00000P00000>0?ooo`030?l0003oool0oooo05d0oooo00<00000
0?ooo`3oool0>03oool005T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonP0?ooo`80o`0000<0oooo
0?l0003o00000P00000>0?ooo`030?l0003oool0oooo05d0oooo00<000000?ooo`3oool0>03oool0
05T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0o`3ooonP0?ooo`80o`0000<0oooo0?l0003o00000P00000>
0?ooo`030?l0003oool0oooo05d0oooo00<000000?ooo`3oool0>03oool005T0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0o`3ooonP0?ooo`D0o`000P00000>0?ooo`030?l0003oool0oooo05d0oooo00<00000
0?ooo`3oool0>03oool005T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00L0oooo1@00003o0?oooih0oooo1@3o0002000000h0oooo00<0o`00
0?ooo`3oool0G@3oool00`000000oooo0?ooo`0h0?ooo`00FP3oool4000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooX03oool50?l0
00800000KP3oool00`000000oooo0?ooo`0h0?ooo`00F@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oo
oj00oooo0P3o00020?ooo`030?l000000000000006h0oooo00<000000?ooo`3oool0>03oool005T0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0o`3ooonP0?ooo`80o`000P3oool00`3o000000000000001^0?oo
o`030000003oool0oooo03P0oooo001I0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooX03oool20?l0
0080oooo00<0o`00000000000000KP3oool00`000000oooo0?ooo`0h0?ooo`00FP3oool4000000@0
oooo1000000:0?ooo`030000003oool0oooo0?l0ooooX03oool01@3o0000oooo0?ooo`3oool0o`00
00800000KP3oool00`000000oooo0?ooo`0h0?ooo`00L03oool300000?l0ooooX03oool01@3o0000
oooo0?ooo`3oool0o`0000800000KP3oool00`000000oooo0?ooo`0h0?ooo`00L03oool00`000000
oooo0?ooo`3o0?oooj00oooo00D0o`000?ooo`3oool0oooo0?l00002000006h0oooo00<000000?oo
o`3oool0>03oool00700oooo00<000000?ooo`3oool0o`3ooonP0?ooo`050?l0003oool0oooo0?oo
o`3o00000P00001^0?ooo`030000003oool0oooo03P0oooo001`0?ooo`030000003oool0oooo0?l0
ooooX03oool01@3o0000oooo0?ooo`3oool0o`0000800000KP3oool00`000000oooo0?ooo`0h0?oo
o`00L03oool00`000000oooo0?ooo`3o0?oooj00oooo00D0o`000?ooo`3oool0oooo0?l000020000
06h0oooo00<000000?ooo`3oool0>03oool00700oooo0`00003o0?oooj00oooo00D0o`000?ooo`3o
ool0oooo0?l00002000006h0oooo00<000000?ooo`3oool0>03oool00700oooo00<000000?ooo`3o
ool0o`3ooonP0?ooo`050?l0003oool0oooo0?ooo`3o00000P00001^0?ooo`030000003oool0oooo
03P0oooo001`0?ooo`030000003oool0oooo0?l0ooooX03oool01@3o0000oooo0?ooo`3oool0o`00
00800000KP3oool00`000000oooo0?ooo`0h0?ooo`00L03oool00`000000oooo0?ooo`3o0?oooj00
oooo00D0o`000?ooo`3oool0oooo0?l00002000006h0oooo00<000000?ooo`3oool0>03oool00700
oooo00<000000?ooo`3oool0o`3ooonP0?ooo`050?l0003oool0oooo0?ooo`3o00000P00001^0?oo
o`030000003oool0oooo03P0oooo001`0?ooo`<00000o`3ooonP0?ooo`050?l0003oool0oooo0?oo
o`3o00000P00001^0?ooo`030000003oool0oooo03P0oooo001`0?ooo`030000003oool0oooo0?l0
ooooX03oool01@3o0000oooo0?ooo`3oool0o`0000800000KP3oool00`000000oooo0?ooo`0h0?oo
o`00E03oool00`000000oooo0?ooo`030?ooo`@00000103oool4000000X0oooo00<000000?ooo`3o
ool0o`3ooonP0?ooo`050?l0003oool0oooo0?ooo`3o00000P00001^0?ooo`030000003oool0oooo
03P0oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonP0?oo
o`050?l0003oool0oooo0?ooo`3o00000P00001^0?ooo`030000003oool0oooo03P0oooo001D0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonP0?ooo`050?l0003oool0
oooo0?ooo`3o00000P00001^0?ooo`030000003oool0oooo03P0oooo001D0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonP0?ooo`050?l0003oool0oooo0?ooo`3o0000
0P00001^0?ooo`030000003oool0oooo03P0oooo001D0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo
o`00002S000000050?l00000000000000000003o0000L@00000j0?ooo`00E03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`3o0?ooojl0oooo00<0o`000?ooo`3oool0Z03oool005@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0o`3ooon_0?ooo`030?l0003oool0oooo0:P0oooo001B0?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0
oooo[`3oool00`3o0000oooo0?ooo`2X0?ooo`00D`3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo[`3oool00`3o0000
oooo0?ooo`2X0?ooo`00E03oool00`000000oooo0?ooo`030?ooo`@00000103oool400000?l0oooo
/P3oool00`3o0000oooo0?ooo`2X0?ooo`00o`3ooooo0?oooaT0oooo00<0o`000?ooo`3oool0Z03o
ool00?l0ooooo`3ooolI0?ooo`030?l0003oool0oooo0:P0oooo003o0?ooool0oooo6@3oool00`3o
0000oooo0?ooo`2X0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 705.25}, {140.25, 0}} -> {-168.488, -22.8486, \
1.34201, 0.935103}}]
}, Open  ]],

Cell["But there are some exceptions to this rule", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Count[peak - base, x_ /; x < 0]\)], "Input"],

Cell[BoxData[
    \(6\)], "Output"]
}, Open  ]],

Cell["\<\
The correlation which can be sensed from a look at the data is confirmd \
through a regressionen analysis. For the regression analysis we look at the \
one day changes of the prices.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(regdata\  = {Difference[peak, 1], Difference[base, 1]}\  // \ 
          Transpose;\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[regdata, PlotJoined \[Rule] False, Frame \[Rule] True, \ 
        PlotRange \[Rule] \ Automatic];\)\), "\[IndentingNewLine]", 
    \(Regress[regdata, {1, y}, y]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.498109 0.0171889 0.306684 0.0155551 [
[.15433 -0.0125 -14.6563 -17.75 ]
[.15433 -0.0125 14.6563 0 ]
[.32622 -0.0125 -14.6563 -17.75 ]
[.32622 -0.0125 14.6563 0 ]
[.49811 -0.0125 -5.90625 -17.75 ]
[.49811 -0.0125 5.90625 0 ]
[.67 -0.0125 -9.8125 -17.75 ]
[.67 -0.0125 9.8125 0 ]
[.84189 -0.0125 -9.8125 -17.75 ]
[.84189 -0.0125 9.8125 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07336 -29.3125 -8.875 ]
[-0.0125 .07336 0 8.875 ]
[-0.0125 .15113 -29.3125 -8.875 ]
[-0.0125 .15113 0 8.875 ]
[-0.0125 .22891 -21.5 -8.875 ]
[-0.0125 .22891 0 8.875 ]
[-0.0125 .30668 -11.8125 -8.875 ]
[-0.0125 .30668 0 8.875 ]
[-0.0125 .38446 -11.8125 -8.875 ]
[-0.0125 .38446 0 8.875 ]
[-0.0125 .46223 -19.625 -8.875 ]
[-0.0125 .46223 0 8.875 ]
[-0.0125 .54001 -19.625 -8.875 ]
[-0.0125 .54001 0 8.875 ]
[-0.0125 .61779 -19.625 -8.875 ]
[-0.0125 .61779 0 8.875 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15433 0 m
.15433 .00625 L
s
gsave
.15433 -0.0125 -75.6563 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.32622 0 m
.32622 .00625 L
s
gsave
.32622 -0.0125 -75.6563 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.49811 0 m
.49811 .00625 L
s
gsave
.49811 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.67 0 m
.67 .00625 L
s
gsave
.67 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.84189 0 m
.84189 .00625 L
s
gsave
.84189 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.18871 0 m
.18871 .00375 L
s
.22309 0 m
.22309 .00375 L
s
.25746 0 m
.25746 .00375 L
s
.29184 0 m
.29184 .00375 L
s
.3606 0 m
.3606 .00375 L
s
.39498 0 m
.39498 .00375 L
s
.42935 0 m
.42935 .00375 L
s
.46373 0 m
.46373 .00375 L
s
.53249 0 m
.53249 .00375 L
s
.56686 0 m
.56686 .00375 L
s
.60124 0 m
.60124 .00375 L
s
.63562 0 m
.63562 .00375 L
s
.70438 0 m
.70438 .00375 L
s
.73875 0 m
.73875 .00375 L
s
.77313 0 m
.77313 .00375 L
s
.80751 0 m
.80751 .00375 L
s
.11995 0 m
.11995 .00375 L
s
.08558 0 m
.08558 .00375 L
s
.0512 0 m
.0512 .00375 L
s
.01682 0 m
.01682 .00375 L
s
.87627 0 m
.87627 .00375 L
s
.91064 0 m
.91064 .00375 L
s
.94502 0 m
.94502 .00375 L
s
.9794 0 m
.9794 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07336 m
.00625 .07336 L
s
gsave
-0.0125 .07336 -90.3125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .15113 m
.00625 .15113 L
s
gsave
-0.0125 .15113 -90.3125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .22891 m
.00625 .22891 L
s
gsave
-0.0125 .22891 -82.5 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .30668 m
.00625 .30668 L
s
gsave
-0.0125 .30668 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .38446 m
.00625 .38446 L
s
gsave
-0.0125 .38446 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .46223 m
.00625 .46223 L
s
gsave
-0.0125 .46223 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .54001 m
.00625 .54001 L
s
gsave
-0.0125 .54001 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .61779 m
.00625 .61779 L
s
gsave
-0.0125 .61779 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08891 m
.00375 .08891 L
s
0 .10447 m
.00375 .10447 L
s
0 .12002 m
.00375 .12002 L
s
0 .13558 m
.00375 .13558 L
s
0 .16669 m
.00375 .16669 L
s
0 .18224 m
.00375 .18224 L
s
0 .1978 m
.00375 .1978 L
s
0 .21335 m
.00375 .21335 L
s
0 .24446 m
.00375 .24446 L
s
0 .26002 m
.00375 .26002 L
s
0 .27557 m
.00375 .27557 L
s
0 .29113 m
.00375 .29113 L
s
0 .32224 m
.00375 .32224 L
s
0 .33779 m
.00375 .33779 L
s
0 .35335 m
.00375 .35335 L
s
0 .3689 m
.00375 .3689 L
s
0 .40001 m
.00375 .40001 L
s
0 .41557 m
.00375 .41557 L
s
0 .43112 m
.00375 .43112 L
s
0 .44668 m
.00375 .44668 L
s
0 .47779 m
.00375 .47779 L
s
0 .49334 m
.00375 .49334 L
s
0 .5089 m
.00375 .5089 L
s
0 .52445 m
.00375 .52445 L
s
0 .55556 m
.00375 .55556 L
s
0 .57112 m
.00375 .57112 L
s
0 .58667 m
.00375 .58667 L
s
0 .60223 m
.00375 .60223 L
s
0 .0578 m
.00375 .0578 L
s
0 .04225 m
.00375 .04225 L
s
0 .02669 m
.00375 .02669 L
s
0 .01114 m
.00375 .01114 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.15433 .61178 m
.15433 .61803 L
s
.32622 .61178 m
.32622 .61803 L
s
.49811 .61178 m
.49811 .61803 L
s
.67 .61178 m
.67 .61803 L
s
.84189 .61178 m
.84189 .61803 L
s
.125 Mabswid
.18871 .61428 m
.18871 .61803 L
s
.22309 .61428 m
.22309 .61803 L
s
.25746 .61428 m
.25746 .61803 L
s
.29184 .61428 m
.29184 .61803 L
s
.3606 .61428 m
.3606 .61803 L
s
.39498 .61428 m
.39498 .61803 L
s
.42935 .61428 m
.42935 .61803 L
s
.46373 .61428 m
.46373 .61803 L
s
.53249 .61428 m
.53249 .61803 L
s
.56686 .61428 m
.56686 .61803 L
s
.60124 .61428 m
.60124 .61803 L
s
.63562 .61428 m
.63562 .61803 L
s
.70438 .61428 m
.70438 .61803 L
s
.73875 .61428 m
.73875 .61803 L
s
.77313 .61428 m
.77313 .61803 L
s
.80751 .61428 m
.80751 .61803 L
s
.11995 .61428 m
.11995 .61803 L
s
.08558 .61428 m
.08558 .61803 L
s
.0512 .61428 m
.0512 .61803 L
s
.01682 .61428 m
.01682 .61803 L
s
.87627 .61428 m
.87627 .61803 L
s
.91064 .61428 m
.91064 .61803 L
s
.94502 .61428 m
.94502 .61803 L
s
.9794 .61428 m
.9794 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07336 m
1 .07336 L
s
.99375 .15113 m
1 .15113 L
s
.99375 .22891 m
1 .22891 L
s
.99375 .30668 m
1 .30668 L
s
.99375 .38446 m
1 .38446 L
s
.99375 .46223 m
1 .46223 L
s
.99375 .54001 m
1 .54001 L
s
.99375 .61779 m
1 .61779 L
s
.125 Mabswid
.99625 .08891 m
1 .08891 L
s
.99625 .10447 m
1 .10447 L
s
.99625 .12002 m
1 .12002 L
s
.99625 .13558 m
1 .13558 L
s
.99625 .16669 m
1 .16669 L
s
.99625 .18224 m
1 .18224 L
s
.99625 .1978 m
1 .1978 L
s
.99625 .21335 m
1 .21335 L
s
.99625 .24446 m
1 .24446 L
s
.99625 .26002 m
1 .26002 L
s
.99625 .27557 m
1 .27557 L
s
.99625 .29113 m
1 .29113 L
s
.99625 .32224 m
1 .32224 L
s
.99625 .33779 m
1 .33779 L
s
.99625 .35335 m
1 .35335 L
s
.99625 .3689 m
1 .3689 L
s
.99625 .40001 m
1 .40001 L
s
.99625 .41557 m
1 .41557 L
s
.99625 .43112 m
1 .43112 L
s
.99625 .44668 m
1 .44668 L
s
.99625 .47779 m
1 .47779 L
s
.99625 .49334 m
1 .49334 L
s
.99625 .5089 m
1 .5089 L
s
.99625 .52445 m
1 .52445 L
s
.99625 .55556 m
1 .55556 L
s
.99625 .57112 m
1 .57112 L
s
.99625 .58667 m
1 .58667 L
s
.99625 .60223 m
1 .60223 L
s
.99625 .0578 m
1 .0578 L
s
.99625 .04225 m
1 .04225 L
s
.99625 .02669 m
1 .02669 L
s
.99625 .01114 m
1 .01114 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30668 m
1 .30668 L
s
.49811 0 m
.49811 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.40661 .24711 Mdot
.45339 .27713 Mdot
.65867 .40421 Mdot
.51422 .31742 Mdot
.4893 .30015 Mdot
.36876 .23855 Mdot
.53494 .31959 Mdot
.44626 .27853 Mdot
.46684 .28351 Mdot
.67669 .42459 Mdot
.4503 .2678 Mdot
.49507 .31633 Mdot
.54876 .33468 Mdot
.43606 .2636 Mdot
.41165 .23389 Mdot
.47165 .28911 Mdot
.63606 .40157 Mdot
.52702 .33375 Mdot
.47754 .29875 Mdot
.52553 .31617 Mdot
.46925 .286 Mdot
.38939 .24415 Mdot
.44318 .26406 Mdot
.67941 .41619 Mdot
.51566 .33888 Mdot
.49516 .29035 Mdot
.45435 .28397 Mdot
.46829 .28475 Mdot
.41562 .25582 Mdot
.46037 .28366 Mdot
.62588 .38757 Mdot
.47436 .2972 Mdot
.4999 .30902 Mdot
.50047 .30731 Mdot
.5267 .32473 Mdot
.42816 .26375 Mdot
.4375 .26126 Mdot
.61905 .38353 Mdot
.47281 .30342 Mdot
.53773 .31571 Mdot
.46392 .29144 Mdot
.50199 .31088 Mdot
.43475 .26282 Mdot
.46657 .28584 Mdot
.61249 .37684 Mdot
.47907 .29937 Mdot
.47711 .29642 Mdot
.53497 .32473 Mdot
.5013 .31415 Mdot
.42794 .25411 Mdot
.4401 .26842 Mdot
.57705 .3633 Mdot
.51982 .32193 Mdot
.48354 .30171 Mdot
.51915 .32162 Mdot
.47962 .2972 Mdot
.46556 .27246 Mdot
.44293 .2692 Mdot
.61286 .38819 Mdot
.4589 .28973 Mdot
.57135 .35195 Mdot
.50392 .31244 Mdot
.47619 .29688 Mdot
.45564 .26531 Mdot
.42997 .25395 Mdot
.68586 .41992 Mdot
.5796 .35942 Mdot
.34965 .2272 Mdot
.60189 .36937 Mdot
.44598 .27464 Mdot
.35462 .21118 Mdot
.42944 .25022 Mdot
.73865 .46317 Mdot
.51663 .32022 Mdot
.57583 .35148 Mdot
.42345 .27448 Mdot
.54511 .33422 Mdot
.31147 .20013 Mdot
.44574 .27075 Mdot
.72093 .42397 Mdot
.56368 .39193 Mdot
.4722 .25909 Mdot
.51722 .32535 Mdot
.51134 .31259 Mdot
.24134 .14553 Mdot
.41795 .26344 Mdot
.78373 .47203 Mdot
.55025 .35039 Mdot
.50375 .32333 Mdot
.6322 .37404 Mdot
.28373 .18924 Mdot
.35 .19904 Mdot
.41804 .25349 Mdot
.72962 .45897 Mdot
.50709 .31182 Mdot
.52137 .30964 Mdot
.65439 .39846 Mdot
.3093 .20371 Mdot
.36492 .21833 Mdot
.39979 .24322 Mdot
.72159 .45648 Mdot
.51494 .32208 Mdot
.47634 .29673 Mdot
.52141 .31462 Mdot
.46197 .29144 Mdot
.39542 .21678 Mdot
.35616 .22066 Mdot
.69903 .42319 Mdot
.43431 .26329 Mdot
.62167 .38524 Mdot
.43488 .28833 Mdot
.48467 .29844 Mdot
.43312 .26095 Mdot
.38595 .23544 Mdot
.77441 .46301 Mdot
.44159 .31166 Mdot
.64694 .36517 Mdot
.4161 .25115 Mdot
.45226 .28926 Mdot
.28272 .16404 Mdot
.43639 .25209 Mdot
.67392 .43657 Mdot
.62127 .38244 Mdot
.43014 .28273 Mdot
.50931 .30839 Mdot
.47737 .30186 Mdot
.38631 .23482 Mdot
.41675 .25504 Mdot
.78263 .47421 Mdot
.48777 .31415 Mdot
.46678 .28335 Mdot
.51899 .31835 Mdot
.50195 .30606 Mdot
.3718 .2356 Mdot
.39632 .23715 Mdot
.82321 .51341 Mdot
.436 .258 Mdot
.39068 .25473 Mdot
.80307 .44995 Mdot
.18105 .16715 Mdot
.48082 .29517 Mdot
.37352 .21771 Mdot
.75869 .4305 Mdot
.51311 .33577 Mdot
.48623 .29346 Mdot
.3761 .24757 Mdot
.5431 .34479 Mdot
.37402 .2272 Mdot
.44368 .26282 Mdot
.77673 .46768 Mdot
.45703 .31399 Mdot
.55867 .34044 Mdot
.48813 .28444 Mdot
.50142 .31508 Mdot
.3194 .20822 Mdot
.48118 .27791 Mdot
.70294 .43501 Mdot
.46508 .29082 Mdot
.53731 .34884 Mdot
.51026 .29626 Mdot
.41904 .28211 Mdot
.45442 .26982 Mdot
.32659 .19546 Mdot
.80516 .50454 Mdot
.44435 .26982 Mdot
.50918 .31539 Mdot
.60504 .35833 Mdot
.34839 .21071 Mdot
.3289 .20589 Mdot
.50085 .30917 Mdot
.77158 .45881 Mdot
.39213 .27837 Mdot
.65072 .38244 Mdot
.38733 .25209 Mdot
.28425 .19158 Mdot
.57178 .32115 Mdot
.42242 .26173 Mdot
.71032 .43719 Mdot
.50142 .30699 Mdot
.38925 .24493 Mdot
.55808 .3409 Mdot
.54794 .33515 Mdot
.32174 .2048 Mdot
.44465 .26857 Mdot
.87114 .52337 Mdot
.61535 .39395 Mdot
.42129 .26002 Mdot
.31977 .202 Mdot
.38972 .25551 Mdot
.41827 .25769 Mdot
.44656 .26017 Mdot
.45992 .28211 Mdot
.49689 .30762 Mdot
.64712 .38244 Mdot
.45253 .29315 Mdot
.47356 .28802 Mdot
.50292 .31166 Mdot
.46578 .279 Mdot
.38095 .24726 Mdot
.66988 .42459 Mdot
.47599 .29097 Mdot
.56502 .33608 Mdot
.48913 .30731 Mdot
.4024 .23591 Mdot
.48158 .28708 Mdot
.71035 .43548 Mdot
.50774 .32053 Mdot
.52435 .31788 Mdot
.4876 .30482 Mdot
.4472 .28911 Mdot
.43359 .27635 Mdot
.45578 .28895 Mdot
.7554 .43532 Mdot
.46111 .31399 Mdot
.54776 .31524 Mdot
.40132 .26344 Mdot
.57297 .34604 Mdot
.29625 .19142 Mdot
.40745 .24089 Mdot
.80962 .47001 Mdot
.38455 .25629 Mdot
.36704 .23217 Mdot
.63637 .38384 Mdot
.4423 .27915 Mdot
.34127 .21149 Mdot
.46665 .27293 Mdot
.69938 .43501 Mdot
.56149 .34495 Mdot
.45442 .2874 Mdot
.47125 .30373 Mdot
.62632 .35926 Mdot
.30428 .20993 Mdot
.4311 .24726 Mdot
.72644 .43237 Mdot
.34792 .2244 Mdot
.54846 .34168 Mdot
.47844 .29222 Mdot
.48989 .30404 Mdot
.42544 .26437 Mdot
.41852 .25333 Mdot
.64268 .40017 Mdot
.46797 .29751 Mdot
.49867 .31384 Mdot
.6113 .37559 Mdot
.41185 .25286 Mdot
.41537 .26344 Mdot
.44372 .23995 Mdot
.61746 .39021 Mdot
.5052 .31244 Mdot
.48513 .30902 Mdot
.49569 .31011 Mdot
.58106 .35444 Mdot
.4366 .27588 Mdot
.3792 .22533 Mdot
.72823 .44761 Mdot
.6159 .3759 Mdot
.42308 .27464 Mdot
.7705 .47095 Mdot
.16744 .11722 Mdot
.43425 .26764 Mdot
.36116 .20013 Mdot
.73619 .43159 Mdot
.61879 .38555 Mdot
.36249 .2286 Mdot
.45789 .29237 Mdot
.36252 .24509 Mdot
.47502 .28117 Mdot
.4348 .24197 Mdot
.65752 .41977 Mdot
.36342 .22969 Mdot
.59167 .36937 Mdot
.50617 .31026 Mdot
.47538 .29564 Mdot
.44312 .26329 Mdot
.42848 .23326 Mdot
.57351 .36455 Mdot
.58059 .37341 Mdot
.42523 .279 Mdot
.54955 .31415 Mdot
.45372 .293 Mdot
.46071 .26297 Mdot
.32151 .18038 Mdot
.72311 .44995 Mdot
.54522 .36984 Mdot
.40883 .2454 Mdot
.557 .34962 Mdot
.5379 .32659 Mdot
.38809 .2454 Mdot
.46422 .27044 Mdot
.74847 .45026 Mdot
.44583 .31104 Mdot
.38356 .22813 Mdot
.57009 .33826 Mdot
.52071 .32597 Mdot
.41565 .26655 Mdot
.41473 .25162 Mdot
.63121 .38259 Mdot
.57666 .37699 Mdot
.49779 .27511 Mdot
.36593 .24337 Mdot
.39814 .24089 Mdot
.58801 .35646 Mdot
.40715 .22673 Mdot
.43077 .26469 Mdot
.85943 .54063 Mdot
.46518 .28366 Mdot
.85335 .55572 Mdot
.16017 .06714 Mdot
.34275 .24011 Mdot
.45299 .27791 Mdot
.93183 .50874 Mdot
.33393 .25753 Mdot
.38165 .23809 Mdot
.49123 .29611 Mdot
.6654 .41557 Mdot
.21938 .14864 Mdot
.43223 .24773 Mdot
.61603 .38617 Mdot
.30185 .1908 Mdot
.95763 .5327 Mdot
.21961 .17524 Mdot
.49423 .30015 Mdot
.42455 .28335 Mdot
.46809 .265 Mdot
.71985 .42801 Mdot
.42729 .29128 Mdot
.44305 .26811 Mdot
.57818 .3423 Mdot
.36922 .2188 Mdot
.49894 .31119 Mdot
.3948 .23513 Mdot
.76679 .46441 Mdot
.48837 .32799 Mdot
.53256 .30808 Mdot
.38905 .25706 Mdot
.53044 .32177 Mdot
.3451 .22066 Mdot
.46784 .28475 Mdot
.85315 .47546 Mdot
.47317 .32193 Mdot
.36187 .24322 Mdot
.26935 .15378 Mdot
.5575 .33546 Mdot
.46168 .28584 Mdot
.41933 .24275 Mdot
.81396 .50081 Mdot
.4831 .2902 Mdot
.53027 .33188 Mdot
.55562 .32613 Mdot
.27551 .2132 Mdot
.39089 .22331 Mdot
.39485 .22766 Mdot
.54677 .33033 Mdot
.80929 .48821 Mdot
.63485 .41199 Mdot
.25559 .17478 Mdot
.54542 .31788 Mdot
.48187 .30202 Mdot
.32265 .20324 Mdot
.70314 .42086 Mdot
.54564 .35226 Mdot
.69148 .40546 Mdot
.17328 .12205 Mdot
.48632 .31477 Mdot
.52405 .30295 Mdot
.34129 .21724 Mdot
.87913 .52414 Mdot
.40045 .2636 Mdot
.58185 .34666 Mdot
.39397 .23637 Mdot
.41195 .25909 Mdot
.37657 .25364 Mdot
.41618 .23124 Mdot
.82689 .5201 Mdot
.63261 .4025 Mdot
.35838 .21055 Mdot
.68459 .40079 Mdot
.33706 .22969 Mdot
.25643 .15144 Mdot
.36415 .21584 Mdot
.31828 .25395 Mdot
.49403 .30808 Mdot
.62419 .35942 Mdot
.35079 .23326 Mdot
.3616 .23093 Mdot
.26725 .15082 Mdot
.94431 .56256 Mdot
.39452 .26842 Mdot
.49565 .30233 Mdot
.42637 .26733 Mdot
.49672 .30342 Mdot
.31072 .20869 Mdot
.42732 .223 Mdot
.86091 .5299 Mdot
.37996 .28257 Mdot
.43448 .23575 Mdot
.55943 .34448 Mdot
.4895 .30186 Mdot
.30667 .18582 Mdot
.42259 .2552 Mdot
.71711 .42817 Mdot
.51183 .34557 Mdot
.43163 .24477 Mdot
.58196 .36657 Mdot
.41638 .26624 Mdot
.41821 .26888 Mdot
.41205 .22362 Mdot
.73951 .44808 Mdot
.52037 .36533 Mdot
.40623 .25193 Mdot
.55178 .33173 Mdot
.47372 .28817 Mdot
.4041 .21413 Mdot
.38922 .24073 Mdot
.80082 .48261 Mdot
.42089 .29891 Mdot
.5218 .32411 Mdot
.42938 .2566 Mdot
.59122 .36688 Mdot
.2218 .11551 Mdot
.42672 .25551 Mdot
.74354 .44917 Mdot
.52936 .3983 Mdot
.4566 .25504 Mdot
.69074 .43548 Mdot
.509 .29813 Mdot
.29167 .18271 Mdot
.37658 .2286 Mdot
.78551 .45757 Mdot
.61898 .41152 Mdot
.38425 .23466 Mdot
.6233 .38928 Mdot
.41282 .25162 Mdot
.34289 .24882 Mdot
.40278 .2146 Mdot
.77908 .46332 Mdot
.45597 .30513 Mdot
.39566 .24166 Mdot
.39866 .25582 Mdot
.42445 .22844 Mdot
.88048 .54514 Mdot
.33285 .22969 Mdot
.47462 .28973 Mdot
.52848 .34246 Mdot
.43869 .25395 Mdot
.38691 .23093 Mdot
.42242 .25022 Mdot
.72831 .45679 Mdot
.50639 .30186 Mdot
.60322 .38197 Mdot
.39637 .25955 Mdot
.62532 .37513 Mdot
.20111 .13153 Mdot
.43808 .24353 Mdot
.72977 .45508 Mdot
.52885 .34075 Mdot
.49555 .30155 Mdot
.47887 .31182 Mdot
.51077 .293 Mdot
.35069 .2426 Mdot
.45333 .2538 Mdot
.69879 .44326 Mdot
.49905 .30233 Mdot
.5173 .32379 Mdot
.42533 .26453 Mdot
.4997 .29984 Mdot
.37673 .25566 Mdot
.45878 .24975 Mdot
.91222 .52305 Mdot
.27195 .20931 Mdot
.37534 .22393 Mdot
.57353 .34044 Mdot
.46575 .32535 Mdot
.42264 .2412 Mdot
.40059 .22735 Mdot
.68766 .42724 Mdot
.48959 .30793 Mdot
.51845 .31944 Mdot
.5805 .34588 Mdot
.34272 .24509 Mdot
.43187 .25613 Mdot
.48972 .28646 Mdot
.66806 .4263 Mdot
.50513 .30762 Mdot
.51503 .33219 Mdot
.47871 .28693 Mdot
.5012 .31073 Mdot
.39069 .24742 Mdot
.47051 .27324 Mdot
.66632 .39333 Mdot
.53309 .36564 Mdot
.52269 .30933 Mdot
.51505 .32068 Mdot
.37111 .21911 Mdot
.45296 .25846 Mdot
.39039 .23155 Mdot
.91683 .57003 Mdot
.35355 .20278 Mdot
.38122 .23715 Mdot
.36004 .25286 Mdot
.65593 .38959 Mdot
.43071 .28335 Mdot
.40818 .23777 Mdot
.76849 .47032 Mdot
.45031 .27557 Mdot
.52207 .34837 Mdot
.49258 .28397 Mdot
.54783 .36315 Mdot
.31361 .20682 Mdot
.38698 .23513 Mdot
.77508 .43626 Mdot
.9947 .58683 Mdot
.35044 .24415 Mdot
.30429 .21989 Mdot
.58699 .37062 Mdot
.27702 .20371 Mdot
.33669 .1628 Mdot
.79909 .48106 Mdot
.53873 .34308 Mdot
.45527 .27775 Mdot
.41532 .25255 Mdot
.6064 .37948 Mdot
.19298 .12376 Mdot
.3283 .18458 Mdot
.94907 .56708 Mdot
.44462 .28817 Mdot
.472 .28071 Mdot
.47062 .30031 Mdot
.39482 .23886 Mdot
.29448 .1488 Mdot
.45211 .29424 Mdot
.30672 .2272 Mdot
.35127 .24089 Mdot
.47022 .28351 Mdot
.54577 .35242 Mdot
.37845 .25644 Mdot
.39276 .22486 Mdot
.84651 .50548 Mdot
.41913 .26562 Mdot
.52755 .35179 Mdot
.25964 .13589 Mdot
.84037 .49786 Mdot
.49736 .31042 Mdot
.34143 .20418 Mdot
.52078 .28366 Mdot
.3287 .20573 Mdot
.55051 .34184 Mdot
.80085 .46301 Mdot
.15707 .10213 Mdot
.56633 .37186 Mdot
.45136 .28568 Mdot
.64493 .37793 Mdot
.27421 .19562 Mdot
.88944 .52165 Mdot
.54034 .34588 Mdot
.47174 .35242 Mdot
.37226 .20278 Mdot
.361 .19951 Mdot
.72467 .51745 Mdot
.34019 .16638 Mdot
.41549 .27682 Mdot
.22826 .19204 Mdot
.32207 .15284 Mdot
.3456 .20744 Mdot
.8362 .48526 Mdot
.29161 .2468 Mdot
.56536 .30466 Mdot
.46365 .31462 Mdot
.4582 .26375 Mdot
.15983 .07118 Mdot
.51084 .30015 Mdot
.77964 .48588 Mdot
.4746 .31633 Mdot
.46287 .24182 Mdot
.4995 .32737 Mdot
.45492 .2958 Mdot
.36882 .20604 Mdot
.44322 .26888 Mdot
.72046 .44217 Mdot
.35759 .20371 Mdot
.59348 .39208 Mdot
.43599 .26935 Mdot
.48207 .30575 Mdot
.37681 .21786 Mdot
.45946 .2482 Mdot
.68623 .4571 Mdot
.49322 .30684 Mdot
.47344 .30373 Mdot
.48654 .30077 Mdot
.46539 .28102 Mdot
.45888 .27993 Mdot
.44881 .25317 Mdot
.59878 .38601 Mdot
.42991 .27028 Mdot
.62763 .39504 Mdot
.52895 .33515 Mdot
.36098 .22253 Mdot
.60689 .37233 Mdot
.38499 .23606 Mdot
.63808 .37948 Mdot
.46333 .29253 Mdot
.52343 .31975 Mdot
.56795 .35008 Mdot
.3714 .2454 Mdot
.43644 .26204 Mdot
.49344 .30684 Mdot
.64075 .38664 Mdot
.46978 .28413 Mdot
.44594 .26609 Mdot
.54675 .35319 Mdot
.62028 .38228 Mdot
.27766 .16249 Mdot
.44173 .2524 Mdot
.67633 .44092 Mdot
.52458 .32286 Mdot
.45174 .27635 Mdot
.47061 .28615 Mdot
.46935 .29471 Mdot
.47959 .31493 Mdot
.4396 .24337 Mdot
.59905 .38446 Mdot
.50862 .30653 Mdot
.44106 .27262 Mdot
.53677 .33359 Mdot
.43152 .25364 Mdot
.47387 .29502 Mdot
.44606 .2552 Mdot
.63906 .40857 Mdot
.48943 .28195 Mdot
.51601 .31788 Mdot
.46962 .28631 Mdot
.4902 .31539 Mdot
.3919 .24011 Mdot
.43139 .25209 Mdot
.7293 .45897 Mdot
.51328 .35755 Mdot
.52412 .29984 Mdot
.46839 .28024 Mdot
.30672 .2132 Mdot
.52502 .28522 Mdot
.36689 .21538 Mdot
.45042 .28988 Mdot
.80187 .49646 Mdot
.44134 .28817 Mdot
.53204 .33219 Mdot
.44226 .28444 Mdot
.49553 .31042 Mdot
.42027 .24306 Mdot
.80601 .50392 Mdot
.4253 .26049 Mdot
.49944 .31742 Mdot
.58519 .35833 Mdot
.43783 .2818 Mdot
.34576 .15876 Mdot
.40853 .2692 Mdot
.79108 .49117 Mdot
.59441 .35599 Mdot
.42229 .30451 Mdot
.47267 .26764 Mdot
.424 .2734 Mdot
.43574 .26142 Mdot
.32775 .19173 Mdot
.73321 .44248 Mdot
.55595 .34682 Mdot
.57275 .32551 Mdot
.34149 .25037 Mdot
.44902 .23497 Mdot
.3676 .22611 Mdot
.43573 .2594 Mdot
.71049 .45975 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00B`3oool6
000000<0oooo1000000O0?ooo`030000003oool0oooo00<0oooo1000000L0?ooo`@000008`3oool0
0`000000oooo0?ooo`030?ooo`@00000703oool6000000<0oooo1000000Y0?ooo`00C03oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo001=0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool09P3oool00440oooo1`0000060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`L000001P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02H0oooo001?0?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
7@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool09P3oool00500oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool07P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
02H0oooo001@0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0V0?ooo`00B`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool06P3oool00`000000oooo000000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo02H0oooo001;0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0K0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02H0oooo001<0?ooo`@00000103o
ool4000001l0oooo00<000000?ooo`3oool00`3oool4000001`0oooo1000000S0?ooo`030000003o
ool0oooo00<0oooo1000000M0?ooo`@00000103oool4000002T0oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000X0?ooonl000002@3oool0
02P0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool002P0oooo0P00001e0?ooo`03
0000003oool0oooo07<0oooo0P0000090?ooo`00:03oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`070?ooo`00:03oool20000
07D0oooo00<000000?ooo`3oool0L`3oool2000000T0oooo000X0?ooo`030000003oool0oooo07@0
oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`070?ooo`00:03oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool01`3oool002P0oooo0P00
001e0?ooo`030000003oool0oooo07<0oooo0P0000090?ooo`00:03oool00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00L0oooo000X0?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`070?ooo`00
5`3oool00`000000oooo0?ooo`030?ooo`@000001`3oool2000007D0oooo00<000000?ooo`3oool0
L`3oool2000000T0oooo000G0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000070?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`070?ooo`005`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`070?ooo`002`3oool7000000D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00L0oooo000G0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool2000007D0oooo00<000000?oo
o`3oool0L`3oool2000000T0oooo000G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`070?ooo`005`3oool00`000000oooo0?ooo`020?ooo`D00000
1`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
1`3oool001D0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`090?ooo`800000M@3o
ool00`000000oooo0?ooo`1c0?ooo`8000002@3oool001H0oooo0P0000050?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo00L0oooo000G0?ooo`030000003oool0oooo00<0oooo1@0000060?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`070?ooo`00:03oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`070?ooo`00:03oool2000007D0oooo00<000000?ooo`3oool0L`3oool2000000T0oooo
000X0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`070?ooo`00:03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`070?ooo`00:03oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`070?oo
o`00:03oool2000002L0oooo00D000000?ooo`3oool0oooo000000190?ooo`030000003oool0oooo
07<0oooo0P0000090?ooo`00:03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo07@0
oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool01`3oool002P0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool01`3oool001L0oooo00<000000?ooo`3oool00`3oool4000000L0oooo0P00001e
0?ooo`030000003oool0oooo07<0oooo0P0000090?ooo`005`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`070?oo
o`005`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00L0oooo000;0?ooo`L00000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool2000003/0oooo00@000000?ooo`00000000002`3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo07<0oooo0P0000090?ooo`005`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool01`3oool001L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`070?ooo`005`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo00X0oooo0P00000U0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool01`3oool0
01D0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo0P00000Y0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0L`3oool20000
00T0oooo000F0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo07@0
oooo00<000000?ooo`3oool01`3oool001L0oooo00<000000?ooo`3oool00`3oool4000000L0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo07@0oooo
00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`070?ooo`00:03oool2000004L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo07<0oooo0P0000090?ooo`00:03oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo008000001P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo00L0oooo000X0?ooo`800000B03oool00`000000oooo
0?ooo`060?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3oool0L`3oool2000000T0
oooo000X0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0
A`3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool01`3oool002P0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
0P0000000`3oool000000000000Q0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
1`3oool001d0oooo100000070?ooo`800000?`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00X0oooo0P0000060?ooo`<000005P3oool00`000000oooo0?ooo`1c0?ooo`8000002@3o
ool001`0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool01P3oool2000000030?ooo`000000oooo00@000007@3oool00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo00L0oooo000L0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1?0?ooo`040000003oool0oooo000000<0oooo0P00
00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000004@3oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo00L0oooo000B0?ooo`L00000203oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`02000000040?ooo`000000oooo00000080oooo0P0000000`3oool000000?ooo`020?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`070?ooo`008@3o
ool00`000000oooo0?ooo`040?ooo`800000C@3oool200000080oooo00<000000?ooo`3oool00P00
00040?ooo`8000001@3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo07<0oooo
0P0000090?ooo`00703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo00000005000000030?ooo`000000000000@0oooo00@0
00000?ooo`3oool00000303oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00L0oooo
000L0?ooo`D000001`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0000000<0oooo00D0
00000?ooo`3oool000000?ooo`0300000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo000000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`070?ooo`00703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`0000000P3oool3000000<0oooo00L000000?ooo`3oool000000?ooo`000000oooo
0080000000@0oooo0000003oool000003P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo00L0oooo000M0?ooo`030000003oool0oooo00P0oooo0P0000130?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01@3oool200000080oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo000000060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L`3oool2
000000T0oooo000M0?ooo`D000001P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
00L0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool01@000000oooo00000000
0000oooo00H0000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo00L0oooo000X0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool01`3oool4
000000030?ooo`000000oooo00<0oooo1@0000020?ooo`<000002P3oool00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo00L0oooo000X0?ooo`800000G03oool01P000000oooo0?ooo`3oool0
00000?ooo`80000000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0L`3oool2000000T0oooo000X0?ooo`030000003oool0oooo05`0oooo00<0
00000?ooo`3oool00P0000001@3oool00000000000000000oooo0080000000D0oooo000000000000
oooo000000070?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool01`3oool002P0oooo
00<000000?ooo`3oool0FP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool70000
00040?ooo`000000oooo000000H0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`07
0?ooo`00:03oool00`000000oooo0?ooo`1Q0?ooo`8000000`3oool300000080oooo0`0000050?oo
o`800000MP3oool00`000000oooo0?ooo`070?ooo`00:03oool2000005/0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`000000oooo00P000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo07<0oooo0P0000090?ooo`00:03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo00H0oooo00H000000?ooo`00000000000?ooo`0000030?ooo`H000000P3oool2
000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`07
0?ooo`00:03oool00`000000oooo0?ooo`1T0?ooo`040000003oool000000?ooo`80000000P0oooo
00000000000000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`1^0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool00P3oool5000000030?ooo`00000000000080000000@0oooo0000003oool0
0000MP3oool00`000000oooo0?ooo`070?ooo`007@3oool4000000L0oooo0P00001Y0?ooo`800000
0P3oool5000000060?ooo`000000oooo0000003oool00000L`3oool2000000T0oooo000L0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1Q0?ooo`03
0000003oool0oooo00P0oooo1`000000103oool000000?ooo`0000020?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool01`3oool001`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`3oool5000000040?ooo`0000000000000000<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00L0oooo000L0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oooo_000000T0oooo000L0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1V0?ooo`8000001`3oool010000000
oooo0?ooo`3oool400000080oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`070?oo
o`00703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0J@3oool300000080oooo1`000000103oool000000000003oool200000080oooo00<000000?oo
o`000000J`3oool00`000000oooo0?ooo`070?ooo`00703oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0M03oool2000000050?ooo`00000000000000
003oool00P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool01`3oool001`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`80
0000K03oool00`000000oooo000000060?ooo`80000000<0oooo0000000000000P0000000`3oool0
00000?ooo`070?ooo`030000003oool0oooo0680oooo0P0000090?ooo`00703oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0L@3oool010000000oooo
0?ooo`0000080?ooo`050000003oool0oooo0?ooo`000000J@3oool00`000000oooo0?ooo`070?oo
o`007@3oool4000000L0oooo00<000000?ooo`3oool0M03oool010000000oooo0?ooo`0000020?oo
o`<0000000@0oooo0000000000000000JP3oool00`000000oooo0?ooo`070?ooo`00:03oool00`00
0000oooo0?ooo`1d0?ooo`040000003oool0oooo000000<0oooo00P000000?ooo`3oool0oooo0000
003oool000000?ooo`800000IP3oool00`000000oooo0?ooo`070?ooo`00:03oool2000007D0oooo
00@000000?ooo`3oool000000P3oool2000000<0oooo100000020?ooo`800000H`3oool2000000T0
oooo000X0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`0000001P3oool200000080oooo
0P0000020?ooo`030000003oool0000006<0oooo00<000000?ooo`3oool01`3oool002P0oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0P3oool200000080oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`070?ooo`00:03o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`00001S0?ooo`030000003o
ool0oooo00L0oooo000X0?ooo`800000M@3oool010000000oooo0?ooo`00000?0?ooo`@000000P3o
ool010000000oooo0?ooo`3oool2000005L0oooo0P0000090?ooo`00:03oool00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000080?ooo`050000003oool000000?ooo`000000
3@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00L0oooo000M0?ooo`@000001`3o
ool2000007D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo0000001M0?ooo`8000002@3oool001`0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`030?ooo`<000000P3oool2000005L0oooo00<000000?ooo`3oool0
1`3oool001`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`8000001P3o
ool2000005@0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo01@0oooo0P0000030?ooo`80000000<0oooo
0000000000000P3oool200000580oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?oo
o`3oool0103oool2000007D0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`3oool4
00000080oooo00<000000?ooo`3oool0DP3oool2000000T0oooo000L0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`8000001`3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo00L0oooo000L0?ooo`D000001`3oool00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo00L0oooo000L0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0
oooo00D000000?ooo`000000oooo000000070?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool01`3oool001d0oooo00<000000?ooo`3oool0203oool2000007D0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0AP3oool2000000T0oooo000M0?ooo`D000001P3oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`070?ooo`00:03o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo01T0oooo00D000000?ooo`3oool0oooo
0000001F0?ooo`030000003oool0oooo00L0oooo000X0?ooo`800000M@3oool00`000000oooo0?oo
o`0T0?ooo`040000003oool0oooo000004/0oooo0P0000090?ooo`00:03oool00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000004H0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`040?ooo`800000203oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00L0oooo000X0?ooo`800000M@3oool00`00
0000oooo0?ooo`0/0?ooo`8000001@3oool00`000000oooo0000000m0?ooo`8000002@3oool002P0
oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0V0?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000=@3oool0
0`000000oooo0?ooo`070?ooo`00:03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000003l0oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01`3oool001L0
oooo00<000000?ooo`3oool00`3oool4000000L0oooo0P00001e0?ooo`030000003oool0oooo0380
oooo00@000000?ooo`3oool0oooo0`00000<0?ooo`030000003oool0oooo02/0oooo0P0000090?oo
o`005`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`070?ooo`005`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000T0
oooo00D000000?ooo`3oool0oooo0000000b0?ooo`030000003oool0oooo00L0oooo000G0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`030?ooo`04
0000003oool00000000000@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`070?oo
o`005`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool2000007D0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`80
00002@3oool001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0m0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`070?ooo`00
5`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo000E0?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`800000M@3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo0P0000090?ooo`005P3oool2
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool01`3oool001L0oooo00<000000?ooo`3oool00`3oool40000
00L0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`070?ooo`00:03oool00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`070?ooo`00:03oool2000007D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0280oooo0P0000090?ooo`00:03oool00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`070?ooo`00:03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo04D0oooo0P000008
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool002P0oooo0P00001e0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool09P3oool2000000T0oooo000X0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`005`3oool0
0`000000oooo0?ooo`030?ooo`@000001`3oool2000007D0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0000000K0?ooo`8000002@3oool001L0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool001L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool001L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`070?ooo`00
5`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo0P00001e0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool07P3oool2000000T0oooo000G0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00L0oooo000G0?ooo`030000003oool0oooo0080oooo1@0000070?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`070?ooo`005@3oool00`00
0000oooo000000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool001H0
oooo0P0000050?ooo`030000003oool0oooo00P0oooo0P00001e0?ooo`030000003oool0oooo07<0
oooo0P0000090?ooo`005`3oool00`000000oooo0?ooo`030?ooo`D000001P3oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`070?ooo`00:03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`00:03oool2000007D0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`0@0?ooo`8000002@3oool002P0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00L0oooo000X0?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`070?ooo`00
:03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
1`3oool002P0oooo0P00001e0?ooo`030000003oool0oooo07<0oooo0P0000090?ooo`00:03oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool01`3oool0
02P0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
00L0oooo000X0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`070?ooo`00503oool6000000<0oooo100000070?ooo`800000M@3oool00`000000oooo
0?ooo`1c0?ooo`8000002@3oool001D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo00L0oooo000F0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000G0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo000H0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`04
0?ooonl000002@3oool001T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3l
0?ooo`006@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?`0oooo000D0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3l
0?ooo`00503oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0o03oool001D0oooo100000040?ooo`@00000o`3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-38.8206, -25.3047, 0.24395, \
0.269573}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"1", "0.0017443238037849038`", "0.07056691639980915`", 
                  "0.024718719376968856`", "0.9802865756030552`"},
                {"y", "0.5369308902106007`", "0.00328290013620851`", 
                  "163.55382982520857`", 
                  "3.5317970396750413511963314`12.1717*^-548"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{1, y}, {"Estimate", "SE", 
                "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.97520949367796`\), 
        ",", \(AdjustedRSquared \[Rule] 0.9751730370510158`\), 
        ",", \(EstimatedVariance \[Rule] 3.3961478620052503`\), ",", 
        RowBox[{"ANOVATable", "\[Rule]", 
          InterpretationBox[GridBox[{
                {"\<\"\"\>", "\<\"DF\"\>", "\<\"SumOfSq\"\>", \
"\<\"MeanSq\"\>", "\<\"FRatio\"\>", "\<\"PValue\"\>"},
                {"\<\"Model\"\>", "1", "90846.46371791269`", 
                  "90846.46371791269`", "26749.855250493285`", 
                  "3.53179703967504135119499804796`12.1717*^-548"},
                {"\<\"Error\"\>", "680", "2309.38054616357`", 
                  "3.3961478620052503`", "\<\"\"\>", "\<\"\"\>"},
                {"\<\"Total\"\>", "681", 
                  "93155.84426407625`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            
            TableForm[ {{1, 90846.463717912688, 90846.463717912688, 
              26749.855250493285, 3.53179703968`12.1717*^-548}, {680, 
              2309.3805461635702, 3.3961478620052503}, {681, 
              93155.844264076251}}, TableHeadings -> {{"Model", "Error", 
              "Total"}, {"DF", "SumOfSq", "MeanSq", "FRatio", 
              "PValue"}}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Interesting is always the look at the residuen of the regression.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(res\  = \ 
        Regress[regdata, {1, y}, y, 
          RegressionReport \[Rule] {\ FitResiduals, 
              EstimatedVariance}];\)\), "\[IndentingNewLine]", 
    \(\(ndist\  = \ 
        NormalDistribution[0, \@EstimatedVariance]\  /. \ 
          res;\)\), "\[IndentingNewLine]", 
    \(\(resdata\  = FitResiduals\ \  /. \ res;\)\), "\[IndentingNewLine]", 
    \(\(DisplayTogether[Histogram[\ resdata\ , HistogramScale \[Rule] 1]\ , 
        Plot[PDF[ndist, y], {y, \(-6\), 6}]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.324324 0.027027 0.0147151 2.12396 [
[.05405 .00222 -14.6563 -17.75 ]
[.05405 .00222 14.6563 0 ]
[.32432 .00222 -5.90625 -17.75 ]
[.32432 .00222 5.90625 0 ]
[.59459 .00222 -9.8125 -17.75 ]
[.59459 .00222 9.8125 0 ]
[.86486 .00222 -9.8125 -17.75 ]
[.86486 .00222 9.8125 0 ]
[-0.0125 .12091 -31.375 -8.875 ]
[-0.0125 .12091 0 8.875 ]
[-0.0125 .22711 -23.5625 -8.875 ]
[-0.0125 .22711 0 8.875 ]
[-0.0125 .33331 -31.375 -8.875 ]
[-0.0125 .33331 0 8.875 ]
[-0.0125 .43951 -23.5625 -8.875 ]
[-0.0125 .43951 0 8.875 ]
[-0.0125 .5457 -31.375 -8.875 ]
[-0.0125 .5457 0 8.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05405 .01472 m
.05405 .02097 L
s
gsave
.05405 .00222 -75.6563 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.32432 .01472 m
.32432 .02097 L
s
gsave
.32432 .00222 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.59459 .01472 m
.59459 .02097 L
s
gsave
.59459 .00222 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.86486 .01472 m
.86486 .02097 L
s
gsave
.86486 .00222 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .01472 m
1 .01472 L
s
0 .12091 m
.00625 .12091 L
s
gsave
-0.0125 .12091 -92.375 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .22711 m
.00625 .22711 L
s
gsave
-0.0125 .22711 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .33331 m
.00625 .33331 L
s
gsave
-0.0125 .33331 -92.375 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
0 .43951 m
.00625 .43951 L
s
gsave
-0.0125 .43951 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .5457 m
.00625 .5457 L
s
gsave
-0.0125 .5457 -92.375 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03595 m
.00375 .03595 L
s
0 .05719 m
.00375 .05719 L
s
0 .07843 m
.00375 .07843 L
s
0 .09967 m
.00375 .09967 L
s
0 .14215 m
.00375 .14215 L
s
0 .16339 m
.00375 .16339 L
s
0 .18463 m
.00375 .18463 L
s
0 .20587 m
.00375 .20587 L
s
0 .24835 m
.00375 .24835 L
s
0 .26959 m
.00375 .26959 L
s
0 .29083 m
.00375 .29083 L
s
0 .31207 m
.00375 .31207 L
s
0 .35455 m
.00375 .35455 L
s
0 .37579 m
.00375 .37579 L
s
0 .39703 m
.00375 .39703 L
s
0 .41827 m
.00375 .41827 L
s
0 .46075 m
.00375 .46075 L
s
0 .48199 m
.00375 .48199 L
s
0 .50323 m
.00375 .50323 L
s
0 .52446 m
.00375 .52446 L
s
0 .56694 m
.00375 .56694 L
s
0 .58818 m
.00375 .58818 L
s
0 .60942 m
.00375 .60942 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01783 L
.02703 .01783 L
.02703 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01783 L
.02703 .01783 L
.02703 .01472 L
0 .01472 L
s
1 0 0 r
.02703 .01472 m
.02703 .01472 L
.05405 .01472 L
.05405 .01472 L
F
0 g
.02703 .01472 m
.02703 .01472 L
.05405 .01472 L
.05405 .01472 L
.02703 .01472 L
s
1 0 0 r
.05405 .01472 m
.05405 .01783 L
.08108 .01783 L
.08108 .01472 L
F
0 g
.05405 .01472 m
.05405 .01783 L
.08108 .01783 L
.08108 .01472 L
.05405 .01472 L
s
1 0 0 r
.08108 .01472 m
.08108 .01472 L
.10811 .01472 L
.10811 .01472 L
F
0 g
.08108 .01472 m
.08108 .01472 L
.10811 .01472 L
.10811 .01472 L
.08108 .01472 L
s
1 0 0 r
.10811 .01472 m
.10811 .01472 L
.13514 .01472 L
.13514 .01472 L
F
0 g
.10811 .01472 m
.10811 .01472 L
.13514 .01472 L
.13514 .01472 L
.10811 .01472 L
s
1 0 0 r
.13514 .01472 m
.13514 .01472 L
.16216 .01472 L
.16216 .01472 L
F
0 g
.13514 .01472 m
.13514 .01472 L
.16216 .01472 L
.16216 .01472 L
.13514 .01472 L
s
1 0 0 r
.16216 .01472 m
.16216 .01472 L
.18919 .01472 L
.18919 .01472 L
F
0 g
.16216 .01472 m
.16216 .01472 L
.18919 .01472 L
.18919 .01472 L
.16216 .01472 L
s
1 0 0 r
.18919 .01472 m
.18919 .03652 L
.21622 .03652 L
.21622 .01472 L
F
0 g
.18919 .01472 m
.18919 .03652 L
.21622 .03652 L
.21622 .01472 L
.18919 .01472 L
s
1 0 0 r
.21622 .01472 m
.21622 .03652 L
.24324 .03652 L
.24324 .01472 L
F
0 g
.21622 .01472 m
.21622 .03652 L
.24324 .03652 L
.24324 .01472 L
.21622 .01472 L
s
1 0 0 r
.24324 .01472 m
.24324 .1424 L
.27027 .1424 L
.27027 .01472 L
F
0 g
.24324 .01472 m
.24324 .1424 L
.27027 .1424 L
.27027 .01472 L
.24324 .01472 L
s
1 0 0 r
.27027 .01472 m
.27027 .35417 L
.2973 .35417 L
.2973 .01472 L
F
0 g
.27027 .01472 m
.27027 .35417 L
.2973 .35417 L
.2973 .01472 L
.27027 .01472 L
s
1 0 0 r
.2973 .01472 m
.2973 .56283 L
.32432 .56283 L
.32432 .01472 L
F
0 g
.2973 .01472 m
.2973 .56283 L
.32432 .56283 L
.32432 .01472 L
.2973 .01472 L
s
1 0 0 r
.32432 .01472 m
.32432 .60332 L
.35135 .60332 L
.35135 .01472 L
F
0 g
.32432 .01472 m
.32432 .60332 L
.35135 .60332 L
.35135 .01472 L
.32432 .01472 L
s
1 0 0 r
.35135 .01472 m
.35135 .29189 L
.37838 .29189 L
.37838 .01472 L
F
0 g
.35135 .01472 m
.35135 .29189 L
.37838 .29189 L
.37838 .01472 L
.35135 .01472 L
s
1 0 0 r
.37838 .01472 m
.37838 .14863 L
.40541 .14863 L
.40541 .01472 L
F
0 g
.37838 .01472 m
.37838 .14863 L
.40541 .14863 L
.40541 .01472 L
.37838 .01472 L
s
1 0 0 r
.40541 .01472 m
.40541 .06143 L
.43243 .06143 L
.43243 .01472 L
F
0 g
.40541 .01472 m
.40541 .06143 L
.43243 .06143 L
.43243 .01472 L
.40541 .01472 L
s
1 0 0 r
.43243 .01472 m
.43243 .02094 L
.45946 .02094 L
.45946 .01472 L
F
0 g
.43243 .01472 m
.43243 .02094 L
.45946 .02094 L
.45946 .01472 L
.43243 .01472 L
s
1 0 0 r
.45946 .01472 m
.45946 .01472 L
.48649 .01472 L
.48649 .01472 L
F
0 g
.45946 .01472 m
.45946 .01472 L
.48649 .01472 L
.48649 .01472 L
.45946 .01472 L
s
1 0 0 r
.48649 .01472 m
.48649 .01783 L
.51351 .01783 L
.51351 .01472 L
F
0 g
.48649 .01472 m
.48649 .01783 L
.51351 .01783 L
.51351 .01472 L
.48649 .01472 L
s
1 0 0 r
.51351 .01472 m
.51351 .01472 L
.54054 .01472 L
.54054 .01472 L
F
0 g
.51351 .01472 m
.51351 .01472 L
.54054 .01472 L
.54054 .01472 L
.51351 .01472 L
s
1 0 0 r
.54054 .01472 m
.54054 .01472 L
.56757 .01472 L
.56757 .01472 L
F
0 g
.54054 .01472 m
.54054 .01472 L
.56757 .01472 L
.56757 .01472 L
.54054 .01472 L
s
1 0 0 r
.56757 .01472 m
.56757 .01472 L
.59459 .01472 L
.59459 .01472 L
F
0 g
.56757 .01472 m
.56757 .01472 L
.59459 .01472 L
.59459 .01472 L
.56757 .01472 L
s
1 0 0 r
.59459 .01472 m
.59459 .01472 L
.62162 .01472 L
.62162 .01472 L
F
0 g
.59459 .01472 m
.59459 .01472 L
.62162 .01472 L
.62162 .01472 L
.59459 .01472 L
s
1 0 0 r
.62162 .01472 m
.62162 .01472 L
.64865 .01472 L
.64865 .01472 L
F
0 g
.62162 .01472 m
.62162 .01472 L
.64865 .01472 L
.64865 .01472 L
.62162 .01472 L
s
1 0 0 r
.64865 .01472 m
.64865 .01472 L
.67568 .01472 L
.67568 .01472 L
F
0 g
.64865 .01472 m
.64865 .01472 L
.67568 .01472 L
.67568 .01472 L
.64865 .01472 L
s
1 0 0 r
.67568 .01472 m
.67568 .01472 L
.7027 .01472 L
.7027 .01472 L
F
0 g
.67568 .01472 m
.67568 .01472 L
.7027 .01472 L
.7027 .01472 L
.67568 .01472 L
s
1 0 0 r
.7027 .01472 m
.7027 .01472 L
.72973 .01472 L
.72973 .01472 L
F
0 g
.7027 .01472 m
.7027 .01472 L
.72973 .01472 L
.72973 .01472 L
.7027 .01472 L
s
1 0 0 r
.72973 .01472 m
.72973 .01472 L
.75676 .01472 L
.75676 .01472 L
F
0 g
.72973 .01472 m
.72973 .01472 L
.75676 .01472 L
.75676 .01472 L
.72973 .01472 L
s
1 0 0 r
.75676 .01472 m
.75676 .01472 L
.78378 .01472 L
.78378 .01472 L
F
0 g
.75676 .01472 m
.75676 .01472 L
.78378 .01472 L
.78378 .01472 L
.75676 .01472 L
s
1 0 0 r
.78378 .01472 m
.78378 .01472 L
.81081 .01472 L
.81081 .01472 L
F
0 g
.78378 .01472 m
.78378 .01472 L
.81081 .01472 L
.81081 .01472 L
.78378 .01472 L
s
1 0 0 r
.81081 .01472 m
.81081 .01472 L
.83784 .01472 L
.83784 .01472 L
F
0 g
.81081 .01472 m
.81081 .01472 L
.83784 .01472 L
.83784 .01472 L
.81081 .01472 L
s
1 0 0 r
.83784 .01472 m
.83784 .01472 L
.86486 .01472 L
.86486 .01472 L
F
0 g
.83784 .01472 m
.83784 .01472 L
.86486 .01472 L
.86486 .01472 L
.83784 .01472 L
s
1 0 0 r
.86486 .01472 m
.86486 .01472 L
.89189 .01472 L
.89189 .01472 L
F
0 g
.86486 .01472 m
.86486 .01472 L
.89189 .01472 L
.89189 .01472 L
.86486 .01472 L
s
1 0 0 r
.89189 .01472 m
.89189 .01472 L
.91892 .01472 L
.91892 .01472 L
F
0 g
.89189 .01472 m
.89189 .01472 L
.91892 .01472 L
.91892 .01472 L
.89189 .01472 L
s
1 0 0 r
.91892 .01472 m
.91892 .01472 L
.94595 .01472 L
.94595 .01472 L
F
0 g
.91892 .01472 m
.91892 .01472 L
.94595 .01472 L
.94595 .01472 L
.91892 .01472 L
s
1 0 0 r
.94595 .01472 m
.94595 .01472 L
.97297 .01472 L
.97297 .01472 L
F
0 g
.94595 .01472 m
.94595 .01472 L
.97297 .01472 L
.97297 .01472 L
.94595 .01472 L
s
1 0 0 r
.97297 .01472 m
.97297 .01783 L
1 .01783 L
1 .01472 L
F
0 g
.97297 .01472 m
.97297 .01783 L
1 .01783 L
1 .01472 L
.97297 .01472 L
s
.16216 .01701 m
.16522 .01751 L
.16857 .01817 L
.17532 .01995 L
.17891 .0212 L
.18275 .02281 L
.18967 .02661 L
.19692 .03217 L
.20378 .0393 L
.21058 .04861 L
.21686 .05956 L
.22378 .07465 L
.23026 .09201 L
.24315 .13655 L
.25635 .1959 L
.27039 .27054 L
.28391 .34555 L
.29692 .40992 L
.30362 .43644 L
.31076 .45777 L
.31426 .46522 L
.31624 .46849 L
.31805 .47088 L
.31964 .47248 L
.32055 .47319 L
.32139 .47371 L
.32185 .47394 L
.32228 .47412 L
.32268 .47426 L
.32309 .47437 L
.32331 .47441 L
.32355 .47445 L
.32397 .4745 L
.32421 .47451 L
.32446 .47451 L
.3247 .4745 L
.32492 .47448 L
.32536 .47441 L
.32577 .47432 L
.32613 .4742 L
.32653 .47406 L
.32743 .47361 L
.32826 .47308 L
.32977 .47177 L
.33136 .46994 L
.33472 .4646 L
.33841 .45647 L
.34504 .43642 L
.35215 .40807 L
.36621 .33757 L
Mistroke
.37975 .26227 L
.39277 .19355 L
.40663 .13209 L
.41997 .08745 L
.42728 .06901 L
.43415 .05515 L
.441 .04429 L
.4473 .03653 L
.45372 .03045 L
.46076 .02551 L
.46742 .02213 L
.47084 .02079 L
.47455 .01958 L
.48068 .01805 L
.48649 .01701 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00<@3oool00`000000oooo0?ooo`030?ooo`@00000=`3oool4000003h0
oooo00<000000?ooo`3oool00`3oool4000003P0oooo1P0000030?ooo`@000007@3oool00340oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`00<@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01X0oooo000T0?ooo`L000001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01X0oooo000a0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0>@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool06P3oool0
0340oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool06P3oool00340oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0j0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06P3oool0
02l0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0J0?ooo`00<03oool20000
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0>P3oool2000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0J0?ooo`00<@3oool00`000000oooo0?ooo`030?ooo`@00000=`3oool40000
03h0oooo00<000000?ooo`3oool00`3oool4000003T0oooo100000040?ooo`@000007@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00280oooo00<000000?ooo`3oool0n`3oool00280oooo00<00000
0?ooo`3oool0n`3oool00280oooo00<000000?ooo`3oool0n`3oool00280oooooP0000000280oooo
200000060?ooo`P000004`3oool3000000@0oooo00<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo
0?ooo`020?ooo`X000004`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01T0oooo
200000000280oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0K0?ooo`<0000000<0
oooo0000003o00001@3o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000o`0000@0o`002000
0000103oool0000000000000000M0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
8@3oool00280oooo00<000000?ooo`3oool0;03oool2000000H0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o
00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000030000003oool0oooo00@0oooo0P0000280?ooo`008P3oool0
0`000000oooo0?ooo`0]0?ooo`8000001@3o00000`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000
o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l000030000003o0000
o`0000@0o`0000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`280?ooo`008P3oool00`00
0000oooo0?ooo`0]0?ooo`030000003o0000000000@0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`00
0000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000040?l000030000003oool0oooo0080oooo00<000000?ooo`3oool0R@3oool00280
oooo0P00000^0?ooo`h000001P3o00000`000000o`000?l000040?l000030000003o0000o`0000@0
o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000o`0000<0
o`0000<000000?l0003o0000103o00001@000000oooo0?ooo`3oool0000008`0oooo000R0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool01`3oool00`000000o`000?l000040?l00003
0000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l00003
0000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l00004
0000003oool0oooo000008d0oooo000R0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool01P3oool00`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o
0000103o00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o
00000`3o00000`000000o`000?l000040?l000030000003oool0000008h0oooo000R0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool01@3oool00`000000o`000?l000040?l000030000
003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000o`000?l000040?l000030000
003oool0000008h0oooo000R0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0103o
ool00`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o
00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o
00000`000000o`000?l000040?l000800000S`3oool00280oooo0P00000d0?ooo`030000003oool0
oooo00@0oooo00<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000
o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000
o`0000<0o`0000<000000?l0003o0000103o0002000008l0oooo000R0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool00`3oool00`000000o`000?l000040?l000030000003o0000o`00
00@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000o`00
00@0o`0000<000000?l0003o00000`3o000800000900oooo000R0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool00P3oool00`000000o`000?l000040?l000030000003o0000o`0000@0
o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000o`0000@0
o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0
oooo000R0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool00P3oool00`000000o`00
0?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo
0?ooo`030?ooo`030000003oool0oooo08l0oooo000R0?ooo`030000003oool0oooo03H0oooo00D0
00000?ooo`3oool0oooo000000060?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
103o00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
0`3o00000`000000oooo0?ooo`030?ooo`030000003oool0oooo08l0oooo000R0?ooo`800000=`3o
ool01@000000oooo0?ooo`3oool0000000H0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003oool0oooo0080oooo00<000000?ooo`3oool0T03oool00280oooo00<0
00000?ooo`3oool0=P3oool01@000000oooo0?ooo`3oool0000000H0o`0000<000000?l0003o0000
103o00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
103o00000`000000o`000?l000030?l000030000003oool0oooo0080oooo00<000000?ooo`3oool0
T03oool00280oooo00<000000?ooo`3oool0=`3oool010000000oooo0?ooo`0000060?l000030000
003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000
003o0000o`0000@0o`0000<000000?l0003o00000`3o00001@000000oooo0?ooo`3oool0000009<0
oooo000R0?ooo`030000003oool0oooo03L0oooo00@000000?ooo`3oool000001P3o00000`000000
o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000
o`000?l000040?l000030000003o0000o`0000<0o`0000D000000?ooo`3oool0oooo0000002C0?oo
o`008P3oool00`000000oooo0?ooo`0g0?ooo`040000003oool0oooo000000H0o`0000<000000?l0
003o0000103o00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0
003o0000103o00000`000000o`000?l000030?l000050000003oool0oooo0?ooo`000000T`3oool0
0280oooo00<000000?ooo`3oool0=`3oool010000000oooo0?ooo`0000060?l000030000003o0000
o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000
o`0000@0o`0000<000000?l0003o00000`3o000010000000oooo0?ooo`00002D0?ooo`008P3oool2
000003T0oooo00<000000?ooo`0000001P3o00000`000000o`000?l000040?l000030000003o0000
o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000
o`0000<0o`0000@000000?ooo`3oool00000U03oool000@0oooo100000040?ooo`040000003oool0
oooo0?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool0>03oool00`000000oooo0000
00060?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l0
00040?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o000010000000oooo0?oo
o`00002D0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0>03oool00`000000oooo000000060?l000030000003o0000o`0000@0o`00
00<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o000010000000oooo0?ooo`00002D0?ooo`000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>03oool00`000000
oooo000000060?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000
o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000
oooo0000002E0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0>@3oool2000000H0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`00
0?l000030?l000030000003oool0000009D0oooo00030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool3000003T0oooo0P0000060?l000030000003o0000o`0000@0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o00000`000000oooo0000002E0?ooo`000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>@3oool2000000H0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<0
00000?l0003o0000103o00000`000000o`000?l000030?l000030000003oool0000009D0oooo0003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D000001P3oool00`000000oooo0?ooo`0i0?ooo`8000001P3o0000
0`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o0000
0`000000o`000?l000040?l000030000003o0000o`0000<0o`000P00002F0?ooo`000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo03X0oooo00<000000?l0003o0000103o0000
0`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o0000
0`000000o`000?l000040?l000030000003o0000o`0000<0o`000P00002F0?ooo`000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0>P3oool00`000000o`000?l00004
0?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l00004
0?l000030000003o0000o`0000@0o`0000<000000?l0003o00000`3o0002000009H0oooo00040?oo
o`@00000203oool4000000@0oooo1@0000050?ooo`800000>`3oool00`000000o`000?l000040?l0
00030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l0
00030000003o0000o`0000@0o`0000<000000?l0003o00000`3o00000`000000oooo0?ooo`2E0?oo
o`008P3oool00`000000oooo0?ooo`0j0?ooo`P000001P3o00000`000000o`000?l000040?l00003
0000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000030?l00003
0000003oool0oooo09D0oooo000R0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
0`3oool00`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
103o00000`000000o`000?l000040?l000L00000U`3oool00280oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`030?ooo`030000003o0000o`0000@0o`0000<000000?l0003o0000103o
00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2E0?ooo`008P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00<0oooo00<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000
o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`020?ooo`030000003oool0
oooo09H0oooo000R0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool00`00
0000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`00
0000o`000?l000040?l000030000003oool0oooo0080oooo00<000000?ooo`3oool0UP3oool00280
oooo0P00000m0?ooo`030000003oool0oooo0080oooo00<000000?l0003o0000103o00000`000000
o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000
oooo0?ooo`020?ooo`030000003oool0oooo09H0oooo000R0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool00P3oool00`000000o`000?l000040?l000030000003o0000o`0000@0o`00
00<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003oool0oooo0080oooo
00<000000?ooo`3oool0UP3oool00280oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`020?ooo`030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l0
00040?l000030000003o0000o`0000@0o`0000D000000?ooo`3oool0oooo0000002I0?ooo`008P3o
ool00`000000oooo0?ooo`0m0?ooo`050000003oool0oooo0?ooo`0000001P3o00000`000000o`00
0?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00001@000000oooo
0?ooo`3oool0000009T0oooo000R0?ooo`030000003oool0oooo03d0oooo00D000000?ooo`3oool0
oooo000000060?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000
o`000?l000040?l000050000003oool0oooo0?ooo`000000V@3oool00280oooo0P00000n0?ooo`05
0000003oool0oooo0?ooo`0000001P3o00000`000000o`000?l000040?l000030000003o0000o`00
00@0o`0000<000000?l0003o0000103o00001@000000oooo0?ooo`3oool0000009T0oooo000R0?oo
o`030000003oool0oooo03d0oooo00D000000?ooo`3oool0oooo000000060?l000030000003o0000
o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000040000003oool0
oooo000009X0oooo000R0?ooo`030000003oool0oooo03h0oooo00@000000?ooo`3oool000001P3o
00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o
000010000000oooo0?ooo`00002J0?ooo`008P3oool00`000000oooo0?ooo`0n0?ooo`040000003o
ool0oooo000000H0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000
003o0000o`0000@0o`0000@000000?ooo`3oool00000VP3oool00280oooo00<000000?ooo`3oool0
?P3oool010000000oooo0?ooo`0000060?l000030000003o0000o`0000@0o`0000<000000?l0003o
0000103o00000`000000o`000?l000040?l000040000003oool0oooo000009X0oooo000R0?ooo`03
0000003oool0oooo03h0oooo00@000000?ooo`3oool000001P3o00000`000000o`000?l000040?l0
00030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo0000002K0?oo
o`008P3oool2000003l0oooo00@000000?ooo`3oool000001P3o00000`000000o`000?l000040?l0
00030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo0000002K0?oo
o`002`3oool4000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`0000001P3o00000`000000o`000?l000040?l00003
0000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo0000002K0?ooo`00
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0000000H0o`0000<000000?l0003o0000
103o00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?ooo`000000
V`3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo000000060?l000030000003o
0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o
ool0000009/0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo03l0oooo00<000000?ooo`0000001P3o0000
0`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o0000
0`000000oooo0000002K0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool3000003l0oooo00<000000?ooo`0000001P3o00000`00
0000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00020000
09`0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo03l0oooo00<000000?ooo`0000001P3o00000`000000
o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o0002000009`0
oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0400oooo0P0000060?l000030000003o0000o`0000@0o`00
00<000000?l0003o0000103o00000`000000o`000?l000040?l000800000W03oool000X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000P0oooo00<0
00000?ooo`3oool0@03oool2000000H0o`0000<000000?l0003o0000103o00000`000000o`000?l0
00040?l000030000003o0000o`0000@0o`000P00002L0?ooo`002P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo0P0000080?ooo`030000003oool0oooo0400oooo0P000006
0?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l00004
0?l000800000W03oool000/0oooo1000000:0?ooo`030000003oool0oooo00H0oooo0P0000110?oo
o`8000001P3o00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0
003o0000103o0002000009`0oooo000R0?ooo`030000003oool0oooo0400oooo0P0000060?l00003
0000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l00003
0000003oool0oooo09/0oooo000R0?ooo`030000003oool0oooo0400oooo0P0000060?l000030000
003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000
003oool0oooo09/0oooo000R0?ooo`030000003oool0oooo0440oooo00<000000?l0003o0000103o
00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o
00000`000000oooo0?ooo`2K0?ooo`008P3oool00`000000oooo0?ooo`110?ooo`030000003o0000
o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000
o`0000@0o`0000<000000?ooo`3oool0V`3oool00280oooo00<000000?ooo`3oool0@@3oool00`00
0000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`00
0000o`000?l000040?l000030000003oool0oooo09/0oooo000R0?ooo`800000@P3oool00`000000
o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000
o`000?l000040?l000030000003oool0oooo09/0oooo000R0?ooo`030000003oool0oooo0440oooo
00<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000o`0000@0o`00
00<000000?l0003o00000`3o0002000009d0oooo000R0?ooo`030000003oool0oooo0440oooo00<0
00000?l0003o0000103o00000`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<0
00000?l0003o00000`3o0002000009d0oooo000R0?ooo`030000003oool0oooo0440oooo0P000005
0?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l00003
0?l000800000W@3oool00280oooo00<000000?ooo`3oool0@@3oool2000000D0o`0000<000000?l0
003o0000103o00000`000000o`000?l000040?l000030000003o0000o`0000<0o`000P00002M0?oo
o`008P3oool200000480oooo0P0000050?l000030000003o0000o`0000@0o`0000<000000?l0003o
0000103o0008000009d0oooo000R0?ooo`030000003oool0oooo0440oooo0P0000050?l000030000
003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`020?ooo`030000
003oool0oooo09d0oooo000R0?ooo`030000003oool0oooo0440oooo0P0000050?l000030000003o
0000o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`020?ooo`030000003o
ool0oooo09d0oooo000R0?ooo`030000003oool0oooo0440oooo00<000000?l000000000103o0000
0`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2M0?ooo`008P3oool00`000000oooo0?ooo`110?ooo`030000003o00000000
00@0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003oool0oooo
0080oooo00<000000?ooo`3oool0W@3oool00280oooo0P0000120?ooo`030000003o0000000000@0
o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000050000003oool0oooo0?oo
o`000000X03oool00280oooo00<000000?ooo`3oool0@@3oool00`000000o`00000000040?l00003
0000003o0000o`0000@0o`0000<000000?l0003o0000103o00001@000000oooo0?ooo`3oool00000
0:00oooo00040?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo100000060?ooo`030000003oool0oooo0440oooo00@000000?l0003o000000000`3o00000`00
0000o`000?l000040?l000030000003o0000o`0000@0o`0000D000000?ooo`3oool0oooo0000002P
0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0@@3oool0
10000000o`000?l0000000030?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o
00001@000000oooo0?ooo`3oool000000:00oooo00030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`110?ooo`040000003o0000o`00000000<0o`00
00<000000?l0003o0000103o00000`000000o`000?l000040?l000050000003oool0oooo0?ooo`00
0000X03oool000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`110?ooo`040000
003o0000o`00000000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l00004
0000003oool0oooo00000:40oooo00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo0`0000110?ooo`04
0000003o0000o`00000000<0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l0
00040000003oool0oooo00000:40oooo00030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`110?ooo`050000003o0000o`000?l0000000000P3o0000
0`000000o`000?l000040?l000030000003o0000o`0000@0o`0000@000000?ooo`3oool00000X@3o
ool000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo1@0000060?ooo`030000003oool0oooo0440oooo00D000000?l0003o0000o`000000
00020?l000030000003o0000o`0000@0o`0000<000000?l0003o0000103o000010000000oooo0?oo
o`00002Q0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0440oooo00D0
00000?l0003o0000o`00000000020?l000030000003o0000o`0000@0o`0000<000000?l0003o0000
103o000010000000oooo0?ooo`00002Q0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo0P0000050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
@@3oool01@000000o`000?l0003o000000000080o`0000<000000?l0003o0000103o00000`000000
o`000?l000040?l000030000003oool000000:80oooo00040?ooo`@000002P3oool00`000000oooo
0?ooo`030?ooo`D000001@3oool200000480oooo200000060?l000030000003o0000o`0000@0o`00
00<000000?ooo`000000XP3oool00280oooo00<000000?ooo`3oool0AP3oool00`000000oooo0000
00060?l000030000003o0000o`0000@0o`0000<000000?ooo`000000XP3oool00280oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo000000060?l000030000003o0000o`0000@0o`0000<00000
0?ooo`000000XP3oool00280oooo00<000000?ooo`3oool0AP3oool00`000000oooo000000060?l0
00030000003o0000o`0000@0o`0000<000000?ooo`000000XP3oool00280oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo000000060?l000030000003o0000o`0000@0o`0000<000000?ooo`00
0000XP3oool00280oooo0P0000170?ooo`030000003oool0000000H0o`0000<000000?l0003o0000
103o000200000:<0oooo000R0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`0000001P3o
00000`000000o`000?l000040?l000800000X`3oool00280oooo00<000000?ooo`3oool0A`3oool2
000000H0o`0000<000000?l0003o0000103o000200000:<0oooo000R0?ooo`030000003oool0oooo
04L0oooo0P0000060?l000030000003o0000o`0000@0o`000P00002S0?ooo`008P3oool00`000000
oooo0?ooo`170?ooo`8000001P3o00000`000000o`000?l000040?l000800000X`3oool00280oooo
00<000000?ooo`3oool0A`3oool2000000H0o`0000<000000?l0003o0000103o000200000:<0oooo
000R0?ooo`800000B03oool2000000H0o`0000<000000?l0003o0000103o00000`000000oooo0?oo
o`2R0?ooo`008P3oool00`000000oooo0?ooo`180?ooo`030000003o0000o`0000@0o`0000<00000
0?l0003o0000103o00000`000000oooo0?ooo`2R0?ooo`008P3oool00`000000oooo0?ooo`180?oo
o`030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`2R0?oo
o`008P3oool00`000000oooo0?ooo`180?ooo`030000003o0000o`0000@0o`0000<000000?l0003o
0000103o00000`000000oooo0?ooo`2R0?ooo`008P3oool00`000000oooo0?ooo`180?ooo`030000
003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`2R0?ooo`008P3o
ool2000004T0oooo0P0000050?l000030000003o0000o`0000<0o`000P00002T0?ooo`008P3oool0
0`000000oooo0?ooo`180?ooo`8000001@3o00000`000000o`000?l000030?l000800000Y03oool0
00/0oooo100000040?ooo`030000003oool0oooo00H000001P3oool00`000000oooo0?ooo`180?oo
o`8000001@3o00000`000000o`000?l000030?l000800000Y03oool000X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0B03oool2000000D0o`0000<000000?l0003o00000`3o000200000:@0oooo000:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo04P0oooo00<000000?l000000000103o00000`000000o`000?l000020?l000030000
003o000000000:@0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04P0oooo00<000000?l000000000103o
00000`000000o`000?l000020?l000030000003o000000000:@0oooo000:0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`<00000B03oool0
0`000000o`00000000040?l000030000003o0000o`000080o`0000<000000?l000000000Y03oool0
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0B03oool00`000000o`00000000040?l000050000003o0000o`00
0?l0000000000P3o00000`000000oooo0?ooo`2R0?ooo`002P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`180?oo
o`040000003o0000o`00000000<0o`0000D000000?l0003o0000o`00000000020?l000030000003o
ool0oooo0:80oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B03oool0
10000000o`000?l0000000030?l000040000003o0000o`00000000<0o`0000<000000?ooo`3oool0
XP3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`180?ooo`040000003o
0000o`00000000<0o`0000@000000?l0003o000000000`3o00000`000000oooo0?ooo`2R0?ooo`00
2`3oool4000000P0oooo100000070?ooo`800000B@3oool010000000o`000?l0000000030?l00004
0000003o0000o`00000000<0o`0000<000000?ooo`3oool0XP3oool00280oooo00<000000?ooo`3o
ool0B03oool01@000000o`000?l0003o000000000080o`0000@000000?l0003o000000000`3o0000
0`000000oooo0?ooo`2R0?ooo`008P3oool00`000000oooo0?ooo`180?ooo`030000003o0000o`00
0080o`0000D000000?l000000000o`00000000040?l000030000003oool0oooo0:80oooo000R0?oo
o`030000003oool0oooo04P0oooo00<000000?l0003o00000`3o0003000000D0o`0000<000000?oo
o`3oool0XP3oool00280oooo00<000000?ooo`3oool0B03oool00`000000o`000?l000040?l00003
0000003o0000o`0000@0o`0000<000000?ooo`3oool0XP3oool00280oooo0P0000190?ooo`030000
003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`2R0?ooo`008P3o
ool00`000000oooo0?ooo`180?ooo`030000003o0000o`0000@0o`0000<000000?l0003o0000103o
00000`000000oooo0?ooo`2R0?ooo`008P3oool00`000000oooo0?ooo`180?ooo`030000003o0000
o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`2R0?ooo`008P3oool00`00
0000oooo0?ooo`180?ooo`030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`00
0000oooo0?ooo`2R0?ooo`008P3oool00`000000oooo0?ooo`180?ooo`030000003o0000o`0000@0
o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`2R0?ooo`008P3oool00`000000oooo
0?ooo`180?ooo`030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo
0?ooo`2R0?ooo`008P3oool2000004T0oooo00<000000?l0003o0000103o00000`000000o`000?l0
00040?l000030000003oool0oooo0:80oooo000R0?ooo`030000003oool0oooo04P0oooo00<00000
0?l0003o0000103o00000`000000o`000?l000040?l000030000003oool0oooo0:80oooo000R0?oo
o`030000003oool0oooo04P0oooo00<000000?l0003o0000103o00000`000000o`000?l000040?l0
00030000003oool0oooo0:80oooo000R0?ooo`030000003oool0oooo04P0oooo00<000000?l0003o
0000103o00000`000000o`000?l000040?l000030000003oool0oooo0:80oooo000R0?ooo`030000
003oool0oooo04P0oooo00<000000?l0003o0000103o00000`000000o`000?l000040?l000030000
003oool0oooo0:80oooo000R0?ooo`800000B@3oool00`000000o`000?l000040?l000030000003o
0000o`0000@0o`0000<000000?ooo`3oool0XP3oool00280oooo00<000000?ooo`3oool0B03oool0
0`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool0XP3oool0
00@0oooo100000040?ooo`030000003oool0oooo00H000000`3oool4000000H0oooo00<000000?oo
o`3oool0B03oool00`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?oo
o`3oool0XP3oool000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo
04P0oooo00<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003oool0oooo
0:80oooo00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`180?ooo`030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000
oooo0?ooo`2R0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`<00000B03oool00`000000o`00
0?l000040?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool0XP3oool000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`180?ooo`030000003o0000o`0000@0o`0000<0
00000?l0003o0000103o00000`000000oooo0?ooo`2R0?ooo`000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo04P0oooo00<000000?l0003o0000103o00000`000000o`000?l0
00040?l000030000003oool0oooo0:80oooo00030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`05000000H0oooo00<000000?ooo`3oool0B03oool0
0`000000o`000?l000040?l000030000003o0000o`0000@0o`0000<000000?ooo`3oool0XP3oool0
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`180?ooo`030000003o0000
o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`2R0?ooo`000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0B03oool8000000H0o`0000<00000
0?ooo`3oool0XP3oool000@0oooo100000080?ooo`@00000103oool5000000D0oooo0P00001@0?oo
o`030000003o0000o`0000@0o`0000<000000?ooo`3oool0XP3oool00280oooo00<000000?ooo`3o
ool0C`3oool00`000000o`000?l000040?l000030000003oool0oooo0:80oooo000R0?ooo`030000
003oool0oooo04l0oooo00<000000?l0003o0000103o00000`000000oooo0?ooo`2R0?ooo`008P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003o0000o`0000@0o`0000<000000?ooo`3oool0XP3o
ool00280oooo00<000000?ooo`3oool0C`3oool00`000000o`000?l000040?l000030000003oool0
oooo0:80oooo000R0?ooo`800000D03oool00`000000o`000?l000040?l000030000003oool0oooo
0:80oooo000R0?ooo`030000003oool0oooo04l0oooo00<000000?l0003o0000103o00000`000000
oooo0?ooo`2R0?ooo`008P3oool00`000000oooo0?ooo`1?0?ooo`030000003o0000o`0000@0o`00
00<000000?ooo`3oool0XP3oool00280oooo00<000000?ooo`3oool0C`3oool00`000000o`000?l0
00040?l000030000003oool0oooo0:80oooo000R0?ooo`030000003oool0oooo04l0oooo2000002T
0?ooo`008P3oool200000?`0oooo000R0?ooo`030000003oool0oooo0?/0oooo000R0?ooo`030000
003oool0oooo0?/0oooo000R0?ooo`030000003oool0oooo0?/0oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-17.0608, -0.0424494, \
0.146554, 0.00186487}}]
}, Open  ]],

Cell[TextData[{
  "A mean to explore through visualization the possible deviation of the \
observed distribution to the normal distribution is the QQ-plot. The QQ plot \
is not available in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " but it can be constructed with a few lines of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code. "
}], "Text"],

Cell[BoxData[
    \(QQPlot[data_, dist_, opts___?OptionQ] := 
      Module[{orderstats = Sort[data], n = Length[data], refQuantile, yTicks, 
          nline}, \[IndentingNewLine]refQuantile\  = \ 
          Function[x, Quantile[dist, x], 
            Listable]; \[IndentingNewLine]yTicks\  = \ 
          Map[{refQuantile[#/100. ], #} &, {1, 5, 10, 25, 50, 75, 90, 95, 
              99}]; \[IndentingNewLine]nline\  = \ 
          Map[{refQuantile[#], refQuantile[#]} &, {0.01, 
              0.99}]; \[IndentingNewLine]Show@\[IndentingNewLine]Graphics[{{\
SteelBlue, \[IndentingNewLine]MapThread[
                  Circle[{#1, #2}, Offset[{3, 3}]] &, {orderstats, 
                    refQuantile[Range[n]/\((n + 1. )\)]}]}}, opts, 
            Frame \[Rule] 
              True, \[IndentingNewLine]FrameTicks \[Rule] {Automatic, yTicks, 
                None, None}, FrameLabel \[Rule] \ "\<Quantiles\>", 
            Prolog \[Rule] {{GrayLevel[0], \ Line[nline]}}, 
            AspectRatio \[Rule] Automatic]\[IndentingNewLine]]\)], "Input"],

Cell["\<\
Applying the QQ plot to the residuals shows us that the distribution of the \
residual is not a normal distribution. If it would be, the blue circles would \
be closer to the straight black line.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(QQPlot[resdata, ndist, 
        FrameLabel \[Rule] \ "\<Quantiles\>"]\ ;\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.04221 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.49568 0.0905175 0.521107 0.0905175 [
[.13361 -0.0125 -10.75 -17.75 ]
[.13361 -0.0125 10.75 0 ]
[.31464 -0.0125 -10.75 -17.75 ]
[.31464 -0.0125 10.75 0 ]
[.49568 -0.0125 -5.90625 -17.75 ]
[.49568 -0.0125 5.90625 0 ]
[.67671 -0.0125 -5.90625 -17.75 ]
[.67671 -0.0125 5.90625 0 ]
[.85775 -0.0125 -5.90625 -17.75 ]
[.85775 -0.0125 5.90625 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .13305 -11.8125 -8.875 ]
[-0.0125 .13305 0 8.875 ]
[-0.0125 .24673 -11.8125 -8.875 ]
[-0.0125 .24673 0 8.875 ]
[-0.0125 .30733 -19.625 -8.875 ]
[-0.0125 .30733 0 8.875 ]
[-0.0125 .40859 -19.625 -8.875 ]
[-0.0125 .40859 0 8.875 ]
[-0.0125 .52111 -19.625 -8.875 ]
[-0.0125 .52111 0 8.875 ]
[-0.0125 .63362 -19.625 -8.875 ]
[-0.0125 .63362 0 8.875 ]
[-0.0125 .73488 -19.625 -8.875 ]
[-0.0125 .73488 0 8.875 ]
[-0.0125 .79549 -19.625 -8.875 ]
[-0.0125 .79549 0 8.875 ]
[-0.0125 .90917 -19.625 -8.875 ]
[-0.0125 .90917 0 8.875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .52111 -37.375 -31.7188 ]
[-0.01875 .52111 -19.625 31.7188 ]
[ 0 1.04221 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1.04221 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13361 0 m
.13361 .00625 L
s
gsave
.13361 -0.0125 -71.75 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.31464 0 m
.31464 .00625 L
s
gsave
.31464 -0.0125 -71.75 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.49568 0 m
.49568 .00625 L
s
gsave
.49568 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.67671 0 m
.67671 .00625 L
s
gsave
.67671 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.85775 0 m
.85775 .00625 L
s
gsave
.85775 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.17887 0 m
.17887 .00375 L
s
.22413 0 m
.22413 .00375 L
s
.26939 0 m
.26939 .00375 L
s
.3599 0 m
.3599 .00375 L
s
.40516 0 m
.40516 .00375 L
s
.45042 0 m
.45042 .00375 L
s
.54094 0 m
.54094 .00375 L
s
.5862 0 m
.5862 .00375 L
s
.63146 0 m
.63146 .00375 L
s
.72197 0 m
.72197 .00375 L
s
.76723 0 m
.76723 .00375 L
s
.81249 0 m
.81249 .00375 L
s
.08835 0 m
.08835 .00375 L
s
.04309 0 m
.04309 .00375 L
s
.90301 0 m
.90301 .00375 L
s
.94827 0 m
.94827 .00375 L
s
.99353 0 m
.99353 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .13305 m
.00625 .13305 L
s
gsave
-0.0125 .13305 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .24673 m
.00625 .24673 L
s
gsave
-0.0125 .24673 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .30733 m
.00625 .30733 L
s
gsave
-0.0125 .30733 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .40859 m
.00625 .40859 L
s
gsave
-0.0125 .40859 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
0 .52111 m
.00625 .52111 L
s
gsave
-0.0125 .52111 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
0 .63362 m
.00625 .63362 L
s
gsave
-0.0125 .63362 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
0 .73488 m
.00625 .73488 L
s
gsave
-0.0125 .73488 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
1.000 setlinewidth
grestore
0 .79549 m
.00625 .79549 L
s
gsave
-0.0125 .79549 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(95) show
1.000 setlinewidth
grestore
0 .90917 m
.00625 .90917 L
s
gsave
-0.0125 .90917 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(99) show
1.000 setlinewidth
grestore
0 0 m
0 1.04221 L
s
gsave
-0.01875 .52111 -121.219 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
92.7188 12.875 translate
90 rotate
-92.7188 -12.875 translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Quantiles) show
122.438 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1.04221 m
1 1.04221 L
s
1 0 m
1 1.04221 L
s
0 0 m
1 0 L
1 1.04221 L
0 1.04221 L
closepath
clip
newpath
.5 Mabswid
.10762 .13305 m
.88374 .90917 L
s
.274 .51 .706 r
newpath
-0.5722 .02481 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
-0.35897 .06142 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.05706 .08401 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.06547 .10063 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.08157 .1139 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.09807 .125 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.11464 .13459 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.12136 .14304 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.12558 .15063 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.15254 .15751 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.16433 .16383 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.17591 .16968 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.2087 .17512 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.21703 .18022 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.2177 .18501 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.22275 .18955 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.22919 .19385 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.2413 .19794 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.24671 .20185 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.24848 .20559 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.25254 .20918 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.25549 .21263 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.25954 .21595 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.25986 .21916 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.26099 .22226 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.26267 .22526 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.26268 .22816 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.26271 .23098 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.26445 .23372 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.2651 .23638 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.26516 .23898 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.26951 .2415 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.2745 .24397 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.27544 .24637 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.27544 .24872 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.2755 .25102 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.27974 .25326 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.28379 .25546 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.28745 .25761 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.28792 .25972 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.28818 .26179 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.29181 .26382 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.29256 .26582 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.2936 .26777 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.29361 .2697 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.2938 .27159 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.29451 .27345 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.29744 .27527 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.29776 .27707 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.29798 .27884 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.2996 .28059 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.30828 .28231 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.30962 .284 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.31238 .28567 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.31266 .28732 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.3135 .28894 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.31437 .29054 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.31605 .29212 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.31637 .29368 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.31729 .29522 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.32163 .29674 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.32323 .29825 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.32355 .29973 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.32767 .3012 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.32784 .30265 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.32799 .30409 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.33004 .30551 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.33121 .30691 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.33328 .3083 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.3335 .30967 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.33522 .31103 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.33783 .31238 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.33873 .31371 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.33903 .31503 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.33921 .31634 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.33953 .31763 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.34025 .31892 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.34202 .32019 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.34258 .32144 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.34309 .32269 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.34499 .32393 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.34539 .32515 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.34545 .32637 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.34567 .32758 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.34625 .32877 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.34692 .32996 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.34853 .33113 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.3488 .3323 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.34924 .33345 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.35233 .3346 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.3543 .33574 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.35667 .33687 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.3578 .338 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.35796 .33911 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.35832 .34022 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.35853 .34131 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.36035 .3424 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.36111 .34349 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.36111 .34456 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.3623 .34563 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.36289 .34669 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.36398 .34775 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.36646 .34879 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.36897 .34983 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.36911 .35087 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.37064 .35189 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.37124 .35292 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.3714 .35393 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.37483 .35494 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.37515 .35594 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.37594 .35694 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.37608 .35793 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.37614 .35891 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.37871 .35989 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.37896 .36087 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.379 .36184 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38006 .3628 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38044 .36376 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38083 .36471 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38095 .36566 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38133 .3666 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38214 .36754 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38384 .36847 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38474 .3694 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.385 .37032 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38707 .37124 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38741 .37215 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38782 .37306 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38799 .37397 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38804 .37487 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.3884 .37577 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38862 .37666 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.38968 .37755 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39058 .37843 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39133 .37931 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39292 .38019 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39335 .38106 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39344 .38193 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39353 .3828 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39354 .38366 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.394 .38452 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39417 .38537 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39431 .38622 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39529 .38707 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39553 .38791 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39565 .38875 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39633 .38959 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39673 .39042 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39808 .39125 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39837 .39208 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39838 .39291 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39846 .39373 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.39958 .39454 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40045 .39536 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40053 .39617 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40133 .39698 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40158 .39779 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40257 .39859 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40283 .39939 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40321 .40019 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40421 .40098 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40424 .40177 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40441 .40256 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40442 .40335 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40452 .40413 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40493 .40492 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40626 .4057 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40678 .40647 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40682 .40725 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40756 .40802 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40842 .40879 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40846 .40955 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40882 .41032 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.40943 .41108 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41007 .41184 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41009 .4126 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41085 .41335 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41235 .41411 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41236 .41486 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41315 .41561 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41366 .41635 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41462 .4171 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41496 .41784 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41506 .41858 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41623 .41932 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41819 .42005 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41826 .42079 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41846 .42152 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4194 .42225 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.41962 .42298 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42024 .42371 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4214 .42443 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4215 .42516 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42337 .42588 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42459 .4266 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4249 .42732 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42505 .42803 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42562 .42875 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42568 .42946 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42581 .43017 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42623 .43088 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42673 .43159 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42692 .43229 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4276 .433 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42784 .4337 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42821 .4344 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.42829 .4351 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43014 .4358 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43038 .4365 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43077 .43719 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43253 .43789 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43255 .43858 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43278 .43927 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.433 .43996 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43339 .44065 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4345 .44134 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4354 .44202 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.436 .44271 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43606 .44339 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43615 .44407 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43668 .44475 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43688 .44543 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43867 .44611 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43879 .44679 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43894 .44746 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.439 .44814 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43905 .44881 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.43951 .44948 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44068 .45015 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44118 .45082 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44134 .45149 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44141 .45216 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44152 .45282 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44202 .45349 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44346 .45415 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44398 .45482 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44405 .45548 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44438 .45614 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.445 .4568 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44588 .45746 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44606 .45812 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44695 .45877 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44794 .45943 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4483 .46008 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44832 .46074 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44888 .46139 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44907 .46204 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44964 .46269 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44997 .46334 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.44998 .46399 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45012 .46464 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45076 .46529 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4512 .46594 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45216 .46658 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45222 .46723 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45273 .46787 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45341 .46852 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45347 .46916 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4538 .4698 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45393 .47044 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45437 .47109 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45467 .47173 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45478 .47236 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4551 .473 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45564 .47364 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45601 .47428 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45632 .47491 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45644 .47555 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45674 .47619 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45678 .47682 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4575 .47745 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.45861 .47809 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46046 .47872 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46048 .47935 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46215 .47998 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46328 .48061 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46341 .48124 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46478 .48187 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46489 .4825 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4664 .48313 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46652 .48376 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46663 .48439 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46691 .48501 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46695 .48564 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4675 .48627 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46804 .48689 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46828 .48752 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46848 .48814 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.46934 .48877 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47053 .48939 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4729 .49001 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47322 .49063 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47377 .49126 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47381 .49188 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47575 .4925 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47579 .49312 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4764 .49374 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47654 .49436 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47714 .49498 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47722 .4956 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47742 .49622 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47742 .49684 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47782 .49746 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4783 .49808 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4787 .49869 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47924 .49931 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.47988 .49993 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.48044 .50055 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.48057 .50116 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.48073 .50178 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.48101 .5024 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.48105 .50301 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.48111 .50363 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4823 .50424 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.48241 .50486 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.48484 .50547 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.48554 .50609 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4865 .5067 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4871 .50732 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.48798 .50793 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4895 .50855 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49021 .50916 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49066 .50977 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49104 .51039 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49128 .511 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49138 .51161 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4918 .51223 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49191 .51284 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49246 .51345 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4925 .51406 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49259 .51468 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49265 .51529 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4931 .5159 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49354 .51652 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.4937 .51713 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49385 .51774 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49495 .51835 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49506 .51896 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49515 .51958 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49516 .52019 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49553 .5208 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49553 .52141 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49616 .52203 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49631 .52264 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49655 .52325 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49659 .52386 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49695 .52447 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49716 .52509 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49806 .5257 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49887 .52631 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49915 .52692 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.49995 .52754 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5 .52815 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50046 .52876 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50086 .52938 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50143 .52999 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50148 .5306 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50227 .53121 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50282 .53183 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50338 .53244 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50349 .53306 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50404 .53367 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50419 .53428 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50436 .5349 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5044 .53551 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50484 .53613 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50552 .53674 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5068 .53736 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50681 .53797 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50715 .53859 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50746 .5392 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50752 .53982 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50771 .54043 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50775 .54105 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50833 .54167 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50893 .54228 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50896 .5429 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50899 .54352 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.509 .54414 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.50963 .54476 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51007 .54537 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51017 .54599 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51024 .54661 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51031 .54723 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51088 .54785 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51137 .54847 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51142 .54909 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51146 .54971 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51149 .55034 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51201 .55096 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51223 .55158 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51241 .5522 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51257 .55283 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51287 .55345 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5143 .55407 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51439 .5547 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51472 .55532 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51481 .55595 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5149 .55657 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51501 .5572 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51515 .55783 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51521 .55846 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51524 .55908 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51587 .55971 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51662 .56034 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51755 .56097 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51812 .5616 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51924 .56223 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51935 .56286 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51942 .56349 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.51968 .56413 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52026 .56476 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52046 .56539 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5207 .56603 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52093 .56666 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52112 .5673 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5212 .56794 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52143 .56857 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5219 .56921 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52228 .56985 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52283 .57049 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52285 .57113 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52292 .57177 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52334 .57241 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52336 .57305 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52354 .5737 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52379 .57434 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.524 .57499 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5241 .57563 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52454 .57628 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52454 .57692 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52508 .57757 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52597 .57822 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52611 .57887 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52686 .57952 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52733 .58017 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52781 .58082 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52907 .58148 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52991 .58213 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.52994 .58279 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53051 .58344 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53067 .5841 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53099 .58476 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53174 .58542 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53259 .58608 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53411 .58674 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53505 .5874 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53545 .58806 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53558 .58873 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53613 .58939 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53645 .59006 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53718 .59072 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53754 .59139 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53846 .59206 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53887 .59273 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53898 .59341 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53904 .59408 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.53943 .59475 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54047 .59543 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54082 .59611 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54138 .59678 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5415 .59746 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54183 .59814 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54209 .59882 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5428 .59951 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54385 .60019 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54565 .60088 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54579 .60156 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54738 .60225 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54798 .60294 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54802 .60363 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54804 .60433 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54807 .60502 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5483 .60572 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54831 .60641 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54887 .60711 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54917 .60781 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5492 .60851 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54923 .60922 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.54983 .60992 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55011 .61063 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5503 .61133 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55058 .61204 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55123 .61276 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55184 .61347 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55194 .61418 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55316 .6149 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55357 .61562 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55421 .61634 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55426 .61706 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55427 .61778 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55534 .61851 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55682 .61923 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.55747 .61996 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56023 .62069 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56091 .62142 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56092 .62216 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56517 .6229 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56528 .62363 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56551 .62437 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56575 .62512 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56687 .62586 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56748 .62661 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56772 .62736 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56821 .62811 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56836 .62886 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56857 .62962 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.56994 .63037 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57129 .63113 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57196 .6319 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57272 .63266 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57397 .63343 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57412 .6342 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5746 .63497 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57592 .63574 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57607 .63652 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57642 .6373 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57643 .63808 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57647 .63886 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57856 .63965 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57871 .64044 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57885 .64123 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.57979 .64203 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.58008 .64282 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.58018 .64362 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.58035 .64443 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.5809 .64523 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.58131 .64604 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.58257 .64685 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.58324 .64767 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.58373 .64849 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.58771 .64931 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.58811 .65013 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.59 .65096 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.59007 .65179 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.59141 .65262 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.59247 .65346 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.59575 .6543 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.59586 .65515 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.59614 .65599 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.59767 .65684 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.60073 .6577 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.6018 .65856 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.60245 .65942 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.60327 .66028 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.60423 .66115 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.60494 .66202 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.60539 .6629 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.60562 .66378 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.60615 .66467 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.60684 .66555 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.60692 .66645 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.60753 .66734 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.60909 .66824 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.61069 .66915 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.61198 .67006 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.6126 .67097 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.61295 .67189 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.61322 .67282 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.61624 .67374 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.61785 .67468 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.61811 .67562 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.61905 .67656 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.62014 .67751 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.62099 .67846 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.62219 .67942 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.62238 .68038 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.62312 .68135 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.62364 .68232 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.62399 .6833 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.62466 .68429 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.62635 .68528 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.6269 .68627 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.62863 .68728 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.62997 .68828 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.63045 .6893 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.63071 .69032 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.63075 .69135 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.63328 .69238 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.63576 .69342 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.63643 .69447 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.63913 .69552 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.63998 .69658 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.64024 .69765 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.64268 .69873 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.64345 .69981 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.64414 .7009 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.64459 .702 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.6449 .7031 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.64538 .70422 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.64707 .70534 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.65013 .70647 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.65063 .70761 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.65369 .70876 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.65422 .70992 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.65474 .71108 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.65494 .71226 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.65523 .71344 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.65613 .71464 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.65761 .71584 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.65921 .71706 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.66108 .71829 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.6627 .71952 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.66312 .72077 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.66336 .72203 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.66496 .7233 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.66511 .72458 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.66592 .72588 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.66722 .72718 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.66861 .7285 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.6687 .72983 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.67035 .73118 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.67182 .73254 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.67201 .73391 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.67252 .7353 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.6728 .73671 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.67321 .73813 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.67371 .73956 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.67479 .74101 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.67671 .74248 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.67975 .74397 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.68121 .74547 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.68188 .74699 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.68255 .74853 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.68302 .75009 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.68326 .75167 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.68352 .75328 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.68362 .7549 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.68431 .75655 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.68927 .75821 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.68988 .75991 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.69299 .76163 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.69564 .76337 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.69595 .76514 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.69712 .76694 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.69722 .76877 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.70034 .77063 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.70169 .77252 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.70284 .77444 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.70403 .7764 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.71105 .77839 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.71812 .78042 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.72164 .78249 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.7217 .7846 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.7228 .78675 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.72284 .78895 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.72292 .7912 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.72599 .79349 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.7271 .79584 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.728 .79825 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.72981 .80071 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.7309 .80324 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.73212 .80583 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.7353 .80849 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.73568 .81123 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.7389 .81405 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.73968 .81696 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.74068 .81996 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.74096 .82305 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.74227 .82626 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.74862 .82958 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.75423 .83303 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.76386 .83662 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.76863 .84036 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.77271 .84427 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.77277 .84837 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.77383 .85267 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.77872 .8572 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.77928 .862 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.7857 .8671 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.80201 .87254 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.80614 .87838 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.80779 .8847 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.81537 .89159 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.83526 .89917 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.83621 .90763 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.83892 .91721 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.84405 .92832 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.94027 .94158 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
.9403 .95821 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
1.08142 .98079 0 0 3 3 Mabsadd pop 0 365.73 arc
s
newpath
2.68122 1.0174 0 0 3 3 Mabsadd pop 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 300.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001;2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00D03oool00`000000oooo0?ooo`0U0?ooo`H000008`3oool4000002L0
oooo1P00000[0?ooo`030000003oool0oooo0200oooo001@0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`00B`3oool7000002P0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09`3oool700000240oooo00120?ooo`L000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01`0oooo1`0000050?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`00C03oool01@000000oooo0?ooo`3oool0
000002/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool09P3oool01@000000oooo0?ooo`3oool000000280oooo001=
0?ooo`040000003oool0oooo000002`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool09P3oool010000000oooo0?oo
o`00000R0?ooo`00C@3oool010000000oooo0?ooo`00000/0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02H0oooo
00@000000?ooo`3oool000008P3oool004h0oooo00<000000?ooo`0000009`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09`3oool00`000000oooo
0000000R0?ooo`00C`3oool2000002L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02P0oooo0P00000R0?ooo`00D03oool00`000000oooo0?ooo`0V
0?ooo`@00000903oool4000002P0oooo1000000/0?ooo`030000003oool0oooo0200oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo000Y0?ooooH000000@3oool002T0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool200000040oooo
000Y0?ooo`030000003oool0oooo0?80oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`3b
0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0lP3oool100000040oooo000Y0?ooo`03
0000003oool0oooo0?80oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`3b0?ooo`400000
0@3oool002T0oooo00<000000?ooo`3oool0lP3oool100000040oooo000Y0?ooo`030000003oool0
oooo0?80oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`3b0?ooo`4000000@3oool002T0
oooo00<000000?ooo`3oool0lP3oool100000040oooo000Y0?ooo`030000003oool0oooo0?80oooo
0@0000010?ooo`00:@3oool00`000000oooo0?ooo`3b0?ooo`4000000@3oool002T0oooo00<00000
0?ooo`3oool0lP3oool100000040oooo000Y0?ooo`030000003oool0oooo0?80oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`3b0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0
lP3oool100000040oooo000Y0?ooo`030000003oool0oooo00/0oooo0P16P[CU0?ooo`4000000@3o
ool002T0oooo00<000000?ooo`3oool02@3oool204J2]080oooo0P16P[CS0?ooo`4000000@3oool0
02T0oooo00<000000?ooo`3oool0203oool00`16P[@0oooo0?ooo`030?ooo`0304J2]03oool0oooo
0>40oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`080?ooo`0304J2]03oool0oooo00<0
oooo00<0AX:d0?ooo`3oool0h@3oool100000040oooo000Y0?ooo`030000003oool0oooo00P0oooo
00<0AX:d0?ooo`3oool00`3oool00`16P[@0oooo0?ooo`3Q0?ooo`4000000@3oool002T0oooo00<0
00000?ooo`3oool02@3oool00`16P[@0oooo0?ooo`0504J2]>40oooo0@0000010?ooo`00:@3oool0
0`000000oooo0?ooo`0:0?ooo`<0AX:d0`3oool00`16P[@0oooo0?ooo`3O0?ooo`4000000@3oool0
02T0oooo00<000000?ooo`3oool02`3oool00`16P[@0oooo0?ooo`020?ooo`80AX:dh03oool10000
0040oooo000Y0?ooo`030000003oool0oooo00/0oooo00@0AX:d0?ooo`3oool0oooo1016P[CO0?oo
o`4000000@3oool002T0oooo00<000000?ooo`3oool02`3oool01P16P[@0oooo0?ooo`16P[@0oooo
04J2]080oooo0P16P[CM0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0303oool504J2
]0<0oooo00<0AX:d0?ooo`16P[@0f`3oool100000040oooo000Y0?ooo`030000003oool0oooo00h0
oooo00<0AX:d0?ooo`3oool00`3oool204J2]0030?ooo`16P[@0AX:d0=T0oooo0@0000010?ooo`00
8@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00@0AX:d0?ooo`3oool0
oooo0P16P[@30?ooo`0304J2]03oool0oooo0=L0oooo0@0000010?ooo`008@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00l0oooo00<0AX:d0?ooo`3oool00`16P[@30?ooo`<0AX:d
e`3oool100000040oooo000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403o
ool304J2]0D0oooo00<0AX:d0?ooo`3oool00P16P[CE0?ooo`4000000@3oool00240oooo00<00000
0?ooo`3oool01@3oool3000001<0oooo00@0AX:d0?ooo`3oool0oooo0P16P[@20?ooo`80AX:de@3o
ool100000040oooo000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool4
04J2]0040?ooo`16P[@0AX:d0?ooo`80AX:de03oool100000040oooo000Q0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool05`3oool204J2]0030?ooo`16P[@0AX:d0080AX:de03oool1
00000040oooo000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool304J2
]0040?ooo`16P[@0AX:d0?ooo`80AX:d0`3oool00`16P[@0oooo0?ooo`3<0?ooo`4000000@3oool0
01l0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0H0?ooo`<0AX:d00H0oooo0000
0016P[@0oooo04J2]03oool204J2]0030?ooo`16P[@0AX:d0<`0oooo0@0000010?ooo`00803oool2
000000L0oooo00<000000?ooo`3oool06@3oool01P16P[@0oooo0?ooo`3oool0AX:d0?ooo`80AX:d
103oool204J2]</0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01X0oooo0`16P[@0103oool0AX:d0?ooo`16P[@30?ooo`H0AX:db03oool100000040oooo
000Y0?ooo`030000003oool0oooo01X0oooo00L0AX:d0?ooo`3oool0oooo04J2]0000000AX:d0080
oooo00<0AX:d0?ooo`16P[@00`16P[@00`3oool0AX:d04J2]0360?ooo`4000000@3oool002T0oooo
00<000000?ooo`3oool06`3oool304J2]080oooo00D0000004J2]03oool0AX:d0?ooo`0204J2]080
oooo00<0AX:d0?ooo`16P[@00`3oool304J2]<00oooo0@0000010?ooo`00:@3oool00`000000oooo
0?ooo`0Q0?ooo`0800000016P[@0AX:d04J2]03oool0AX:d0?ooo`16P[@30?ooo`0304J2]03oool0
AX:d00<0oooo0P16P[Bn0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool08P3oool01`00
0000oooo04J2]03oool0AX:d0?ooo`16P[@00P3oool204J2]0040?ooo`16P[@0oooo0?ooo`D0AX:d
_03oool100000040oooo000Y0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`16P[@00P16
P[@20?ooo`80AX:d0P3oool00`16P[@0oooo04J2]00204J2]0030?ooo`16P[@0AX:d0;`0oooo0@00
00010?ooo`00:@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0AX:d103oool0
1016P[@0oooo04J2]03oool204J2]0030?ooo`16P[@0AX:d0;/0oooo0@0000010?ooo`00:@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00H0oooo1016P[@00`3oool0AX:d04J2]005
04J2];P0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00L0oooo1016P[@00`3oool0AX:d0?ooo`0204J2]0030?ooo`16P[@0AX:d0;H0oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00L0oooo1P16P[@00`3oool0
AX:d04J2]00304J2];D0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00L0oooo0`16P[@00`3oool0AX:d04J2]00204J2]0040?ooo`16P[@0AX:d04J2];@0
oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo
3016P[Bc0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`080?ooo`@0AX:d00<0oooo04J2]016P[@00`16P[Bc0?ooo`4000000@3oool002T0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`T0AX:d/P3oool100000040oooo000Y0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool904J2];40oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo2016P[Ba0?ooo`40
00000@3oool002T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`090?ooo`L0AX:d
/@3oool100000040oooo000Y0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0203o
ool804J2];00oooo0@0000010?ooo`007`3oool4000000H0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`080?ooo`L0AX:d/03oool100000040oooo000N0?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00L0oooo2016P[B_
0?ooo`4000000@3oool001h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool01P3oool904J2]:h0oooo0@0000010?oo
o`008`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool01@3oool:04J2]:d0oooo0@0000010?ooo`008`3oool00`000000oooo0?ooo`030?ooo`<00000
=03oool00`000000oooo0?ooo`050?ooo`X0AX:d[03oool100000040oooo000N0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo00D0oooo2P16P[B[0?ooo`4000000@3oool001h0oooo1@0000060?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool01@3oool:04J2]:X0oooo0@0000010?ooo`007P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01@3oool:04J2
]:T0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool01@3oool904J2]:T0oooo0@0000010?ooo`007`3oool5000000D0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`050?ooo`T0AX:dZ03oool100000040oooo
000Y0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool01@3oool904J2]:L0oooo0@00
00010?ooo`00:@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00@0oooo2`16P[BU
0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`040?oo
o`X0AX:dY@3oool100000040oooo000Y0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool00`3oool;04J2]:@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo00<0oooo3016P[BR0?ooo`4000000@3oool001T0oooo00<000000?ooo`3oool00`3o
ool4000000H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`030?ooo`D0AX:d00<0
oooo04J2]016P[@00`16P[BR0?ooo`4000000@3oool001T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`040?ooo`X0AX:dX@3oool100000040oooo000I0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0103oool:04J2]:00oooo0@0000010?ooo`006@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00@0oooo2`16P[BN0?ooo`4000000@3oool001T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
0`0000130?ooo`030000003oool0oooo00@0oooo2P16P[BN0?ooo`4000000@3oool001T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`050?ooo`T0AX:dW@3oool100000040oooo000I
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0103oool904J2]9d0oooo0@000001
0?ooo`005`3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00@0oooo2@16P[BL0?oo
o`4000000@3oool001P0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00@0oooo2016P[BL0?ooo`40
00000@3oool001T0oooo00<000000?ooo`3oool00`3oool4000000H0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`030?ooo`X0AX:dVP3oool100000040oooo000Y0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool00`3oool:04J2]9T0oooo0@0000010?ooo`00:@3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00<0oooo2@16P[BI0?ooo`4000000@3oool0
02T0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`020?ooo`/0AX:dU`3oool10000
0040oooo000Y0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool00P3oool;04J2]9H0
oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00<0oooo
2P16P[BE0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`030?ooo`X0AX:dU03oool100000040oooo000Y0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool00P3oool:04J2]9@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo0080oooo2P16P[BC0?ooo`4000000@3oool002T0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`030?ooo`T0AX:dTP3oool100000040oooo000Y0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool00P3oool904J2]980oooo0@0000010?ooo`00:@3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0080oooo2@16P[BA0?ooo`4000000@3o
ool002T0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`020?ooo`P0AX:dT@3oool1
00000040oooo000Y0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool804J2
]900oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`1F0?ooo`040000003oool0oooo0?oo
o`T0AX:dS`3oool100000040oooo000Y0?ooo`030000003oool0oooo05L0oooo00@000000?ooo`3o
ool0oooo2016P[B?0?ooo`4000000@3oool001H0oooo1P0000030?ooo`@000001P3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo00T0AX:dSP3oool100000040oooo000G0?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool02016P[B>0?ooo`4000000@3oool001P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`0804J2]8d0oooo0@0000010?ooo`006@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0F`3oool00`000000oooo04J2
]00804J2]8`0oooo0@0000010?ooo`001@3oool6000000l0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`030?ooo`<00000G03oool00`000000oooo04J2]00804J2]8/0oooo0@000001
0?ooo`00103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05d0oooo00<00000
04J2]016P[@02016P[B:0?ooo`4000000@3oool000<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00D000001P3oool00`000000oooo0?ooo`1N0?oo
o`0300000016P[@0AX:d00P0AX:dR@3oool100000040oooo00030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool0G`3oool00`000000AX:d04J2]00704J2]8T0oooo0@0000010?oo
o`000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0H03oool:04J2
]8P0oooo0@0000010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000X0
oooo100000040?ooo`D000001@3oool00`000000oooo0?ooo`1Q0?ooo`0300000016P[@0AX:d00L0
AX:dQ`3oool100000040oooo00030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`1R0?ooo`X0AX:dQP3oool100000040oooo00040?ooo`030000003o
ool0oooo00<0oooo0`00000L0?ooo`030000003oool0oooo06<0oooo2@16P[B60?ooo`4000000@3o
ool000D0oooo1@0000020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0I03oool9
04J2]8D0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`1U0?ooo`T0AX:dQ03oool10000
0040oooo000Y0?ooo`030000003oool0oooo06D0oooo2P16P[B30?ooo`4000000@3oool000D0oooo
1`00000M0?ooo`030000003oool0oooo06H0oooo2@16P[B30?ooo`4000000@3oool000`0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1W0?ooo`T0AX:dPP3oool100000040oooo000<
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0I`3oool904J2]880oooo0@000001
0?ooo`00303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06P0oooo2@16P[B10?oo
o`4000000@3oool000/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1Y0?ooo`T0
AX:dP03oool100000040oooo00050?ooo`P00000703oool00`000000oooo0?ooo`1Z0?ooo`T0AX:d
O`3oool100000040oooo000Y0?ooo`030000003oool0oooo06X0oooo2P16P[An0?ooo`4000000@3o
ool002T0oooo00<000000?ooo`3oool0J`3oool:04J2]7d0oooo0@0000010?ooo`001P3oool01000
0000oooo0?ooo`3oool2000001d0oooo00<000000?ooo`3oool0J`3oool;04J2]7`0oooo0@000001
0?ooo`001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1/0?ooo`X0AX:dO03oool100000040oooo00050?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1^0?ooo`T0AX:dN`3oool1
00000040oooo00050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1_0?ooo`X0AX:dN@3oool100000040oooo00050?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1`0?ooo`T0AX:dN@3oool1
00000040oooo00060?ooo`L000002P3oool4000000@0oooo100000060?ooo`030000003oool0oooo
0700oooo2P16P[Ah0?ooo`4000000@3oool001H0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1a0?oo
o`T0AX:dN03oool100000040oooo000F0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0780oooo2@16P[Ag0?oo
o`4000000@3oool000D0oooo2000000>0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00`3oool3000007<0oooo2016P[Ag0?ooo`4000000@3oool000H0oooo00<000000?ooo`3o
ool04P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0M03oool804J2]7H0oooo0@0000010?ooo`001@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo07@0oooo2@16P[Ae0?ooo`4000000@3oool000D0oooo00<000000?ooo`3o
ool03P3oool5000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo07D0oooo2016P[Ae0?ooo`4000000@3oool000D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1e0?ooo`T0AX:dM03oool100000040oooo00060?ooo`L000002P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1f0?ooo`P0AX:dM03oool100000040oooo000G0?ooo`D000000`3oool4
000000H0oooo00<000000?ooo`3oool0M`3oool804J2]7<0oooo0@0000010?ooo`001@3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo07L0oooo2016P[Ac0?ooo`4000000@3oool000<0
oooo2P00000L0?ooo`030000003oool0oooo07L0oooo2@16P[Ab0?ooo`4000000@3oool000D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo07P0oooo
2016P[@00`000000oooo0?ooo`1_0?ooo`4000000@3oool000D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo07T0oooo2016P[@00`000000oooo0?oo
o`1^0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0N@3oool804J2]0030?ooo`000000
oooo06h0oooo0@0000010?ooo`000`3oool00`000000oooo00000007000001`0oooo00<000000?oo
o`3oool0N@3oool904J2]0030?ooo`000000oooo06d0oooo0@0000010?ooo`00:@3oool00`000000
oooo0?ooo`1j0?ooo`T0AX:d00<0oooo0000003oool0K03oool100000040oooo000Y0?ooo`030000
003oool0oooo07/0oooo2@16P[@00`3oool000000?ooo`1[0?ooo`4000000@3oool000<0oooo2P00
000L0?ooo`030000003oool0oooo07/0oooo2@16P[@20?ooo`030000003oool0oooo06T0oooo0@00
00010?ooo`00:@3oool00`000000oooo0?ooo`1l0?ooo`T0AX:d0P3oool00`000000oooo0?ooo`1X
0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0O03oool:04J2]080oooo00<000000?oo
o`3oool0I`3oool100000040oooo00060?ooo`H000007@3oool00`000000oooo0?ooo`1m0?ooo`X0
AX:d0P3oool00`000000oooo0?ooo`1V0?ooo`4000000@3oool000D0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo07h0oooo2@16P[@30?ooo`03
0000003oool0oooo06D0oooo0@0000010?ooo`001@3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0O`3oool904J2]0<0oooo00<000000?ooo`3o
ool0I03oool100000040oooo00050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`200?ooo`P0AX:d103oool00`000000oooo0?ooo`1S0?ooo`40
00000@3oool000D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo0800oooo2@16P[@40?ooo`030000003oool0oooo0680oooo0@0000010?ooo`00
1P3oool300000080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`210?ooo`X0AX:d
0`3oool00`000000oooo0?ooo`1Q0?ooo`4000000@3oool001P0oooo00<000000?ooo`3oool0103o
ool4000000H0oooo00<000000?ooo`3oool0P@3oool;04J2]0<0oooo00<000000?ooo`3oool0H03o
ool100000040oooo000H0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo0880oooo2`16P[@30?ooo`030000003oool0oooo05l0oooo0@00
00010?ooo`001P3oool2000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`23
0?ooo`/0AX:d0`3oool00`000000oooo0?ooo`1N0?ooo`4000000@3oool000D0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`240?ooo`X0AX:d103oool00`000000oooo0?ooo`1M
0?ooo`4000000@3oool000D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool3000008D0oooo2P16P[@4
0?ooo`030000003oool0oooo05`0oooo0@0000010?ooo`001@3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0QP3oool:04J2]0@0oooo00<00000
0?ooo`3oool0F`3oool100000040oooo00060?ooo`030000003oool0oooo00<000003P3oool01000
0000oooo0?ooo`3oool5000000H0oooo00<000000?ooo`3oool0Q`3oool:04J2]0@0oooo00<00000
0?ooo`3oool0FP3oool100000040oooo000J0?ooo`050000003oool0oooo0?ooo`0000002P3oool0
0`000000oooo0?ooo`280?ooo`/0AX:d0`3oool00`000000oooo0?ooo`1I0?ooo`4000000@3oool0
01/0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo08T0oooo3016P[@2
0?ooo`030000003oool0oooo05P0oooo0@0000010?ooo`005P3oool6000000<0oooo1@0000050?oo
o`030000003oool0oooo08T0oooo3016P[@30?ooo`030000003oool0oooo05L0oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`2:0?ooo``0AX:d0`3oool00`000000oooo0?ooo`1F0?ooo`40
00000@3oool002T0oooo00<000000?ooo`3oool0R`3oool<04J2]0<0oooo00<000000?ooo`3oool0
E@3oool100000040oooo000Y0?ooo`030000003oool0oooo08d0oooo2`16P[@30?ooo`030000003o
ool0oooo05@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`2?0?ooo`X0AX:d0`3oool0
0`000000oooo0?ooo`1C0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0T03oool:04J2
]0<0oooo00<000000?ooo`3oool0DP3oool100000040oooo000Y0?ooo`030000003oool0oooo0940
oooo2P16P[@30?ooo`030000003oool0oooo0540oooo0@0000010?ooo`00:@3oool00`000000oooo
0?ooo`2A0?ooo`/0AX:d0`3oool00`000000oooo0?ooo`1@0?ooo`4000000@3oool002T0oooo00<0
00000?ooo`3oool0T`3oool;04J2]080oooo00<000000?ooo`3oool0C`3oool100000040oooo000Y
0?ooo`030000003oool0oooo09@0oooo2`16P[@20?ooo`030000003oool0oooo04h0oooo0@000001
0?ooo`00:@3oool00`000000oooo0?ooo`2E0?ooo`X0AX:d0`3oool00`000000oooo0?ooo`1=0?oo
o`4000000@3oool002T0oooo00<000000?ooo`3oool0UP3oool;04J2]080oooo00<000000?ooo`3o
ool0C03oool100000040oooo000Y0?ooo`030000003oool0oooo09L0oooo2P16P[@30?ooo`030000
003oool0oooo04/0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`2H0?ooo`X0AX:d0`3o
ool00`000000oooo0?ooo`1:0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0V@3oool:
04J2]0<0oooo00<000000?ooo`3oool0B@3oool100000040oooo000Y0?ooo`030000003oool0oooo
09X0oooo2P16P[@30?ooo`030000003oool0oooo04P0oooo0@0000010?ooo`005`3oool3000000D0
oooo100000060?ooo`030000003oool0oooo09/0oooo2P16P[@30?ooo`030000003oool0oooo04L0
oooo0@0000010?ooo`005P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo09`0oooo2@16P[@40?ooo`03
0000003oool0oooo04H0oooo0@0000010?ooo`006`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0W@3oool904J2]0@0oooo00<000000?ooo`3o
ool0A@3oool100000040oooo000K0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2N0?ooo`P0AX:d1@3oool00`000000oooo0?ooo`140?ooo`40
00000@3oool001L0oooo0`0000001@3oool000000?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00`3oool3000009h0oooo2P16P[@40?ooo`030000003oool0oooo04<0oooo0@0000010?ooo`00
5P3oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo09l0oooo2@16P[@50?ooo`030000003oool0oooo0480
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2O0?ooo`T0AX:d1P3oool00`000000
oooo0?ooo`110?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0X03oool:04J2]0D0
oooo00<000000?ooo`3oool0@03oool100000040oooo000F0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:40
oooo2@16P[@60?ooo`030000003oool0oooo03l0oooo0@0000010?ooo`005`3oool4000000@0oooo
100000060?ooo`030000003oool0oooo0:80oooo2@16P[@60?ooo`030000003oool0oooo03h0oooo
0@0000010?ooo`00:@3oool00`000000oooo0?ooo`2R0?ooo`X0AX:d1P3oool00`000000oooo0?oo
o`0m0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0X`3oool:04J2]0H0oooo00<00000
0?ooo`3oool0?03oool100000040oooo000Y0?ooo`030000003oool0oooo0:@0oooo3016P[@40?oo
o`030000003oool0oooo03/0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`2U0?ooo`d0
AX:d0`3oool00`000000oooo0?ooo`0j0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0
YP3oool<04J2]0@0oooo00<000000?ooo`3oool0>@3oool100000040oooo000G0?ooo`<000001@3o
ool4000000H0oooo00<000000?ooo`3oool0Y`3oool;04J2]0D0oooo00<000000?ooo`3oool0>03o
ool100000040oooo000F0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool0Z03oool;04J2]0D0oooo00<000000?ooo`3oool0
=`3oool100000040oooo000K0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2Y0?ooo`X0AX:d1P3oool00`000000oooo0?ooo`0f0?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0:`0oooo2016P[@60?ooo`030000003oool0oooo03D0oooo0@0000010?ooo`005`3oool3
000000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool00`3oool300000:`0oooo2016P[@7
0?ooo`030000003oool0oooo03@0oooo0@0000010?ooo`005P3oool010000000oooo0?ooo`3oool2
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0:`0oooo2@16P[@70?ooo`030000003oool0oooo03<0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D000001P3oool00`000000oooo0?ooo`2]0?oo
o`T0AX:d1`3oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool001H0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0:h0oooo2016P[@80?oo
o`030000003oool0oooo0340oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`2_0?ooo`L0AX:d2@3oool00`00
0000oooo0?ooo`0`0?ooo`4000000@3oool001L0oooo100000040?ooo`D000001@3oool00`000000
oooo0?ooo`2_0?ooo`P0AX:d2@3oool00`000000oooo0?ooo`0_0?ooo`4000000@3oool002T0oooo
00<000000?ooo`3oool0/03oool804J2]0T0oooo00<000000?ooo`3oool0;P3oool100000040oooo
000Y0?ooo`030000003oool0oooo0;00oooo2P16P[@80?ooo`030000003oool0oooo02d0oooo0@00
00010?ooo`00:@3oool00`000000oooo0?ooo`2`0?ooo`L0AX:d00<0oooo04J2]016P[@00P16P[@7
0?ooo`030000003oool0oooo02`0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`2a0?oo
o`L0AX:d00<0oooo04J2]016P[@00P16P[@70?ooo`030000003oool0oooo02/0oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`2b0?ooo`<0AX:d00<0oooo04J2]016P[@00`16P[@00`3oool0
AX:d04J2]0070?ooo`030000003oool0oooo02X0oooo0@0000010?ooo`00:@3oool00`000000oooo
0?ooo`2d0?ooo`P0AX:d00<0oooo04J2]016P[@01`3oool00`000000oooo0?ooo`0Y0?ooo`400000
0@3oool002T0oooo00<000000?ooo`3oool0]@3oool404J2]0030?ooo`16P[@0AX:d00<0AX:d203o
ool00`000000oooo0?ooo`0X0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0]`3oool4
04J2]0040?ooo`16P[@0AX:d04J2]0T0oooo00<000000?ooo`3oool09`3oool100000040oooo000Y
0?ooo`030000003oool0oooo0;P0oooo2016P[@90?ooo`030000003oool0oooo02H0oooo0@000001
0?ooo`00:@3oool00`000000oooo0?ooo`2i0?ooo`D0AX:d00D0oooo04J2]016P[@0oooo04J2]007
0?ooo`030000003oool0oooo02D0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`2i0?oo
o`0404J2]03oool0AX:d0?ooo`D0AX:d00<0oooo04J2]016P[@01P3oool00`000000oooo0?ooo`0T
0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0^@3oool404J2]0060?ooo`16P[@0AX:d
0?ooo`16P[@0oooo0P16P[@70?ooo`030000003oool0oooo02<0oooo0@0000010?ooo`00:@3oool0
0`000000oooo0?ooo`2j0?ooo``0AX:d1`3oool00`000000oooo0?ooo`0R0?ooo`4000000@3oool0
02T0oooo00<000000?ooo`3oool0^`3oool304J2]0030?ooo`16P[@0AX:d0080AX:d0P3oool204J2
]0L0oooo00<000000?ooo`3oool08@3oool100000040oooo000Y0?ooo`030000003oool0oooo0;d0
oooo1016P[@30?ooo`<0AX:d203oool00`000000oooo0?ooo`0P0?ooo`4000000@3oool002T0oooo
00<000000?ooo`3oool0`03oool804J2]0P0oooo00<000000?ooo`3oool07`3oool100000040oooo
000Y0?ooo`030000003oool0oooo0<00oooo0`16P[@20?ooo`<0AX:d0P3oool00`16P[@0oooo0?oo
o`040?ooo`030000003oool0oooo01h0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`31
0?ooo`D0AX:d0P3oool204J2]0030?ooo`16P[@0AX:d00D0oooo00<000000?ooo`3oool07@3oool1
00000040oooo000G0?ooo`<000001@3oool3000000L0oooo00<000000?ooo`3oool0`P3oool404J2
]0040?ooo`16P[@0oooo0?ooo`<0AX:d1P3oool00`000000oooo0?ooo`0L0?ooo`4000000@3oool0
01H0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`330?ooo`0404J2]03oool0oooo0?ooo`<0AX:d0P3oool204J2]0H0oooo
00<000000?ooo`3oool06`3oool100000040oooo000K0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`340?ooo`@0AX:d0`3oool304J2]0L0oooo00<0
00000?ooo`3oool06P3oool100000040oooo000K0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool300000<L0oooo1016P[@00`3oool0AX:d04J2]0080?ooo`030000003oool0
oooo01T0oooo0@0000010?ooo`005`3oool3000000030?ooo`000000oooo0080oooo0`0000000`3o
ool000000?ooo`040?ooo`030000003oool0oooo0<L0oooo1`16P[@T0?ooo`4000000@3oool001H0
oooo00@000000?ooo`3oool0oooo0P0000020?ooo`040000003oool0oooo0?ooo`8000001@3oool0
0`000000oooo0?ooo`380?ooo`0704J2]03oool0oooo0?ooo`16P[@0oooo04J2]00S0?ooo`400000
0@3oool001H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0b03oool404J2]0030?ooo`16P[@0AX:d02<0oooo
0@0000010?ooo`005P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`390?ooo`0404J2]03oool0oooo0?ooo`80
AX:d8`3oool100000040oooo000F0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0<T0oooo1016P[@20?ooo`03
04J2]03oool0oooo0180oooo00<0AX:d0?ooo`3oool02`3oool100000040oooo000G0?ooo`@00000
103oool4000000H0oooo00<000000?ooo`3oool0b@3oool00`16P[@0oooo0?ooo`020?ooo`0304J2
]03oool0oooo0140oooo0P16P[@00`3oool0AX:d04J2]00;0?ooo`4000000@3oool002T0oooo00<0
00000?ooo`3oool0bP3oool01@16P[@0oooo0?ooo`3oool0AX:d0180oooo00<0AX:d0?ooo`3oool0
0P3oool00`16P[@0oooo0?ooo`090?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0b`3o
ool304J2]1<0oooo00<0AX:d0?ooo`3oool00`3oool00`16P[@0oooo0?ooo`080?ooo`4000000@3o
ool002T0oooo00<000000?ooo`3oool0h@3oool01@16P[@0oooo0?ooo`16P[@0oooo0080AX:d2P3o
ool100000040oooo000Y0?ooo`030000003oool0oooo0>80oooo0P16P[@00`3oool0AX:d04J2]00;
0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0h@3oool00`16P[@0oooo04J2]00304J2
]0/0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`3Q0?ooo`0304J2]03oool0oooo00<0
oooo00<0AX:d0?ooo`3oool0203oool100000040oooo000Y0?ooo`030000003oool0oooo0>40oooo
00<0AX:d0?ooo`3oool00`3oool00`16P[@0oooo0?ooo`080?ooo`4000000@3oool002T0oooo00<0
00000?ooo`3oool0hP3oool01@16P[@0oooo0?ooo`3oool0AX:d00/0oooo0@0000010?ooo`00:@3o
ool00`000000oooo0?ooo`3S0?ooo`@0AX:d2`3oool100000040oooo000Y0?ooo`030000003oool0
oooo0?80oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`3b0?ooo`4000000@3oool002T0
oooo00<000000?ooo`3oool0lP3oool100000040oooo000Y0?ooo`030000003oool0oooo0?80oooo
0@0000010?ooo`00:@3oool00`000000oooo0?ooo`3b0?ooo`4000000@3oool002T0oooo00<00000
0?ooo`3oool0lP3oool100000040oooo000Y0?ooo`030000003oool0oooo0?80oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`3b0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0
lP3oool100000040oooo000Y0?ooo`030000003oool0oooo0?80oooo0@0000010?ooo`00:@3oool0
0`000000oooo0?ooo`3b0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0lP3oool10000
0040oooo000Y0?ooo`030000003oool0oooo0?80oooo0@0000010?ooo`00:@3oool00`000000oooo
0?ooo`3b0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0lP3oool100000040oooo000Y
0?ooo`030000003oool0oooo0?80oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`3b0?oo
o`4000000@3oool002T0oooomP0000010?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {299.125, 0}} -> {-7.36924, -7.21612, \
0.0451096, 0.0451096}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Looking for auto correlations", "Subsection"],

Cell[TextData[{
  "We are also interested in possible auto-correlations in the data. To \
visualize them we can build an autocorrelation plot, which is constructed \
around the function ",
  StyleBox["CorrelationFunction", "MR"],
  " which comes with the package ",
  StyleBox["TimeSeries", "MR"],
  "."
}], "Text"],

Cell[BoxData[
    \(AutoCorrelationPlot[data_, k_, opts___?OptionQ]\  := \ 
      Module[{n = Length[data]}, 
        Show@\[IndentingNewLine]Graphics[{{SteelBlue, 
                Sequence @@ 
                  MapThread[{Disk[{#1, #2}, Offset[{3, 3}]], 
                        Line[{{#1, 0}, {#1, #2}}]} &, {Range[k + 1] - 1, 
                      CorrelationFunction[data, k]}]}, {Dashing[{0.01}], 
                GrayLevel[
                  0.5], \[IndentingNewLine]Line[{{0, 2/Sqrt[n]}, {k, 
                      1.96/Sqrt[n]}}], \[IndentingNewLine]Line[{{0, \(-2\)/
                        Sqrt[n]}, {k, \(-1.96\)/Sqrt[n]}}]}}, opts, 
            Axes \[Rule] {True, False}, Frame \[Rule] True, 
            FrameTicks \[Rule] {Automatic, Automatic, None, None}, 
            PlotRange \[Rule] All, 
            FrameLabel \[Rule] {"\<Lag\>", \ "\<\>"}]]\)], "Input"],

Cell["\<\
The doted gray lines are the boundary at which autocorrelations are \
significant at a 95% level.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Day-of-week effects", "Subsubsection"],

Cell[TextData[{
  "The newly constructed plot can be used for analyzing the data. As a first \
analysis the one day differences in the data are explored. The function ",
  StyleBox["Difference", "MR"],
  " comes from the TimeSeries package."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AutoCorrelationPlot[Difference[peak, 1], 30, 
        AspectRatio \[Rule] 0.3];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0808484 0.212009 [
[.02381 -0.0125 -5.90625 -17.75 ]
[.02381 -0.0125 5.90625 0 ]
[.18254 -0.0125 -5.90625 -17.75 ]
[.18254 -0.0125 5.90625 0 ]
[.34127 -0.0125 -9.8125 -17.75 ]
[.34127 -0.0125 9.8125 0 ]
[.5 -0.0125 -9.8125 -17.75 ]
[.5 -0.0125 9.8125 0 ]
[.65873 -0.0125 -9.8125 -17.75 ]
[.65873 -0.0125 9.8125 0 ]
[.81746 -0.0125 -9.8125 -17.75 ]
[.81746 -0.0125 9.8125 0 ]
[.97619 -0.0125 -9.8125 -17.75 ]
[.97619 -0.0125 9.8125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.7188 -35.5 ]
[.5 -0.0125 13.7188 -17.75 ]
[-0.0125 .03845 -33.25 -8.875 ]
[-0.0125 .03845 0 8.875 ]
[-0.0125 .08085 -11.8125 -8.875 ]
[-0.0125 .08085 0 8.875 ]
[-0.0125 .12325 -23.5625 -8.875 ]
[-0.0125 .12325 0 8.875 ]
[-0.0125 .16565 -23.5625 -8.875 ]
[-0.0125 .16565 0 8.875 ]
[-0.0125 .20805 -23.5625 -8.875 ]
[-0.0125 .20805 0 8.875 ]
[-0.0125 .25046 -23.5625 -8.875 ]
[-0.0125 .25046 0 8.875 ]
[-0.0125 .29286 -11.8125 -8.875 ]
[-0.0125 .29286 0 8.875 ]
[ 0 0 -0.125 0 ]
[ 0 .3 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.7188 -39.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lag) show
86.438 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03845 m
.00625 .03845 L
s
gsave
-0.0125 .03845 -94.25 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .08085 m
.00625 .08085 L
s
gsave
-0.0125 .08085 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12325 m
.00625 .12325 L
s
gsave
-0.0125 .12325 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .16565 m
.00625 .16565 L
s
gsave
-0.0125 .16565 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .20805 m
.00625 .20805 L
s
gsave
-0.0125 .20805 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .25046 m
.00625 .25046 L
s
gsave
-0.0125 .25046 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .29286 m
.00625 .29286 L
s
gsave
-0.0125 .29286 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04905 m
.00375 .04905 L
s
0 .05965 m
.00375 .05965 L
s
0 .07025 m
.00375 .07025 L
s
0 .09145 m
.00375 .09145 L
s
0 .10205 m
.00375 .10205 L
s
0 .11265 m
.00375 .11265 L
s
0 .13385 m
.00375 .13385 L
s
0 .14445 m
.00375 .14445 L
s
0 .15505 m
.00375 .15505 L
s
0 .17625 m
.00375 .17625 L
s
0 .18685 m
.00375 .18685 L
s
0 .19745 m
.00375 .19745 L
s
0 .21865 m
.00375 .21865 L
s
0 .22925 m
.00375 .22925 L
s
0 .23985 m
.00375 .23985 L
s
0 .26106 m
.00375 .26106 L
s
0 .27166 m
.00375 .27166 L
s
0 .28226 m
.00375 .28226 L
s
0 .02785 m
.00375 .02785 L
s
0 .01725 m
.00375 .01725 L
s
0 .00665 m
.00375 .00665 L
s
.25 Mabswid
0 0 m
0 .3 L
s
0 .3 m
1 .3 L
s
1 0 m
1 .3 L
s
0 .08085 m
1 .08085 L
s
.274 .51 .706 r
.02381 .29286 m
.02381 .29286 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.5 Mabswid
.02381 .08085 m
.02381 .29286 L
s
.05556 .04107 m
.05556 .04107 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.05556 .08085 m
.05556 .04107 L
s
.0873 .00714 m
.0873 .00714 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.0873 .08085 m
.0873 .00714 L
s
.11905 .09431 m
.11905 .09431 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.11905 .08085 m
.11905 .09431 L
s
.15079 .07513 m
.15079 .07513 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.15079 .08085 m
.15079 .07513 L
s
.18254 .08058 m
.18254 .08058 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.18254 .08085 m
.18254 .08058 L
s
.21429 .06545 m
.21429 .06545 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.21429 .08085 m
.21429 .06545 L
s
.24603 .12502 m
.24603 .12502 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.24603 .08085 m
.24603 .12502 L
s
.27778 .06809 m
.27778 .06809 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.27778 .08085 m
.27778 .06809 L
s
.30952 .06381 m
.30952 .06381 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.30952 .08085 m
.30952 .06381 L
s
.34127 .08942 m
.34127 .08942 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.34127 .08085 m
.34127 .08942 L
s
.37302 .07167 m
.37302 .07167 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.37302 .08085 m
.37302 .07167 L
s
.40476 .07131 m
.40476 .07131 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.40476 .08085 m
.40476 .07131 L
s
.43651 .07907 m
.43651 .07907 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.43651 .08085 m
.43651 .07907 L
s
.46825 .111 m
.46825 .111 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.46825 .08085 m
.46825 .111 L
s
.5 .06844 m
.5 .06844 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.5 .08085 m
.5 .06844 L
s
.53175 .07365 m
.53175 .07365 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.53175 .08085 m
.53175 .07365 L
s
.56349 .08225 m
.56349 .08225 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.56349 .08085 m
.56349 .08225 L
s
.59524 .07924 m
.59524 .07924 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.59524 .08085 m
.59524 .07924 L
s
.62698 .07046 m
.62698 .07046 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.62698 .08085 m
.62698 .07046 L
s
.65873 .06982 m
.65873 .06982 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.65873 .08085 m
.65873 .06982 L
s
.69048 .11951 m
.69048 .11951 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.69048 .08085 m
.69048 .11951 L
s
.72222 .07617 m
.72222 .07617 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.72222 .08085 m
.72222 .07617 L
s
.75397 .06969 m
.75397 .06969 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.75397 .08085 m
.75397 .06969 L
s
.78571 .08699 m
.78571 .08699 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.78571 .08085 m
.78571 .08699 L
s
.81746 .07518 m
.81746 .07518 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.81746 .08085 m
.81746 .07518 L
s
.84921 .07166 m
.84921 .07166 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.84921 .08085 m
.84921 .07166 L
s
.88095 .07936 m
.88095 .07936 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.88095 .08085 m
.88095 .07936 L
s
.9127 .10931 m
.9127 .10931 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.9127 .08085 m
.9127 .10931 L
s
.94444 .07204 m
.94444 .07204 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.94444 .08085 m
.94444 .07204 L
s
.97619 .0725 m
.97619 .0725 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.97619 .08085 m
.97619 .0725 L
s
.5 g
[ .01 ] 0 setdash
.02381 .09708 m
.97619 .09676 L
s
.02381 .06461 m
.97619 .06494 L
s
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{531.625, 159.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008C0000Wb000`400?l00000o`00003oo`3ooooo
0?oooaD0oooo003o0?ooool0oooo5@3oool00?l0oooo8`3oool400000>d0oooo003o0?ooob80oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3Z0?ooo`00o`3ooolW0?ooo`030000003o
ool0oooo0>X0oooo003o0?oooa80oooo1`0000020?ooo`<0000000<0oooo0000003oool00P3oool3
000000030?ooo`000000oooo0>/0oooo003o0?oooa80oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`3oool200000080oooo00@000000?ooo`3oool0oooo0P00003/0?ooo`00o`3ooolB
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0>X0oooo003o0?oooa80oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3Z0?ooo`00o`3ooolB0?ooo`030000003oool0oooo00L0oooo100000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0jP3oool00?l0oooo4P3oool00`000000oooo0?ooo`0:0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0jP3oool00?l0oooo4P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool2
00000>`0oooo003o0?oooa80oooo00<000000?ooo`3oool01P3oool4000000@0oooo0`0000000`3o
ool000000?ooo`3[0?ooo`00o`3ooolB0?ooo`030000003oool0oooo0?l0oooo003o0?oooa80oooo
00<000000?ooo`3oool0o`3oool00?l0ooooo`3ooolE0?ooo`00o`3ooooo0?oooaD0oooo003o0?oo
ool0oooo5@3oool00?l0ooooo`3ooolE0?ooo`00o`3ooooo0?oooaD0oooo003o0?ooool0oooo5@3o
ool00?l0ooooo`3ooolE0?ooo`00o`3ooooo0?oooaD0oooo001X0?ooo`@00000=`3oool4000003D0
oooo00<000000?ooo`3oool00`3oool400000380oooo00<000000?ooo`3oool00`3oool4000002h0
oooo1P0000030?ooo`@00000;P3oool6000000<0oooo1000000_0?ooo`@00000103oool400000400
oooo001W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<`3oool01@000000oooo
0?ooo`3oool0000003D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
02l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000002h0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03d0oooo001W
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo03d0oooo001W0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0300oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0m0?ooo`00I`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02l0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0`0?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0?@3oool006L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<03o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0300oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0]0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo03d0oooo001W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
<`3oool5000003D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool5000003<0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00D00000<`3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo03d0oooo001W0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000380oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo03d0oooo001W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0e0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02h0oooo0P0000050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000340oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo03d0oooo001X0?ooo`@00000=`3oool5000003@0oooo
00<000000?ooo`3oool00`3oool400000380oooo00<000000?ooo`3oool00`3oool5000002h0oooo
100000040?ooo`@00000;`3oool4000000@0oooo1@00000^0?ooo`@00000103oool400000400oooo
003o0?ooool0oooo5@3oool00?l0ooooo`3ooolE0?ooo`00o`3ooooo0?oooaD0oooo003o0?ooool0
oooo5@3oool00?l0ooooo`3ooolE0?ooo`00o`3ooooo0?oooaD0oooo003o0?ooool0oooo5@3oool0
0640ooooo`00001g000003`0oooo001Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`070?ooo`@0AX:d2P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`070?ooo`D0AX:d2@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo03X0oooo001Q0?ooo`8000001P3oool00`000000oooo0?ooo`0B0?ooo`H0AX:d8@3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0j0?ooo`00H@3oool00`000000oooo0?ooo`0K0?ooo`D0AX:do`3ooomC
0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo01/0oooo1016P[Co0?oo
oe@0oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?ooo`3oool07@3oool00`16P[@0
oooo0?ooo`3o0?oooe<0oooo00<000000?ooo`3oool0>P3oool00640oooo0P00000N0?ooo`0304J2
]03oool0oooo0?l0ooooD`3oool00`000000oooo0?ooo`0j0?ooo`00H@3oool00`000000oooo0?oo
o`0M0?ooo`0304J2]03oool0oooo0?l0ooooD`3oool00`000000oooo0?ooo`0j0?ooo`00H@3oool0
0`000000oooo0?ooo`0M0?ooo`0304J2]03oool0oooo0?l0ooooD`3oool00`000000oooo0?ooo`0j
0?ooo`00H@3oool00`000000oooo0?ooo`0M0?ooo`0304J2]03oool0oooo0?l0ooooD`3oool00`00
0000oooo0?ooo`0j0?ooo`00B03oool4000000@0oooo00<000000?ooo`3oool01P0000080?ooo`80
00007P3oool00`16P[@0oooo0?ooo`3o0?oooe<0oooo00<000000?ooo`3oool0>P3oool004L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool07@3oool00`16P[@0oooo0?ooo`3o0?oooe<0oooo00<000000?ooo`3oool0
>P3oool004L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool07@3oool00`16P[@0oooo0?ooo`3o0?oooe<0oooo00<0
00000?ooo`3oool0>P3oool003h0oooo1`0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo1@16P[@9
0?ooo`0304J2]03oool0oooo0?l0ooooD`3oool00`000000oooo0?ooo`0j0?ooo`00A`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool30000
00h0oooo1P16P[@90?ooo`0304J2]03oool0oooo0?l0ooooD`3oool00`000000oooo0?ooo`0j0?oo
o`00A`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0?0?ooo`D0AX:d2@3oool00`16P[@0oooo0?ooo`3o0?oooe<0
oooo00<000000?ooo`3oool0>P3oool004L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool504J2]0T0oooo
00<0AX:d0?ooo`3oool0o`3ooomC0?ooo`030000003oool0oooo03X0oooo00170?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03`3oool404J2]0X0oooo00<0AX:d0?ooo`3oool0o`3o
oomC0?ooo`030000003oool0oooo03X0oooo00170?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo0P00000B
0?ooo`0304J2]03oool0oooo00T0oooo00<0AX:d0?ooo`3oool0o`3ooomC0?ooo`030000003oool0
oooo03X0oooo00180?ooo`@00000203oool4000000T0oooo00<000000?ooo`3oool04@3oool00`16
P[@0oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooooD`3oool00`000000oooo0?ooo`0j0?oo
o`00H@3oool00`000000oooo0?ooo`0A0?ooo`0304J2]03oool0oooo00T0oooo00<0AX:d0?ooo`3o
ool0o`3ooomC0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo0140oooo
00<0AX:d0?ooo`3oool02@3oool00`16P[@0oooo0?ooo`1>0?ooo`@0AX:do`3oool10?ooo`030000
003oool0oooo03X0oooo001Q0?ooo`8000004P3oool00`16P[@0oooo0?ooo`090?ooo`0304J2]03o
ool0oooo02/0oooo1016P[@O0?ooo`D0AX:do`3oool00`000000oooo0?ooo`0j0?ooo`00H@3oool0
0`000000oooo0?ooo`050?ooo`D0Ogmo0`3oool507moO`80oooo1@1oOgl30?ooo`D0Ogmo0P3oool5
07moO`<0oooo1@1oOgl20?ooo`D0Ogmo0`3oool407moO`<0oooo1@1oOgl30?ooo`@0Ogmo0`16P[@5
07moO`<0oooo101oOgl30?ooo`D0Ogmo0`16P[@407moO`80oooo00<0AX:d07moO`1oOgl00`1oOgl2
0?ooo`D0Ogmo0`3oool507moO`80oooo1@1oOgl30?ooo`D0Ogmo0P3oool507moO`<0oooo1@1oOgl2
0?ooo`D0Ogmo0`3oool507moO`80oooo1@1oOgl304J2]0@0Ogmo0`3oool507moO`<0oooo101oOgl3
0?ooo`D0Ogmo0`3oool407moO`<0oooo1@1oOgl30?ooo`@0Ogmo0`3oool507moO`80AX:d1@1oOgl3
0?ooo`D0Ogmo0P3oool507moO`<0oooo1@1oOgl20?ooo`D0Ogmo00<0AX:d0?ooo`3oool01@1oOgl2
0?ooo`D0Ogmo0`3oool507moO`80oooo1@1oOgl30?ooo`@0Ogmo0`3oool507moO`<0oooo101oOgl3
0?ooo`D0Ogmo0`3oool407moO`<0oooo1@1oOgl30?ooo`@0Ogmo2@3oool00`000000oooo0?ooo`0j
0?ooo`00H@3oool00`000000oooo0?ooo`0A0?ooo`0304J2]03oool0oooo00T0oooo00<0AX:d0?oo
o`3oool0:P3oool604J2]180oooo1@16P[@70?ooo`D0AX:d4`3oool404J2]0P0oooo1016P[@O0?oo
o`D0AX:d:`3oool404J2]0P0oooo1@16P[@N0?ooo`D0AX:d7`3oool404J2]1l0oooo1@16P[@70?oo
o`@0AX:d1`3oool00`000000oooo0?ooo`0j0?ooo`00H@3oool200000180oooo00<0AX:d0?ooo`3o
ool02@3oool00`16P[@0oooo0?ooo`0C0?ooo`@0AX:d4`3oool604J2]140oooo1P16P[@70?ooo`@0
AX:d503oool504J2]0L0oooo1@16P[@M0?ooo`H0AX:d1`3oool404J2]1l0oooo1P16P[@60?ooo`H0
AX:d7@3oool604J2]1<0oooo1016P[@80?ooo`D0AX:d7P3oool504J2]0L0oooo1@16P[@60?ooo`03
0000003oool0oooo03X0oooo001D0?ooo`@000002@3oool00`000000oooo0?ooo`0A0?ooo`0304J2
]03oool0oooo00T0oooo00<0AX:d0?ooo`3oool04`3oool504J2]180oooo1@16P[@C0?ooo`D0AX:d
2@3oool00`16P[@0oooo0?ooo`0B0?ooo`H0AX:d1P3oool604J2]1h0oooo1@16P[@70?ooo`D0AX:d
7`3oool504J2]0H0oooo1P16P[@B0?ooo`D0AX:d1`3oool504J2]1<0oooo1@16P[@60?ooo`H0AX:d
7@3oool604J2]0H0oooo1P16P[@60?ooo`030000003oool0oooo03X0oooo001C0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`0304J2]03o
ool0oooo00T0oooo00<0AX:d0?ooo`3oool04P3oool604J2]0L0oooo1016P[@:0?ooo`0304J2]03o
ool0oooo0180oooo1016P[@:0?ooo`0304J2]03oool0oooo01<0oooo1@16P[@70?ooo`D0AX:d1`3o
ool404J2]1<0oooo1016P[@70?ooo`H0AX:d4`3oool404J2]0P0oooo1@16P[@60?ooo`D0AX:d4`3o
ool504J2]0L0oooo1016P[@C0?ooo`H0AX:d1`3oool504J2]0L0oooo1016P[@C0?ooo`D0AX:d1`3o
ool504J2]0H0oooo00<000000?ooo`3oool0>P3oool005<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<0AX:d0?ooo`3oool02@3oool0
0`16P[@0oooo0?ooo`0C0?ooo`D0AX:d1`3oool504J2]0T0oooo00<0AX:d0?ooo`3oool0503oool0
0`16P[@0oooo0?ooo`090?ooo`0304J2]03oool0oooo01<0oooo1016P[@80?ooo`@0AX:d203oool5
04J2]1@0oooo00<0AX:d0?ooo`3oool01`3oool504J2]0L0oooo1016P[@80?ooo`D0AX:d1`3oool4
04J2]0X0oooo00<0AX:d0?ooo`3oool04@3oool604J2]0T0oooo00<0AX:d0?ooo`3oool04`3oool5
04J2]0L0oooo1016P[@80?ooo`D0AX:d4P3oool404J2]0P0oooo1016P[@70?ooo`030000003oool0
oooo03X0oooo001C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool80000
000304J2]0000000000000T0000000<0AX:d0000000000002@0000000`16P[@00000000000090000
000304J2]0000000000000L000001016P[@7000000H0AX:d2@0000000`16P[@00000000000080000
000304J2]0000000000000T0000000<0AX:d0000000000002@0000000`16P[@00000000000090000
000304J2]0000000000000T0000000<0AX:d0000000000002@0000000`16P[@00000000000060000
00H0AX:d200000000`16P[@00000000000090000000304J2]0000000000000L000001016P[@80000
00D0AX:d1P00000604J2]0T0000000<0AX:d0000000000002@0000000`16P[@00000000000080000
000304J2]0000000000000L000001@16P[@90000000304J2]0000000000000T0000000<0AX:d0000
000000001`00000404J2]0X0000000<0AX:d0000000000001P00000604J2]0P0000000<0AX:d0000
000000002@0000000`16P[@00000000000090000000304J2]0000000000000L00000?03oool005<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<0AX:d0?ooo`3oool08@3oool00`16P[@0oooo0?ooo`0C0?ooo`D0AX:d503oool00`16P[@0
oooo0?ooo`0Q0?ooo`0304J2]03oool0oooo01h0oooo1P16P[@80?ooo`0304J2]03oool0oooo01h0
oooo1P16P[@70?ooo`D0AX:d803oool00`16P[@0oooo0?ooo`070?ooo`@0AX:d503oool404J2]1l0
oooo1P16P[@80?ooo`0304J2]03oool0oooo01h0oooo00<000000?ooo`3oool0>P3oool005<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<0AX:d0?ooo`3oool08@3oool00`16P[@0oooo0?ooo`0C0?ooo`@0AX:d5@3oool00`16P[@0oooo
0?ooo`0O0?ooo`@0AX:d7`3oool504J2]0T0oooo00<0AX:d0?ooo`3oool07`3oool504J2]0L0oooo
1016P[@Q0?ooo`0304J2]03oool0oooo01l0oooo1@16P[@N0?ooo`D0AX:d2@3oool00`16P[@0oooo
0?ooo`0N0?ooo`030000003oool0oooo03X0oooo001C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`0304J2]03oool0oooo01l0oooo0`16
P[@^0?ooo`0304J2]03oool0oooo01h0oooo1P16P[@/0?ooo`0304J2]03oool0oooo01l0oooo1016
P[@]0?ooo`0304J2]03oool0oooo01h0oooo1P16P[@/0?ooo`0304J2]03oool0oooo01h0oooo00<0
00000?ooo`3oool0>P3oool005<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`8000001P3oool00`16P[@0oooo0?ooo`0O0?ooo`@0AX:d;@3oool00`16P[@0oooo0?ooo`0O
0?ooo`D0AX:d;03oool00`16P[@0oooo0?ooo`1@0?ooo`0304J2]03oool0oooo01l0oooo1@16P[@/
0?ooo`0304J2]03oool0oooo01h0oooo00<000000?ooo`3oool0>P3oool005<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0AX:d0?oo
o`3oool07P3oool604J2]2`0oooo00<0AX:d0?ooo`3oool07`3oool504J2]2`0oooo00<0AX:d0?oo
o`3oool0D03oool00`16P[@0oooo0?ooo`0O0?ooo`@0AX:d;@3oool00`16P[@0oooo0?ooo`0N0?oo
o`030000003oool0oooo03X0oooo001D0?ooo`@000002@3oool00`000000oooo0?ooo`050?ooo`D0
Ogmo0`3oool507moO`80oooo1@1oOgl30?ooo`D0Ogmo0P3oool507moO`<0AX:d1@1oOgl20?ooo`D0
Ogmo0`3oool407moO`<0oooo1@1oOgl30?ooo`@0Ogmo0`3oool507moO`<0oooo101oOgl30?ooo`D0
Ogmo0`3oool407moO`<0oooo1@1oOgl20?ooo`D0Ogmo0`16P[@507moO`80oooo1@1oOgl30?ooo`D0
Ogmo0P3oool507moO`<0oooo1@1oOgl20?ooo`D0Ogmo0`3oool507moO`80oooo1@1oOgl30?ooo`@0
Ogmo0`3oool507moO`<0oooo101oOgl30?ooo`D0Ogmo0`3oool407moO`<0oooo1@1oOgl30?ooo`@0
Ogmo0`3oool507moO`80oooo1@1oOgl30?ooo`D0Ogmo0P3oool507moO`<0oooo1@1oOgl20?ooo`D0
Ogmo0`3oool507moO`80oooo1@1oOgl30?ooo`D0Ogmo0P3oool507moO`<0oooo101oOgl30?ooo`D0
Ogmo0`3oool407moO`<0oooo1@1oOgl30?ooo`@0Ogmo0`3oool507moO`<0oooo101oOgl90?ooo`03
0000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo00D0oooo00<0AX:d0?ooo`3oool0
7`3oool504J2]2`0oooo00<0AX:d0?ooo`3oool0D03oool00`16P[@0oooo0?ooo`1@0?ooo`0304J2
]03oool0oooo0500oooo00<0AX:d0?ooo`3oool07P3oool00`000000oooo0?ooo`0j0?ooo`00H@3o
ool2000000H0oooo00<0AX:d0?ooo`3oool08@3oool204J2]2d0oooo00<0AX:d0?ooo`3oool0D03o
ool00`16P[@0oooo0?ooo`1@0?ooo`0304J2]03oool0oooo0500oooo00<0AX:d0?ooo`3oool07P3o
ool00`000000oooo0?ooo`0j0?ooo`00H@3oool00`000000oooo0?ooo`050?ooo`0304J2]03oool0
oooo0500oooo00<0AX:d0?ooo`3oool0D03oool00`16P[@0oooo0?ooo`1@0?ooo`0304J2]03oool0
oooo04h0oooo1@16P[@N0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo
00D0oooo00<0AX:d0?ooo`3oool0D03oool00`16P[@0oooo0?ooo`1>0?ooo`D0AX:dD03oool00`16
P[@0oooo0?ooo`1>0?ooo`D0AX:d7P3oool00`000000oooo0?ooo`0j0?ooo`00H@3oool00`000000
oooo0?ooo`050?ooo`0304J2]03oool0oooo0500oooo00<0AX:d0?ooo`3oool0CP3oool504J2]500
oooo00<0AX:d0?ooo`3oool0C@3oool604J2]1h0oooo00<000000?ooo`3oool0>P3oool00640oooo
0P0000060?ooo`0304J2]03oool0oooo0500oooo00<0AX:d0?ooo`3oool0C@3oool604J2]500oooo
00<0AX:d0?ooo`3oool0CP3oool504J2]1h0oooo00<000000?ooo`3oool0>P3oool004P0oooo1000
00040?ooo`030000003oool0oooo00H00000203oool00`000000oooo0?ooo`050?ooo`0304J2]03o
ool0oooo0500oooo00<0AX:d0?ooo`3oool0CP3oool504J2]4h0oooo1@16P[A>0?ooo`D0AX:d7P3o
ool00`000000oooo0?ooo`0j0?ooo`00A`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`0304J2]03oool0
oooo0500oooo00<0AX:d0?ooo`3oool0CP3oool504J2]4h0oooo1@16P[Aa0?ooo`030000003oool0
oooo03X0oooo00170?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<0AX:d0?ooo`3oool0CP3oool504J2
]:00oooo1P16P[Aa0?ooo`030000003oool0oooo03X0oooo00170?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`<000001@3oool00`16P[@0
oooo0?ooo`1>0?ooo`D0AX:dX@3oool504J2]740oooo00<000000?ooo`3oool0>P3oool004L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01@3oool00`16P[@0oooo0?ooo`1=0?ooo`H0AX:dX@3oool504J2]740oooo
00<000000?ooo`3oool0>P3oool004L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo0?oo
o`1>0?ooo`D0AX:do`3ooolH0?ooo`030000003oool0oooo03X0oooo00170?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<0AX:d0?ooo`3oool0CP3oool504J2]?l0oooo603oool00`000000oooo0?ooo`0j
0?ooo`00A`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`8000001P3oool00`16P[@0oooo0?ooo`3o0?oo
of/0oooo00<000000?ooo`3oool0>P3oool004L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`0304J2]03oool0oooo0?l0ooooJ`3oool00`000000oooo0?ooo`0j0?ooo`00
B03oool4000000P0oooo100000090?ooo`030000003oool0oooo00D0oooo00<0AX:d0?ooo`3oool0
o`3ooom[0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`8000001P3oool0
0`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?oo
o`3oool01@3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool00640
oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3o
ool0>P3oool00640oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo
00<000000?ooo`3oool0>P3oool004P0oooo100000040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01`3oool2000000H0oooo00<0AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003o
ool0oooo03X0oooo00170?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<0AX:d0?ooo`3oool0o`3ooom[
0?ooo`030000003oool0oooo03X0oooo00170?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool7000000P0oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?oo
of/0oooo00<000000?ooo`3oool0>P3oool004L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`050?ooo`0304J2]03oool0oooo0?l0ooooJ`3oool00`000000oooo0?ooo`0j0?ooo`00
A`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000090?ooo`<000001@3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3o
ool0>P3oool004L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?ooof/0
oooo00<000000?ooo`3oool0>P3oool004L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`16P[@0
oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool004L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0
1@3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool004L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`8000002@3oool2000000H0oooo00<0
AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo03X0oooo00180?ooo`@000002`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<0AX:d0?ooo`3oool0o`3ooom[
0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo00D0oooo00<0AX:d0?oo
o`3oool0o`3ooom[0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo00D0
oooo00<0AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`800000
1P3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool00640oooo00<0
00000?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3o
ool00640oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<00000
0?ooo`3oool0>P3oool00640oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?oo
of/0oooo00<000000?ooo`3oool0>P3oool004P0oooo100000040?ooo`040000003oool0oooo0?oo
o`@000002@3oool2000000H0oooo00<0AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo
03X0oooo00170?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`16P[@0
oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool004L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`0304J2]03oool0oooo0?l0ooooJ`3oool00`000000oooo
0?ooo`0j0?ooo`00A`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo03X0oooo00170?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`3oool01P3oool3
000000D0oooo00<0AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo03X0oooo00170?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo000000020000
00T0oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?oo
o`3oool0>P3oool004L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?ooof/0
oooo00<000000?ooo`3oool0>P3oool004L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo
0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool004L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000203oool2000000H0oooo
00<0AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo03X0oooo00180?ooo`@000002@3o
ool3000000T0oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<0
00000?ooo`3oool0>P3oool00640oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o
0?ooof/0oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?ooo`3oool01@3oool00`16
P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool00640oooo0P0000060?ooo`03
04J2]03oool0oooo0?l0ooooJ`3oool00`000000oooo0?ooo`0j0?ooo`00H@3oool00`000000oooo
0?ooo`050?ooo`0304J2]03oool0oooo0?l0ooooJ`3oool00`000000oooo0?ooo`0j0?ooo`00H@3o
ool00`000000oooo0?ooo`050?ooo`0304J2]03oool0oooo0?l0ooooJ`3oool00`000000oooo0?oo
o`0j0?ooo`00H@3oool00`000000oooo0?ooo`050?ooo`0304J2]03oool0oooo0?l0ooooJ`3oool0
0`000000oooo0?ooo`0j0?ooo`00B03oool4000000@0oooo00@000000?ooo`3oool0oooo10000009
0?ooo`8000001P3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool0
04L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`0304J2]03oool0oooo
0?l0ooooJ`3oool00`000000oooo0?ooo`0j0?ooo`00A`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<0AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo03X0
oooo00170?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo
0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool004L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool3000000D0oooo00<0AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo03X0oooo0017
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool4000000T0oooo00<00000
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool0
04L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`0304J2]03oool0oooo
0?l0ooooJ`3oool00`000000oooo0?ooo`0j0?ooo`00A`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<0AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo03X0
oooo00170?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`0304J2]03oool0oooo0?l0oooo
J`3oool00`000000oooo0?ooo`0j0?ooo`00B03oool4000000P0oooo100000090?ooo`030000003o
ool0oooo00D0oooo00<0AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo03X0oooo001Q
0?ooo`030000003oool0oooo00D0oooo00<0AX:d0?ooo`3oool0o`3ooom[0?ooo`030000003oool0
oooo03X0oooo001Q0?ooo`030000003oool0oooo00D0oooo00<0AX:d0?ooo`3oool0o`3ooom[0?oo
o`030000003oool0oooo03X0oooo001Q0?ooo`8000001P3oool00`16P[@0oooo0?ooo`3o0?ooof/0
oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?ooo`3oool01@3oool00`16P[@0oooo
0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?ooo`3oool01@3o
ool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool00640oooo00<00000
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool0
05H0oooo00<000000?ooo`3oool0203oool2000000H0oooo00<0AX:d0?ooo`3oool0o`3ooom[0?oo
o`030000003oool0oooo03X0oooo001F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01@3oool00`16P[@0oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool0>P3oool005H0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`D0AX:do`3ooom[0?ooo`030000
003oool0oooo03X0oooo001F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool604J2]?l0ooooJ`3oool00`000000oooo0?ooo`0j0?ooo`00EP3oool00`000000oooo0?ooo`08
0?ooo`<000000`3oool504J2]?l0ooooJ`3oool00`000000oooo0?ooo`0j0?ooo`00EP3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo1@16P[Co0?ooof/0oooo00<000000?oo
o`3oool0>P3oool005H0oooo00<000000?ooo`3oool0203oool6000000D0AX:do`00001/000003`0
oooo001D0?ooo`030000003oool000000?l0oooo_@3oool005D0oooo0P00003o0?oookd0oooo001F
0?ooo`030000003oool0oooo0?l0oooo^`3oool00?l0ooooo`3ooolE0?ooo`00o`3ooooo0?oooaD0
oooo003o0?ooool0oooo5@3oool00001\
\>"],
  ImageRangeCache->{{{0, 530.625}, {158.438, 0}} -> {-8.93405, -0.888589, \
0.0843305, 0.0126276}}]
}, Open  ]],

Cell[TextData[{
  "There seems to be significant autocorrelation in respect to the previous \
day, the day before the previous day and then on the seventh, ",
  Cell[BoxData[
      \(TraditionalForm\`fourteenth, \(\(...\) \(7\^n\) \(th\)\)\)]],
  " day. This indicates a day-of-the-week effect in the data. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Seasonal effects", "Subsubsection"],

Cell["\<\
If we only look on weekly sequences of the data a seasonal pattern can be \
observed.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DayOfWeek[dates[\([3]\)]]\)], "Input"],

Cell[BoxData[
    \("Sunday"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AutoCorrelationPlot[peak[\([Range[3, Length[peak], 7]]\)], 52, 
        AspectRatio \[Rule] 0.3];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0238095 0.018315 0.0799597 0.212897 [
[.02381 -0.0125 -5.90625 -17.75 ]
[.02381 -0.0125 5.90625 0 ]
[.20696 -0.0125 -9.8125 -17.75 ]
[.20696 -0.0125 9.8125 0 ]
[.39011 -0.0125 -9.8125 -17.75 ]
[.39011 -0.0125 9.8125 0 ]
[.57326 -0.0125 -9.8125 -17.75 ]
[.57326 -0.0125 9.8125 0 ]
[.75641 -0.0125 -9.8125 -17.75 ]
[.75641 -0.0125 9.8125 0 ]
[.93956 -0.0125 -9.8125 -17.75 ]
[.93956 -0.0125 9.8125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.7188 -35.5 ]
[.5 -0.0125 13.7188 -17.75 ]
[-0.0125 .03738 -33.25 -8.875 ]
[-0.0125 .03738 0 8.875 ]
[-0.0125 .07996 -11.8125 -8.875 ]
[-0.0125 .07996 0 8.875 ]
[-0.0125 .12254 -23.5625 -8.875 ]
[-0.0125 .12254 0 8.875 ]
[-0.0125 .16512 -23.5625 -8.875 ]
[-0.0125 .16512 0 8.875 ]
[-0.0125 .2077 -23.5625 -8.875 ]
[-0.0125 .2077 0 8.875 ]
[-0.0125 .25028 -23.5625 -8.875 ]
[-0.0125 .25028 0 8.875 ]
[-0.0125 .29286 -11.8125 -8.875 ]
[-0.0125 .29286 0 8.875 ]
[ 0 0 -0.125 0 ]
[ 0 .3 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20696 0 m
.20696 .00625 L
s
gsave
.20696 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.39011 0 m
.39011 .00625 L
s
gsave
.39011 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.57326 0 m
.57326 .00625 L
s
gsave
.57326 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.75641 0 m
.75641 .00625 L
s
gsave
.75641 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.93956 0 m
.93956 .00625 L
s
gsave
.93956 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.06044 0 m
.06044 .00375 L
s
.09707 0 m
.09707 .00375 L
s
.1337 0 m
.1337 .00375 L
s
.17033 0 m
.17033 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.28022 0 m
.28022 .00375 L
s
.31685 0 m
.31685 .00375 L
s
.35348 0 m
.35348 .00375 L
s
.42674 0 m
.42674 .00375 L
s
.46337 0 m
.46337 .00375 L
s
.5 0 m
.5 .00375 L
s
.53663 0 m
.53663 .00375 L
s
.60989 0 m
.60989 .00375 L
s
.64652 0 m
.64652 .00375 L
s
.68315 0 m
.68315 .00375 L
s
.71978 0 m
.71978 .00375 L
s
.79304 0 m
.79304 .00375 L
s
.82967 0 m
.82967 .00375 L
s
.8663 0 m
.8663 .00375 L
s
.90293 0 m
.90293 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.7188 -39.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lag) show
86.438 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03738 m
.00625 .03738 L
s
gsave
-0.0125 .03738 -94.25 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .07996 m
.00625 .07996 L
s
gsave
-0.0125 .07996 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12254 m
.00625 .12254 L
s
gsave
-0.0125 .12254 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .16512 m
.00625 .16512 L
s
gsave
-0.0125 .16512 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .2077 m
.00625 .2077 L
s
gsave
-0.0125 .2077 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .25028 m
.00625 .25028 L
s
gsave
-0.0125 .25028 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .29286 m
.00625 .29286 L
s
gsave
-0.0125 .29286 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04803 m
.00375 .04803 L
s
0 .05867 m
.00375 .05867 L
s
0 .06931 m
.00375 .06931 L
s
0 .0906 m
.00375 .0906 L
s
0 .10125 m
.00375 .10125 L
s
0 .11189 m
.00375 .11189 L
s
0 .13318 m
.00375 .13318 L
s
0 .14383 m
.00375 .14383 L
s
0 .15447 m
.00375 .15447 L
s
0 .17576 m
.00375 .17576 L
s
0 .18641 m
.00375 .18641 L
s
0 .19705 m
.00375 .19705 L
s
0 .21834 m
.00375 .21834 L
s
0 .22899 m
.00375 .22899 L
s
0 .23963 m
.00375 .23963 L
s
0 .26092 m
.00375 .26092 L
s
0 .27157 m
.00375 .27157 L
s
0 .28221 m
.00375 .28221 L
s
0 .02674 m
.00375 .02674 L
s
0 .01609 m
.00375 .01609 L
s
0 .00545 m
.00375 .00545 L
s
.25 Mabswid
0 0 m
0 .3 L
s
0 .3 m
1 .3 L
s
1 0 m
1 .3 L
s
0 .07996 m
1 .07996 L
s
.274 .51 .706 r
.02381 .29286 m
.02381 .29286 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.5 Mabswid
.02381 .07996 m
.02381 .29286 L
s
.04212 .22625 m
.04212 .22625 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.04212 .07996 m
.04212 .22625 L
s
.06044 .19744 m
.06044 .19744 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.06044 .07996 m
.06044 .19744 L
s
.07875 .1986 m
.07875 .1986 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.07875 .07996 m
.07875 .1986 L
s
.09707 .19472 m
.09707 .19472 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.09707 .07996 m
.09707 .19472 L
s
.11538 .17617 m
.11538 .17617 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.11538 .07996 m
.11538 .17617 L
s
.1337 .15183 m
.1337 .15183 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.1337 .07996 m
.1337 .15183 L
s
.15201 .15341 m
.15201 .15341 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.15201 .07996 m
.15201 .15341 L
s
.17033 .16203 m
.17033 .16203 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.17033 .07996 m
.17033 .16203 L
s
.18864 .1318 m
.18864 .1318 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.18864 .07996 m
.18864 .1318 L
s
.20696 .11383 m
.20696 .11383 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.20696 .07996 m
.20696 .11383 L
s
.22527 .10218 m
.22527 .10218 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.22527 .07996 m
.22527 .10218 L
s
.24359 .08948 m
.24359 .08948 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.24359 .07996 m
.24359 .08948 L
s
.2619 .07214 m
.2619 .07214 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.2619 .07996 m
.2619 .07214 L
s
.28022 .0526 m
.28022 .0526 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.28022 .07996 m
.28022 .0526 L
s
.29853 .05114 m
.29853 .05114 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.29853 .07996 m
.29853 .05114 L
s
.31685 .04859 m
.31685 .04859 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.31685 .07996 m
.31685 .04859 L
s
.33516 .04076 m
.33516 .04076 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.33516 .07996 m
.33516 .04076 L
s
.35348 .02424 m
.35348 .02424 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.35348 .07996 m
.35348 .02424 L
s
.37179 .01617 m
.37179 .01617 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.37179 .07996 m
.37179 .01617 L
s
.39011 .02491 m
.39011 .02491 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.39011 .07996 m
.39011 .02491 L
s
.40842 .01629 m
.40842 .01629 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.40842 .07996 m
.40842 .01629 L
s
.42674 .00714 m
.42674 .00714 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.42674 .07996 m
.42674 .00714 L
s
.44505 .00762 m
.44505 .00762 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.44505 .07996 m
.44505 .00762 L
s
.46337 .00743 m
.46337 .00743 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.46337 .07996 m
.46337 .00743 L
s
.48168 .01804 m
.48168 .01804 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.48168 .07996 m
.48168 .01804 L
s
.5 .02358 m
.5 .02358 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.5 .07996 m
.5 .02358 L
s
.51832 .01272 m
.51832 .01272 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.51832 .07996 m
.51832 .01272 L
s
.53663 .02542 m
.53663 .02542 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.53663 .07996 m
.53663 .02542 L
s
.55495 .03172 m
.55495 .03172 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.55495 .07996 m
.55495 .03172 L
s
.57326 .04157 m
.57326 .04157 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.57326 .07996 m
.57326 .04157 L
s
.59158 .05271 m
.59158 .05271 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.59158 .07996 m
.59158 .05271 L
s
.60989 .06347 m
.60989 .06347 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.60989 .07996 m
.60989 .06347 L
s
.62821 .08204 m
.62821 .08204 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.62821 .07996 m
.62821 .08204 L
s
.64652 .07899 m
.64652 .07899 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.64652 .07996 m
.64652 .07899 L
s
.66484 .08999 m
.66484 .08999 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.66484 .07996 m
.66484 .08999 L
s
.68315 .10254 m
.68315 .10254 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.68315 .07996 m
.68315 .10254 L
s
.70147 .10942 m
.70147 .10942 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.70147 .07996 m
.70147 .10942 L
s
.71978 .1019 m
.71978 .1019 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.71978 .07996 m
.71978 .1019 L
s
.7381 .10751 m
.7381 .10751 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.7381 .07996 m
.7381 .10751 L
s
.75641 .11993 m
.75641 .11993 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.75641 .07996 m
.75641 .11993 L
s
.77473 .1147 m
.77473 .1147 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.77473 .07996 m
.77473 .1147 L
s
.79304 .11476 m
.79304 .11476 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.79304 .07996 m
.79304 .11476 L
s
.81136 .13023 m
.81136 .13023 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.81136 .07996 m
.81136 .13023 L
s
.82967 .13193 m
.82967 .13193 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.82967 .07996 m
.82967 .13193 L
s
.84799 .13053 m
.84799 .13053 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.84799 .07996 m
.84799 .13053 L
s
.8663 .12715 m
.8663 .12715 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.8663 .07996 m
.8663 .12715 L
s
.88462 .12308 m
.88462 .12308 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.88462 .07996 m
.88462 .12308 L
s
.90293 .12335 m
.90293 .12335 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.90293 .07996 m
.90293 .12335 L
s
.92125 .1223 m
.92125 .1223 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.92125 .07996 m
.92125 .1223 L
s
.93956 .11897 m
.93956 .11897 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.93956 .07996 m
.93956 .11897 L
s
.95788 .11769 m
.95788 .11769 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.95788 .07996 m
.95788 .11769 L
s
.97619 .1222 m
.97619 .1222 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.97619 .07996 m
.97619 .1222 L
s
.5 g
[ .01 ] 0 setdash
.02381 .12297 m
.97619 .12211 L
s
.02381 .03695 m
.97619 .03781 L
s
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{566, 169.75},
  ImageMargins->{{0, 0}, {0, 27.9375}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008f0000ZB000`400?l00000o`00003oo`3ooooo
0?ooocP0oooo003o0?ooool0oooo>03oool00?l0oooo=03oool400000?l0oooo003o0?oooc<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3l0?ooo`00o`3ooolh0?ooo`030000003o
ool0oooo0?`0oooo003o0?ooob<0oooo1`0000020?ooo`<0000000<0oooo0000003oool00P3oool3
000000030?ooo`000000oooo0?d0oooo003o0?ooob<0oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`3oool200000080oooo00@000000?ooo`3oool0oooo0P00003n0?ooo`00o`3ooolS
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0?`0oooo003o0?ooob<0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3l0?ooo`00o`3ooolS0?ooo`030000003oool0oooo00L0oooo100000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0o03oool00?l0oooo8`3oool00`000000oooo0?ooo`0:0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o03oool00?l0oooo8`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool2
00000?h0oooo003o0?ooob<0oooo00<000000?ooo`3oool01P3oool4000000@0oooo0`0000000`3o
ool000000?ooo`3m0?ooo`00o`3ooolS0?ooo`030000003oool0oooo0?l0oooo4P3oool00?l0oooo
8`3oool00`000000oooo0?ooo`3o0?oooa80oooo003o0?ooool0oooo>03oool00?l0ooooo`3ooolh
0?ooo`00o`3ooooo0?ooocP0oooo003o0?ooool0oooo>03oool00?l0ooooo`3ooolh0?ooo`00o`3o
oooo0?ooocP0oooo003o0?ooool0oooo>03oool00?l0ooooo`3ooolh0?ooo`00J@3oool4000004D0
oooo00<000000?ooo`3oool00`3oool4000003h0oooo1P0000030?ooo`@00000?P3oool4000000@0
oooo100000120?ooo`030000003oool0oooo0080oooo1000000n0?ooo`@00000103oool400000500
oooo001X0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0?`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`00J03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo03X0oooo1`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0C@3oool006P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0o0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`0o0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0C@3oool006P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0o0?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`0o0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0>`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0o0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0C@3o
ool006P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0?03oool3000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0l0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1=0?ooo`00J03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0400oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0o0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool5000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`00J03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0400oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo03d0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo04d0oooo001X0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0@@3oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0n0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04d0oooo
001Y0?ooo`@00000A@3oool00`000000oooo0?ooo`030?ooo`@00000?`3oool4000000@0oooo1000
000n0?ooo`@00000103oool400000480oooo00<000000?ooo`3oool00P3oool4000003h0oooo1@00
00030?ooo`@00000D03oool00?l0ooooo`3ooolh0?ooo`00o`3ooooo0?ooocP0oooo003o0?ooool0
oooo>03oool00?l0ooooo`3ooolh0?ooo`00o`3ooooo0?ooocP0oooo003o0?ooool0oooo>03oool0
0?l0ooooo`3ooolh0?ooo`00H@3ooooo000009X00000?03oool00640oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo1@16P[@30?ooo`<0AX:d
103oool404J2]0d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0:0?ooo`D0AX:d0`3oool404J2]0<0oooo1@16P[@<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0j0?ooo`00H@3oool3
000000L0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo00T0oooo1P16P[@20?ooo`H0AX:d00<0oooo04J2]016P[@01016P[@Z0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo03X0oooo001Q0?ooo`030000003oool0oooo0:T0oooo1@16P[@30?ooo`D0AX:d0P3oool504J2
]180oooo1016P[C20?ooo`030000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo09<0
oooo1016P[@;0?ooo`@0AX:d0`3oool404J2]0@0oooo1@16P[@20?ooo`D0AX:d4@3oool604J2]<40
oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?ooo`3oool0T`3oool504J2]0X0oooo
1@16P[@40?ooo`0304J2]03oool0oooo00D0oooo0P16P[@50?ooo`80AX:d103oool404J2]0X0oooo
1P16P[C10?ooo`030000003oool0oooo03X0oooo001Q0?ooo`<00000TP3oool604J2]0T0oooo1P16
P[@40?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?oo
o`030?ooo`D0AX:d2@3oool604J2]<40oooo00<000000?ooo`3oool0>P3oool00640oooo00<00000
0?ooo`3oool0R`3oool504J2]0<0oooo1@16P[@20?ooo`@0AX:d103oool504J2]0@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo0080oooo1P16P[@2
0?ooo`@0AX:d0`3oool504J2]<80oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?oo
o`3oool0R`3oool504J2]0<0oooo1016P[@30?ooo`D0AX:d0`3oool404J2]0D0oooo00<0AX:d0?oo
o`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo0080oooo1P16P[@20?oo
o`D0AX:d1@3oool00`16P[@0oooo0?ooo`020?ooo`@0AX:d^`3oool00`000000oooo0?ooo`0j0?oo
o`00H@3oool00`000000oooo0?ooo`2:0?ooo`H0AX:d1@3oool01016P[@0oooo0?ooo`3oool604J2
]0D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo
00@0oooo00<0AX:d0?ooo`3oool00P3oool504J2]080oooo1P16P[@50?ooo`0304J2]03oool0oooo
0080oooo1@16P[Bj0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`<00000R`3oool504J2]0D0
oooo00<0AX:d0?ooo`3oool00P3oool504J2]0D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0
oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0
oooo0?ooo`020?ooo`D0AX:d1@3oool01016P[@0oooo0?ooo`3oool604J2]0<0oooo1016P[Bc0?oo
o`030000003oool0oooo03X0oooo00190?ooo`@00000103oool00`000000oooo0?ooo`06000000L0
oooo00<000000?ooo`3oool0R`3oool504J2]0D0oooo00<0AX:d0?ooo`3oool00P3oool504J2]0D0
oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0
oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`020?ooo`@0AX:d1P3oool00`16P[@0
oooo0?ooo`020?ooo`D0AX:d0P3oool504J2];<0oooo00<000000?ooo`3oool0>P3oool004P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0S@3oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo0080oooo
1016P[@60?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo
0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`050?ooo`0304J2]03oool0oooo0080oooo1016P[@20?ooo`H0AX:d/`3oool00`000000oooo
0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`2=0?ooo`0304J2]03oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0
AX:d0?ooo`3oool00P3oool504J2];<0oooo00<000000?ooo`3oool0>P3oool003h0oooo1`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo1@1oOgl30?ooo`D0Ogmo0`3oool507moO`@0oooo1@1oOgl3
0?ooo`D0Ogmo0`3oool507moO`<0oooo1@1oOgl30?ooo`D0Ogmo0`3oool507moO`<0oooo1P1oOgl^
0?ooo`@0AX:d1@3oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo0080oooo1@16P[@3
0?ooo`@0AX:d[03oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool4000005P0oooo1@1oOgl30?oo
o`D0Ogmo0`3oool507moO`<0oooo1@1oOgl30?ooo`D0Ogmo0`3oool507moO`<0AX:d1P1oOgl30?oo
o`D0Ogmo0`3oool507moO`<0oooo1@1oOgl30?ooo`D0Ogmo0`3oool507moO`<0oooo1@1oOgl30?oo
o`H0Ogmo00<0oooo04J2]03oool01@1oOgl00`3oool0AX:d0?ooo`0507moO`0304J2]03oool0oooo
00D0Ogmo0`3oool507moO`80AX:d00<0oooo07moO`1oOgl00`1oOgl30?ooo`D0Ogmo103oool507mo
O`<0oooo1@1oOgl30?ooo`D0Ogmo0`3oool507moO`<0oooo1@1oOgl30?ooo`D0Ogmo0`3oool507mo
O`@0oooo1@1oOgl30?ooo`D0Ogmo0`3oool507moO`<0oooo1@1oOgl30?ooo`D0Ogmo0`3oool507mo
O`<0oooo1@1oOgl40?ooo`D0Ogmo0`3oool507moO`<0oooo1@1oOgl30?ooo`D0Ogmo2P3oool00`00
0000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`230?ooo`H0AX:d103oool00`16P[@0
oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0
oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0
oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0
oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool00P3oool604J2]:/0
oooo00<000000?ooo`3oool0>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0O@3oool404J2]0<0oooo
1@16P[@40?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo
0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`030?ooo`D0AX:dZ`3oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo07D0oooo1016P[@40?ooo`@0AX:d0`3oool404J2]0D0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00<0oooo1016
P[B/0?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`00001^
0?ooo`@0AX:d0`3oool504J2]080oooo1@16P[@50?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool00P3oool504J2]:@0oooo00<000000?ooo`3oool0>P3oool004T0oooo100000080?oo
o`@00000203oool00`000000oooo0?ooo`1^0?ooo`D0AX:d00<0oooo04J2]016P[@01016P[@20?oo
o`H0AX:d103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?oo
o`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo0080oooo1@16P[BT0?oo
o`030000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo06d0oooo1P16P[@20?ooo`D0
AX:d0P3oool504J2]0D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`03
04J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`03
04J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool01016P[@0oooo0?ooo`3oool604J2
]:@0oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?ooo`3oool0K@3oool604J2]080
oooo1016P[@60?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0
oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0
oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0
oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0
oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0
oooo0?ooo`020?ooo`D0AX:dY03oool00`000000oooo0?ooo`0j0?ooo`00H@3oool3000006d0oooo
1@16P[@50?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo
0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`050?ooo`0304J2]03oool0oooo0080oooo1@16P[@30?ooo`@0AX:dW@3oool00`000000oooo
0?ooo`0j0?ooo`00H@3oool00`000000oooo0?ooo`1`0?ooo`0304J2]03oool0oooo00@0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`030?ooo`D0AX:dW03oool00`000000oooo0?oo
o`0j0?ooo`00H@3oool00`000000oooo0?ooo`1`0?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`020?ooo`H0AX:dW03oool00`000000oooo0?ooo`0j
0?ooo`00H@3oool00`000000oooo0?ooo`1`0?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?oo
o`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?oo
o`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?oo
o`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`030?ooo`D0AX:dW03oool00`000000oooo0?ooo`0j0?oo
o`00H@3oool00`000000oooo0?ooo`1V0?ooo`@0AX:d1P3oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`03
04J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`03
04J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`03
04J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool00`3oool404J2]9d0oooo00<000000?ooo`3o
ool0>P3oool005D0oooo100000080?ooo`<00000IP3oool504J2]0D0oooo00<0AX:d0?ooo`3oool0
103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0
103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0
1@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0
103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0
1@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0
1@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0
W03oool00`000000oooo0?ooo`0j0?ooo`00E03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0I@3oool604J2]0D0oooo00<0AX:d0?ooo`3oool0103o
ool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0103o
ool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3o
ool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103o
ool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3o
ool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3o
ool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0W03o
ool00`000000oooo0?ooo`0j0?ooo`00E03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0IP3oool504J2]0D0oooo00<0AX:d0?ooo`3oool0103oool0
0`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool0
0`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool0
0`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool0
0`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool0
0`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool0
0`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool02P3oool4
04J2]8h0oooo00<000000?ooo`3oool0>P3oool005@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo06H0oooo1016P[@60?ooo`0304J2]03oool0oooo
00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo
00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo
00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo
00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo
00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo
00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo
0080oooo1@16P[@20?ooo`H0AX:dS@3oool00`000000oooo0?ooo`0j0?ooo`00E03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo2P0000000`16P[@000000000000500000003
04J2]0000000000000@0000000<0AX:d0000000000001@0000000`16P[@000000000000400000003
04J2]0000000000000@0000000<0AX:d0000000000001@0000000`16P[@000000000000400000003
04J2]0000000000000D0000000<0AX:d000000000000100000000`16P[@000000000000500000003
04J2]0000000000000@0000000<0AX:d0000000000001@0000000`16P[@000000000000400000003
04J2]0000000000000D0000000<0AX:d000000000000100000000`16P[@000000000000500000003
04J2]0000000000000@0000000<0AX:d000000000000100000000`16P[@000000000000500000003
04J2]0000000000000@0000000<0AX:d0000000000001@0000000`16P[@000000000000400000003
04J2]0000000000000D0000000<0AX:d000000000000100000000`16P[@000000000000500000003
04J2]0000000000000@0000000<0AX:d0000000000001@0000000`16P[@000000000000400000003
04J2]0000000000000@0000000<0AX:d0000000000001@0000000`16P[@000000000000400000003
04J2]0000000000000D0000000<0AX:d0000000000000P00000504J2]0<000001@16P[@400000003
04J2]0000000000000D0000000<0AX:d000000000000100000000`16P[@000000000000500000003
04J2]0000000000000@0000000<0AX:d0000000000001@0000000`16P[@000000000000400000003
04J2]0000000000000@0000000<0AX:d0000000000001@0000000`16P[@000000000000400000003
04J2]0000000000000D0000000<0AX:d000000000000100000000`16P[@000000000000500000003
04J2]0000000000000@0000000<0AX:d0000000000001@0000000`16P[@000000000000400000003
04J2]0000000000000D0000000<0AX:d000000000000100000000`16P[@0000000000008000003`0
oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo
0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`050?ooo`0304J2]03oool0oooo09H0oooo1P16P[@30?ooo`D0AX:d103oool00`16P[@0oooo
0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo
0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo
0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01`3oool00`000000oooo
0?ooo`0j0?ooo`00E03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0
AX:d0?ooo`3oool00`3oool404J2]9P0oooo1@16P[@30?ooo`@0AX:d0`3oool504J2]0D0oooo00<0
AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`070?ooo`030000003oool0oooo03X0oooo001D
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`05
0?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`05
0?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`04
0?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`03
0?ooo`D0AX:dU`3oool404J2]0/0oooo1@16P[@50?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01`3oool00`000000oooo0?ooo`0j0?ooo`00E03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo0`0000070?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?oo
o`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`020?ooo`H0AX:dY@3oool604J2]0D0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?oo
o`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?oo
o`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?oo
o`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`070?ooo`030000003oool0oooo03X0oooo001E0?ooo`@0
0000203oool00`000000oooo0?ooo`070?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3o
ool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3o
ool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3o
ool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3o
ool0103oool00`16P[@0oooo0?ooo`020?ooo`H0AX:dYP3oool504J2]0D0oooo00<0AX:d0?ooo`3o
ool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3o
ool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3o
ool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3o
ool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3o
ool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3o
ool0103oool00`16P[@0oooo0?ooo`070?ooo`030000003oool0oooo03X0oooo001Q0?ooo`030000
003oool0oooo00L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2
]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2
]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2
]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2
]03oool0oooo0080oooo1@16P[BW0?ooo`@0AX:d1P3oool00`16P[@0oooo0?ooo`040?ooo`0304J2
]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2
]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2
]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2
]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2
]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2
]03oool0oooo00L0oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?ooo`3oool01`3o
ool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3o
ool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3o
ool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103o
ool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo0080oooo1@16P[Bf0?ooo`@0AX:d1@3o
ool00`16P[@0oooo0?ooo`030?ooo`@0AX:d1@3oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03o
ool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03o
ool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03o
ool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03o
ool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03o
ool0oooo00L0oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?ooo`3oool01`3oool0
0`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool0
0`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool0
0`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool0
0`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo0080oooo1@16P[Bf0?ooo`D0AX:d103oool0
0`16P[@0oooo0?ooo`030?ooo`D0AX:d103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0
oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0
oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0
oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0
oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0
oooo00L0oooo00<000000?ooo`3oool0>P3oool00640oooo0`0000070?ooo`0304J2]03oool0oooo
00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo
00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo
00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo
00D0oooo00@0AX:d0?ooo`3oool0oooo1P16P[Be0?ooo`H0AX:d103oool00`16P[@0oooo0?ooo`02
0?ooo`H0AX:d0P3oool404J2]0H0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`04
0?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`05
0?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`04
0?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`05
0?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01`3oool00`000000oooo0?ooo`0j
0?ooo`00H@3oool00`000000oooo0?ooo`070?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?oo
o`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?oo
o`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?oo
o`3oool00P3oool504J2];H0oooo1@16P[@20?ooo`@0AX:d0`3oool604J2]080oooo1@16P[@50?oo
o`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?oo
o`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?oo
o`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?oo
o`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?oo
o`0304J2]03oool0oooo00L0oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?ooo`3o
ool01`3oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3o
ool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3o
ool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3o
ool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo0080oooo1016P[Bg0?ooo`@0
AX:d0`3oool504J2]080oooo1@16P[@20?ooo`H0AX:d1@3oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`03
04J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`070?ooo`03
0000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool0
1@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0
103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0
103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0
0`3oool404J2]<@0oooo1P16P[@:0?ooo`D0AX:d1@3oool00`16P[@0oooo0?ooo`020?ooo`@0AX:d
0`3oool504J2]0D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2
]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2
]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2
]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01`3oool00`000000oooo0?ooo`0j0?ooo`00H@3o
ool3000000L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03o
ool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03o
ool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03o
ool0oooo00@0oooo00<0AX:d0?ooo`3oool00`3oool504J2]<@0oooo1@16P[@:0?ooo`@0AX:d1P3o
ool00`16P[@0oooo0?ooo`020?ooo`D0AX:d0P3oool504J2]0D0oooo00<0AX:d0?ooo`3oool0103o
ool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3o
ool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103o
ool00`16P[@0oooo0?ooo`030?ooo`@0AX:d1@3oool00`16P[@0oooo0?ooo`070?ooo`030000003o
ool0oooo03X0oooo00190?ooo`@00000103oool00`000000oooo0?ooo`06000000L0oooo00<00000
0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`020?ooo`H0AX:da03oool404J2]1<0oooo1016P[@2
0?ooo`H0AX:d00<0oooo04J2]016P[@01016P[@50?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo0080oooo1016P[@4
0?ooo`D0AX:d103oool00`16P[@0oooo0?ooo`070?ooo`030000003oool0oooo03X0oooo00180?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?oo
o`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?oo
o`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?oo
o`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool00`3oool504J2]=/0oooo1@16P[@20?oo
o`D0AX:d0P3oool504J2]0D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?oo
o`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool00`3oool304J2]0H0oooo00<0AX:d0?oo
o`3oool00`3oool404J2]0<0oooo1@16P[@20?ooo`H0AX:d0P3oool404J2]0P0oooo00<000000?oo
o`3oool0>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`050?ooo`03
04J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`030?ooo`@0
AX:df`3oool604J2]080oooo1016P[@30?ooo`D0AX:d1@3oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`030?ooo`@0
AX:d0`3oool504J2]0<0oooo1@16P[@00`3oool0AX:d04J2]00404J2]080oooo1P16P[@20?ooo`D0
AX:d1`3oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool4000000H0oooo1@1oOgl30?ooo`D0Ogmo
0P3oool00`16P[@0Ogmo07moO`0307moO`80oooo00<0AX:d0?ooo`1oOgl0101oOgl00`16P[@0oooo
0?ooo`0507moO`<0oooo1@1oOgl30?ooo`D0Ogmo0`3oool507moO`<0oooo1@1oOgl30?ooo`H0Ogmo
0`3oool507moO`<0oooo1@1oOgl30?ooo`D0Ogmo0`3oool507moO`<0oooo1@1oOgl30?ooo`D0Ogmo
0`3oool607moO`<0oooo1@1oOgl30?ooo`D0Ogmo0`3oool507moO`<0oooo1@1oOgl30?ooo`D0Ogmo
0`3oool507moO`<0oooo1P1oOgl30?ooo`D0Ogmo0`3oool507moO`<0oooo1@1oOgl30?ooo`D0Ogmo
0`3oool507moO`<0oooo1@1oOgl40?ooo`D0Ogmo0`3oool507moO`<0oooo1@1oOgl30?ooo`D0Ogmo
0`3oool507moO`<0oooo1@1oOgl30?ooo`D0Ogmo1016P[@507moO`<0oooo1@1oOgl30?ooo`D0Ogmo
0`3oool507moO`<0oooo1@1oOgl20?ooo`0304J2]01oOgl0Ogmo00<0Ogmo00<0oooo04J2]016P[@0
1@1oOgl404J2]0D0Ogmo0`16P[@507moO`<0AX:d1@1oOgl304J2]0D0Ogmo0`16P[@70?ooo`030000
003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool01@3o
ool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103o
ool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103o
ool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0hP3o
ool504J2]180oooo1016P[@50?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool00P3o
ool504J2]0<0oooo1@16P[@20?ooo`D0AX:d0P3oool604J2]080oooo1016P[@;0?ooo`D0AX:d1`3o
ool00`000000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`0304J2]03oool0
oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0
oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0
oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`020?ooo`D0AX:dn@3oool5
04J2]080oooo1@16P[@30?ooo`@0AX:d0P3oool604J2]0<0oooo1@16P[@20?ooo`D0AX:d0P3oool5
04J2]180oooo1016P[@80?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo
00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo
00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo
0080oooo1@16P[Ch0?ooo`H0AX:d0P3oool504J2]080oooo1P16P[@20?ooo`D0AX:d0`3oool404J2
]0<0oooo1016P[@V0?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0
oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0
oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0
oooo00@0AX:d0?ooo`3oool0oooo1P16P[Ci0?ooo`D0AX:d00<0oooo04J2]016P[@01016P[@30?oo
o`D0AX:d0P3oool404J2]3D0oooo00<000000?ooo`3oool0>P3oool004P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool3000000L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`03
04J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`03
04J2]03oool0oooo0080oooo1@16P[Ci0?ooo`D0AX:d0P3oool504J2]0<0oooo1@16P[@k0?ooo`03
0000003oool0oooo03X0oooo00190?ooo`@00000203oool4000000P0oooo00<000000?ooo`3oool0
1`3oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0
1@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0
1@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0
0P3oool404J2]?`0oooo0P16P[@30?ooo`@0AX:d103oool404J2]3`0oooo00<000000?ooo`3oool0
>P3oool00640oooo00<000000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03o
ool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03o
ool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03o
ool0oooo00D0oooo00<0AX:d0?ooo`3oool0o`3ooom@0?ooo`030000003oool0oooo03X0oooo001Q
0?ooo`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`04
0?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`04
0?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`05
0?ooo`0304J2]03oool0oooo0?l0ooooD03oool00`000000oooo0?ooo`0j0?ooo`00H@3oool30000
00L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo
00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo
00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo
0?l0ooooD03oool00`000000oooo0?ooo`0j0?ooo`00H@3oool00`000000oooo0?ooo`070?ooo`03
04J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`03
04J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`030?ooo`@0
AX:d1@3oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo0?l0ooooD03oool00`000000
oooo0?ooo`0j0?ooo`00H@3oool00`000000oooo0?ooo`070?ooo`0304J2]03oool0oooo00D0oooo
00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo
00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`030?ooo`D0AX:d0P3oool504J2]0D0oooo
00<0AX:d0?ooo`3oool0o`3ooom@0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`030000003o
ool0oooo00L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03o
ool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03o
ool0oooo0080oooo1P16P[@20?ooo`D0AX:d1@3oool00`16P[@0oooo0?ooo`3o0?oooe00oooo00<0
00000?ooo`3oool0>P3oool00640oooo0`0000070?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`030?ooo`D0AX:d00<0oooo04J2]016P[@01016P[@5
0?ooo`0304J2]03oool0oooo0?l0ooooD03oool00`000000oooo0?ooo`0j0?ooo`00B@3oool40000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo
00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo
00<0oooo1016P[@30?ooo`D0AX:d0`3oool404J2]?l0ooooD@3oool00`000000oooo0?ooo`0j0?oo
o`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3o
ool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3o
ool0103oool00`16P[@0oooo0?ooo`0:0?ooo`@0AX:d103oool504J2]?l0ooooD03oool00`000000
oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
1`0000070?ooo`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo
0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`040?ooo`0304J2]03oool0oooo0140oooo1P16P[Co0?oooe00oooo00<000000?ooo`3oool0
>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`0304J2]03o
ool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03o
ool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`0B0?ooo`D0AX:do`3o
oom@0?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000P0oooo100000060?ooo`0304J2]03o
ool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03o
ool0oooo00@0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`0B0?ooo`@0AX:do`3o
oomA0?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00L0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0
AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo0?l0ooooI`3o
ool00`000000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`070?ooo`0304J2]03o
ool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03o
ool0oooo00@0oooo00<0AX:d0?ooo`3oool00P3oool504J2]?l0ooooI`3oool00`000000oooo0?oo
o`0j0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`000000203oool00`000000oooo0?ooo`070?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d
0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d
0?ooo`3oool00P3oool504J2]?l0ooooI`3oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`<000001`3oool00`16
P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16
P[@0oooo0?ooo`040?ooo`0404J2]03oool0oooo0?ooo`H0AX:do`3ooomW0?ooo`030000003oool0
oooo03X0oooo00190?ooo`@000002`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo
00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`020?ooo`D0AX:do`3ooomW0?oo
o`030000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3o
ool01@3oool00`16P[@0oooo0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3o
ool0103oool00`16P[@0oooo0?ooo`020?ooo`D0AX:do`3ooomW0?ooo`030000003oool0oooo03X0
oooo001Q0?ooo`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo
0?ooo`040?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo
0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool0>P3oool00640oooo0`0000070?ooo`0304J2]03o
ool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03o
ool0oooo00@0oooo00<0AX:d0?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo03X0oooo001Q
0?ooo`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`04
0?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0103oool00`16P[@0oooo0?ooo`3o
0?ooofh0oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?ooo`3oool01`3oool00`16
P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo00@0oooo00<0AX:d0?ooo`3oool01@3oool00`16
P[@0oooo0?ooo`020?ooo`@0AX:do`3ooom_0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`03
0000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`020?ooo`@0
AX:d103oool404J2]080oooo1P16P[Co0?ooofh0oooo00<000000?ooo`3oool0>P3oool00640oooo
00<000000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03oool0oooo0080oooo
1@16P[@30?ooo`D0AX:d0P3oool504J2]?l0ooooKP3oool00`000000oooo0?ooo`0j0?ooo`00B@3o
ool4000000@0oooo00@000000?ooo`3oool0oooo100000080?ooo`<000001`3oool00`16P[@0oooo
0?ooo`050?ooo`0404J2]03oool0oooo0?ooo`H0AX:d0P3oool604J2]080oooo1@16P[Co0?ooofh0
oooo00<000000?ooo`3oool0>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool00P3oool504J2]080oooo
1P16P[@20?ooo`@0AX:do`3ooom_0?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`050?ooo`0304J2]03o
ool0oooo0080oooo1016P[@30?ooo`D0AX:do`3ooomf0?ooo`030000003oool0oooo03X0oooo0018
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`05
0?ooo`0304J2]03oool0oooo0?l0ooooQ03oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo
00D0oooo100000060?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0o`3ooon40?oo
o`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo00000002000000P0oooo00<000000?ooo`3oool01`3oool00`16P[@0
oooo0?ooo`050?ooo`0304J2]03oool0oooo0?l0ooooQ03oool00`000000oooo0?ooo`0j0?ooo`00
B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`070?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0
o`3ooon40?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<0
AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?ooo`3o0?oooh@0oooo00<000000?ooo`3oool0>P3o
ool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`050000003oool0
oooo0?ooo`0000001`3oool3000000L0oooo00<0AX:d0?ooo`3oool01@3oool00`16P[@0oooo0?oo
o`3o0?oooh@0oooo00<000000?ooo`3oool0>P3oool004T0oooo100000090?ooo`<00000203oool0
0`000000oooo0?ooo`070?ooo`0304J2]03oool0oooo00D0oooo00<0AX:d0?ooo`3oool0o`3ooon4
0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo00L0oooo00<0AX:d0?oo
o`3oool00`3oool404J2]?l0ooooQ@3oool00`000000oooo0?ooo`0j0?ooo`00H@3oool00`000000
oooo0?ooo`070?ooo`0304J2]03oool0oooo0080oooo1P16P[Co0?oooh@0oooo00<000000?ooo`3o
ool0>P3oool00640oooo00<000000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`020?ooo`H0AX:d
o`3ooon40?ooo`030000003oool0oooo03X0oooo001Q0?ooo`<000001`3oool00`16P[@0oooo0?oo
o`020?ooo`H0AX:do`3ooon40?ooo`030000003oool0oooo03X0oooo001Q0?ooo`030000003oool0
oooo00L0oooo00<0AX:d0?ooo`3oool00P3oool504J2]?l0ooooQ@3oool00`000000oooo0?ooo`0j
0?ooo`00H@3oool00`000000oooo0?ooo`070?ooo`0304J2]03oool0oooo0?l0ooooS03oool00`00
0000oooo0?ooo`0j0?ooo`00H@3oool00`000000oooo0?ooo`070?ooo`0304J2]03oool0oooo0?l0
ooooS03oool00`000000oooo0?ooo`0j0?ooo`00H@3oool3000000L0oooo00<0AX:d0?ooo`3oool0
o`3ooon<0?ooo`030000003oool0oooo03X0oooo00190?ooo`@00000103oool010000000oooo0?oo
o`3oool4000000P0oooo00<000000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`3o0?oooh`0oooo
00<000000?ooo`3oool0>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`0304J2]03oool0oooo0?l0ooooS03oool00`000000oooo0?ooo`0j0?ooo`00B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool0o`3ooon<
0?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo100000060?oo
o`0304J2]03oool0oooo0?l0ooooS03oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool0o`3ooon<0?ooo`03
0000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool4000000P0oooo00<000000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`3o0?oooh`0oooo
00<000000?ooo`3oool0>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`0304J2]03oool0oooo0?l0ooooS03oool00`000000oooo0?ooo`0j0?ooo`00B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool0o`3ooon<
0?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`0000070?oo
o`0304J2]03oool0oooo0?l0ooooS03oool00`000000oooo0?ooo`0j0?ooo`00B@3oool4000000P0
oooo100000080?ooo`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool0o`3ooon<0?ooo`03
0000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo00L0oooo00<0AX:d0?ooo`3oool0
o`3ooon<0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`030000003oool0oooo00L0oooo00<0
AX:d0?ooo`3oool0o`3ooon<0?ooo`030000003oool0oooo03X0oooo001Q0?ooo`<000001`3oool0
0`16P[@0oooo0?ooo`3o0?oooh`0oooo00<000000?ooo`3oool0>P3oool00640oooo00<000000?oo
o`3oool01`3oool00`16P[@0oooo0?ooo`3o0?oooh`0oooo00<000000?ooo`3oool0>P3oool00640
oooo00<000000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`3o0?oooh`0oooo00<000000?ooo`3o
ool0>P3oool00640oooo00<000000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`3o0?oooh`0oooo
00<000000?ooo`3oool0>P3oool00640oooo0`0000070?ooo`0304J2]03oool0oooo0?l0ooooS03o
ool00`000000oooo0?ooo`0j0?ooo`00E`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<0AX:d0?ooo`3oool0o`3ooon<0?ooo`030000003oool0oooo03X0oooo001G0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`16P[@0oooo0?ooo`3o0?oo
oh`0oooo00<000000?ooo`3oool0>P3oool005L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`050?ooo`@0AX:do`3ooon=0?ooo`030000003oool0oooo03X0oooo001G0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool604J2]?l0ooooS03oool00`000000oooo
0?ooo`0j0?ooo`00E`3oool00`000000oooo0?ooo`070?ooo`@00000103oool504J2]?l0ooooS03o
ool00`000000oooo0?ooo`0j0?ooo`00E`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00D0oooo1@16P[Co0?oooh`0oooo00<000000?ooo`3oool0>P3oool005L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`@0AX:do`3ooon=0?ooo`030000003oool0oooo
03X0oooo001E0?ooo`030000003oool0000000T0ooooo`00002J000003`0oooo001F0?ooo`800000
o`3ooooO0?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooomd0oooo003o0?ooool0oooo>03oool0
0?l0ooooo`3ooolh0?ooo`00o`3ooooo0?ooocP0oooo0000\
\>"],
  ImageRangeCache->{{{0, 565}, {168.75, 0}} -> {-14.4314, -0.843695, \
0.134053, 0.0115322}}]
}, Open  ]],

Cell["\<\
When looking at all the sundays in the data there is a significant negative \
autocorrelation around the 26th week, indicating a half year effect. It is \
interessting that these autocorrelation are not so clearly visible for other \
days of the week (yet?)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DayOfWeek[dates[\([6]\)]]\)], "Input"],

Cell[BoxData[
    \("Wednesday"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AutoCorrelationPlot[peak[\([Range[6, Length[peak], 7]]\)], 52, 
        AspectRatio \[Rule] 0.3];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0238095 0.018315 0.0553693 0.237488 [
[.02381 -0.0125 -5.90625 -17.75 ]
[.02381 -0.0125 5.90625 0 ]
[.20696 -0.0125 -9.8125 -17.75 ]
[.20696 -0.0125 9.8125 0 ]
[.39011 -0.0125 -9.8125 -17.75 ]
[.39011 -0.0125 9.8125 0 ]
[.57326 -0.0125 -9.8125 -17.75 ]
[.57326 -0.0125 9.8125 0 ]
[.75641 -0.0125 -9.8125 -17.75 ]
[.75641 -0.0125 9.8125 0 ]
[.93956 -0.0125 -9.8125 -17.75 ]
[.93956 -0.0125 9.8125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.7188 -35.5 ]
[.5 -0.0125 13.7188 -17.75 ]
[-0.0125 .00787 -33.25 -8.875 ]
[-0.0125 .00787 0 8.875 ]
[-0.0125 .05537 -11.8125 -8.875 ]
[-0.0125 .05537 0 8.875 ]
[-0.0125 .10287 -23.5625 -8.875 ]
[-0.0125 .10287 0 8.875 ]
[-0.0125 .15036 -23.5625 -8.875 ]
[-0.0125 .15036 0 8.875 ]
[-0.0125 .19786 -23.5625 -8.875 ]
[-0.0125 .19786 0 8.875 ]
[-0.0125 .24536 -23.5625 -8.875 ]
[-0.0125 .24536 0 8.875 ]
[-0.0125 .29286 -11.8125 -8.875 ]
[-0.0125 .29286 0 8.875 ]
[ 0 0 -0.125 0 ]
[ 0 .3 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20696 0 m
.20696 .00625 L
s
gsave
.20696 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.39011 0 m
.39011 .00625 L
s
gsave
.39011 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.57326 0 m
.57326 .00625 L
s
gsave
.57326 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.75641 0 m
.75641 .00625 L
s
gsave
.75641 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.93956 0 m
.93956 .00625 L
s
gsave
.93956 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.06044 0 m
.06044 .00375 L
s
.09707 0 m
.09707 .00375 L
s
.1337 0 m
.1337 .00375 L
s
.17033 0 m
.17033 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.28022 0 m
.28022 .00375 L
s
.31685 0 m
.31685 .00375 L
s
.35348 0 m
.35348 .00375 L
s
.42674 0 m
.42674 .00375 L
s
.46337 0 m
.46337 .00375 L
s
.5 0 m
.5 .00375 L
s
.53663 0 m
.53663 .00375 L
s
.60989 0 m
.60989 .00375 L
s
.64652 0 m
.64652 .00375 L
s
.68315 0 m
.68315 .00375 L
s
.71978 0 m
.71978 .00375 L
s
.79304 0 m
.79304 .00375 L
s
.82967 0 m
.82967 .00375 L
s
.8663 0 m
.8663 .00375 L
s
.90293 0 m
.90293 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.7188 -39.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lag) show
86.438 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00787 m
.00625 .00787 L
s
gsave
-0.0125 .00787 -94.25 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .05537 m
.00625 .05537 L
s
gsave
-0.0125 .05537 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .10287 m
.00625 .10287 L
s
gsave
-0.0125 .10287 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .15036 m
.00625 .15036 L
s
gsave
-0.0125 .15036 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .19786 m
.00625 .19786 L
s
gsave
-0.0125 .19786 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .24536 m
.00625 .24536 L
s
gsave
-0.0125 .24536 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .29286 m
.00625 .29286 L
s
gsave
-0.0125 .29286 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01975 m
.00375 .01975 L
s
0 .03162 m
.00375 .03162 L
s
0 .04349 m
.00375 .04349 L
s
0 .06724 m
.00375 .06724 L
s
0 .07912 m
.00375 .07912 L
s
0 .09099 m
.00375 .09099 L
s
0 .11474 m
.00375 .11474 L
s
0 .12662 m
.00375 .12662 L
s
0 .13849 m
.00375 .13849 L
s
0 .16224 m
.00375 .16224 L
s
0 .17411 m
.00375 .17411 L
s
0 .18599 m
.00375 .18599 L
s
0 .20974 m
.00375 .20974 L
s
0 .22161 m
.00375 .22161 L
s
0 .23349 m
.00375 .23349 L
s
0 .25723 m
.00375 .25723 L
s
0 .26911 m
.00375 .26911 L
s
0 .28098 m
.00375 .28098 L
s
.25 Mabswid
0 0 m
0 .3 L
s
0 .3 m
1 .3 L
s
1 0 m
1 .3 L
s
0 .05537 m
1 .05537 L
s
.274 .51 .706 r
.02381 .29286 m
.02381 .29286 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.5 Mabswid
.02381 .05537 m
.02381 .29286 L
s
.04212 .1475 m
.04212 .1475 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.04212 .05537 m
.04212 .1475 L
s
.06044 .09082 m
.06044 .09082 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.06044 .05537 m
.06044 .09082 L
s
.07875 .12332 m
.07875 .12332 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.07875 .05537 m
.07875 .12332 L
s
.09707 .14634 m
.09707 .14634 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.09707 .05537 m
.09707 .14634 L
s
.11538 .0756 m
.11538 .0756 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.11538 .05537 m
.11538 .0756 L
s
.1337 .05794 m
.1337 .05794 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.1337 .05537 m
.1337 .05794 L
s
.15201 .07133 m
.15201 .07133 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.15201 .05537 m
.15201 .07133 L
s
.17033 .08145 m
.17033 .08145 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.17033 .05537 m
.17033 .08145 L
s
.18864 .04905 m
.18864 .04905 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.18864 .05537 m
.18864 .04905 L
s
.20696 .04354 m
.20696 .04354 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.20696 .05537 m
.20696 .04354 L
s
.22527 .07278 m
.22527 .07278 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.22527 .05537 m
.22527 .07278 L
s
.24359 .05644 m
.24359 .05644 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.24359 .05537 m
.24359 .05644 L
s
.2619 .04541 m
.2619 .04541 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.2619 .05537 m
.2619 .04541 L
s
.28022 .04264 m
.28022 .04264 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.28022 .05537 m
.28022 .04264 L
s
.29853 .07985 m
.29853 .07985 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.29853 .05537 m
.29853 .07985 L
s
.31685 .0413 m
.31685 .0413 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.31685 .05537 m
.31685 .0413 L
s
.33516 .02926 m
.33516 .02926 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.33516 .05537 m
.33516 .02926 L
s
.35348 .05003 m
.35348 .05003 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.35348 .05537 m
.35348 .05003 L
s
.37179 .09055 m
.37179 .09055 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.37179 .05537 m
.37179 .09055 L
s
.39011 .04797 m
.39011 .04797 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.39011 .05537 m
.39011 .04797 L
s
.40842 .04823 m
.40842 .04823 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.40842 .05537 m
.40842 .04823 L
s
.42674 .05485 m
.42674 .05485 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.42674 .05537 m
.42674 .05485 L
s
.44505 .05481 m
.44505 .05481 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.44505 .05537 m
.44505 .05481 L
s
.46337 .04829 m
.46337 .04829 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.46337 .05537 m
.46337 .04829 L
s
.48168 .06576 m
.48168 .06576 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.48168 .05537 m
.48168 .06576 L
s
.5 .0787 m
.5 .0787 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.5 .05537 m
.5 .0787 L
s
.51832 .0757 m
.51832 .0757 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.51832 .05537 m
.51832 .0757 L
s
.53663 .06519 m
.53663 .06519 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.53663 .05537 m
.53663 .06519 L
s
.55495 .06751 m
.55495 .06751 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.55495 .05537 m
.55495 .06751 L
s
.57326 .07911 m
.57326 .07911 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.57326 .05537 m
.57326 .07911 L
s
.59158 .05893 m
.59158 .05893 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.59158 .05537 m
.59158 .05893 L
s
.60989 .07884 m
.60989 .07884 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.60989 .05537 m
.60989 .07884 L
s
.62821 .06748 m
.62821 .06748 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.62821 .05537 m
.62821 .06748 L
s
.64652 .04756 m
.64652 .04756 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.64652 .05537 m
.64652 .04756 L
s
.66484 .04308 m
.66484 .04308 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.66484 .05537 m
.66484 .04308 L
s
.68315 .05579 m
.68315 .05579 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.68315 .05537 m
.68315 .05579 L
s
.70147 .03653 m
.70147 .03653 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.70147 .05537 m
.70147 .03653 L
s
.71978 .04651 m
.71978 .04651 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.71978 .05537 m
.71978 .04651 L
s
.7381 .04243 m
.7381 .04243 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.7381 .05537 m
.7381 .04243 L
s
.75641 .04902 m
.75641 .04902 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.75641 .05537 m
.75641 .04902 L
s
.77473 .04326 m
.77473 .04326 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.77473 .05537 m
.77473 .04326 L
s
.79304 .02803 m
.79304 .02803 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.79304 .05537 m
.79304 .02803 L
s
.81136 .02436 m
.81136 .02436 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.81136 .05537 m
.81136 .02436 L
s
.82967 .04381 m
.82967 .04381 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.82967 .05537 m
.82967 .04381 L
s
.84799 .04097 m
.84799 .04097 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.84799 .05537 m
.84799 .04097 L
s
.8663 .03642 m
.8663 .03642 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.8663 .05537 m
.8663 .03642 L
s
.88462 .04842 m
.88462 .04842 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.88462 .05537 m
.88462 .04842 L
s
.90293 .05247 m
.90293 .05247 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.90293 .05537 m
.90293 .05247 L
s
.92125 .04718 m
.92125 .04718 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.92125 .05537 m
.92125 .04718 L
s
.93956 .04934 m
.93956 .04934 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.93956 .05537 m
.93956 .04934 L
s
.95788 .08499 m
.95788 .08499 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.95788 .05537 m
.95788 .08499 L
s
.97619 .07228 m
.97619 .07228 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.97619 .05537 m
.97619 .07228 L
s
.5 g
[ .01 ] 0 setdash
.02381 .1036 m
.97619 .10263 L
s
.02381 .00714 m
.97619 .00811 L
s
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{684.75, 205.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:/0000cB000`400?l00000o`00003oo`3ooooo
0?ooojh0oooo003o0?ooool0oooo[P3oool00?l0ooooL03oool400000?l0oooo>P3oool00?l0oooo
K`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo=`3oool00?l0ooooM03o
ool00`000000oooo0?ooo`3o0?ooocL0oooo003o0?oooel0oooo1`0000020?ooo`<0000000<0oooo
0000003oool00P3oool3000000030?ooo`000000oooo0?l0oooo>03oool00?l0ooooG`3oool00`00
0000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000oooo0?ooo`3o
ool200000?l0oooo>@3oool00?l0ooooG`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooocL0oooo003o
0?oooel0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooocL0oooo003o0?oooel0oooo00<00000
0?ooo`3oool01`3oool400000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o
0?ooocL0oooo003o0?oooel0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0?l0oooo=`3oool00?l0ooooG`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool200000?l0oooo>@3oool0
0?l0ooooG`3oool00`000000oooo0?ooo`060?ooo`@00000103oool3000000030?ooo`000000oooo
0?l0oooo>03oool00?l0ooooG`3oool00`000000oooo0?ooo`3o0?oood`0oooo003o0?oooel0oooo
00<000000?ooo`3oool0o`3ooom<0?ooo`00o`3ooooo0?ooojh0oooo003o0?ooool0oooo[P3oool0
0?l0ooooo`3ooon^0?ooo`00o`3ooooo0?ooojh0oooo003o0?ooool0oooo[P3oool00?l0ooooo`3o
oon^0?ooo`00o`3ooooo0?ooojh0oooo003o0?ooool0oooo[P3oool006h0oooo1000001J0?ooo`03
0000003oool0oooo00<0oooo1000001C0?ooo`H000000`3oool4000005@0oooo100000040?ooo`@0
0000E`3oool00`000000oooo0?ooo`020?ooo`@00000E03oool4000000@0oooo1000001F0?ooo`00
K@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0500oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0D`3oool006d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`1?0?ooo`L000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo05<0oooo001]0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0E@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
E@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05<0oooo001]0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0E03oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0E@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0500oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0E@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05<0oooo001]
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0E@3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0580oooo0`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0D@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0D`3oool006d0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1E0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0E@3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0540oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0500oooo1@0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0D`3oool006d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1C0?ooo`00K@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo05H0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0D03oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
D`3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1C0?ooo`00KP3o
ool4000005X0oooo00<000000?ooo`3oool00`3oool4000005@0oooo100000040?ooo`@00000E03o
ool4000000@0oooo1000001G0?ooo`030000003oool0oooo0080oooo1000001D0?ooo`D000000`3o
ool4000005H0oooo003o0?ooool0oooo[P3oool00?l0ooooo`3ooon^0?ooo`00o`3ooooo0?ooojh0
oooo003o0?ooool0oooo[P3oool00?l0ooooo`3ooon^0?ooo`00o`3ooooo0?ooojh0oooo003o0?oo
ool0oooo[P3oool00?l0ooooo`3ooon^0?ooo`00o`3ooooo0?ooojh0oooo00190?ooo`@00000103o
ool00`000000oooo0?ooo`06000000T0ooooo`00003o000000l00000?03oool004P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo03X0oooo000n0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo05d0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo05d0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`@000002@3oool607moO`@0oooo1P1oOgl50?ooo`H0Ogmo
103oool607moO`@0oooo1`1oOgl40?ooo`H0Ogmo103oool707moO`@0oooo1P1oOgl40?ooo`L0Ogmo
103oool607moO`@0oooo1`1oOgl40?ooo`H0Ogmo103oool707moO`@0oooo1P1oOgl40?ooo`L0Ogmo
103oool607moO`@0oooo1`1oOgl40?ooo`H0Ogmo103oool707moO`@0oooo1P1oOgl40?ooo`H0Ogmo
1@3oool607moO`@0oooo1P1oOgl50?ooo`H0Ogmo103oool607moO`D0oooo1P1oOgl40?ooo`H0Ogmo
1@3oool607moO`@0oooo1P1oOgl50?ooo`H0Ogmo103oool607moO`D0oooo1P1oOgl40?ooo`H0Ogmo
1@3oool607moO`@0oooo1P1oOgl40?ooo`L0Ogmo103oool607moO`@0oooo1`1oOgl40?ooo`H0Ogmo
103oool707moO`@0oooo1P1oOgl40?ooo`L0Ogmo103oool607moO`@0oooo1`1oOgl40?ooo`H0Ogmo
103oool707moO`@0oooo1P1oOgl40?ooo`L0Ogmo303oool00`000000oooo0?ooo`0j0?ooo`00B03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3o0?ooool0oooo2`3oool00`000000oooo0?ooo`0j0?ooo`00B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo2`3oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooo`3oool;0?ooo`030000003oool0oooo
03X0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`/0
oooo00<000000?ooo`3oool0>P3oool004T0oooo100000080?ooo`@000002P3oool00`000000oooo
0?ooo`3o0?ooool0oooo2`3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool300000?l0ooooo`3o
ool;0?ooo`030000003oool0oooo03X0oooo001S0?ooo`030000003oool0oooo0?l0ooooY@3oool5
04J2]600oooo00<000000?ooo`3oool0>P3oool006<0oooo00<000000?ooo`3oool0o`3ooonU0?oo
o`D0AX:dH03oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`2[0?ooo`<0
AX:dk@3oool404J2]0@0oooo1P16P[AP0?ooo`030000003oool0oooo03X0oooo001S0?ooo`030000
003oool0oooo0:/0oooo1016P[C/0?ooo`D0AX:d103oool504J2]600oooo00<000000?ooo`3oool0
>P3oool006<0oooo00<000000?ooo`3oool0ZP3oool604J2]>X0oooo1P16P[@40?ooo`D0AX:dH03o
ool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`2[0?ooo`D0AX:dj`3oool5
04J2]0H0oooo00<0AX:d0?ooo`3oool0H03oool00`000000oooo0?ooo`0j0?ooo`00H`3oool30000
0:/0oooo1@16P[Bk0?ooo`@0AX:d;03oool404J2]0L0oooo00<0AX:d0?ooo`3oool0603oool504J2
]4<0oooo00<000000?ooo`3oool0>P3oool006<0oooo00<000000?ooo`3oool0[@3oool204J2];`0
oooo1@16P[@]0?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool0603oool504J2]4<0
oooo00<000000?ooo`3oool0>P3oool006<0oooo00<000000?ooo`3oool0[@3oool00`16P[@0oooo
0?ooo`2j0?ooo`H0AX:d;@3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo01L0oooo
1P16P[A30?ooo`030000003oool0oooo03X0oooo001S0?ooo`030000003oool0oooo08h0oooo0`16
P[@@0?ooo`D0AX:d1`3oool00`16P[@0oooo0?ooo`2k0?ooo`D0AX:d3P3oool404J2]1/0oooo00<0
AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`0?0?ooo`@0AX:d1@3oool504J2]4<0oooo00<0
00000?ooo`3oool0>P3oool006<0oooo00<000000?ooo`3oool0J03oool404J2]280oooo1016P[@?
0?ooo`D0AX:d1`3oool00`16P[@0oooo0?ooo`2X0?ooo`@0AX:d3`3oool404J2]0l0oooo1@16P[@>
0?ooo`D0AX:d1`3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00D0oooo1016P[@5
0?ooo`H0AX:d103oool404J2]4@0oooo00<000000?ooo`3oool0>P3oool006<0oooo00<000000?oo
o`3oool0J03oool504J2]1L0oooo1@16P[@40?ooo`H0AX:d3@3oool604J2]0L0oooo00<0AX:d0?oo
o`3oool0Z03oool504J2]100oooo00<0AX:d0?ooo`3oool03@3oool604J2]0h0oooo1@16P[@70?oo
o`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool01@3oool504J2]0@0oooo1P16P[@60?oo
o`0304J2]03oool0oooo04<0oooo00<000000?ooo`3oool0>P3oool006<0oooo0`00001W0?ooo`H0
AX:d5`3oool504J2]0D0oooo1@16P[@>0?ooo`D0AX:d1`3oool00`16P[@0oooo0?ooo`0H0?ooo`@0
AX:d1@3oool504J2]1P0oooo1016P[AL0?ooo`@0AX:d1@3oool604J2]100oooo00<0AX:d0?ooo`3o
ool0103oool504J2]0D0oooo1@16P[@=0?ooo`H0AX:d1`3oool00`16P[@0oooo0?ooo`060?ooo`03
04J2]03oool0oooo00@0oooo1P16P[@40?ooo`H0AX:d1P3oool00`16P[@0oooo0?ooo`0H0?ooo`@0
AX:d9`3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`1N0?ooo`@0AX:d
1@3oool604J2]1H0oooo1P16P[@50?ooo`D0AX:d3P3oool404J2]0P0oooo00<0AX:d0?ooo`3oool0
103oool504J2]0l0oooo1@16P[@40?ooo`D0AX:d603oool504J2]5/0oooo1@16P[@40?ooo`H0AX:d
403oool00`16P[@0oooo0?ooo`030?ooo`H0AX:d1@3oool504J2]0D0oooo1016P[@50?ooo`D0AX:d
1`3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00D0oooo1@16P[@40?ooo`D0AX:d
1`3oool00`16P[@0oooo0?ooo`050?ooo`@0AX:d3`3oool504J2]0D0oooo1016P[@M0?ooo`030000
003oool0oooo03X0oooo001E0?ooo`@000002P3oool00`000000oooo0?ooo`1N0?ooo`D0AX:d103o
ool504J2]1P0oooo1@16P[@50?ooo`@0AX:d4@3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03o
ool0oooo00@0oooo1@16P[@>0?ooo`H0AX:d0`3oool604J2]1L0oooo1P16P[AJ0?ooo`H0AX:d103o
ool504J2]140oooo00<0AX:d0?ooo`3oool0103oool504J2]0L0oooo0P16P[@60?ooo`D0AX:d103o
ool404J2]0P0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`050?ooo`@0AX:d203o
ool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00@0oooo1P16P[@=0?ooo`H0AX:d1@3o
ool504J2]1`0oooo00<000000?ooo`3oool0>P3oool005@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo05d0oooo1P16P[@70?ooo`0304J2]03oool0
oooo01L0oooo1@16P[@70?ooo`0304J2]03oool0oooo0100oooo00<0AX:d0?ooo`3oool01`3oool0
0`16P[@0oooo0?ooo`030?ooo`H0AX:d3P3oool604J2]0@0oooo1@16P[@H0?ooo`D0AX:dF`3oool5
04J2]0L0oooo00<0AX:d0?ooo`3oool0403oool00`16P[@0oooo0?ooo`040?ooo`D0AX:d1`3oool0
0`16P[@0oooo0?ooo`040?ooo`H0AX:d1P3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0
oooo00H0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0
oooo00H0oooo00<0AX:d0?ooo`3oool01@3oool504J2]0@0oooo1@16P[@50?ooo`D0AX:d103oool6
04J2]1`0oooo00<000000?ooo`3oool0>P3oool005@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo05h0oooo1@16P[@70?ooo`0304J2]03oool0oooo
01T0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`0@0?ooo`0304J2]03oool0oooo
00L0oooo00<0AX:d0?ooo`3oool0103oool504J2]0h0oooo1@16P[@50?ooo`D0AX:d1@3oool404J2
]0D0oooo1@16P[@50?ooo`D0AX:dF`3oool404J2]0P0oooo00<0AX:d0?ooo`3oool0103oool504J2
]0L0oooo00<0AX:d0?ooo`3oool0103oool504J2]0L0oooo00<0AX:d0?ooo`3oool0103oool604J2
]0H0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo
00L0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo
00D0oooo1@16P[@30?ooo`H0AX:d1@3oool404J2]0D0oooo1P16P[@L0?ooo`030000003oool0oooo
03X0oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`110?ooo`@0AX:d6@3oool404J2]0P0oooo00<0AX:d0?ooo`3oool03P3oool404J2]0L0
oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`0@0?ooo`0304J2]03oool0oooo00L0
oooo00<0AX:d0?ooo`3oool0103oool504J2]140oooo00<0AX:d0?ooo`3oool01P3oool204J2]0H0
oooo1@16P[@40?ooo`D0AX:d1`3oool204J2]5h0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0
oooo0?ooo`040?ooo`D0AX:d1`3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00L0
oooo00<0AX:d0?ooo`3oool0103oool504J2]0L0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0
oooo0?ooo`060?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0
oooo0?ooo`060?ooo`0304J2]03oool0oooo00D0oooo1016P[@50?ooo`D0AX:d1`3oool00`16P[@0
oooo0?ooo`040?ooo`D0AX:d7@3oool00`000000oooo0?ooo`0j0?ooo`00E03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo3@0000000`16P[@00000000000060000000304J2
]0000000000000L0000000<0AX:d0000000000001P0000000`16P[@00000000000070000000304J2
]0000000000000L0000000<0AX:d0000000000001000000504J2]0L0000000<0AX:d000000000000
1P0000000`16P[@00000000000070000000304J2]0000000000000L0000000<0AX:d000000000000
1P0000000`16P[@0000000000005000000D0AX:d1P0000000`16P[@00000000000070000000304J2
]0000000000000L0000000<0AX:d0000000000001P0000000`16P[@00000000000070000000304J2
]0000000000000H0000000<0AX:d0000000000001`0000000`16P[@00000000000070000000304J2
]0000000000000H0000000<0AX:d0000000000001000000604J2]0<000001P16P[@70000000304J2
]0000000000000L0000000<0AX:d0000000000001P0000000`16P[@00000000000070000000304J2
]0000000000000H0000000<0AX:d0000000000001`0000000`16P[@00000000000070000000304J2
]0000000000000@000001@16P[@70000000304J2]0000000000000H0000000<0AX:d000000000000
1`0000000`16P[@00000000000070000000304J2]0000000000000<000001P16P[@70000000304J2
]0000000000000H0000000<0AX:d0000000000001`0000000`16P[@00000000000070000000304J2
]0000000000000H0000000<0AX:d0000000000001`0000000`16P[@00000000000060000000304J2
]0000000000000L0000000<0AX:d0000000000001`0000000`16P[@00000000000060000000304J2
]0000000000000L0000000<0AX:d0000000000001000000504J2]0L0000000<0AX:d000000000000
1`0000000`16P[@00000000000060000000304J2]0000000000000L0000000<0AX:d000000000000
2P00000l0?ooo`00E03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00L0oooo00<0
AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo00L0oooo00<0
AX:d0?ooo`3oool00`3oool604J2]0L0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?oo
o`0J0?ooo`0304J2]03oool0oooo00@0oooo1P16P[@J0?ooo`0304J2]03oool0oooo02<0oooo00<0
AX:d0?ooo`3oool0603oool504J2]0@0oooo1@16P[@A0?ooo`0304J2]03oool0oooo00H0oooo00<0
AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00L0oooo00<0
AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`040?ooo`D0AX:d1`3oool00`16P[@0oooo0?oo
o`060?ooo`0304J2]03oool0oooo01P0oooo1@16P[A^0?ooo`D0AX:d6P3oool00`16P[@0oooo0?oo
o`070?ooo`0304J2]03oool0oooo00T0oooo00<000000?ooo`3oool0>P3oool005@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<0AX:d
0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d
0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo00@0oooo1@16P[@7
0?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool06P3oool00`16P[@0oooo0?ooo`05
0?ooo`D0AX:d6P3oool00`16P[@0oooo0?ooo`0S0?ooo`0304J2]03oool0oooo01P0oooo1016P[@5
0?ooo`D0AX:d4@3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d
0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d
0?ooo`3oool00`3oool604J2]0L0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`0H
0?ooo`D0AX:dS@3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo00T0oooo00<00000
0?ooo`3oool0>P3oool005@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`070?oo
o`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`070?oo
o`0304J2]03oool0oooo00@0oooo1@16P[@70?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?oo
o`3oool06P3oool00`16P[@0oooo0?ooo`050?ooo`@0AX:d6`3oool00`16P[@0oooo0?ooo`0S0?oo
o`0304J2]03oool0oooo03L0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`070?oo
o`0304J2]03oool0oooo00@0oooo1@16P[@70?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?oo
o`3oool0103oool504J2]0L0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`0J0?oo
o`80AX:dSP3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo00T0oooo00<000000?oo
o`3oool0>P3oool005@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`070?ooo`03
04J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`070?ooo`03
04J2]03oool0oooo00@0oooo1016P[@80?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3o
ool06P3oool00`16P[@0oooo0?ooo`0T0?ooo`0304J2]03oool0oooo02<0oooo00<0AX:d0?ooo`3o
ool0=@3oool404J2]0L0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`040?ooo`D0
AX:d1`3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo00@0oooo1016P[@80?ooo`03
04J2]03oool0oooo00@0oooo1016P[B[0?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?ooo`3o
ool02@3oool00`000000oooo0?ooo`0j0?ooo`00E@3oool4000000X0oooo00<000000?ooo`3oool0
2P3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?ooo`3oool0
1P3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?ooo`3oool0
403oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo01X0oooo00<0AX:d0?ooo`3oool0
903oool00`16P[@0oooo0?ooo`0S0?ooo`0304J2]03oool0oooo03@0oooo1P16P[@60?ooo`0304J2
]03oool0oooo00L0oooo00<0AX:d0?ooo`3oool00`3oool604J2]0D0oooo1016P[@80?ooo`0304J2
]03oool0oooo0100oooo00<0AX:d0?ooo`3oool0103oool504J2]:X0oooo00<0AX:d0?ooo`3oool0
1`3oool00`16P[@0oooo0?ooo`090?ooo`030000003oool0oooo03X0oooo001S0?ooo`<000002P3o
ool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?ooo`3oool01P3o
ool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?ooo`3oool0403o
ool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo01X0oooo00<0AX:d0?ooo`3oool0903o
ool00`16P[@0oooo0?ooo`0S0?ooo`0304J2]03oool0oooo03@0oooo1P16P[@60?ooo`0304J2]03o
ool0oooo00L0oooo00<0AX:d0?ooo`3oool0103oool504J2]0@0oooo1P16P[@70?ooo`0304J2]03o
ool0oooo0100oooo00<0AX:d0?ooo`3oool00`3oool604J2]:X0oooo00<0AX:d0?ooo`3oool01`3o
ool00`16P[@0oooo0?ooo`090?ooo`030000003oool0oooo03X0oooo001S0?ooo`030000003oool0
oooo00X0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0
oooo00H0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0
oooo00h0oooo1016P[@70?ooo`0304J2]03oool0oooo01P0oooo1@16P[@T0?ooo`0304J2]03oool0
oooo02<0oooo00<0AX:d0?ooo`3oool0=03oool604J2]0H0oooo00<0AX:d0?ooo`3oool01`3oool0
0`16P[@0oooo0?ooo`040?ooo`D0AX:d1@3oool504J2]0L0oooo00<0AX:d0?ooo`3oool0403oool0
0`16P[@0oooo0?ooo`040?ooo`D0AX:dZP3oool00`16P[@0oooo0?ooo`050?ooo`@0AX:d2P3oool0
0`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo
00H0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo
00L0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`0=0?ooo`H0AX:d1P3oool00`16
P[@0oooo0?ooo`0H0?ooo`D0AX:d903oool00`16P[@0oooo0?ooo`0S0?ooo`0304J2]03oool0oooo
03@0oooo1@16P[@70?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?ooo`3oool03P3oool504J2
]0L0oooo00<0AX:d0?ooo`3oool0403oool00`16P[@0oooo0?ooo`040?ooo`D0AX:dZP3oool00`16
P[@0oooo0?ooo`050?ooo`D0AX:d2@3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000
oooo0?ooo`0:0?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0
oooo0?ooo`060?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?ooo`3oool01@3oool404J2]0l0
oooo1@16P[@60?ooo`0304J2]03oool0oooo01L0oooo1P16P[@T0?ooo`0304J2]03oool0oooo02<0
oooo00<0AX:d0?ooo`3oool0@03oool00`16P[@0oooo0?ooo`050?ooo`@0AX:d3`3oool404J2]0P0
oooo00<0AX:d0?ooo`3oool0403oool00`16P[@0oooo0?ooo`040?ooo`D0AX:dZP3oool00`16P[@0
oooo0?ooo`040?ooo`H0AX:d2@3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo
0?ooo`0:0?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo
0?ooo`060?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?ooo`3oool01@3oool504J2]0h0oooo
1@16P[@60?ooo`0304J2]03oool0oooo01P0oooo1@16P[@T0?ooo`0304J2]03oool0oooo02<0oooo
00<0AX:d0?ooo`3oool0?P3oool504J2]0D0oooo1@16P[@J0?ooo`0304J2]03oool0oooo00h0oooo
0`16P[Be0?ooo`0304J2]03oool0oooo00D0oooo1@16P[@90?ooo`030000003oool0oooo03X0oooo
001S0?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?oo
o`070?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?oo
o`040?ooo`H0AX:d3P3oool404J2]0L0oooo00<0AX:d0?ooo`3oool0603oool404J2]2<0oooo1016
P[@T0?ooo`0304J2]03oool0oooo03h0oooo1@16P[@40?ooo`H0AX:d603oool404J2]0l0oooo1016
P[Bd0?ooo`0304J2]03oool0oooo00D0oooo1016P[@:0?ooo`030000003oool0oooo03X0oooo001S
0?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`07
0?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`04
0?ooo`H0AX:d5`3oool504J2]3l0oooo1@16P[@S0?ooo`0304J2]03oool0oooo03d0oooo1P16P[@5
0?ooo`D0AX:d5`3oool604J2]0d0oooo1P16P[Bc0?ooo`0304J2]03oool0oooo01<0oooo00<00000
0?ooo`3oool0>P3oool006<0oooo0`00000:0?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?oo
o`3oool01`3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?oo
o`3oool0103oool504J2]1P0oooo1@16P[@n0?ooo`H0AX:d8`3oool00`16P[@0oooo0?ooo`0n0?oo
o`D0AX:d1@3oool404J2]1P0oooo1P16P[@>0?ooo`D0AX:d/`3oool00`16P[@0oooo0?ooo`0C0?oo
o`030000003oool0oooo03X0oooo001S0?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3o
ool01P3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3o
ool01`3oool00`16P[@0oooo0?ooo`0P0?ooo`H0AX:d?P3oool604J2]2<0oooo00<0AX:d0?ooo`3o
ool0?P3oool504J2]240oooo1P16P[@>0?ooo`D0AX:d/@3oool504J2]1<0oooo00<000000?ooo`3o
ool0>P3oool006<0oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`060?ooo`0304J2
]03oool0oooo00L0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`070?ooo`0304J2
]03oool0oooo0240oooo1@16P[@n0?ooo`D0AX:d903oool00`16P[@0oooo0?ooo`100?ooo`80AX:d
8P3oool504J2]140oooo0P16P[Bb0?ooo`D0AX:d4`3oool00`000000oooo0?ooo`0j0?ooo`00H`3o
ool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool01`3o
ool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?ooo`3oool08@3o
ool504J2]6L0oooo00<0AX:d0?ooo`3oool0o`3oool^0?ooo`H0AX:d4`3oool00`000000oooo0?oo
o`0j0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d
0?ooo`3oool01@3oool404J2]0L0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`2;
0?ooo`@0AX:do`3oool`0?ooo`D0AX:d4`3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`00
0000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool01@3oool504J2
]0H0oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`2:0?ooo`H0AX:do`3oool_0?oo
o`@0AX:d503oool00`000000oooo0?ooo`0j0?ooo`00H`3oool3000000X0oooo00<0AX:d0?ooo`3o
ool01P3oool00`16P[@0oooo0?ooo`040?ooo`H0AX:d1P3oool00`16P[@0oooo0?ooo`070?ooo`03
04J2]03oool0oooo08/0oooo1@16P[Co0?ooodL0oooo00<000000?ooo`3oool0>P3oool006<0oooo
00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00D0oooo
1@16P[@60?ooo`0304J2]03oool0oooo00L0oooo00<0AX:d0?ooo`3oool0R`3oool504J2]?l0oooo
A`3oool00`000000oooo0?ooo`0j0?ooo`00B@3oool4000000@0oooo00<000000?ooo`3oool01P00
00090?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?oo
o`050?ooo`@0AX:d1`3oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo08/0oooo1016
P[Co0?ooodP0oooo00<000000?ooo`3oool0>P3oool004P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool0
0`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo0100oooo00<0AX:d0?ooo`3oool01`3oool0
0`16P[@0oooo0?ooo`3o0?ooomL0oooo00<000000?ooo`3oool0>P3oool004P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo0100oooo00<0AX:d0?oo
o`3oool01`3oool00`16P[@0oooo0?ooo`3o0?ooomL0oooo00<000000?ooo`3oool0>P3oool004P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo0100
oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`3o0?ooomL0oooo00<000000?ooo`3o
ool0>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo100000090?ooo`H0Ogmo0`3oool00`16P[@0Ogmo07moO`0407moO`D0oooo
1P1oOgl0103oool0AX:d0?ooo`3oool607moO`040?ooo`16P[@0oooo0?ooo`L0Ogmo103oool607mo
O`@0oooo1`1oOgl40?ooo`H0Ogmo103oool707moO`@0oooo1P1oOgl40?ooo`L0Ogmo103oool607mo
O`@0oooo1`1oOgl40?ooo`H0Ogmo103oool707moO`@0oooo1P1oOgl40?ooo`L0Ogmo103oool607mo
O`@0oooo1`1oOgl40?ooo`H0Ogmo103oool607moO`D0oooo1P1oOgl40?ooo`H0Ogmo1@3oool607mo
O`@0oooo1P1oOgl50?ooo`H0Ogmo103oool607moO`D0oooo1P1oOgl40?ooo`H0Ogmo1@3oool607mo
O`@0oooo1P1oOgl50?ooo`H0Ogmo103oool607moO`D0oooo1P1oOgl40?ooo`H0Ogmo103oool707mo
O`@0oooo1P1oOgl40?ooo`L0Ogmo103oool607moO`@0oooo1`1oOgl40?ooo`H0Ogmo103oool707mo
O`@0oooo1P1oOgl40?ooo`L0Ogmo103oool607moO`@0oooo1`1oOgl40?ooo`H0Ogmo103oool707mo
O``0oooo00<000000?ooo`3oool0>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`16P[@0
oooo0?ooo`060?ooo`0304J2]03oool0oooo0100oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0
oooo0?ooo`3o0?ooomL0oooo00<000000?ooo`3oool0>P3oool004P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2P3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo0100oooo00<0AX:d0?ooo`3oool0
1`3oool00`16P[@0oooo0?ooo`3o0?ooomL0oooo00<000000?ooo`3oool0>P3oool004P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo00H0oooo00<0
AX:d0?ooo`3oool0403oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo0?l0ooooe`3o
ool00`000000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00X0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`0@0?ooo`0304J2]03oool0
oooo00L0oooo00<0AX:d0?ooo`3oool0o`3ooooG0?ooo`030000003oool0oooo03X0oooo00190?oo
o`@00000203oool4000000X0oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`060?oo
o`0304J2]03oool0oooo0100oooo00<0AX:d0?ooo`3oool01`3oool00`16P[@0oooo0?ooo`3o0?oo
omL0oooo00<000000?ooo`3oool0>P3oool006<0oooo0`00000:0?ooo`0304J2]03oool0oooo00H0
oooo00<0AX:d0?ooo`3oool0403oool00`16P[@0oooo0?ooo`070?ooo`0304J2]03oool0oooo0?l0
ooooe`3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2
]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool0403oool00`16P[@0oooo0?ooo`070?ooo`0304J2
]03oool0oooo0?l0ooooe`3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?oo
o`0:0?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool0403oool00`16P[@0oooo0?oo
o`070?ooo`0304J2]03oool0oooo0?l0ooooe`3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool0
0`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool03P3oool5
04J2]0L0oooo00<0AX:d0?ooo`3oool0o`3ooooG0?ooo`030000003oool0oooo03X0oooo001S0?oo
o`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`0>0?oo
o`D0AX:d1`3oool00`16P[@0oooo0?ooo`3o0?ooomL0oooo00<000000?ooo`3oool0>P3oool006<0
oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00d0
oooo1P16P[@70?ooo`0304J2]03oool0oooo0?l0ooooe`3oool00`000000oooo0?ooo`0j0?ooo`00
H`3oool3000000X0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`0>0?ooo`D0AX:d
1`3oool00`16P[@0oooo0?ooo`3o0?ooomL0oooo00<000000?ooo`3oool0>P3oool006<0oooo00<0
00000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo00h0oooo1@16
P[@70?ooo`0304J2]03oool0oooo0?l0ooooe`3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool0
0`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool06P3oool0
0`16P[@0oooo0?ooo`3o0?ooomL0oooo00<000000?ooo`3oool0>P3oool006<0oooo00<000000?oo
o`3oool02P3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0oooo01X0oooo00<0AX:d0?oo
o`3oool0o`3ooooG0?ooo`030000003oool0oooo03X0oooo001S0?ooo`030000003oool0oooo00X0
oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`0J0?ooo`0304J2]03oool0oooo0?l0
ooooe`3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2
]03oool0oooo00H0oooo00<0AX:d0?ooo`3oool06P3oool00`16P[@0oooo0?ooo`3o0?ooomL0oooo
00<000000?ooo`3oool0>P3oool006<0oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?oo
o`060?ooo`0304J2]03oool0oooo01X0oooo00<0AX:d0?ooo`3oool0o`3ooooG0?ooo`030000003o
ool0oooo03X0oooo001S0?ooo`<000002P3oool00`16P[@0oooo0?ooo`060?ooo`0304J2]03oool0
oooo01X0oooo00<0AX:d0?ooo`3oool0o`3ooooG0?ooo`030000003oool0oooo03X0oooo001S0?oo
o`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool01P3oool00`16P[@0oooo0?ooo`0J0?oo
o`0304J2]03oool0oooo0?l0ooooe`3oool00`000000oooo0?ooo`0j0?ooo`00B@3oool4000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0
oooo00<0AX:d0?ooo`3oool0103oool404J2]1T0oooo1016P[Co0?ooomP0oooo00<000000?ooo`3o
ool0>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`040?ooo`D0AX:d
603oool504J2]?l0ooooe`3oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo1`0000090?ooo`030000003oool0oooo00X0oooo00<0
AX:d0?ooo`3oool00`3oool604J2]1L0oooo1P16P[Co0?ooomL0oooo00<000000?ooo`3oool0>P3o
ool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0
oooo00@0oooo1@16P[@H0?ooo`D0AX:do`3ooooG0?ooo`030000003oool0oooo03X0oooo00180?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000000X0oooo100000090?ooo`0304J2]03oool0oooo00@0oooo1@16P[@H0?ooo`@0AX:do`3ooooH
0?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00X0oooo00<0AX:d
0?ooo`3oool01P3oool204J2]?l0oooom@3oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j
0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`0000002P3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`00
0000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo0P00000:0?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool0o`3oooom0?ooo`03
0000003oool0oooo03X0oooo00190?ooo`@000002`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00X0oooo00<0AX:d0?ooo`3oool0o`3oooom0?ooo`030000003oool0oooo03X0oooo
001S0?ooo`<000002P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0>P3o
ool006<0oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<00000
0?ooo`3oool0>P3oool006<0oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`3o0?oo
ood0oooo00<000000?ooo`3oool0>P3oool006<0oooo00<000000?ooo`3oool02P3oool00`16P[@0
oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0>P3oool006<0oooo00<000000?ooo`3oool0
2P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0>P3oool006<0oooo00<0
00000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0>P3o
ool006<0oooo0`00000:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j
0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`00
0000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0
ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2
]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?oo
o`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool0
0`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j
0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`00
0000oooo0?ooo`0j0?ooo`00H`3oool3000000X0oooo00<0AX:d0?ooo`3oool0o`3oooom0?ooo`03
0000003oool0oooo03X0oooo001S0?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool0
o`3oooom0?ooo`030000003oool0oooo03X0oooo00190?ooo`@00000103oool010000000oooo0?oo
o`3oool4000000X0oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo
00<000000?ooo`3oool0>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool0o`3oooom
0?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0>P3oool004P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000
oooo0?ooo`070?ooo`@000002@3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3o
ool0>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool00000008000002P3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0oooo
o@3oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`0304J2]03o
ool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:
0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool0o`3oooom0?ooo`030000003oool0
oooo03X0oooo00190?ooo`@000002@3oool3000000X0oooo00<000000?ooo`3oool02P3oool00`16
P[@0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0>P3oool006<0oooo0`00000:0?ooo`03
04J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo
0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00H`3o
ool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?oo
o`0j0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool0
0`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo
0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`03
04J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool3000000X0oooo
00<0AX:d0?ooo`3oool0o`3oooom0?ooo`030000003oool0oooo03X0oooo001S0?ooo`030000003o
ool0oooo00X0oooo00<0AX:d0?ooo`3oool0o`3oooom0?ooo`030000003oool0oooo03X0oooo001S
0?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool0o`3oooom0?ooo`030000003oool0
oooo03X0oooo001S0?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool0o`3oooom0?oo
o`030000003oool0oooo03X0oooo001S0?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3o
ool0o`3oooom0?ooo`030000003oool0oooo03X0oooo001S0?ooo`030000003oool0oooo00X0oooo
00<0AX:d0?ooo`3oool0o`3oooom0?ooo`030000003oool0oooo03X0oooo001S0?ooo`030000003o
ool0oooo00X0oooo00<0AX:d0?ooo`3oool0o`3oooom0?ooo`030000003oool0oooo03X0oooo001S
0?ooo`<000002P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0>P3oool0
06<0oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?oo
o`3oool0>P3oool004T0oooo100000040?ooo`040000003oool0oooo0?ooo`@000002P3oool00`00
0000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?oo
o`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3o
ool0o`3oooom0?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0
>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03o
ool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00B03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`07
0?ooo`@000002@3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0>P3oool0
04P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`@000002P3oool00`00
0000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?oo
o`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3o
ool0o`3oooom0?ooo`030000003oool0oooo03X0oooo00180?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0
>P3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03o
ool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00B@3oool4000000P0oooo1000000:
0?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool0o`3oooom0?ooo`030000003oool0
oooo03X0oooo001S0?ooo`<000002P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?oo
o`3oool0>P3oool006<0oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`3o0?ooood0
oooo00<000000?ooo`3oool0>P3oool006<0oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo
0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0>P3oool006<0oooo00<000000?ooo`3oool02P3o
ool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0>P3oool006<0oooo00<00000
0?ooo`3oool02P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool0>P3oool0
06<0oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?oo
o`3oool0>P3oool006<0oooo0`00000:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000
oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0oooo
o@3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03o
ool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`000000oooo0?ooo`0:
0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`00
0000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?oo
o`00H`3oool00`000000oooo0?ooo`0:0?ooo`0304J2]03oool0oooo0?l0ooooo@3oool00`000000
oooo0?ooo`0j0?ooo`00H`3oool3000000X0oooo00<0AX:d0?ooo`3oool0o`3oooom0?ooo`030000
003oool0oooo03X0oooo001S0?ooo`030000003oool0oooo00X0oooo00<0AX:d0?ooo`3oool0o`3o
ooom0?ooo`030000003oool0oooo03X0oooo001S0?ooo`030000003oool0oooo00X0oooo00<0AX:d
0?ooo`3oool0o`3oooom0?ooo`030000003oool0oooo03X0oooo001G0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`16P[@0oooo0?ooo`3o0?ooood0oooo00<000000?oo
o`3oool0>P3oool005L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
04J2]03oool0oooo0?l0ooooo@3oool00`000000oooo0?ooo`0j0?ooo`00E`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo1016P[Co0?ooooh0oooo00<000000?ooo`3oool0
>P3oool005L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`H0AX:do`3o
ooom0?ooo`030000003oool0oooo03X0oooo001G0?ooo`030000003oool0oooo00T0oooo10000006
0?ooo`H0AX:do`3oooom0?ooo`030000003oool0oooo03X0oooo001G0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01`3oool604J2]?l0ooooo@3oool00`000000oooo0?ooo`0j0?oo
o`00E`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo1@16P[Co0?ooooh0
oooo00<000000?ooo`3oool0>P3oool005D0oooo00<000000?ooo`0000002`3ooooo00000?l00000
3`00000l0?ooo`00EP3oool200000?l0ooooo`3ooomF0?ooo`00E`3oool00`000000oooo0?ooo`3o
0?ooool0ooooE03oool00?l0ooooo`3ooon^0?ooo`00o`3ooooo0?ooojh0oooo003o0?ooool0oooo
[P3oool00001\
\>"],
  ImageRangeCache->{{{0, 683.75}, {204.438, 0}} -> {-11.6777, -0.570963, \
0.104165, 0.00803314}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A first try to construct a forward curve", "Section"],

Cell["\<\
We have the feeling that parts of the price changes are not random, i.e we \
think we are able to predict in part the future evolvement of the prices. To \
achieve this we try to identify the non-random parts of the data and build a \
function for them. We call this function a forward curve. Our assumption is \
that the future prices will randomly realize around this forward curve.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Adjusting for weekly pattern", "Subsection"],

Cell["\<\
Doing an autocorrelation analysis and looking at the data seemed to reveal an \
day-of-the-week effect. To further explore this day-of-the-week effect, the \
data is rearranged in weekly chunks, then the mean for each week is \
calculated and the difference of each day of the week to the mean of the week \
is calculated.\
\>", "Text"],

Cell[BoxData[
    \(\(data\  = \ 
        Map[Transpose[{Range[7], # - Mean[#]}] &, 
            Partition[Drop[peak, 3], 7]]\  // \ Flatten[#, 1] &;\)\)], "Input"],

Cell["\<\
This results in the following picture. The x-axes describe the week days \
starting with Monday and ending with Sunday. As expected are the prices on \
Sunday below the average of the week.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plt\  = 
        ListPlot[data, PlotJoined \[Rule] False, 
          PlotStyle \[Rule] {Green, PointSize[0.02]}, Frame \[Rule] True, 
          PlotRange \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.318689 0.0123162 [
[.02381 -0.0125 -5.90625 -17.75 ]
[.02381 -0.0125 5.90625 0 ]
[.15986 -0.0125 -5.90625 -17.75 ]
[.15986 -0.0125 5.90625 0 ]
[.29592 -0.0125 -5.90625 -17.75 ]
[.29592 -0.0125 5.90625 0 ]
[.43197 -0.0125 -5.90625 -17.75 ]
[.43197 -0.0125 5.90625 0 ]
[.56803 -0.0125 -5.90625 -17.75 ]
[.56803 -0.0125 5.90625 0 ]
[.70408 -0.0125 -5.90625 -17.75 ]
[.70408 -0.0125 5.90625 0 ]
[.84014 -0.0125 -5.90625 -17.75 ]
[.84014 -0.0125 5.90625 0 ]
[.97619 -0.0125 -5.90625 -17.75 ]
[.97619 -0.0125 5.90625 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07236 -29.3125 -8.875 ]
[-0.0125 .07236 0 8.875 ]
[-0.0125 .19553 -29.3125 -8.875 ]
[-0.0125 .19553 0 8.875 ]
[-0.0125 .31869 -11.8125 -8.875 ]
[-0.0125 .31869 0 8.875 ]
[-0.0125 .44185 -19.625 -8.875 ]
[-0.0125 .44185 0 8.875 ]
[-0.0125 .56501 -19.625 -8.875 ]
[-0.0125 .56501 0 8.875 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.15986 0 m
.15986 .00625 L
s
gsave
.15986 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.29592 0 m
.29592 .00625 L
s
gsave
.29592 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.43197 0 m
.43197 .00625 L
s
gsave
.43197 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.56803 0 m
.56803 .00625 L
s
gsave
.56803 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.70408 0 m
.70408 .00625 L
s
gsave
.70408 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84014 0 m
.84014 .00625 L
s
gsave
.84014 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.125 Mabswid
.05102 0 m
.05102 .00375 L
s
.07823 0 m
.07823 .00375 L
s
.10544 0 m
.10544 .00375 L
s
.13265 0 m
.13265 .00375 L
s
.18707 0 m
.18707 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2415 0 m
.2415 .00375 L
s
.26871 0 m
.26871 .00375 L
s
.32313 0 m
.32313 .00375 L
s
.35034 0 m
.35034 .00375 L
s
.37755 0 m
.37755 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45918 0 m
.45918 .00375 L
s
.48639 0 m
.48639 .00375 L
s
.51361 0 m
.51361 .00375 L
s
.54082 0 m
.54082 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62245 0 m
.62245 .00375 L
s
.64966 0 m
.64966 .00375 L
s
.67687 0 m
.67687 .00375 L
s
.73129 0 m
.73129 .00375 L
s
.7585 0 m
.7585 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81293 0 m
.81293 .00375 L
s
.86735 0 m
.86735 .00375 L
s
.89456 0 m
.89456 .00375 L
s
.92177 0 m
.92177 .00375 L
s
.94898 0 m
.94898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07236 m
.00625 .07236 L
s
gsave
-0.0125 .07236 -90.3125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .19553 m
.00625 .19553 L
s
gsave
-0.0125 .19553 -90.3125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .31869 m
.00625 .31869 L
s
gsave
-0.0125 .31869 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .44185 m
.00625 .44185 L
s
gsave
-0.0125 .44185 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .56501 m
.00625 .56501 L
s
gsave
-0.0125 .56501 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .097 m
.00375 .097 L
s
0 .12163 m
.00375 .12163 L
s
0 .14626 m
.00375 .14626 L
s
0 .17089 m
.00375 .17089 L
s
0 .22016 m
.00375 .22016 L
s
0 .24479 m
.00375 .24479 L
s
0 .26942 m
.00375 .26942 L
s
0 .29406 m
.00375 .29406 L
s
0 .34332 m
.00375 .34332 L
s
0 .36795 m
.00375 .36795 L
s
0 .39259 m
.00375 .39259 L
s
0 .41722 m
.00375 .41722 L
s
0 .46648 m
.00375 .46648 L
s
0 .49112 m
.00375 .49112 L
s
0 .51575 m
.00375 .51575 L
s
0 .54038 m
.00375 .54038 L
s
0 .04773 m
.00375 .04773 L
s
0 .0231 m
.00375 .0231 L
s
0 .58965 m
.00375 .58965 L
s
0 .61428 m
.00375 .61428 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15986 .61178 m
.15986 .61803 L
s
.29592 .61178 m
.29592 .61803 L
s
.43197 .61178 m
.43197 .61803 L
s
.56803 .61178 m
.56803 .61803 L
s
.70408 .61178 m
.70408 .61803 L
s
.84014 .61178 m
.84014 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05102 .61428 m
.05102 .61803 L
s
.07823 .61428 m
.07823 .61803 L
s
.10544 .61428 m
.10544 .61803 L
s
.13265 .61428 m
.13265 .61803 L
s
.18707 .61428 m
.18707 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2415 .61428 m
.2415 .61803 L
s
.26871 .61428 m
.26871 .61803 L
s
.32313 .61428 m
.32313 .61803 L
s
.35034 .61428 m
.35034 .61803 L
s
.37755 .61428 m
.37755 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45918 .61428 m
.45918 .61803 L
s
.48639 .61428 m
.48639 .61803 L
s
.51361 .61428 m
.51361 .61803 L
s
.54082 .61428 m
.54082 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62245 .61428 m
.62245 .61803 L
s
.64966 .61428 m
.64966 .61803 L
s
.67687 .61428 m
.67687 .61803 L
s
.73129 .61428 m
.73129 .61803 L
s
.7585 .61428 m
.7585 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.81293 .61428 m
.81293 .61803 L
s
.86735 .61428 m
.86735 .61803 L
s
.89456 .61428 m
.89456 .61803 L
s
.92177 .61428 m
.92177 .61803 L
s
.94898 .61428 m
.94898 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07236 m
1 .07236 L
s
.99375 .19553 m
1 .19553 L
s
.99375 .31869 m
1 .31869 L
s
.99375 .44185 m
1 .44185 L
s
.99375 .56501 m
1 .56501 L
s
.125 Mabswid
.99625 .097 m
1 .097 L
s
.99625 .12163 m
1 .12163 L
s
.99625 .14626 m
1 .14626 L
s
.99625 .17089 m
1 .17089 L
s
.99625 .22016 m
1 .22016 L
s
.99625 .24479 m
1 .24479 L
s
.99625 .26942 m
1 .26942 L
s
.99625 .29406 m
1 .29406 L
s
.99625 .34332 m
1 .34332 L
s
.99625 .36795 m
1 .36795 L
s
.99625 .39259 m
1 .39259 L
s
.99625 .41722 m
1 .41722 L
s
.99625 .46648 m
1 .46648 L
s
.99625 .49112 m
1 .49112 L
s
.99625 .51575 m
1 .51575 L
s
.99625 .54038 m
1 .54038 L
s
.99625 .04773 m
1 .04773 L
s
.99625 .0231 m
1 .0231 L
s
.99625 .58965 m
1 .58965 L
s
.99625 .61428 m
1 .61428 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .31869 m
1 .31869 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.02 w
.15986 .36877 Mdot
.29592 .38031 Mdot
.43197 .374 Mdot
.56803 .28132 Mdot
.70408 .30771 Mdot
.84014 .27056 Mdot
.97619 .24815 Mdot
.15986 .36833 Mdot
.29592 .33407 Mdot
.43197 .3319 Mdot
.56803 .36819 Mdot
.70408 .32373 Mdot
.84014 .26178 Mdot
.97619 .24282 Mdot
.15986 .33698 Mdot
.29592 .35769 Mdot
.43197 .34295 Mdot
.56803 .3626 Mdot
.70408 .34192 Mdot
.84014 .26402 Mdot
.97619 .22466 Mdot
.15986 .35725 Mdot
.29592 .36982 Mdot
.43197 .36771 Mdot
.56803 .33635 Mdot
.70408 .31498 Mdot
.84014 .25588 Mdot
.97619 .22883 Mdot
.15986 .34313 Mdot
.29592 .32612 Mdot
.43197 .3274 Mdot
.56803 .32909 Mdot
.70408 .34958 Mdot
.84014 .29946 Mdot
.97619 .25604 Mdot
.15986 .34295 Mdot
.29592 .32483 Mdot
.43197 .35322 Mdot
.56803 .32872 Mdot
.70408 .3315 Mdot
.84014 .2861 Mdot
.97619 .2635 Mdot
.15986 .34536 Mdot
.29592 .33172 Mdot
.43197 .31667 Mdot
.56803 .34308 Mdot
.70408 .34537 Mdot
.84014 .29509 Mdot
.97619 .25352 Mdot
.15986 .32218 Mdot
.29592 .33774 Mdot
.43197 .3273 Mdot
.56803 .34238 Mdot
.70408 .32913 Mdot
.84014 .30581 Mdot
.97619 .26628 Mdot
.15986 .3253 Mdot
.29592 .29721 Mdot
.43197 .34969 Mdot
.56803 .35385 Mdot
.70408 .33815 Mdot
.84014 .30772 Mdot
.97619 .2589 Mdot
.15986 .35454 Mdot
.29592 .41293 Mdot
.43197 .30656 Mdot
.56803 .38092 Mdot
.70408 .34357 Mdot
.84014 .24076 Mdot
.97619 .19155 Mdot
.15986 .32724 Mdot
.29592 .34051 Mdot
.43197 .3962 Mdot
.56803 .34271 Mdot
.70408 .37638 Mdot
.84014 .24265 Mdot
.97619 .20513 Mdot
.15986 .34056 Mdot
.29592 .38755 Mdot
.43197 .36898 Mdot
.56803 .38267 Mdot
.70408 .39216 Mdot
.84014 .20817 Mdot
.97619 .15074 Mdot
.15986 .33322 Mdot
.29592 .37058 Mdot
.43197 .37463 Mdot
.56803 .4707 Mdot
.70408 .3171 Mdot
.84014 .21098 Mdot
.97619 .1536 Mdot
.15986 .33259 Mdot
.29592 .33903 Mdot
.43197 .35569 Mdot
.56803 .46767 Mdot
.70408 .33238 Mdot
.84014 .23695 Mdot
.97619 .16651 Mdot
.15986 .3566 Mdot
.29592 .36866 Mdot
.43197 .35306 Mdot
.56803 .36976 Mdot
.70408 .34387 Mdot
.84014 .27029 Mdot
.97619 .16858 Mdot
.15986 .34943 Mdot
.29592 .30372 Mdot
.43197 .39225 Mdot
.56803 .34695 Mdot
.70408 .33732 Mdot
.84014 .29076 Mdot
.97619 .21039 Mdot
.15986 .3753 Mdot
.29592 .3348 Mdot
.43197 .44144 Mdot
.56803 .38268 Mdot
.70408 .34983 Mdot
.84014 .1955 Mdot
.97619 .15127 Mdot
.15986 .31083 Mdot
.29592 .39908 Mdot
.43197 .35038 Mdot
.56803 .35841 Mdot
.70408 .34354 Mdot
.84014 .26344 Mdot
.97619 .20514 Mdot
.15986 .36762 Mdot
.29592 .36021 Mdot
.43197 .33776 Mdot
.56803 .35273 Mdot
.70408 .35548 Mdot
.84014 .26498 Mdot
.97619 .19204 Mdot
.15986 .40061 Mdot
.29592 .35611 Mdot
.43197 .27913 Mdot
.56803 .49764 Mdot
.70408 .27046 Mdot
.84014 .25807 Mdot
.97619 .1688 Mdot
.15986 .38267 Mdot
.29592 .39342 Mdot
.43197 .38491 Mdot
.56803 .29748 Mdot
.70408 .32972 Mdot
.84014 .24081 Mdot
.97619 .20181 Mdot
.15986 .35431 Mdot
.29592 .32488 Mdot
.43197 .36827 Mdot
.56803 .36112 Mdot
.70408 .36349 Mdot
.84014 .23544 Mdot
.97619 .22331 Mdot
.15986 .36472 Mdot
.29592 .34105 Mdot
.43197 .36914 Mdot
.56803 .37784 Mdot
.70408 .32119 Mdot
.84014 .28989 Mdot
.97619 .16699 Mdot
.15986 .38259 Mdot
.29592 .34407 Mdot
.43197 .35201 Mdot
.56803 .42862 Mdot
.70408 .32135 Mdot
.84014 .20011 Mdot
.97619 .20207 Mdot
.15986 .40937 Mdot
.29592 .33343 Mdot
.43197 .44278 Mdot
.56803 .3634 Mdot
.70408 .21017 Mdot
.84014 .26295 Mdot
.97619 .20872 Mdot
.15986 .37409 Mdot
.29592 .37646 Mdot
.43197 .29846 Mdot
.56803 .34143 Mdot
.70408 .37714 Mdot
.84014 .25077 Mdot
.97619 .21246 Mdot
.15986 .41392 Mdot
.29592 .49793 Mdot
.43197 .44289 Mdot
.56803 .31511 Mdot
.70408 .23744 Mdot
.84014 .18023 Mdot
.97619 .1433 Mdot
.15986 .2717 Mdot
.29592 .27082 Mdot
.43197 .3776 Mdot
.56803 .34494 Mdot
.70408 .32735 Mdot
.84014 .33079 Mdot
.97619 .30763 Mdot
.15986 .22116 Mdot
.29592 .34424 Mdot
.43197 .32839 Mdot
.56803 .37633 Mdot
.70408 .3699 Mdot
.84014 .30132 Mdot
.97619 .28947 Mdot
.15986 .33682 Mdot
.29592 .34372 Mdot
.43197 .36252 Mdot
.56803 .35499 Mdot
.70408 .31851 Mdot
.84014 .27229 Mdot
.97619 .24196 Mdot
.15986 .38325 Mdot
.29592 .35674 Mdot
.43197 .39231 Mdot
.56803 .32296 Mdot
.70408 .3766 Mdot
.84014 .23196 Mdot
.97619 .16701 Mdot
.15986 .45137 Mdot
.29592 .37 Mdot
.43197 .27609 Mdot
.56803 .37515 Mdot
.70408 .33517 Mdot
.84014 .22279 Mdot
.97619 .20025 Mdot
.15986 .32029 Mdot
.29592 .3657 Mdot
.43197 .3344 Mdot
.56803 .31515 Mdot
.70408 .40702 Mdot
.84014 .26814 Mdot
.97619 .22012 Mdot
.15986 .41876 Mdot
.29592 .31115 Mdot
.43197 .34722 Mdot
.56803 .33313 Mdot
.70408 .32724 Mdot
.84014 .27517 Mdot
.97619 .21815 Mdot
.15986 .33956 Mdot
.29592 .31797 Mdot
.43197 .31837 Mdot
.56803 .39947 Mdot
.70408 .33766 Mdot
.84014 .27838 Mdot
.97619 .23941 Mdot
.15986 .32126 Mdot
.29592 .32634 Mdot
.43197 .31704 Mdot
.56803 .3153 Mdot
.70408 .37474 Mdot
.84014 .33067 Mdot
.97619 .24547 Mdot
.15986 .30186 Mdot
.29592 .38625 Mdot
.43197 .33249 Mdot
.56803 .52766 Mdot
.70408 .29073 Mdot
.84014 .24498 Mdot
.97619 .14685 Mdot
.15986 .3833 Mdot
.29592 .46977 Mdot
.43197 .37259 Mdot
.56803 .34377 Mdot
.70408 .24662 Mdot
.84014 .23007 Mdot
.97619 .18471 Mdot
.15986 .37559 Mdot
.29592 .27908 Mdot
.43197 .34612 Mdot
.56803 .3519 Mdot
.70408 .33561 Mdot
.84014 .29621 Mdot
.97619 .24632 Mdot
.15986 .32364 Mdot
.29592 .38274 Mdot
.43197 .33052 Mdot
.56803 .36737 Mdot
.70408 .33557 Mdot
.84014 .30877 Mdot
.97619 .18223 Mdot
.15986 .32511 Mdot
.29592 .35887 Mdot
.43197 .2949 Mdot
.56803 .33709 Mdot
.70408 .3656 Mdot
.84014 .28677 Mdot
.97619 .26248 Mdot
.15986 .39843 Mdot
.29592 .36097 Mdot
.43197 .27889 Mdot
.56803 .33047 Mdot
.70408 .34666 Mdot
.84014 .28757 Mdot
.97619 .22783 Mdot
.15986 .34633 Mdot
.29592 .40262 Mdot
.43197 .40239 Mdot
.56803 .30768 Mdot
.70408 .23605 Mdot
.84014 .30046 Mdot
.97619 .23529 Mdot
.15986 .10838 Mdot
.29592 .36728 Mdot
.43197 .34368 Mdot
.56803 .59822 Mdot
.70408 .35608 Mdot
.84014 .24476 Mdot
.97619 .21243 Mdot
.15986 .49437 Mdot
.29592 .37673 Mdot
.43197 .29329 Mdot
.56803 .28836 Mdot
.70408 .40823 Mdot
.84014 .20851 Mdot
.97619 .16131 Mdot
.15986 .33739 Mdot
.29592 .19677 Mdot
.43197 .52603 Mdot
.56803 .32647 Mdot
.70408 .32369 Mdot
.84014 .27099 Mdot
.97619 .24948 Mdot
.15986 .40756 Mdot
.29592 .35682 Mdot
.43197 .31737 Mdot
.56803 .37474 Mdot
.70408 .28239 Mdot
.84014 .28298 Mdot
.97619 .20896 Mdot
.15986 .37619 Mdot
.29592 .36921 Mdot
.43197 .39389 Mdot
.56803 .31575 Mdot
.70408 .33891 Mdot
.84014 .22928 Mdot
.97619 .20759 Mdot
.15986 .49468 Mdot
.29592 .47681 Mdot
.43197 .37919 Mdot
.56803 .21528 Mdot
.70408 .25784 Mdot
.84014 .23174 Mdot
.97619 .17529 Mdot
.15986 .38878 Mdot
.29592 .37802 Mdot
.43197 .40106 Mdot
.56803 .44227 Mdot
.70408 .28278 Mdot
.84014 .20595 Mdot
.97619 .13196 Mdot
.15986 .16365 Mdot
.29592 .38661 Mdot
.43197 .48459 Mdot
.56803 .31082 Mdot
.70408 .34472 Mdot
.84014 .33308 Mdot
.97619 .20736 Mdot
.15986 .33789 Mdot
.29592 .37194 Mdot
.43197 .5105 Mdot
.56803 .27776 Mdot
.70408 .26931 Mdot
.84014 .2879 Mdot
.97619 .17553 Mdot
.15986 .43818 Mdot
.29592 .3682 Mdot
.43197 .4282 Mdot
.56803 .35358 Mdot
.70408 .29185 Mdot
.84014 .20476 Mdot
.97619 .14606 Mdot
.15986 .34388 Mdot
.29592 .44026 Mdot
.43197 .34014 Mdot
.56803 .47376 Mdot
.70408 .35837 Mdot
.84014 .1852 Mdot
.97619 .08922 Mdot
.15986 .47641 Mdot
.29592 .34757 Mdot
.43197 .34464 Mdot
.56803 .43498 Mdot
.70408 .32942 Mdot
.84014 .23161 Mdot
.97619 .06619 Mdot
.15986 .45898 Mdot
.29592 .38475 Mdot
.43197 .38299 Mdot
.56803 .33159 Mdot
.70408 .33059 Mdot
.84014 .19632 Mdot
.97619 .1456 Mdot
.15986 .44827 Mdot
.29592 .36362 Mdot
.43197 .31803 Mdot
.56803 .36197 Mdot
.70408 .3558 Mdot
.84014 .21863 Mdot
.97619 .16452 Mdot
.15986 .36022 Mdot
.29592 .37005 Mdot
.43197 .32242 Mdot
.56803 .3825 Mdot
.70408 .32394 Mdot
.84014 .26669 Mdot
.97619 .20502 Mdot
.15986 .36795 Mdot
.29592 .3839 Mdot
.43197 .31807 Mdot
.56803 .35652 Mdot
.70408 .33904 Mdot
.84014 .27168 Mdot
.97619 .19366 Mdot
.15986 .41741 Mdot
.29592 .36208 Mdot
.43197 .37906 Mdot
.56803 .32981 Mdot
.70408 .39653 Mdot
.84014 .19854 Mdot
.97619 .14739 Mdot
.15986 .29323 Mdot
.29592 .31562 Mdot
.43197 .28588 Mdot
.56803 .4239 Mdot
.70408 .4317 Mdot
.84014 .28378 Mdot
.97619 .19671 Mdot
.15986 .3192 Mdot
.29592 .4058 Mdot
.43197 .32422 Mdot
.56803 .41392 Mdot
.70408 .35281 Mdot
.84014 .24159 Mdot
.97619 .17329 Mdot
.15986 .33231 Mdot
.29592 .30212 Mdot
.56803 .3161 Mdot
.70408 .24269 Mdot
.84014 .17143 Mdot
.97619 .11866 Mdot
.15986 .46853 Mdot
.29592 .35012 Mdot
.43197 .33329 Mdot
.56803 .35505 Mdot
.70408 .31247 Mdot
.84014 .2328 Mdot
.97619 .17857 Mdot
.15986 .32935 Mdot
.29592 .33528 Mdot
.43197 .41059 Mdot
.56803 .33769 Mdot
.70408 .42884 Mdot
.84014 .21604 Mdot
.97619 .17302 Mdot
.15986 .33987 Mdot
.29592 .3619 Mdot
.43197 .36006 Mdot
.56803 .34628 Mdot
.70408 .35535 Mdot
.84014 .24972 Mdot
.97619 .21764 Mdot
.15986 .36647 Mdot
.29592 .36715 Mdot
.43197 .3809 Mdot
.56803 .32875 Mdot
.70408 .32989 Mdot
.84014 .24292 Mdot
.97619 .21474 Mdot
.15986 .52492 Mdot
.29592 .36286 Mdot
.43197 .2749 Mdot
.56803 .32893 Mdot
.70408 .30575 Mdot
.84014 .25167 Mdot
.97619 .1818 Mdot
.15986 .34191 Mdot
.29592 .33581 Mdot
.43197 .35038 Mdot
.56803 .40942 Mdot
.70408 .29808 Mdot
.84014 .25062 Mdot
.97619 .24461 Mdot
.15986 .33753 Mdot
.29592 .34256 Mdot
.43197 .35468 Mdot
.56803 .34078 Mdot
.70408 .343 Mdot
.84014 .26603 Mdot
.97619 .24625 Mdot
.15986 .33696 Mdot
.29592 .36202 Mdot
.43197 .37963 Mdot
.56803 .39177 Mdot
.70408 .30078 Mdot
.84014 .26843 Mdot
.97619 .19124 Mdot
.15986 .49836 Mdot
.29592 .39478 Mdot
.43197 .31103 Mdot
.56803 .2121 Mdot
.70408 .32519 Mdot
.84014 .2769 Mdot
.97619 .21246 Mdot
.15986 .37192 Mdot
.29592 .33767 Mdot
.43197 .35484 Mdot
.56803 .35088 Mdot
.70408 .38651 Mdot
.84014 .25431 Mdot
.97619 .17469 Mdot
.15986 .20313 Mdot
.29592 .55894 Mdot
.43197 .45314 Mdot
.56803 .31426 Mdot
.70408 .37795 Mdot
.84014 .21953 Mdot
.97619 .10387 Mdot
.15986 .39616 Mdot
.29592 .42527 Mdot
.43197 .39457 Mdot
.56803 .33525 Mdot
.70408 .41284 Mdot
.84014 .19421 Mdot
.97619 .07253 Mdot
.15986 .45427 Mdot
.29592 .41595 Mdot
.43197 .39724 Mdot
.56803 .37754 Mdot
.70408 .30353 Mdot
.84014 .15763 Mdot
.97619 .12467 Mdot
.15986 .54345 Mdot
.29592 .40632 Mdot
.43197 .3011 Mdot
.56803 .28112 Mdot
.70408 .31527 Mdot
.84014 .22953 Mdot
.97619 .15404 Mdot
.29592 .25728 Mdot
.43197 .50692 Mdot
.56803 .45033 Mdot
.70408 .47142 Mdot
.15986 .36751 Mdot
.29592 .24612 Mdot
.43197 .28367 Mdot
.56803 .50059 Mdot
.70408 .25622 Mdot
.84014 .30511 Mdot
.97619 .27161 Mdot
.15986 .28652 Mdot
.29592 .12609 Mdot
.43197 .40649 Mdot
.56803 .43675 Mdot
.70408 .41785 Mdot
.84014 .32768 Mdot
.97619 .22944 Mdot
.15986 .42871 Mdot
.29592 .59105 Mdot
.43197 .4779 Mdot
.56803 .4187 Mdot
.70408 .22534 Mdot
.84014 .0992 Mdot
.15986 .50541 Mdot
.29592 .35745 Mdot
.43197 .40563 Mdot
.56803 .38094 Mdot
.70408 .35235 Mdot
.84014 .10996 Mdot
.97619 .11909 Mdot
.15986 .39594 Mdot
.29592 .3791 Mdot
.43197 .35385 Mdot
.56803 .35484 Mdot
.70408 .3239 Mdot
.84014 .23126 Mdot
.97619 .19193 Mdot
.15986 .41533 Mdot
.29592 .31465 Mdot
.43197 .38298 Mdot
.56803 .33847 Mdot
.70408 .32697 Mdot
.84014 .24006 Mdot
.97619 .21237 Mdot
.15986 .36218 Mdot
.29592 .35868 Mdot
.43197 .341 Mdot
.56803 .33271 Mdot
.70408 .30927 Mdot
.84014 .28116 Mdot
.97619 .24583 Mdot
.15986 .31308 Mdot
.29592 .26421 Mdot
.43197 .35701 Mdot
.56803 .37911 Mdot
.70408 .28086 Mdot
.84014 .3588 Mdot
.97619 .27775 Mdot
.15986 .3505 Mdot
.29592 .32558 Mdot
.43197 .34373 Mdot
.56803 .39377 Mdot
.70408 .30298 Mdot
.84014 .2588 Mdot
.97619 .25545 Mdot
.15986 .35626 Mdot
.29592 .33596 Mdot
.43197 .29858 Mdot
.56803 .33343 Mdot
.70408 .42097 Mdot
.84014 .26301 Mdot
.97619 .22262 Mdot
.15986 .35604 Mdot
.29592 .375 Mdot
.43197 .34178 Mdot
.56803 .32207 Mdot
.70408 .30147 Mdot
.84014 .28819 Mdot
.97619 .24627 Mdot
.15986 .35634 Mdot
.29592 .36387 Mdot
.43197 .323 Mdot
.56803 .3507 Mdot
.70408 .30298 Mdot
.84014 .28562 Mdot
.97619 .24832 Mdot
.15986 .35752 Mdot
.29592 .3513 Mdot
.43197 .36413 Mdot
.56803 .34372 Mdot
.70408 .33805 Mdot
.84014 .26195 Mdot
.97619 .21414 Mdot
.15986 .37492 Mdot
.29592 .38579 Mdot
.43197 .40443 Mdot
.56803 .38313 Mdot
.70408 .246 Mdot
.84014 .26529 Mdot
.97619 .17126 Mdot
.15986 .17294 Mdot
.29592 .39059 Mdot
.43197 .34991 Mdot
.56803 .37423 Mdot
.70408 .33421 Mdot
.84014 .33236 Mdot
.97619 .27659 Mdot
.15986 .38594 Mdot
.29592 .33377 Mdot
.43197 .33472 Mdot
.56803 .39712 Mdot
.70408 .35393 Mdot
.84014 .24477 Mdot
.97619 .18058 Mdot
.15986 .36173 Mdot
.29592 .43073 Mdot
.43197 .37641 Mdot
.56803 .35818 Mdot
.70408 .30507 Mdot
.84014 .26039 Mdot
.97619 .13832 Mdot
.15986 .35727 Mdot
.29592 .39871 Mdot
.43197 .45219 Mdot
.56803 .33997 Mdot
.70408 .3048 Mdot
.84014 .21129 Mdot
.97619 .16659 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`009@3oool4
00000200oooo00<000000?ooo`3oool07@3oool6000001d0oooo1000000Q0?ooo`030000003oool0
oooo01d0oooo1000000N0?ooo`@000007`3oool00`000000oooo0?ooo`070?ooo`00903oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`0000007@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01`3oool002@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo1`00000M0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01`3oool002@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`060?ooo`00903oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo01X0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`030000003oool0oooo01X0
oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0703oool3000001h0oooo00@000000?ooo`3oool000007P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`0000000P00000P0?ooo`03
0000003oool0oooo00H0oooo000T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
6`3oool010000000oooo0?ooo`00000N0?ooo`D000007@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00D0oooo000T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0000000O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`000000
7P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
1@3oool002@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`8000007`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0M0?ooo`8000007`3oool00`000000oooo0?ooo`0O0?ooo`050000003o
ool0oooo0?ooo`0000008@3oool00`000000oooo0?ooo`040?ooo`009@3oool400000200oooo00<0
00000?ooo`3oool07P3oool4000001h0oooo1000000Q0?ooo`030000003oool0oooo01d0oooo1@00
000N0?ooo`<000007@3oool6000000H0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo000Q0?ooood000000P3oool00240oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool100000040oooo0@3oool00240oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000
003oool0oooo0?T0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@00
00010?ooo`40oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40oooo000Q0?oo
o`800000n@3oool200000080oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40
oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003o
ool0oooo0?T0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@000001
0?ooo`40oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40oooo000Q0?ooo`03
0000003oool0oooo0?T0oooo0@0000010?ooo`40oooo000Q0?ooo`800000n@3oool200000080oooo
000Q0?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40oooo000=0?ooo`H000000`3oool4
000000L0oooo00<000000?ooo`3oool0lP3oool3003o00@0oooo0@0000010?ooo`40oooo000>0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?40oooo1@00o`030?ooo`4000000@3oool10?ooo`003`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3a0?ooo`D00?l00`3oool100000040oooo0@3oool000@0oooo1`0000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0?40oooo1@00o`030?ooo`4000000@3oool10?ooo`004@3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0103oool300000?40oooo1@00o`020?ooo`800000
0P3oool00180oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0?40oooo1@00o`030?ooo`4000000@3oool10?ooo`004P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0lP3oool3003o00@0oooo
0@0000010?ooo`40oooo000=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?40oooo1@00o`030?ooo`400000
0@3oool10?ooo`003@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3a0?ooo`D00?l00`3oool100000040oooo
0@3oool000h0oooo100000040?ooo`@000001`3oool00`000000oooo0?ooo`3@0?ooo`<00?l07P3o
ool5003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`800000d03oool5003o01h0oooo0`00o`03
0?ooo`8000000P3oool00240oooo00<000000?ooo`3oool0903oool3003o0:P0oooo1@00o`0M0?oo
o`D00?l00`3oool100000040oooo0@3oool00240oooo00<000000?ooo`3oool08`3oool5003o0:L0
oooo1@00o`0M0?ooo`D00?l00`3oool100000040oooo0@3oool00240oooo00<000000?ooo`3oool0
8`3oool5003o0:L0oooo1@00o`0M0?ooo`D00?l00`3oool100000040oooo0@3oool00240oooo00<0
00000?ooo`3oool08`3oool5003o0:L0oooo1@00o`0M0?ooo`D00?l00`3oool100000040oooo0@3o
ool00240oooo00<000000?ooo`3oool0903oool3003o0200oooo0`00o`260?ooo`<00?l07P3oool5
003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`800000A`3oool5003o0:H0oooo1@00o`020?oo
o`8000000P3oool00240oooo00<000000?ooo`3oool0AP3oool5003o0:H0oooo1@00o`030?ooo`40
00000@3oool10?ooo`008@3oool00`000000oooo0?ooo`160?ooo`D00?l0YP3oool5003o00<0oooo
0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo04L0oooo0`00o`2W0?ooo`D00?l00`3o
ool100000040oooo0@3oool00240oooo00<000000?ooo`3oool0l@3oool5003o00<0oooo0@000001
0?ooo`40oooo000Q0?ooo`030000003oool0oooo0?40oooo1@00o`030?ooo`4000000@3oool10?oo
o`008@3oool200000?80oooo1@00o`020?ooo`8000000P3oool00240oooo00<000000?ooo`3oool0
d03oool3003o01h0oooo1@00o`030?ooo`4000000@3oool10?ooo`008@3oool00`000000oooo0?oo
o`3?0?ooo`D00?l07@3oool5003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0
oooo02@0oooo0`00o`2X0?ooo`D00?l07@3oool5003o00<0oooo0@0000010?ooo`40oooo000Q0?oo
o`030000003oool0oooo02<0oooo1@00o`2W0?ooo`D00?l07@3oool5003o00<0oooo0@0000010?oo
o`40oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`2X0?ooo`<00?l07P3oool5003o00<0
oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`2W0?ooo`D00?l0
7@3oool5003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`800000903oool5003o0:L0oooo1@00
o`0M0?ooo`D00?l00P3oool200000080oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`2W
0?ooo`D00?l07@3oool5003o00<0oooo0@0000010?ooo`40oooo000@0?ooo`030000003oool0oooo
00<0oooo100000070?ooo`030000003oool0oooo02@0oooo0`00o`2X0?ooo`D00?l07@3oool5003o
00<0oooo0@0000010?ooo`40oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0<l0oooo1@00o`0M0?ooo`D0
0?l00`3oool100000040oooo0@3oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0A`3oool3003o08D0oooo
1@00o`0M0?ooo`D00?l00`3oool100000040oooo0@3oool000@0oooo1`0000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo04H0oooo1@00o`240?ooo`D00?l07@3oool5003o00<0oooo0@0000010?ooo`40oooo000@
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`<00000903oool3003o01l0oooo1@00o`240?ooo`D00?l07@3oool5003o0080oooo0P000002
0?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o08@0oooo1@00o`0M0?oo
o`D00?l00`3oool100000040oooo0@3oool00100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool5003o01l0
oooo0`00o`110?ooo`<00?l0803oool3003o01h0oooo1@00o`0M0?ooo`D00?l00`3oool100000040
oooo0@3oool000h0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool5003o0680oooo1@00o`0N0?ooo`D00?l0
7@3oool5003o01d0oooo1@00o`030?ooo`4000000@3oool10?ooo`003`3oool2000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0oooo0`00
o`1S0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l00`3oool100000040oooo0@3o
ool00100oooo00<000000?ooo`3oool00`3oool4000000L0oooo00<000000?ooo`3oool08`3oool5
003o0680oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`030?ooo`4000000@3oool1
0?ooo`008@3oool2000002@0oooo1@00o`1R0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?oo
o`D00?l00P3oool200000080oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`1S0?ooo`<0
0?l07`3oool5003o01d0oooo1@00o`0M0?ooo`D00?l00`3oool100000040oooo0@3oool00240oooo
00<000000?ooo`3oool0903oool3003o08H0oooo1@00o`0M0?ooo`D00?l07@3oool5003o00<0oooo
0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo0:d0oooo1@00o`0M0?ooo`D00?l07@3o
ool5003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo0:d0oooo1@00o`0M
0?ooo`D00?l07@3oool5003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo
04L0oooo0`00o`1S0?ooo`D00?l07@3oool5003o01d0oooo1@00o`030?ooo`4000000@3oool10?oo
o`008@3oool2000004L0oooo1@00o`1R0?ooo`D00?l07@3oool5003o01d0oooo1@00o`020?ooo`80
00000P3oool00240oooo00<000000?ooo`3oool0AP3oool5003o0680oooo1@00o`0M0?ooo`D00?l0
7@3oool5003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo04H0oooo1@00
o`1R0?ooo`D00?l07@3oool5003o01d0oooo1@00o`030?ooo`4000000@3oool10?ooo`008@3oool0
0`000000oooo0?ooo`160?ooo`D00?l0HP3oool5003o01d0oooo1@00o`0M0?ooo`D00?l00`3oool1
00000040oooo0@3oool00240oooo00<000000?ooo`3oool0AP3oool5003o0680oooo1@00o`0M0?oo
o`D00?l07@3oool5003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo02@0
oooo0`00o`0O0?ooo`D00?l0HP3oool5003o01d0oooo1@00o`0M0?ooo`D00?l00`3oool100000040
oooo0@3oool00240oooo0P00000T0?ooo`D00?l07P3oool5003o01h0oooo0`00o`110?ooo`D00?l0
7@3oool5003o01d0oooo1@00o`020?ooo`8000000P3oool00240oooo00<000000?ooo`3oool08`3o
ool5003o01h0oooo1@00o`0M0?ooo`D00?l07P3oool3003o01l0oooo1@00o`0M0?ooo`D00?l07@3o
ool5003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`0N
0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`03
0?ooo`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0T0?ooo`<00?l07`3oool5003o
01d0oooo1@00o`0M0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l00`3oool10000
0040oooo0@3oool00240oooo00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D0
0?l07@3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o00<0oooo0@0000010?ooo`40
oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`0O0?ooo`<00?l07P3oool5003o01d0oooo
1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`030?ooo`4000000@3oool10?ooo`008@3o
ool00`000000oooo0?ooo`0S0?ooo`D00?l07`3oool3003o01h0oooo1@00o`0M0?ooo`D00?l07P3o
ool5003o01d0oooo1@00o`0M0?ooo`D00?l00`3oool100000040oooo0@3oool00240oooo0P00000T
0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M
0?ooo`D00?l00P3oool200000080oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`0N0?oo
o`D00?l07@3oool5003o01d0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01h0oooo0`00o`040?oo
o`4000000@3oool10?ooo`005P3oool4000000L0oooo00<000000?ooo`3oool08`3oool5003o01h0
oooo1@00o`0M0?ooo`D00?l07@3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o00<0
oooo0@0000010?ooo`40oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l0
7P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l00`3oool100000040oooo0@3oool001D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo1@00
o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00
o`030?ooo`4000000@3oool10?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5
003o01h0oooo1@00o`0N0?ooo`<00?l07`3oool3003o00@0oooo0@0000010?ooo`40oooo000E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103ooolV000000D00?l07P000005003o
01d000001@00o`0M000000D00?l07P000005003o01h000000`00o`0W00000080oooo000E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`D0
0?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0U0?ooo`40
00000@3oool10?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o01h0oooo
1@00o`0M0?ooo`D00?l09@3oool100000040oooo0@3oool001D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07@3o
ool5003o01d0oooo1@00o`0N0?ooo`D00?l07@3oool5003o02D0oooo0@0000010?ooo`40oooo000E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0U
0?ooo`4000000@3oool10?ooo`005P3oool4000000L0oooo00<000000?ooo`3oool08`3oool5003o
01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o01h0oooo1@00o`0M0?ooo`D00?l09@3oool10000
0040oooo0@3oool00240oooo0P00000T0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D0
0?l07P3oool5003o01h0oooo0`00o`0U0?ooo`8000000P3oool00240oooo00<000000?ooo`3oool0
8`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o01h0oooo1@00o`170?ooo`400000
0@3oool10?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o01d0oooo1@00
o`0M0?ooo`D00?l07P3oool5003o01h0oooo0`00o`0V0?ooo`4000000@3oool10?ooo`008@3oool0
0`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3oool5
003o01d0oooo1@00o`0U0?ooo`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0S0?oo
o`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0U0?oo
o`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o01d0
oooo1@00o`0M0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0U0?ooo`4000000@3oool10?ooo`00
8@3oool2000002@0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0N0?ooo`D00?l0
7P3oool3003o02D0oooo0P0000020?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3o
ool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3oool5003o04L0oooo0@0000010?ooo`40oooo000Q
0?ooo`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0N
0?ooo`D00?l0A`3oool100000040oooo0@3oool00240oooo00<000000?ooo`3oool08`3oool5003o
01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o01h0oooo1@00o`170?ooo`4000000@3oool10?oo
o`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D0
0?l07P3oool5003o04L0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo02<0oooo
1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0N0?ooo`D00?l0A`3oool100000040oooo
0@3oool00240oooo00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3o
ool5003o01h0oooo1@00o`170?ooo`4000000@3oool10?ooo`008@3oool2000002@0oooo1@00o`0N
0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0N0?ooo`D00?l0AP3oool200000080oooo000Q0?oo
o`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0N0?oo
o`D00?l0A`3oool100000040oooo0@3oool00240oooo00<000000?ooo`3oool08`3oool5003o01h0
oooo1@00o`0M0?ooo`D00?l07@3oool5003o01h0oooo1@00o`170?ooo`4000000@3oool10?ooo`00
8@3oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l0
7P3oool5003o04L0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00
o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0N0?ooo`D00?l0A`3oool100000040oooo0@3o
ool00240oooo00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5
003o01h0oooo1@00o`170?ooo`4000000@3oool10?ooo`008@3oool2000002@0oooo1@00o`0N0?oo
o`D00?l07P3oool3003o01h0oooo1@00o`0N0?ooo`D00?l0AP3oool200000080oooo000Q0?ooo`03
0000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07P3oool3003o01h0oooo1@00o`0N0?ooo`D0
0?l0A`3oool100000040oooo0@3oool00100oooo00<000000?ooo`3oool00`3oool4000000L0oooo
00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o01h0oooo
1@00o`170?ooo`4000000@3oool10?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3o
ool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3oool5003o04L0oooo0@0000010?ooo`40oooo000@
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0N
0?ooo`D00?l0A`3oool100000040oooo0@3oool00100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool5003o
01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o01l0oooo0`00o`180?ooo`4000000@3oool10?oo
o`00403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool3000002<0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`1Y0?ooo`80
00000P3oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l0
7@3oool5003o06X0oooo0@0000010?ooo`40oooo000@0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo1@00
o`0O0?ooo`<00?l07P3oool5003o01d0oooo1@00o`1Z0?ooo`4000000@3oool10?ooo`003P3oool0
0`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0S0?ooo`D00?l0@03oool5003o01d0oooo1@00o`1Z0?ooo`4000000@3oool1
0?ooo`003`3oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02<0oooo1@00o`100?ooo`D00?l07P3oool3003o06/0oooo0@0000010?oo
o`40oooo000@0?ooo`030000003oool0oooo00<0oooo100000070?ooo`030000003oool0oooo02<0
oooo1@00o`0O0?ooo`<00?l07`3oool3003o01l0oooo0`00o`0P0?ooo`<00?l0B03oool100000040
oooo0@3oool00240oooo0P00000T0?ooo`D00?l07P3oool5003o03l0oooo1@00o`0N0?ooo`D00?l0
AP3oool200000080oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07P3o
ool3003o01h0oooo1@00o`0N0?ooo`D00?l0A`3oool100000040oooo0@3oool00240oooo00<00000
0?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o01h0oooo1@00o`17
0?ooo`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o
01d0oooo1@00o`0M0?ooo`D00?l07`3oool3003o04P0oooo0@0000010?ooo`40oooo000Q0?ooo`03
0000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01h0oooo0`00o`1[0?ooo`40
00000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0T0?ooo`<00?l0803oool3003o01h0oooo
1@00o`2<0?ooo`4000000@3oool10?ooo`008@3oool2000002@0oooo1@00o`0O0?ooo`<00?l07P3o
ool5003o01h0oooo0`00o`1Z0?ooo`8000000P3oool00240oooo00<000000?ooo`3oool08`3oool5
003o01h0oooo1@00o`0N0?ooo`<00?l07P3oool5003o06X0oooo0@0000010?ooo`40oooo000Q0?oo
o`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07P3oool3003o01h0oooo1@00o`1Z0?oo
o`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o01d0
oooo1@00o`0M0?ooo`D00?l0JP3oool100000040oooo0@3oool00240oooo00<000000?ooo`3oool0
8`3oool5003o01l0oooo0`00o`0N0?ooo`D00?l07@3oool5003o06X0oooo0@0000010?ooo`40oooo
000Q0?ooo`030000003oool0oooo02<0oooo1@00o`100?ooo`D00?l07P3oool3003o06/0oooo0@00
00010?ooo`40oooo000Q0?ooo`030000003oool0oooo02@0oooo0`00o`110?ooo`D00?l0S03oool1
00000040oooo0@3oool00240oooo0P00000U0?ooo`<00?l0@P3oool3003o08`0oooo0P0000020?oo
o`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l0@03oool5003o01h0oooo0`00o`1[0?ooo`40
00000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l0@03oool5003o01d0oooo
1@00o`1Z0?ooo`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l0@03o
ool5003o01d0oooo1@00o`1Z0?ooo`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0T
0?ooo`<00?l0@P3oool3003o01h0oooo1@00o`1Z0?ooo`4000000@3oool10?ooo`008@3oool00`00
0000oooo0?ooo`0T0?ooo`<00?l0I03oool3003o06/0oooo0@0000010?ooo`40oooo000Q0?ooo`80
0000903oool5003o0=00oooo0P0000020?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l0
d@3oool100000040oooo0@3oool000d0oooo1P0000030?ooo`@000001`3oool00`000000oooo0?oo
o`0S0?ooo`D00?l0d@3oool100000040oooo0@3oool000h0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool3
003o0200oooo0`00o`2_0?ooo`4000000@3oool10?ooo`003`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`160?oo
o`D00?l0[P3oool100000040oooo0@3oool00100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0AP3oool5003o0:h0
oooo0@0000010?ooo`40oooo000A0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`040?ooo`<00000AP3oool5003o0:d0oooo0P0000020?ooo`004P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0A`3oool3003o0:l0
oooo0@0000010?ooo`40oooo000B0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`3i0?ooo`4000000@3oool10?ooo`003@3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3i0?ooo`4000000@3oool10?ooo`003@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3i0?ooo`40
00000@3oool10?ooo`003P3oool4000000@0oooo100000070?ooo`030000003oool0oooo04L0oooo
0`00o`2_0?ooo`4000000@3oool10?ooo`008@3oool2000004L0oooo1@00o`100?ooo`<00?l0JP3o
ool200000080oooo000Q0?ooo`030000003oool0oooo04H0oooo1@00o`0o0?ooo`D00?l0JP3oool1
00000040oooo0@3oool00240oooo00<000000?ooo`3oool0AP3oool5003o03l0oooo1@00o`1Z0?oo
o`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`170?ooo`<00?l0@03oool5003o06X0
oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo08/0oooo0`00o`1[0?ooo`400000
0@3oool10?ooo`008@3oool00`000000oooo0?ooo`3i0?ooo`4000000@3oool10?ooo`008@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00`3oool1
00000040oooo0@3oool00240ooooo@0000020?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.14854, -32.5993, \
0.0291132, 0.321606}}]
}, Open  ]],

Cell[TextData[{
  "To fit a curve into this data we use our usual first template for \
non-linear estimation ",
  Cell[BoxData[
      \(TraditionalForm\`a + 
        b\[VeryThinSpace]\[ExponentialE]\^\(s\[VeryThinSpace]x\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wfkt[x_]\  = 
      NonlinearFit[data, a + b\ Exp[s\ x], x, {a, b, s}]\)], "Input"],

Cell[BoxData[
    \(\(\(8.644312038155185`\)\(\[InvisibleSpace]\)\) - 
      1.5300351834286285`\ \[ExponentialE]\^\(0.36849018105606796`\ x\)\)], \
"Output"]
}, Open  ]],

Cell["In this case the function seem to able to follow the data. ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fktplt\  = \ 
        Plot[wfkt[x], {x, 1, 7}, 
          PlotStyle \[Rule] \ {Thickness[0.01], Yellow}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[plt, fktplt];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.318424 0.0123674 [
[.02381 -0.0125 -5.90625 -17.75 ]
[.02381 -0.0125 5.90625 0 ]
[.15986 -0.0125 -5.90625 -17.75 ]
[.15986 -0.0125 5.90625 0 ]
[.29592 -0.0125 -5.90625 -17.75 ]
[.29592 -0.0125 5.90625 0 ]
[.43197 -0.0125 -5.90625 -17.75 ]
[.43197 -0.0125 5.90625 0 ]
[.56803 -0.0125 -5.90625 -17.75 ]
[.56803 -0.0125 5.90625 0 ]
[.70408 -0.0125 -5.90625 -17.75 ]
[.70408 -0.0125 5.90625 0 ]
[.84014 -0.0125 -5.90625 -17.75 ]
[.84014 -0.0125 5.90625 0 ]
[.97619 -0.0125 -5.90625 -17.75 ]
[.97619 -0.0125 5.90625 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07108 -29.3125 -8.875 ]
[-0.0125 .07108 0 8.875 ]
[-0.0125 .19475 -29.3125 -8.875 ]
[-0.0125 .19475 0 8.875 ]
[-0.0125 .31842 -11.8125 -8.875 ]
[-0.0125 .31842 0 8.875 ]
[-0.0125 .4421 -19.625 -8.875 ]
[-0.0125 .4421 0 8.875 ]
[-0.0125 .56577 -19.625 -8.875 ]
[-0.0125 .56577 0 8.875 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.15986 0 m
.15986 .00625 L
s
gsave
.15986 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.29592 0 m
.29592 .00625 L
s
gsave
.29592 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.43197 0 m
.43197 .00625 L
s
gsave
.43197 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.56803 0 m
.56803 .00625 L
s
gsave
.56803 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.70408 0 m
.70408 .00625 L
s
gsave
.70408 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84014 0 m
.84014 .00625 L
s
gsave
.84014 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.125 Mabswid
.05102 0 m
.05102 .00375 L
s
.07823 0 m
.07823 .00375 L
s
.10544 0 m
.10544 .00375 L
s
.13265 0 m
.13265 .00375 L
s
.18707 0 m
.18707 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2415 0 m
.2415 .00375 L
s
.26871 0 m
.26871 .00375 L
s
.32313 0 m
.32313 .00375 L
s
.35034 0 m
.35034 .00375 L
s
.37755 0 m
.37755 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45918 0 m
.45918 .00375 L
s
.48639 0 m
.48639 .00375 L
s
.51361 0 m
.51361 .00375 L
s
.54082 0 m
.54082 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62245 0 m
.62245 .00375 L
s
.64966 0 m
.64966 .00375 L
s
.67687 0 m
.67687 .00375 L
s
.73129 0 m
.73129 .00375 L
s
.7585 0 m
.7585 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81293 0 m
.81293 .00375 L
s
.86735 0 m
.86735 .00375 L
s
.89456 0 m
.89456 .00375 L
s
.92177 0 m
.92177 .00375 L
s
.94898 0 m
.94898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07108 m
.00625 .07108 L
s
gsave
-0.0125 .07108 -90.3125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .19475 m
.00625 .19475 L
s
gsave
-0.0125 .19475 -90.3125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .31842 m
.00625 .31842 L
s
gsave
-0.0125 .31842 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .4421 m
.00625 .4421 L
s
gsave
-0.0125 .4421 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .56577 m
.00625 .56577 L
s
gsave
-0.0125 .56577 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .09581 m
.00375 .09581 L
s
0 .12055 m
.00375 .12055 L
s
0 .14528 m
.00375 .14528 L
s
0 .17002 m
.00375 .17002 L
s
0 .21948 m
.00375 .21948 L
s
0 .24422 m
.00375 .24422 L
s
0 .26895 m
.00375 .26895 L
s
0 .29369 m
.00375 .29369 L
s
0 .34316 m
.00375 .34316 L
s
0 .36789 m
.00375 .36789 L
s
0 .39263 m
.00375 .39263 L
s
0 .41736 m
.00375 .41736 L
s
0 .46683 m
.00375 .46683 L
s
0 .49157 m
.00375 .49157 L
s
0 .5163 m
.00375 .5163 L
s
0 .54104 m
.00375 .54104 L
s
0 .04634 m
.00375 .04634 L
s
0 .02161 m
.00375 .02161 L
s
0 .59051 m
.00375 .59051 L
s
0 .61524 m
.00375 .61524 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15986 .61178 m
.15986 .61803 L
s
.29592 .61178 m
.29592 .61803 L
s
.43197 .61178 m
.43197 .61803 L
s
.56803 .61178 m
.56803 .61803 L
s
.70408 .61178 m
.70408 .61803 L
s
.84014 .61178 m
.84014 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05102 .61428 m
.05102 .61803 L
s
.07823 .61428 m
.07823 .61803 L
s
.10544 .61428 m
.10544 .61803 L
s
.13265 .61428 m
.13265 .61803 L
s
.18707 .61428 m
.18707 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2415 .61428 m
.2415 .61803 L
s
.26871 .61428 m
.26871 .61803 L
s
.32313 .61428 m
.32313 .61803 L
s
.35034 .61428 m
.35034 .61803 L
s
.37755 .61428 m
.37755 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45918 .61428 m
.45918 .61803 L
s
.48639 .61428 m
.48639 .61803 L
s
.51361 .61428 m
.51361 .61803 L
s
.54082 .61428 m
.54082 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62245 .61428 m
.62245 .61803 L
s
.64966 .61428 m
.64966 .61803 L
s
.67687 .61428 m
.67687 .61803 L
s
.73129 .61428 m
.73129 .61803 L
s
.7585 .61428 m
.7585 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.81293 .61428 m
.81293 .61803 L
s
.86735 .61428 m
.86735 .61803 L
s
.89456 .61428 m
.89456 .61803 L
s
.92177 .61428 m
.92177 .61803 L
s
.94898 .61428 m
.94898 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07108 m
1 .07108 L
s
.99375 .19475 m
1 .19475 L
s
.99375 .31842 m
1 .31842 L
s
.99375 .4421 m
1 .4421 L
s
.99375 .56577 m
1 .56577 L
s
.125 Mabswid
.99625 .09581 m
1 .09581 L
s
.99625 .12055 m
1 .12055 L
s
.99625 .14528 m
1 .14528 L
s
.99625 .17002 m
1 .17002 L
s
.99625 .21948 m
1 .21948 L
s
.99625 .24422 m
1 .24422 L
s
.99625 .26895 m
1 .26895 L
s
.99625 .29369 m
1 .29369 L
s
.99625 .34316 m
1 .34316 L
s
.99625 .36789 m
1 .36789 L
s
.99625 .39263 m
1 .39263 L
s
.99625 .41736 m
1 .41736 L
s
.99625 .46683 m
1 .46683 L
s
.99625 .49157 m
1 .49157 L
s
.99625 .5163 m
1 .5163 L
s
.99625 .54104 m
1 .54104 L
s
.99625 .04634 m
1 .04634 L
s
.99625 .02161 m
1 .02161 L
s
.99625 .59051 m
1 .59051 L
s
.99625 .61524 m
1 .61524 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .31842 m
1 .31842 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.02 w
.15986 .36871 Mdot
.29592 .3803 Mdot
.43197 .37397 Mdot
.56803 .2809 Mdot
.70408 .3074 Mdot
.84014 .27009 Mdot
.97619 .24759 Mdot
.15986 .36827 Mdot
.29592 .33387 Mdot
.43197 .33169 Mdot
.56803 .36813 Mdot
.70408 .32348 Mdot
.84014 .26128 Mdot
.97619 .24224 Mdot
.15986 .33679 Mdot
.29592 .35759 Mdot
.43197 .34279 Mdot
.56803 .36252 Mdot
.70408 .34175 Mdot
.84014 .26353 Mdot
.97619 .224 Mdot
.15986 .35714 Mdot
.29592 .36977 Mdot
.43197 .36765 Mdot
.56803 .33616 Mdot
.70408 .3147 Mdot
.84014 .25535 Mdot
.97619 .22819 Mdot
.15986 .34297 Mdot
.29592 .32588 Mdot
.43197 .32717 Mdot
.56803 .32887 Mdot
.70408 .34944 Mdot
.84014 .29912 Mdot
.97619 .25551 Mdot
.15986 .34279 Mdot
.29592 .32459 Mdot
.43197 .35309 Mdot
.56803 .32849 Mdot
.70408 .33129 Mdot
.84014 .2857 Mdot
.97619 .26301 Mdot
.15986 .34521 Mdot
.29592 .33151 Mdot
.43197 .3164 Mdot
.56803 .34292 Mdot
.70408 .34522 Mdot
.84014 .29473 Mdot
.97619 .25299 Mdot
.15986 .32193 Mdot
.29592 .33755 Mdot
.43197 .32707 Mdot
.56803 .34221 Mdot
.70408 .32891 Mdot
.84014 .30549 Mdot
.97619 .26579 Mdot
.15986 .32506 Mdot
.29592 .29686 Mdot
.43197 .34955 Mdot
.56803 .35374 Mdot
.70408 .33797 Mdot
.84014 .30741 Mdot
.97619 .25838 Mdot
.15986 .35442 Mdot
.29592 .41305 Mdot
.43197 .30624 Mdot
.56803 .38091 Mdot
.70408 .34341 Mdot
.84014 .24017 Mdot
.97619 .19076 Mdot
.15986 .32701 Mdot
.29592 .34034 Mdot
.43197 .39626 Mdot
.56803 .34254 Mdot
.70408 .37636 Mdot
.84014 .24207 Mdot
.97619 .20439 Mdot
.15986 .34039 Mdot
.29592 .38757 Mdot
.43197 .36892 Mdot
.56803 .38267 Mdot
.70408 .39219 Mdot
.84014 .20745 Mdot
.97619 .14977 Mdot
.15986 .33302 Mdot
.29592 .37053 Mdot
.43197 .37459 Mdot
.56803 .47107 Mdot
.70408 .31683 Mdot
.84014 .21026 Mdot
.97619 .15265 Mdot
.15986 .33238 Mdot
.29592 .33884 Mdot
.43197 .35558 Mdot
.56803 .46802 Mdot
.70408 .33218 Mdot
.84014 .23635 Mdot
.97619 .16561 Mdot
.15986 .3565 Mdot
.29592 .36861 Mdot
.43197 .35294 Mdot
.56803 .36971 Mdot
.70408 .34371 Mdot
.84014 .26982 Mdot
.97619 .16769 Mdot
.15986 .34929 Mdot
.29592 .30339 Mdot
.43197 .39229 Mdot
.56803 .3468 Mdot
.70408 .33713 Mdot
.84014 .29037 Mdot
.97619 .20968 Mdot
.15986 .37527 Mdot
.29592 .3346 Mdot
.43197 .44168 Mdot
.56803 .38268 Mdot
.70408 .34969 Mdot
.84014 .19472 Mdot
.97619 .15031 Mdot
.15986 .31054 Mdot
.29592 .39915 Mdot
.43197 .35025 Mdot
.56803 .35831 Mdot
.70408 .34338 Mdot
.84014 .26294 Mdot
.97619 .2044 Mdot
.15986 .36756 Mdot
.29592 .36012 Mdot
.43197 .33758 Mdot
.56803 .3526 Mdot
.70408 .35537 Mdot
.84014 .26449 Mdot
.97619 .19125 Mdot
.15986 .40069 Mdot
.29592 .356 Mdot
.43197 .2787 Mdot
.56803 .49812 Mdot
.70408 .26999 Mdot
.84014 .25755 Mdot
.97619 .16791 Mdot
.15986 .38267 Mdot
.29592 .39346 Mdot
.43197 .38492 Mdot
.56803 .29713 Mdot
.70408 .3295 Mdot
.84014 .24022 Mdot
.97619 .20106 Mdot
.15986 .3542 Mdot
.29592 .32464 Mdot
.43197 .36821 Mdot
.56803 .36103 Mdot
.70408 .36341 Mdot
.84014 .23483 Mdot
.97619 .22265 Mdot
.15986 .36464 Mdot
.29592 .34088 Mdot
.43197 .36909 Mdot
.56803 .37783 Mdot
.70408 .32094 Mdot
.84014 .2895 Mdot
.97619 .1661 Mdot
.15986 .38259 Mdot
.29592 .34391 Mdot
.43197 .35188 Mdot
.56803 .42882 Mdot
.70408 .3211 Mdot
.84014 .19935 Mdot
.97619 .20132 Mdot
.15986 .40948 Mdot
.29592 .33323 Mdot
.43197 .44303 Mdot
.56803 .36332 Mdot
.70408 .20945 Mdot
.84014 .26246 Mdot
.97619 .208 Mdot
.15986 .37406 Mdot
.29592 .37644 Mdot
.43197 .29811 Mdot
.56803 .34126 Mdot
.70408 .37712 Mdot
.84014 .25022 Mdot
.97619 .21176 Mdot
.15986 .41405 Mdot
.29592 .49841 Mdot
.43197 .44314 Mdot
.56803 .31483 Mdot
.70408 .23684 Mdot
.84014 .17939 Mdot
.97619 .1423 Mdot
.15986 .27124 Mdot
.29592 .27036 Mdot
.43197 .37757 Mdot
.56803 .34478 Mdot
.70408 .32712 Mdot
.84014 .33058 Mdot
.97619 .30732 Mdot
.15986 .22049 Mdot
.29592 .34408 Mdot
.43197 .32817 Mdot
.56803 .37631 Mdot
.70408 .36985 Mdot
.84014 .30098 Mdot
.97619 .28909 Mdot
.15986 .33663 Mdot
.29592 .34356 Mdot
.43197 .36244 Mdot
.56803 .35488 Mdot
.70408 .31825 Mdot
.84014 .27183 Mdot
.97619 .24137 Mdot
.15986 .38325 Mdot
.29592 .35663 Mdot
.43197 .39235 Mdot
.56803 .32271 Mdot
.70408 .37657 Mdot
.84014 .23134 Mdot
.97619 .16611 Mdot
.15986 .45166 Mdot
.29592 .36995 Mdot
.43197 .27565 Mdot
.56803 .37512 Mdot
.70408 .33497 Mdot
.84014 .22213 Mdot
.97619 .1995 Mdot
.15986 .32003 Mdot
.29592 .36563 Mdot
.43197 .3342 Mdot
.56803 .31487 Mdot
.70408 .40712 Mdot
.84014 .26766 Mdot
.97619 .21945 Mdot
.15986 .41891 Mdot
.29592 .31085 Mdot
.43197 .34708 Mdot
.56803 .33293 Mdot
.70408 .32701 Mdot
.84014 .27473 Mdot
.97619 .21747 Mdot
.15986 .33938 Mdot
.29592 .3177 Mdot
.43197 .3181 Mdot
.56803 .39954 Mdot
.70408 .33748 Mdot
.84014 .27795 Mdot
.97619 .23882 Mdot
.15986 .321 Mdot
.29592 .3261 Mdot
.43197 .31677 Mdot
.56803 .31503 Mdot
.70408 .37471 Mdot
.84014 .33045 Mdot
.97619 .2449 Mdot
.15986 .30152 Mdot
.29592 .38627 Mdot
.43197 .33229 Mdot
.56803 .52827 Mdot
.70408 .29035 Mdot
.84014 .2444 Mdot
.97619 .14587 Mdot
.15986 .3833 Mdot
.29592 .47013 Mdot
.43197 .37255 Mdot
.56803 .34361 Mdot
.70408 .24605 Mdot
.84014 .22944 Mdot
.97619 .18389 Mdot
.15986 .37556 Mdot
.29592 .27865 Mdot
.43197 .34597 Mdot
.56803 .35177 Mdot
.70408 .33542 Mdot
.84014 .29585 Mdot
.97619 .24575 Mdot
.15986 .32339 Mdot
.29592 .38274 Mdot
.43197 .3303 Mdot
.56803 .36731 Mdot
.70408 .33537 Mdot
.84014 .30846 Mdot
.97619 .1814 Mdot
.15986 .32487 Mdot
.29592 .35877 Mdot
.43197 .29453 Mdot
.56803 .3369 Mdot
.70408 .36553 Mdot
.84014 .28637 Mdot
.97619 .26199 Mdot
.15986 .3985 Mdot
.29592 .36088 Mdot
.43197 .27846 Mdot
.56803 .33025 Mdot
.70408 .34651 Mdot
.84014 .28718 Mdot
.97619 .22719 Mdot
.15986 .34618 Mdot
.29592 .4027 Mdot
.43197 .40247 Mdot
.56803 .30737 Mdot
.70408 .23544 Mdot
.84014 .30012 Mdot
.97619 .23468 Mdot
.15986 .10724 Mdot
.29592 .36721 Mdot
.43197 .34352 Mdot
.56803 .59911 Mdot
.70408 .35597 Mdot
.84014 .24419 Mdot
.97619 .21172 Mdot
.15986 .49484 Mdot
.29592 .37671 Mdot
.43197 .29292 Mdot
.56803 .28797 Mdot
.70408 .40834 Mdot
.84014 .20779 Mdot
.97619 .16039 Mdot
.15986 .33721 Mdot
.29592 .196 Mdot
.43197 .52662 Mdot
.56803 .32624 Mdot
.70408 .32345 Mdot
.84014 .27053 Mdot
.97619 .24892 Mdot
.15986 .40767 Mdot
.29592 .35671 Mdot
.43197 .3171 Mdot
.56803 .37471 Mdot
.70408 .28197 Mdot
.84014 .28257 Mdot
.97619 .20824 Mdot
.15986 .37616 Mdot
.29592 .36915 Mdot
.43197 .39394 Mdot
.56803 .31547 Mdot
.70408 .33873 Mdot
.84014 .22864 Mdot
.97619 .20686 Mdot
.15986 .49514 Mdot
.29592 .4772 Mdot
.43197 .37918 Mdot
.56803 .21459 Mdot
.70408 .25732 Mdot
.84014 .23111 Mdot
.97619 .17443 Mdot
.15986 .3888 Mdot
.29592 .378 Mdot
.43197 .40114 Mdot
.56803 .44252 Mdot
.70408 .28236 Mdot
.84014 .20522 Mdot
.97619 .13092 Mdot
.15986 .16274 Mdot
.29592 .38663 Mdot
.43197 .48501 Mdot
.56803 .31052 Mdot
.70408 .34456 Mdot
.84014 .33287 Mdot
.97619 .20663 Mdot
.15986 .3377 Mdot
.29592 .3719 Mdot
.43197 .51103 Mdot
.56803 .27732 Mdot
.70408 .26884 Mdot
.84014 .2875 Mdot
.97619 .17467 Mdot
.15986 .43841 Mdot
.29592 .36814 Mdot
.43197 .42839 Mdot
.56803 .35346 Mdot
.70408 .29147 Mdot
.84014 .20402 Mdot
.97619 .14507 Mdot
.15986 .34372 Mdot
.29592 .4405 Mdot
.43197 .33996 Mdot
.56803 .47414 Mdot
.70408 .35827 Mdot
.84014 .18438 Mdot
.97619 .088 Mdot
.15986 .4768 Mdot
.29592 .34742 Mdot
.43197 .34448 Mdot
.56803 .4352 Mdot
.70408 .3292 Mdot
.84014 .23098 Mdot
.97619 .06488 Mdot
.15986 .4593 Mdot
.29592 .38476 Mdot
.43197 .38299 Mdot
.56803 .33138 Mdot
.70408 .33038 Mdot
.84014 .19555 Mdot
.97619 .14462 Mdot
.15986 .44854 Mdot
.29592 .36354 Mdot
.43197 .31776 Mdot
.56803 .36188 Mdot
.70408 .35569 Mdot
.84014 .21794 Mdot
.97619 .16361 Mdot
.15986 .36012 Mdot
.29592 .37 Mdot
.43197 .32217 Mdot
.56803 .3825 Mdot
.70408 .32369 Mdot
.84014 .2662 Mdot
.97619 .20428 Mdot
.15986 .36789 Mdot
.29592 .3839 Mdot
.43197 .3178 Mdot
.56803 .35641 Mdot
.70408 .33886 Mdot
.84014 .27122 Mdot
.97619 .19288 Mdot
.15986 .41756 Mdot
.29592 .362 Mdot
.43197 .37904 Mdot
.56803 .32959 Mdot
.70408 .39658 Mdot
.84014 .19778 Mdot
.97619 .14641 Mdot
.15986 .29286 Mdot
.29592 .31534 Mdot
.43197 .28548 Mdot
.56803 .42407 Mdot
.70408 .43191 Mdot
.84014 .28337 Mdot
.97619 .19594 Mdot
.15986 .31893 Mdot
.29592 .4059 Mdot
.43197 .32397 Mdot
.56803 .41405 Mdot
.70408 .35269 Mdot
.84014 .24101 Mdot
.97619 .17242 Mdot
.15986 .33211 Mdot
.29592 .30179 Mdot
.56803 .31582 Mdot
.70408 .24211 Mdot
.84014 .17056 Mdot
.97619 .11756 Mdot
.15986 .46889 Mdot
.29592 .34999 Mdot
.43197 .33308 Mdot
.56803 .35493 Mdot
.70408 .31218 Mdot
.84014 .23218 Mdot
.97619 .17772 Mdot
.15986 .32913 Mdot
.29592 .33508 Mdot
.43197 .41071 Mdot
.56803 .33751 Mdot
.70408 .42903 Mdot
.84014 .21535 Mdot
.97619 .17215 Mdot
.15986 .3397 Mdot
.29592 .36181 Mdot
.43197 .35997 Mdot
.56803 .34613 Mdot
.70408 .35524 Mdot
.84014 .24917 Mdot
.97619 .21695 Mdot
.15986 .3664 Mdot
.29592 .36708 Mdot
.43197 .38089 Mdot
.56803 .32853 Mdot
.70408 .32967 Mdot
.84014 .24234 Mdot
.97619 .21404 Mdot
.15986 .52551 Mdot
.29592 .36278 Mdot
.43197 .27445 Mdot
.56803 .32871 Mdot
.70408 .30543 Mdot
.84014 .25113 Mdot
.97619 .18096 Mdot
.15986 .34174 Mdot
.29592 .33561 Mdot
.43197 .35025 Mdot
.56803 .40953 Mdot
.70408 .29773 Mdot
.84014 .25007 Mdot
.97619 .24403 Mdot
.15986 .33734 Mdot
.29592 .34239 Mdot
.43197 .35456 Mdot
.56803 .34061 Mdot
.70408 .34283 Mdot
.84014 .26555 Mdot
.97619 .24569 Mdot
.15986 .33677 Mdot
.29592 .36193 Mdot
.43197 .37962 Mdot
.56803 .39181 Mdot
.70408 .30044 Mdot
.84014 .26795 Mdot
.97619 .19045 Mdot
.15986 .49884 Mdot
.29592 .39483 Mdot
.43197 .31074 Mdot
.56803 .21139 Mdot
.70408 .32495 Mdot
.84014 .27646 Mdot
.97619 .21176 Mdot
.15986 .37188 Mdot
.29592 .33749 Mdot
.43197 .35473 Mdot
.56803 .35075 Mdot
.70408 .38652 Mdot
.84014 .25378 Mdot
.97619 .17382 Mdot
.15986 .20238 Mdot
.29592 .55968 Mdot
.43197 .45343 Mdot
.56803 .31398 Mdot
.70408 .37793 Mdot
.84014 .21885 Mdot
.97619 .10271 Mdot
.15986 .39622 Mdot
.29592 .42545 Mdot
.43197 .39462 Mdot
.56803 .33505 Mdot
.70408 .41296 Mdot
.84014 .19342 Mdot
.97619 .07124 Mdot
.15986 .45457 Mdot
.29592 .41609 Mdot
.43197 .3973 Mdot
.56803 .37752 Mdot
.70408 .3032 Mdot
.84014 .15669 Mdot
.97619 .1236 Mdot
.15986 .54411 Mdot
.29592 .40641 Mdot
.43197 .30077 Mdot
.56803 .2807 Mdot
.70408 .31499 Mdot
.84014 .22889 Mdot
.97619 .15309 Mdot
.29592 .25676 Mdot
.43197 .50744 Mdot
.56803 .45061 Mdot
.70408 .47179 Mdot
.15986 .36745 Mdot
.29592 .24556 Mdot
.43197 .28326 Mdot
.56803 .50108 Mdot
.70408 .2557 Mdot
.84014 .30479 Mdot
.97619 .27115 Mdot
.15986 .28612 Mdot
.29592 .12503 Mdot
.43197 .40659 Mdot
.56803 .43697 Mdot
.70408 .418 Mdot
.84014 .32745 Mdot
.97619 .2288 Mdot
.15986 .4289 Mdot
.29592 .59192 Mdot
.43197 .47829 Mdot
.56803 .41885 Mdot
.70408 .22469 Mdot
.84014 .09803 Mdot
.15986 .50592 Mdot
.29592 .35734 Mdot
.43197 .40573 Mdot
.56803 .38093 Mdot
.70408 .35222 Mdot
.84014 .10883 Mdot
.97619 .11799 Mdot
.15986 .39599 Mdot
.29592 .37908 Mdot
.43197 .35373 Mdot
.56803 .35473 Mdot
.70408 .32366 Mdot
.84014 .23063 Mdot
.97619 .19114 Mdot
.15986 .41547 Mdot
.29592 .31436 Mdot
.43197 .38298 Mdot
.56803 .33828 Mdot
.70408 .32674 Mdot
.84014 .23947 Mdot
.97619 .21166 Mdot
.15986 .36209 Mdot
.29592 .35858 Mdot
.43197 .34083 Mdot
.56803 .3325 Mdot
.70408 .30896 Mdot
.84014 .28074 Mdot
.97619 .24526 Mdot
.15986 .31279 Mdot
.29592 .26372 Mdot
.43197 .35691 Mdot
.56803 .3791 Mdot
.70408 .28044 Mdot
.84014 .3587 Mdot
.97619 .27731 Mdot
.15986 .35037 Mdot
.29592 .32535 Mdot
.43197 .34357 Mdot
.56803 .39382 Mdot
.70408 .30265 Mdot
.84014 .25828 Mdot
.97619 .25492 Mdot
.15986 .35615 Mdot
.29592 .33576 Mdot
.43197 .29823 Mdot
.56803 .33323 Mdot
.70408 .42113 Mdot
.84014 .26252 Mdot
.97619 .22195 Mdot
.15986 .35593 Mdot
.29592 .37497 Mdot
.43197 .34161 Mdot
.56803 .32182 Mdot
.70408 .30113 Mdot
.84014 .2878 Mdot
.97619 .2457 Mdot
.15986 .35623 Mdot
.29592 .3638 Mdot
.43197 .32275 Mdot
.56803 .35056 Mdot
.70408 .30265 Mdot
.84014 .28521 Mdot
.97619 .24776 Mdot
.15986 .35742 Mdot
.29592 .35117 Mdot
.43197 .36406 Mdot
.56803 .34356 Mdot
.70408 .33787 Mdot
.84014 .26145 Mdot
.97619 .21344 Mdot
.15986 .37489 Mdot
.29592 .3858 Mdot
.43197 .40452 Mdot
.56803 .38313 Mdot
.70408 .24543 Mdot
.84014 .2648 Mdot
.97619 .17038 Mdot
.15986 .17207 Mdot
.29592 .39062 Mdot
.43197 .34978 Mdot
.56803 .37419 Mdot
.70408 .33401 Mdot
.84014 .33215 Mdot
.97619 .27615 Mdot
.15986 .38595 Mdot
.29592 .33357 Mdot
.43197 .33453 Mdot
.56803 .39718 Mdot
.70408 .35381 Mdot
.84014 .24419 Mdot
.97619 .17974 Mdot
.15986 .36164 Mdot
.29592 .43093 Mdot
.43197 .37638 Mdot
.56803 .35808 Mdot
.70408 .30475 Mdot
.84014 .25988 Mdot
.97619 .13731 Mdot
.15986 .35716 Mdot
.29592 .39878 Mdot
.43197 .45248 Mdot
.56803 .3398 Mdot
.70408 .30448 Mdot
.84014 .21058 Mdot
.97619 .16569 Mdot
1 1 0 r
.01 w
.15986 .39798 m
.19298 .39541 L
.2291 .39234 L
.26301 .38916 L
.29563 .38582 L
.33036 .38192 L
.36378 .37781 L
.3993 .37301 L
.43353 .36793 L
.46646 .36258 L
.50148 .35633 L
.53521 .34973 L
.56764 .34279 L
.60218 .3347 L
.63541 .32616 L
.67074 .3162 L
.70478 .30567 L
.73752 .29457 L
.77235 .28163 L
.80589 .26797 L
.84154 .25202 L
.87588 .23513 L
.90892 .21732 L
.94407 .19655 L
.97619 .17575 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`009@3oool4
00000200oooo00<000000?ooo`3oool07@3oool6000001d0oooo1000000Q0?ooo`030000003oool0
oooo01d0oooo1000000N0?ooo`@000007`3oool00`000000oooo0?ooo`070?ooo`00903oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`0000007@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01`3oool002@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo1`00000M0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01`3oool002@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`060?ooo`00903oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo01X0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`030000003oool0oooo01X0
oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0703oool3000001h0oooo00@000000?ooo`3oool000007P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`0000000P00000P0?ooo`03
0000003oool0oooo00H0oooo000T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
6`3oool010000000oooo0?ooo`00000N0?ooo`D000007@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00D0oooo000T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0000000O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`000000
7P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
1@3oool002@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`8000007`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0M0?ooo`8000007`3oool00`000000oooo0?ooo`0O0?ooo`050000003o
ool0oooo0?ooo`0000008@3oool00`000000oooo0?ooo`040?ooo`009@3oool400000200oooo00<0
00000?ooo`3oool07P3oool4000001h0oooo1000000Q0?ooo`030000003oool0oooo01d0oooo1@00
000N0?ooo`<000007@3oool6000000H0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo000Q0?ooood000000P3oool00240oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool100000040oooo0@3oool00240oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000
003oool0oooo0?T0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@00
00010?ooo`40oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40oooo000Q0?oo
o`800000n@3oool200000080oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40
oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003o
ool0oooo0?T0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@000001
0?ooo`40oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40oooo000Q0?ooo`80
0000n@3oool200000080oooo000Q0?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40oooo
000Q0?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40oooo000=0?ooo`H000000`3oool4
000000L0oooo00<000000?ooo`3oool0lP3oool3003o00@0oooo0@0000010?ooo`40oooo000>0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?40oooo1@00o`030?ooo`4000000@3oool10?ooo`003`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3a0?ooo`D00?l00`3oool100000040oooo0@3oool000@0oooo1`0000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`<00000
l@3oool5003o0080oooo0P0000020?ooo`004@3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3a0?ooo`D00?l00`3oool100000040oooo
0@3oool00180oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0?80oooo0`00o`040?ooo`4000000@3oool10?ooo`004P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0lP3oool3003o00@0oooo
0@0000010?ooo`40oooo000=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?40oooo1@00o`030?ooo`400000
0@3oool10?ooo`003@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3@0?ooo`<00?l07P3oool5003o00<0oooo
0@0000010?ooo`40oooo000>0?ooo`@00000103oool4000000L0oooo00<000000?ooo`3oool0c`3o
ool5003o01d0oooo1@00o`030?ooo`4000000@3oool10?ooo`008@3oool200000=00oooo1@00o`0M
0?ooo`D00?l00P3oool200000080oooo000Q0?ooo`030000003oool0oooo02@0oooo0`00o`2X0?oo
o`D00?l07@3oool5003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo02<0
oooo1@00o`2W0?ooo`D00?l07@3oool5003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000
003oool0oooo02<0oooo1@00o`2W0?ooo`D00?l07P3oool3003o00@0oooo0@0000010?ooo`40oooo
000Q0?ooo`030000003oool0oooo02<0oooo1@00o`2W0?ooo`D00?l07@3oool5003o00<0oooo0@00
00010?ooo`40oooo000Q0?ooo`030000003oool0oooo02@0oooo0`00o`0P0?ooo`<00?l0QP3oool3
003o01h0oooo1@00o`030?ooo`4000000@3oool10?ooo`008@3oool2000004L0oooo1@00o`2V0?oo
o`D00?l00P3oool200000080oooo000Q0?ooo`030000003oool0oooo04H0oooo1@00o`2V0?ooo`D0
0?l00`3oool100000040oooo0@3oool00240oooo00<000000?ooo`3oool0AP3oool5003o0:H0oooo
1@00o`030?ooo`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`170?ooo`<00?l0Y`3o
ool5003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo0?40oooo1@00o`03
0?ooo`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`3a0?ooo`D00?l00`3oool10000
0040oooo0@3oool00240oooo0P00003b0?ooo`D00?l00P3oool200000080oooo000Q0?ooo`030000
003oool0oooo0=00oooo0`00o`0N0?ooo`D00?l00`3oool100000040oooo0@3oool00240oooo00<0
00000?ooo`3oool0c`3oool5003o01d0oooo1@00o`030?ooo`4000000@3oool10?ooo`008@3oool0
0`000000oooo0?ooo`0T0?ooo`<00?l0Z03oool5003o01d0oooo1@00o`030?ooo`4000000@3oool1
0?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l0Y`3oool5003o01d0oooo1@00o`030?oo
o`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l0Z03oool3003o01h0
oooo1@00o`030?ooo`4000000@3oool10?ooo`008@3oool2000002@0oooo1@00o`2W0?ooo`D00?l0
7@3oool5003o0080oooo0P0000020?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l0Y`3o
ool5003o01d0oooo0P00o`000`3oo`000?l0003o00030?ooo`4000000@3oool10?ooo`008@3oool0
0`000000oooo0?ooo`0S0?ooo`D00?l0Y`3oool5003o01d0oooo103oo`001@00o`00oooo0?ooo`3o
ool000000080oooo000@0?ooo`030000003oool0oooo00<0oooo100000070?ooo`030000003oool0
oooo02@0oooo0`00o`2X0?ooo`D00?l0703oool40?oo00800?l00`3oool100000040oooo0@3oool0
0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0c`3oool5003o01X0oooo103oo`04003o00<0oooo0@0000010?oo
o`40oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04L0oooo0`00o`250?ooo`D00?l06@3oool40?oo00D0
0?l00`3oool100000040oooo0@3oool000@0oooo1`0000050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04H0oooo
1@00o`240?ooo`D00?l05`3oool40?oo0080oooo1@00o`030?ooo`4000000@3oool10?ooo`00403o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool3000002@0oooo0`00o`0O0?ooo`D00?l0Q03oool5003o01D0oooo1@3oo`030?ooo`D00?l00P3o
ool200000080oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l0H`3oool3
003o01h0oooo1@00o`0C0?ooo`D0ool01@3oool5003o00<0oooo0@0000010?ooo`40oooo000@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02<0oooo1@00o`0O0?ooo`<00?l0@@3oool3003o01l0oooo1@00o`0M0?oo
o`D00?l04P3oool40?oo00L0oooo1@00o`030?ooo`4000000@3oool10?ooo`003P3oool00`000000
oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0S0?ooo`D00?l0HP3oool5003o01h0oooo1@00o`0M0?ooo`D00?l0403oool40?oo00T0
oooo1@00o`030?ooo`4000000@3oool10?ooo`003`3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0oooo0`00o`1S0?ooo`D00?l0
7P3oool5003o01d0oooo1@00o`0>0?ooo`D0ool02P3oool5003o00<0oooo0@0000010?ooo`40oooo
000@0?ooo`030000003oool0oooo00<0oooo100000070?ooo`030000003oool0oooo02<0oooo1@00
o`1R0?ooo`D00?l07`3oool3003o01h0oooo1@00o`0<0?ooo`D0ool0303oool5003o00<0oooo0@00
00010?ooo`40oooo000Q0?ooo`800000903oool5003o0680oooo1@00o`0N0?ooo`D00?l07@3oool5
003o00/0oooo103oo`0>0?ooo`D00?l00P3oool200000080oooo000Q0?ooo`030000003oool0oooo
02<0oooo1@00o`1S0?ooo`<00?l07`3oool5003o01d0oooo1@00o`090?ooo`@0ool0403oool5003o
00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo02@0oooo0`00o`260?ooo`D0
0?l07@3oool5003o00P0oooo103oo`0A0?ooo`D00?l00`3oool100000040oooo0@3oool00240oooo
00<000000?ooo`3oool0[@3oool5003o01d0oooo1@00o`060?ooo`@0ool04`3oool5003o00<0oooo
0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo04L0oooo0`00o`1S0?ooo`D00?l07@3o
ool5003o00@0oooo1@3oo`0D0?ooo`D00?l00`3oool100000040oooo0@3oool00240oooo00<00000
0?ooo`3oool0AP3oool5003o0680oooo1@00o`0M0?ooo`D00?l000<0oooo0?oo003oo`00103oo`0F
0?ooo`D00?l00`3oool100000040oooo0@3oool00240oooo0P0000170?ooo`D00?l0HP3oool5003o
01d0oooo1000o`060?oo01P0oooo1@00o`020?ooo`8000000P3oool00240oooo00<000000?ooo`3o
ool0AP3oool5003o0680oooo1@00o`0M0?ooo`800?l01@3oo`0K0?ooo`D00?l00`3oool100000040
oooo0@3oool00240oooo00<000000?ooo`3oool0AP3oool5003o0680oooo1@00o`0M0?ooo`D0ool0
7@3oool5003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo04H0oooo1@00
o`1R0?ooo`D00?l06P3oool60?oo00800?l07@3oool5003o00<0oooo0@0000010?ooo`40oooo000Q
0?ooo`030000003oool0oooo04H0oooo1@00o`1R0?ooo`D00?l0603oool60?oo00@00?l07@3oool5
003o00<0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo02@0oooo0`00o`0O0?oo
o`D00?l0HP3oool5003o01H0oooo1@3oo`020?ooo`D00?l07@3oool5003o00<0oooo0@0000010?oo
o`40oooo000Q0?ooo`800000903oool5003o01h0oooo1@00o`0N0?ooo`<00?l07`3oool3003o01l0
oooo1@00o`0D0?ooo`D0ool0103oool5003o01d0oooo1@00o`020?ooo`8000000P3oool00240oooo
00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o01h0oooo
1@00o`0B0?ooo`D0ool01P3oool5003o01d0oooo1@00o`030?ooo`4000000@3oool10?ooo`008@3o
ool00`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3o
ool5003o0100oooo1@3oo`080?ooo`D00?l07@3oool5003o00<0oooo0@0000010?ooo`40oooo000Q
0?ooo`030000003oool0oooo02@0oooo0`00o`0O0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0N
0?ooo`D00?l03P3oool50?oo00X0oooo1@00o`0M0?ooo`D00?l00`3oool100000040oooo0@3oool0
0240oooo00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o
01h0oooo1@00o`0;0?ooo`H0ool0303oool5003o01d0oooo1@00o`030?ooo`4000000@3oool10?oo
o`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l07`3oool3003o01h0oooo1@00o`0M0?ooo`D0
0?l07P3oool5003o00P0oooo1`3oo`0>0?ooo`D00?l07@3oool5003o00<0oooo0@0000010?ooo`40
oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo
1@00o`0N0?ooo`D00?l01@3oool70?oo0140oooo1@00o`0M0?ooo`D00?l00`3oool100000040oooo
0@3oool00240oooo0P00000T0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3o
ool5003o0080oooo1`3oo`0D0?ooo`D00?l07P3oool3003o00<0oooo0P0000020?ooo`008@3oool0
0`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3oool5
003o00H0ool05`3oool5003o01h0oooo0`00o`040?ooo`4000000@3oool10?ooo`005P3oool40000
00L0oooo00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o
01h0oooo0P00o`060?oo01X0oooo1@00o`0M0?ooo`D00?l00`3oool100000040oooo0@3oool001D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0
oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0L0?ooo`P0ool0703oool5003o01d0
oooo1@00o`030?ooo`4000000@3oool10?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l0
7@3oool5003o01L0oooo2@3oo`03003o01d0oooo1@00o`0M0?ooo`D00?l00`3oool100000040oooo
0@3oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02<0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0D0?ooo`P0ool00P3o
ool5003o01h0oooo0`00o`0O0?ooo`<00?l0103oool100000040oooo0@3oool001D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooobH000001@00o`0N000000D00?l07@000005
003o01d000001@00o`0A000000L0ool01P000005003o01h000000`00o`0W00000080oooo000E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?oo
o`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l03P3oool70?oo00T0oooo1@00o`0M0?oo
o`D00?l09@3oool100000040oooo0@3oool001D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0
oooo1@00o`0:0?ooo`P0ool0303oool5003o01d0oooo1@00o`0U0?ooo`4000000@3oool10?ooo`00
5@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
8`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o00H0oooo203oo`0@0?ooo`D00?l0
7@3oool5003o02D0oooo0@0000010?ooo`40oooo000E0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o01d0oooo1@00
o`0M0?ooo`D00?l00P3oool80?oo01@0oooo1@00o`0M0?ooo`D00?l09@3oool100000040oooo0@3o
ool001H0oooo100000070?ooo`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07@3oool5
003o01d0oooo0P00o`090?oo01P0oooo1@00o`0M0?ooo`D00?l09@3oool100000040oooo0@3oool0
0240oooo0P00000T0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0K0?ooo`T0ool0703oool5003o
01h0oooo0`00o`0U0?ooo`8000000P3oool00240oooo00<000000?ooo`3oool08`3oool5003o01h0
oooo1@00o`0M0?ooo`D00?l05`3oool80?oo00<00?l07P3oool5003o04L0oooo0@0000010?ooo`40
oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07@3oool5003o00l0oooo
303oo`020?ooo`D00?l07P3oool5003o01h0oooo0`00o`0V0?ooo`4000000@3oool10?ooo`008@3o
ool00`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0;0?ooo``0ool01P3o
ool5003o01h0oooo1@00o`0M0?ooo`D00?l09@3oool100000040oooo0@3oool00240oooo00<00000
0?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l01P3oool90?oo00h0oooo1@00o`0N
0?ooo`D00?l07@3oool5003o02D0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo
02<0oooo1@00o`0N0?ooo`D00?l07@3oool2003o00h0ool04P3oool5003o01h0oooo1@00o`0M0?oo
o`D00?l09@3oool100000040oooo0@3oool00240oooo0P00000T0?ooo`D00?l07P3oool5003o01/0
oooo3@3oo`0G0?ooo`D00?l07P3oool5003o01h0oooo0`00o`0U0?ooo`8000000P3oool00240oooo
00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0G0?ooo`P0ool00`00o`0M0?ooo`D00?l0
7P3oool5003o04L0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00
o`0N0?ooo`D00?l03P3oool=0?oo0080oooo1@00o`0M0?ooo`D00?l07P3oool5003o04L0oooo0@00
00010?ooo`40oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l01@3ooolB
0?oo00H0oooo1@00o`0M0?ooo`D00?l07P3oool5003o04L0oooo0@0000010?ooo`40oooo000Q0?oo
o`030000003oool0oooo02<0oooo1@00o`0N0?ooo`800?l04@3oo`0?0?ooo`D00?l07@3oool5003o
01h0oooo1@00o`170?ooo`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D0
0?l05`3ooolA0?oo01P0oooo1@00o`0M0?ooo`D00?l07P3oool5003o04L0oooo0@0000010?ooo`40
oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`0?0?oooa40ool00`00o`0M0?ooo`D00?l0
7@3oool5003o01h0oooo1@00o`170?ooo`4000000@3oool10?ooo`008@3oool2000002@0oooo0`00
o`0I0?oo00L0oooo1@00o`0M0?ooo`D00?l07@3oool5003o01h0oooo1@00o`160?ooo`8000000P3o
ool00240oooo00<000000?ooo`3oool08`3oool00`00o`00ool00?oo000A0?oo00l0oooo1@00o`0M
0?ooo`D00?l07@3oool5003o01h0oooo1@00o`170?ooo`4000000@3oool10?ooo`008@3oool00`00
0000oooo0?ooo`0S0?ooo`03003o003oo`00ool000800?l07P3oool5003o01d0oooo1@00o`0M0?oo
o`D00?l07P3oool5003o04L0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo02<0
oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0N0?ooo`D00?l0A`3oool100000040
oooo0@3oool00240oooo00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l0
7@3oool5003o01h0oooo1@00o`170?ooo`4000000@3oool10?ooo`008@3oool00`000000oooo0?oo
o`0S0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3oool5003o04L0oooo0@00
00010?ooo`40oooo000Q0?ooo`800000903oool5003o01h0oooo1@00o`0N0?ooo`<00?l07P3oool5
003o01h0oooo1@00o`160?ooo`8000000P3oool00240oooo00<000000?ooo`3oool08`3oool5003o
01h0oooo1@00o`0N0?ooo`<00?l07P3oool5003o01h0oooo1@00o`170?ooo`4000000@3oool10?oo
o`00403oool00`000000oooo0?ooo`030?ooo`@000001`3oool00`000000oooo0?ooo`0S0?ooo`D0
0?l07P3oool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3oool5003o04L0oooo0@0000010?ooo`40
oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo
1@00o`0N0?ooo`D00?l0A`3oool100000040oooo0@3oool00100oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3o
ool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o01h0oooo1@00o`170?ooo`4000000@3o
ool10?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3oool5003o01d0oooo1@00o`0M
0?ooo`D00?l07P3oool5003o04L0oooo0@0000010?ooo`40oooo000@0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`<000008`3oool5003o
01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o01l0oooo0`00o`170?ooo`8000000P3oool00100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0M0?ooo`D00?l07@3oool5003o06X0
oooo0@0000010?ooo`40oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo1@00o`0O0?ooo`<00?l0
7P3oool5003o01d0oooo1@00o`1Z0?ooo`4000000@3oool10?ooo`003P3oool00`000000oooo0000
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0S0?ooo`D00?l0@03oool5003o01d0oooo1@00o`1Z0?ooo`4000000@3oool10?ooo`003`3oool2
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02<0oooo1@00o`100?ooo`D00?l07P3oool3003o06/0oooo0@0000010?ooo`40oooo000@0?oo
o`030000003oool0oooo00<0oooo100000070?ooo`030000003oool0oooo02<0oooo1@00o`0O0?oo
o`<00?l07`3oool3003o01l0oooo0`00o`1[0?ooo`4000000@3oool10?ooo`008@3oool2000002@0
oooo1@00o`0N0?ooo`D00?l0?`3oool5003o01l0oooo0`00o`170?ooo`8000000P3oool00240oooo
00<000000?ooo`3oool08`3oool5003o01h0oooo1@00o`0N0?ooo`<00?l07P3oool5003o01h0oooo
1@00o`170?ooo`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l07P3o
ool5003o01d0oooo1@00o`0M0?ooo`D00?l07P3oool5003o04L0oooo0@0000010?ooo`40oooo000Q
0?ooo`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07@3oool5003o01d0oooo1@00o`0N
0?ooo`D00?l0A`3oool100000040oooo0@3oool00240oooo00<000000?ooo`3oool08`3oool5003o
01h0oooo1@00o`0M0?ooo`D00?l07P3oool3003o0200oooo0`00o`180?ooo`4000000@3oool10?oo
o`008@3oool00`000000oooo0?ooo`0T0?ooo`<00?l0803oool3003o01h0oooo1@00o`2<0?ooo`40
00000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l07`3oool3003o01h0oooo
1@00o`0N0?ooo`<00?l0J`3oool100000040oooo0@3oool00240oooo0P00000T0?ooo`D00?l07P3o
ool5003o01h0oooo0`00o`0N0?ooo`D00?l0J@3oool200000080oooo000Q0?ooo`030000003oool0
oooo02<0oooo1@00o`0N0?ooo`D00?l0?`3oool5003o06X0oooo0@0000010?ooo`40oooo000Q0?oo
o`030000003oool0oooo02<0oooo1@00o`0N0?ooo`D00?l07P3oool3003o01h0oooo1@00o`1Z0?oo
o`4000000@3oool10?ooo`008@3oool00`000000oooo0?ooo`0S0?ooo`D00?l07`3oool3003o01h0
oooo1@00o`0M0?ooo`D00?l0JP3oool100000040oooo0@3oool00240oooo00<000000?ooo`3oool0
8`3oool5003o0400oooo1@00o`0N0?ooo`<00?l0J`3oool100000040oooo0@3oool00240oooo00<0
00000?ooo`3oool0903oool3003o0440oooo1@00o`2<0?ooo`4000000@3oool10?ooo`008@3oool2
000002D0oooo0`00o`120?ooo`<00?l0S03oool200000080oooo000Q0?ooo`030000003oool0oooo
02<0oooo1@00o`100?ooo`D00?l07P3oool3003o06/0oooo0@0000010?ooo`40oooo000Q0?ooo`03
0000003oool0oooo02<0oooo1@00o`100?ooo`D00?l07@3oool5003o06X0oooo0@0000010?ooo`40
oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`100?ooo`D00?l07@3oool5003o06X0oooo
0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo02@0oooo0`00o`120?ooo`<00?l07P3o
ool5003o06X0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo02@0oooo0`00o`1T
0?ooo`<00?l0J`3oool100000040oooo0@3oool00240oooo0P00000T0?ooo`D00?l0d03oool20000
0080oooo000Q0?ooo`030000003oool0oooo02<0oooo1@00o`3A0?ooo`4000000@3oool10?ooo`00
8@3oool00`000000oooo0?ooo`0S0?ooo`D00?l0d@3oool100000040oooo0@3oool000d0oooo1P00
00030?ooo`@000001`3oool00`000000oooo0?ooo`0T0?ooo`<00?l0803oool3003o0:l0oooo0@00
00010?ooo`40oooo000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo04H0oooo1@00o`2^0?ooo`4000000@3oool1
0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`160?ooo`D00?l0[P3oool100000040oooo0@3oool00100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo0`0000160?ooo`D00?l0[@3oool200000080oooo000A0?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04L0oooo0`00o`2_0?ooo`40
00000@3oool10?ooo`004P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0n@3oool100000040oooo0@3oool00180oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40
oooo000=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?T0oooo0@0000010?ooo`40oooo000=0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04L0oooo0`00o`2_0?ooo`4000000@3oool10?ooo`003P3oool4000000@0oooo
100000070?ooo`030000003oool0oooo04H0oooo1@00o`2^0?ooo`4000000@3oool10?ooo`008@3o
ool2000004L0oooo1@00o`100?ooo`<00?l0JP3oool200000080oooo000Q0?ooo`030000003oool0
oooo04H0oooo1@00o`0o0?ooo`D00?l0JP3oool100000040oooo0@3oool00240oooo00<000000?oo
o`3oool0A`3oool3003o0400oooo1@00o`1Z0?ooo`4000000@3oool10?ooo`008@3oool00`000000
oooo0?ooo`2:0?ooo`D00?l0JP3oool100000040oooo0@3oool00240oooo00<000000?ooo`3oool0
R`3oool3003o06/0oooo0@0000010?ooo`40oooo000Q0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`4000000@3oool10?ooo`008@3oooom
00000080oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.14854, -32.4429, \
0.0291132, 0.320275}}]
}, Open  ]],

Cell["\<\
We then use the function to \"correct\" the observed prices. The RotateLeft \
is necessary because the data does not start with a Monday.\
\>", "Text"],

Cell[BoxData[
    \(\(peak1\  = \ 
        peak\  - 
          Map[wfkt[#] &, 
            RotateLeft[Mod[Range[Length[peak]], 7] + 1, 3]];\)\)], "Input"],

Cell["\<\
The autocorrelation plot for the \"corrected\" data reveals that the weekly \
autocorrelation has disappeared.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AutoCorrelationPlot[Difference[peak1, 1], 30, 
        AspectRatio \[Rule] 0.3];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0824204 0.210437 [
[.02381 -0.0125 -5.90625 -17.75 ]
[.02381 -0.0125 5.90625 0 ]
[.18254 -0.0125 -5.90625 -17.75 ]
[.18254 -0.0125 5.90625 0 ]
[.34127 -0.0125 -9.8125 -17.75 ]
[.34127 -0.0125 9.8125 0 ]
[.5 -0.0125 -9.8125 -17.75 ]
[.5 -0.0125 9.8125 0 ]
[.65873 -0.0125 -9.8125 -17.75 ]
[.65873 -0.0125 9.8125 0 ]
[.81746 -0.0125 -9.8125 -17.75 ]
[.81746 -0.0125 9.8125 0 ]
[.97619 -0.0125 -9.8125 -17.75 ]
[.97619 -0.0125 9.8125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.7188 -35.5 ]
[.5 -0.0125 13.7188 -17.75 ]
[-0.0125 .04033 -33.25 -8.875 ]
[-0.0125 .04033 0 8.875 ]
[-0.0125 .08242 -11.8125 -8.875 ]
[-0.0125 .08242 0 8.875 ]
[-0.0125 .12451 -23.5625 -8.875 ]
[-0.0125 .12451 0 8.875 ]
[-0.0125 .1666 -23.5625 -8.875 ]
[-0.0125 .1666 0 8.875 ]
[-0.0125 .20868 -23.5625 -8.875 ]
[-0.0125 .20868 0 8.875 ]
[-0.0125 .25077 -23.5625 -8.875 ]
[-0.0125 .25077 0 8.875 ]
[-0.0125 .29286 -11.8125 -8.875 ]
[-0.0125 .29286 0 8.875 ]
[ 0 0 -0.125 0 ]
[ 0 .3 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -66.9063 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -70.8125 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.7188 -39.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lag) show
86.438 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04033 m
.00625 .04033 L
s
gsave
-0.0125 .04033 -94.25 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .08242 m
.00625 .08242 L
s
gsave
-0.0125 .08242 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12451 m
.00625 .12451 L
s
gsave
-0.0125 .12451 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .1666 m
.00625 .1666 L
s
gsave
-0.0125 .1666 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .20868 m
.00625 .20868 L
s
gsave
-0.0125 .20868 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .25077 m
.00625 .25077 L
s
gsave
-0.0125 .25077 -84.5625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .29286 m
.00625 .29286 L
s
gsave
-0.0125 .29286 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .00877 m
.00375 .00877 L
s
0 .01929 m
.00375 .01929 L
s
0 .02981 m
.00375 .02981 L
s
0 .05085 m
.00375 .05085 L
s
0 .06138 m
.00375 .06138 L
s
0 .0719 m
.00375 .0719 L
s
0 .09294 m
.00375 .09294 L
s
0 .10346 m
.00375 .10346 L
s
0 .11399 m
.00375 .11399 L
s
0 .13503 m
.00375 .13503 L
s
0 .14555 m
.00375 .14555 L
s
0 .15607 m
.00375 .15607 L
s
0 .17712 m
.00375 .17712 L
s
0 .18764 m
.00375 .18764 L
s
0 .19816 m
.00375 .19816 L
s
0 .2192 m
.00375 .2192 L
s
0 .22973 m
.00375 .22973 L
s
0 .24025 m
.00375 .24025 L
s
0 .26129 m
.00375 .26129 L
s
0 .27181 m
.00375 .27181 L
s
0 .28234 m
.00375 .28234 L
s
.25 Mabswid
0 0 m
0 .3 L
s
0 .3 m
1 .3 L
s
1 0 m
1 .3 L
s
0 .08242 m
1 .08242 L
s
.274 .51 .706 r
.02381 .29286 m
.02381 .29286 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.5 Mabswid
.02381 .08242 m
.02381 .29286 L
s
.05556 .0427 m
.05556 .0427 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.05556 .08242 m
.05556 .0427 L
s
.0873 .00714 m
.0873 .00714 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.0873 .08242 m
.0873 .00714 L
s
.11905 .09901 m
.11905 .09901 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.11905 .08242 m
.11905 .09901 L
s
.15079 .07712 m
.15079 .07712 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.15079 .08242 m
.15079 .07712 L
s
.18254 .09056 m
.18254 .09056 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.18254 .08242 m
.18254 .09056 L
s
.21429 .07047 m
.21429 .07047 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.21429 .08242 m
.21429 .07047 L
s
.24603 .10237 m
.24603 .10237 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.24603 .08242 m
.24603 .10237 L
s
.27778 .07331 m
.27778 .07331 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.27778 .08242 m
.27778 .07331 L
s
.30952 .07143 m
.30952 .07143 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.30952 .08242 m
.30952 .07143 L
s
.34127 .09337 m
.34127 .09337 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.34127 .08242 m
.34127 .09337 L
s
.37302 .07326 m
.37302 .07326 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.37302 .08242 m
.37302 .07326 L
s
.40476 .07993 m
.40476 .07993 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.40476 .08242 m
.40476 .07993 L
s
.43651 .08595 m
.43651 .08595 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.43651 .08242 m
.43651 .08595 L
s
.46825 .08668 m
.46825 .08668 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.46825 .08242 m
.46825 .08668 L
s
.5 .07368 m
.5 .07368 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.5 .08242 m
.5 .07368 L
s
.53175 .08244 m
.53175 .08244 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.53175 .08242 m
.53175 .08244 L
s
.56349 .08522 m
.56349 .08522 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.56349 .08242 m
.56349 .08522 L
s
.59524 .08194 m
.59524 .08194 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.59524 .08242 m
.59524 .08194 L
s
.62698 .07893 m
.62698 .07893 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.62698 .08242 m
.62698 .07893 L
s
.65873 .07541 m
.65873 .07541 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.65873 .08242 m
.65873 .07541 L
s
.69048 .0964 m
.69048 .0964 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.69048 .08242 m
.69048 .0964 L
s
.72222 .08244 m
.72222 .08244 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.72222 .08242 m
.72222 .08244 L
s
.75397 .078 m
.75397 .078 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.75397 .08242 m
.75397 .078 L
s
.78571 .0906 m
.78571 .0906 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.78571 .08242 m
.78571 .0906 L
s
.81746 .07719 m
.81746 .07719 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.81746 .08242 m
.81746 .07719 L
s
.84921 .08026 m
.84921 .08026 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.84921 .08242 m
.84921 .08026 L
s
.88095 .08659 m
.88095 .08659 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.88095 .08242 m
.88095 .08659 L
s
.9127 .08466 m
.9127 .08466 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.9127 .08242 m
.9127 .08466 L
s
.94444 .07775 m
.94444 .07775 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.94444 .08242 m
.94444 .07775 L
s
.97619 .08129 m
.97619 .08129 0 0 3 3 Mabsadd pop 0 365.73 arc
F
.97619 .08242 m
.97619 .08129 L
s
.5 g
[ .01 ] 0 setdash
.02381 .09854 m
.97619 .09821 L
s
.02381 .0663 m
.97619 .06663 L
s
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{637.875, 191.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009m0000_b000`400?l00000o`00003oo`3ooooo
0?ooogl0oooo003o0?ooool0ooooO`3oool00?l0ooooF@3oool400000?l0oooo8P3oool00?l0oooo
F03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo7`3oool00?l0ooooG@3o
ool00`000000oooo0?ooo`3o0?oooal0oooo003o0?ooodP0oooo1`0000020?ooo`<0000000<0oooo
0000003oool00P3oool3000000030?ooo`000000oooo0?l0oooo803oool00?l0ooooB03oool00`00
0000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000oooo0?ooo`3o
ool200000?l0oooo8@3oool00?l0ooooB03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?oooal0oooo003o
0?ooodP0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooal0oooo003o0?ooodP0oooo00<00000
0?ooo`3oool01`3oool400000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o
0?oooal0oooo003o0?ooodP0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0?l0oooo7`3oool00?l0ooooB03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool200000?l0oooo8@3oool0
0?l0ooooB03oool00`000000oooo0?ooo`060?ooo`@00000103oool3000000030?ooo`000000oooo
0?l0oooo803oool00?l0ooooB03oool00`000000oooo0?ooo`3o0?oooc@0oooo003o0?ooodP0oooo
00<000000?ooo`3oool0o`3ooold0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0ooooO`3oool0
0?l0ooooo`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0ooooO`3oool00?l0ooooo`3o
oomo0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0ooooO`3oool006`0oooo100000180?ooo`@0
0000AP3oool00`000000oooo0?ooo`030?ooo`@00000@P3oool00`000000oooo0?ooo`030?ooo`@0
0000?`3oool6000000<0oooo1000000n0?ooo`H000000`3oool400000400oooo100000040?ooo`@0
0000@P3oool006/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`140?ooo`050000
003oool0oooo0?ooo`000000AP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000@03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000?`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0?`3o
ool006/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0?`3oool006/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0@@3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo03l0oooo001[0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0440oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0o0?ooo`00J`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`110?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0@03oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo03h0oooo0`0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0?`3oool006/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`140?ooo`D00000AP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`020?ooo`D00000A03oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool01@0000140?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0?`3oool006/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04H0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000@`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0?`3oool006/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo04H0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0?P3oool2000000D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000@P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0?`3oool006`0oooo100000180?ooo`D00000
A@3oool00`000000oooo0?ooo`030?ooo`@00000@P3oool00`000000oooo0?ooo`030?ooo`D00000
?`3oool4000000@0oooo1000000o0?ooo`@00000103oool5000003l0oooo100000040?ooo`@00000
@P3oool00?l0ooooo`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0ooooO`3oool00?l0
ooooo`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0ooooO`3oool00?l0ooooo`3ooomo
0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0ooooO`3oool00680ooooo`00003Q000003/0oooo
001R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0:0?ooo`@0AX:d3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03T0oooo001R
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool504J2]2/0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0>@3oool00680oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0H0?oo
o`H0AX:d:`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool3000002D0oooo1@16P[Co0?oook<0
oooo00<000000?ooo`3oool0>@3oool00680oooo00<000000?ooo`3oool09@3oool404J2]?l0oooo
]03oool00`000000oooo0?ooo`0i0?ooo`00HP3oool00`000000oooo0?ooo`0W0?ooo`0304J2]03o
ool0oooo0?l0oooo/`3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool00`000000oooo0?ooo`0W
0?ooo`0304J2]03oool0oooo0?l0oooo/`3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool00`00
0000oooo0?ooo`0W0?ooo`0304J2]03oool0oooo0?l0oooo/`3oool00`000000oooo0?ooo`0i0?oo
o`00HP3oool3000002L0oooo00<0AX:d0?ooo`3oool0o`3ooonc0?ooo`030000003oool0oooo03T0
oooo001R0?ooo`030000003oool0oooo02L0oooo00<0AX:d0?ooo`3oool0o`3ooonc0?ooo`030000
003oool0oooo03T0oooo001R0?ooo`030000003oool0oooo02L0oooo00<0AX:d0?ooo`3oool0o`3o
oonc0?ooo`030000003oool0oooo03T0oooo001R0?ooo`030000003oool0oooo02L0oooo00<0AX:d
0?ooo`3oool0o`3ooonc0?ooo`030000003oool0oooo03T0oooo001R0?ooo`030000003oool0oooo
02L0oooo00<0AX:d0?ooo`3oool0o`3ooonc0?ooo`030000003oool0oooo03T0oooo001R0?ooo`<0
00009`3oool00`16P[@0oooo0?ooo`3o0?oook<0oooo00<000000?ooo`3oool0>@3oool004T0oooo
100000040?ooo`030000003oool0oooo00H00000203oool00`000000oooo0?ooo`0W0?ooo`0304J2
]03oool0oooo0?l0oooo/`3oool00`000000oooo0?ooo`0i0?ooo`00B03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0W0?ooo`0304J2]03oool0oooo0?l0oooo/`3oool00`000000oooo0?ooo`0i0?ooo`00B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0W0?ooo`0304J2]03oool0oooo0?l0oooo/`3oool00`000000oooo0?ooo`0i
0?ooo`00?P3oool7000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool404J2]0d0oooo00<0AX:d0?oo
o`3oool0o`3ooonc0?ooo`030000003oool0oooo03T0oooo00180?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`@000005@3oool504J2]0`0
oooo00<0AX:d0?ooo`3oool0o`3ooonc0?ooo`030000003oool0oooo03T0oooo00180?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01D0oooo1P16P[@<0?ooo`0304J2]03oool0oooo0?l0oooo/`3oool00`000000oooo
0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`D0AX:d303oool00`16P[@0oooo0?oo
o`3o0?oook<0oooo00<000000?ooo`3oool0>@3oool004P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0F0?ooo`@0AX:d3@3oool00`16P[@0oooo0?ooo`3o0?oook<0oooo00<00000
0?ooo`3oool0>@3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?oo
o`0304J2]03oool0oooo00`0oooo00<0AX:d0?ooo`3oool0o`3ooonc0?ooo`030000003oool0oooo
03T0oooo00190?ooo`@00000203oool4000000T0oooo0`00000H0?ooo`0304J2]03oool0oooo00`0
oooo00<0AX:d0?ooo`3oool0o`3ooonc0?ooo`030000003oool0oooo03T0oooo001R0?ooo`030000
003oool0oooo01P0oooo00<0AX:d0?ooo`3oool0303oool00`16P[@0oooo0?ooo`3o0?oook<0oooo
00<000000?ooo`3oool0>@3oool00680oooo00<000000?ooo`3oool0603oool00`16P[@0oooo0?oo
o`0<0?ooo`0304J2]03oool0oooo0?l0oooo/`3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool0
0`000000oooo0?ooo`0H0?ooo`0304J2]03oool0oooo00`0oooo00<0AX:d0?ooo`3oool0o`3ooonc
0?ooo`030000003oool0oooo03T0oooo001R0?ooo`030000003oool0oooo01P0oooo00<0AX:d0?oo
o`3oool0303oool00`16P[@0oooo0?ooo`3o0?oook<0oooo00<000000?ooo`3oool0>@3oool00680
oooo0`00000H0?ooo`0304J2]03oool0oooo00`0oooo00<0AX:d0?ooo`3oool0o`3ooonc0?ooo`03
0000003oool0oooo03T0oooo001R0?ooo`030000003oool0oooo01P0oooo00<0AX:d0?ooo`3oool0
303oool00`16P[@0oooo0?ooo`3o0?oook<0oooo00<000000?ooo`3oool0>@3oool00680oooo00<0
00000?ooo`3oool02@3oool607moO`<0oooo1P1oOgl01016P[@0oooo0?ooo`3oool607moO`@0oooo
1@1oOgl40?ooo`H0Ogmo103oool507moO`@0oooo1P1oOgl40?ooo`H0Ogmo0`3oool607moO`@0oooo
1P1oOgl00`16P[@0oooo0?ooo`0607moO`@0oooo1P1oOgl40?ooo`D0Ogmo103oool607moO`@0oooo
1@1oOgl40?ooo`H0Ogmo103oool607moO`<0oooo1P1oOgl40?ooo`H0Ogmo0`3oool607moO`@0oooo
1P1oOgl40?ooo`D0Ogmo103oool607moO`@0oooo1P1oOgl30?ooo`H0Ogmo103oool607moO`<0oooo
1P1oOgl40?ooo`H0Ogmo103oool507moO`@0oooo1P1oOgl40?ooo`D0Ogmo103oool607moO`@0oooo
1P1oOgl30?ooo`H0Ogmo103oool607moO`<0oooo1P1oOgl40?ooo`H0Ogmo103oool507moO`@0oooo
1P1oOgl40?ooo`H0Ogmo0`3oool607moO`@0oooo1P1oOgl30?ooo`H0Ogmo103oool607moO`@0oooo
1@1oOgl40?ooo`H0Ogmo103oool507moO`@0oooo1P1oOgl<0?ooo`030000003oool0oooo03T0oooo
001R0?ooo`030000003oool0oooo01P0oooo00<0AX:d0?ooo`3oool0303oool00`16P[@0oooo0?oo
o`0h0?ooo`D0AX:d:03oool504J2]?l0ooooB@3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool0
0`000000oooo0?ooo`0H0?ooo`0304J2]03oool0oooo00`0oooo00<0AX:d0?ooo`3oool0=`3oool6
04J2]1T0oooo1@16P[@:0?ooo`D0AX:d6P3oool404J2]3T0oooo1016P[C]0?ooo`030000003oool0
oooo03T0oooo001R0?ooo`<00000603oool00`16P[@0oooo0?ooo`0<0?ooo`0304J2]03oool0oooo
01X0oooo0`16P[@K0?ooo`D0AX:d6@3oool504J2]0T0oooo1P16P[@I0?ooo`H0AX:d=`3oool504J2
]4L0oooo1@16P[BQ0?ooo`030000003oool0oooo03T0oooo001E0?ooo`@000002@3oool00`000000
oooo0?ooo`0H0?ooo`0304J2]03oool0oooo00`0oooo00<0AX:d0?ooo`3oool06P3oool404J2]1X0
oooo1016P[@I0?ooo`H0AX:d2P3oool504J2]1X0oooo1@16P[@f0?ooo`H0AX:d>03oool504J2]0X0
oooo1@16P[@Y0?ooo`@0AX:d6P3oool504J2]3P0oooo1016P[@I0?ooo`030000003oool0oooo03T0
oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0H0?ooo`0304J2]03oool0oooo00`0oooo00<0AX:d0?ooo`3oool06@3oool604J2]1/0oooo
00<0AX:d0?ooo`3oool06@3oool504J2]0X0oooo1@16P[@J0?ooo`D0AX:d2P3oool404J2]2T0oooo
1@16P[@h0?ooo`D0AX:d2@3oool604J2]2T0oooo1@16P[@H0?ooo`H0AX:d2P3oool504J2]2T0oooo
1@16P[@:0?ooo`<0AX:d2`3oool00`000000oooo0?ooo`0i0?ooo`00E03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`16P[@0oooo0?oo
o`0<0?ooo`0304J2]03oool0oooo01T0oooo1P16P[@K0?ooo`0304J2]03oool0oooo01T0oooo1016
P[@=0?ooo`0304J2]03oool0oooo01X0oooo1016P[@;0?ooo`D0AX:d:03oool504J2]0/0oooo1016
P[@J0?ooo`@0AX:d2P3oool604J2]0X0oooo1@16P[@J0?ooo`@0AX:d2P3oool604J2]1T0oooo1@16
P[@:0?ooo`D0AX:d:03oool604J2]0X0oooo1016P[@:0?ooo`030000003oool0oooo03T0oooo001D
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H
0?ooo`0304J2]03oool0oooo00`0oooo00<0AX:d0?ooo`3oool06@3oool604J2]1/0oooo00<0AX:d
0?ooo`3oool06`3oool00`16P[@0oooo0?ooo`0<0?ooo`0304J2]03oool0oooo01`0oooo00<0AX:d
0?ooo`3oool02@3oool604J2]2X0oooo00<0AX:d0?ooo`3oool02`3oool504J2]0X0oooo1016P[@;
0?ooo`D0AX:d2P3oool504J2]0X0oooo1016P[@K0?ooo`D0AX:d2P3oool504J2]1T0oooo1@16P[@9
0?ooo`H0AX:d6P3oool404J2]0/0oooo1@16P[@90?ooo`H0AX:d2@3oool00`000000oooo0?ooo`0i
0?ooo`00E03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo300000000`16
P[@000000000000<0000000304J2]0000000000000`0000000<0AX:d000000000000300000000`16
P[@000000000000:000000D0AX:d3@0000000`16P[@000000000000<0000000304J2]00000000000
00`0000000<0AX:d000000000000300000000`16P[@000000000000<0000000304J2]00000000000
00d0000000<0AX:d000000000000300000000`16P[@000000000000:000000D0AX:d2P00000404J2
]0/000001@16P[@<0000000304J2]0000000000000X000001P16P[@:000000D0AX:d2@00000604J2
]0X000001016P[@=0000000304J2]0000000000000d0000000<0AX:d0000000000002@00000604J2
]0X000001016P[@=0000000304J2]0000000000000X000001016P[@;000000D0AX:d2`00000404J2
]0/000001@16P[@:000000@0AX:d2`00000504J2]0X00000>`3oool005@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<0AX:d0?ooo`3o
ool0:P3oool00`16P[@0oooo0?ooo`0L0?ooo`0304J2]03oool0oooo01/0oooo00<0AX:d0?ooo`3o
ool0:`3oool00`16P[@0oooo0?ooo`0I0?ooo`@0AX:d2`3oool504J2]0X0oooo1@16P[@I0?ooo`H0
AX:d2@3oool604J2]0X0oooo1@16P[@[0?ooo`0304J2]03oool0oooo00X0oooo1@16P[@K0?ooo`03
04J2]03oool0oooo01T0oooo1@16P[@;0?ooo`D0AX:d2@3oool604J2]1T0oooo1@16P[@90?ooo`03
0000003oool0oooo03T0oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo02X0oooo00<0AX:d0?ooo`3oool0
6P3oool404J2]1`0oooo00<0AX:d0?ooo`3oool0:`3oool00`16P[@0oooo0?ooo`0W0?ooo`H0AX:d
2@3oool604J2]1T0oooo1@16P[@;0?ooo`D0AX:d2P3oool404J2]2`0oooo00<0AX:d0?ooo`3oool0
2P3oool404J2]1X0oooo1016P[@Y0?ooo`H0AX:d2P3oool504J2]1T0oooo1016P[@:0?ooo`030000
003oool0oooo03T0oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo02X0oooo00<0AX:d0?ooo`3oool06P3o
ool504J2]1/0oooo00<0AX:d0?ooo`3oool0:@3oool404J2]2T0oooo1@16P[@:0?ooo`D0AX:d:@3o
ool404J2]3/0oooo00<0AX:d0?ooo`3oool0:03oool504J2]2P0oooo1P16P[@:0?ooo`@0AX:d:03o
ool00`000000oooo0?ooo`0i0?ooo`00E03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02@3oool00`16P[@0oooo0?ooo`0Z0?ooo`0304J2]03oool0
oooo01T0oooo1P16P[@K0?ooo`0304J2]03oool0oooo02T0oooo1@16P[@X0?ooo`@0AX:d2`3oool4
04J2]6T0oooo00<0AX:d0?ooo`3oool09`3oool604J2]2P0oooo1@16P[@g0?ooo`030000003oool0
oooo03T0oooo001E0?ooo`@000002@3oool3000000T0oooo00<0AX:d0?ooo`3oool0:P3oool00`16
P[@0oooo0?ooo`0J0?ooo`D0AX:d6`3oool00`16P[@0oooo0?ooo`0X0?ooo`H0AX:dXP3oool404J2
]2T0oooo1@16P[AT0?ooo`030000003oool0oooo03T0oooo001R0?ooo`030000003oool0oooo00T0
oooo00<0AX:d0?ooo`3oool0:03oool504J2]1X0oooo1016P[@L0?ooo`0304J2]03oool0oooo02P0
oooo1P16P[BR0?ooo`D0AX:d:03oool404J2]6D0oooo00<000000?ooo`3oool0>@3oool00680oooo
00<000000?ooo`3oool02@3oool00`16P[@0oooo0?ooo`0X0?ooo`D0AX:d>P3oool00`16P[@0oooo
0?ooo`0X0?ooo`D0AX:dXP3oool604J2]940oooo00<000000?ooo`3oool0>@3oool00680oooo00<0
00000?ooo`3oool02@3oool607moO`<0oooo1P1oOgl40?ooo`H0Ogmo103oool507moO`@0oooo1P1o
Ogl404J2]0D0Ogmo103oool607moO`@0oooo1P1oOgl30?ooo`H0Ogmo103oool607moO`<0oooo1P1o
Ogl30?ooo`0304J2]01oOgl0Ogmo00@0Ogmo103oool507moO`@0oooo1P1oOgl40?ooo`D0Ogmo103o
ool607moO`@0oooo1P1oOgl30?ooo`H0Ogmo103oool607moO`<0oooo1P1oOgl40?ooo`H0Ogmo103o
ool507moO`@0oooo1P1oOgl40?ooo`H0Ogmo0`3oool607moO`@0oooo1P1oOgl30?ooo`H0Ogmo103o
ool607moO`@0oooo1@1oOgl40?ooo`H0Ogmo103oool507moO`@0oooo1P1oOgl40?ooo`H0Ogmo0`3o
ool607moO`0404J2]03oool0oooo0?ooo`H0Ogmo0`3oool607moO`@0oooo1P1oOgl40?ooo`D0Ogmo
103oool607moO`@0oooo1P1oOgl30?ooo`H0Ogmo103oool607moO`<0oooo1P1oOgl40?ooo`H0Ogmo
103oool507moO`@0oooo1P1oOgl40?ooo`D0Ogmo103oool607moO``0oooo00<000000?ooo`3oool0
>@3oool00680oooo00<000000?ooo`3oool02@3oool00`16P[@0oooo0?ooo`0X0?ooo`D0AX:d=`3o
ool604J2]<l0oooo1@16P[BB0?ooo`030000003oool0oooo03T0oooo001R0?ooo`<000002@3oool0
0`16P[@0oooo0?ooo`0X0?ooo`@0AX:d>@3oool504J2]?l0ooooI`3oool00`000000oooo0?ooo`0i
0?ooo`00HP3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo06D0oooo1@16P[Co0?oo
ofL0oooo00<000000?ooo`3oool0>@3oool00680oooo00<000000?ooo`3oool02@3oool00`16P[@0
oooo0?ooo`1U0?ooo`@0AX:do`3ooomX0?ooo`030000003oool0oooo03T0oooo001R0?ooo`030000
003oool0oooo00T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`030000003oool0oooo03T0oooo
001R0?ooo`030000003oool0oooo00T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`030000003o
ool0oooo03T0oooo001R0?ooo`<000002@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<00000
0?ooo`3oool0>@3oool004T0oooo100000040?ooo`030000003oool0oooo00H00000203oool00`00
0000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?oo
o`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000
oooo0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0oooo
d@3oool00`000000oooo0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`0304J2]03o
ool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool4000000P0oooo00<0AX:d
0?ooo`3oool0o`3ooooA0?ooo`030000003oool0oooo03T0oooo00180?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`030000003oool0oooo03T0oooo00180?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`030000003oool0oooo03T0
oooo00180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`16P[@0oooo
0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool004P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?oo
o`0i0?ooo`00B@3oool4000000P0oooo100000090?ooo`<000002@3oool00`16P[@0oooo0?ooo`3o
0?ooom40oooo00<000000?ooo`3oool0>@3oool00680oooo00<000000?ooo`3oool02@3oool00`16
P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool00680oooo00<000000?ooo`3o
ool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool00680oooo
00<000000?ooo`3oool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0
>@3oool00680oooo00<000000?ooo`3oool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<0
00000?ooo`3oool0>@3oool00680oooo0`0000090?ooo`0304J2]03oool0oooo0?l0ooood@3oool0
0`000000oooo0?ooo`0i0?ooo`00HP3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo
0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool00`000000oooo0?ooo`090?ooo`03
04J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool00`000000oooo
0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00HP3o
ool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?oo
o`0i0?ooo`00HP3oool3000000T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`030000003oool0
oooo03T0oooo001R0?ooo`030000003oool0oooo00T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?oo
o`030000003oool0oooo03T0oooo00190?ooo`@00000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40
oooo00<000000?ooo`3oool0>@3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`16P[@0oooo
0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool004P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`L00000203oool00`000000oooo0?ooo`090?ooo`0304J2]03o
ool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`07
0?ooo`@00000203oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool0
04P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool0
0`000000oooo0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0
oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`09
0?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00B03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000002@3oool00`00
0000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?oo
o`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0P0000090?ooo`<0
00002@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool004T0oooo
1000000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`16P[@0oooo
0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool00680oooo00<000000?ooo`3oool02@3o
ool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool00680oooo00<00000
0?ooo`3oool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool0
0680oooo00<000000?ooo`3oool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?oo
o`3oool0>@3oool00680oooo0`0000090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000
oooo0?ooo`0i0?ooo`00HP3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0oooo
d@3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool00`000000oooo0?ooo`090?ooo`0304J2]03o
ool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool00`000000oooo0?ooo`09
0?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool00`00
0000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?oo
o`00HP3oool3000000T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`030000003oool0oooo03T0
oooo001R0?ooo`030000003oool0oooo00T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`030000
003oool0oooo03T0oooo00190?ooo`@00000103oool010000000oooo0?ooo`3oool4000000T0oooo
00<000000?ooo`3oool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0
>@3oool004P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`0304J2]03o
ool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`030000003oool0
oooo03T0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo100000080?ooo`0304J2]03oool0oooo
0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool004P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000800000
2@3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo
0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3o
ool00`000000oooo0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0
oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00B03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000080?ooo`<000002@3oool0
0`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool004T0oooo100000090?oo
o`<000002@3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`00
0000oooo0?ooo`0i0?ooo`00HP3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0
ooood@3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool00`000000oooo0?ooo`090?ooo`0304J2
]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool00`000000oooo0?oo
o`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool3
000000T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`030000003oool0oooo03T0oooo001R0?oo
o`030000003oool0oooo00T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`030000003oool0oooo
03T0oooo001R0?ooo`030000003oool0oooo00T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`03
0000003oool0oooo03T0oooo001R0?ooo`030000003oool0oooo00T0oooo00<0AX:d0?ooo`3oool0
o`3ooooA0?ooo`030000003oool0oooo03T0oooo001R0?ooo`030000003oool0oooo00T0oooo00<0
AX:d0?ooo`3oool0o`3ooooA0?ooo`030000003oool0oooo03T0oooo001R0?ooo`<000002@3oool0
0`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool00680oooo00<000000?oo
o`3oool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool004T0
oooo100000040?ooo`040000003oool0oooo0?ooo`@000002@3oool00`000000oooo0?ooo`090?oo
o`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00B03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`03
0000003oool0oooo03T0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool004P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool4000000P0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`030000003o
ool0oooo03T0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool0
0`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool004P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`@000002@3oool00`000000oooo0?ooo`090?oo
o`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00B03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<0AX:d0?ooo`3oool0o`3ooooA0?ooo`03
0000003oool0oooo03T0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool004P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3o
ool00`000000oooo0?ooo`0i0?ooo`00B@3oool4000000P0oooo100000090?ooo`<000002@3oool0
0`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool00680oooo00<000000?oo
o`3oool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool00680
oooo00<000000?ooo`3oool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3o
ool0>@3oool00680oooo00<000000?ooo`3oool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo
00<000000?ooo`3oool0>@3oool00680oooo00<000000?ooo`3oool02@3oool00`16P[@0oooo0?oo
o`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool00680oooo0`0000090?ooo`0304J2]03oool0
oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool00`000000oooo0?ooo`090?oo
o`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00HP3oool00`000000
oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00
HP3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3oool00`000000oooo
0?ooo`0i0?ooo`00HP3oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0ooood@3o
ool00`000000oooo0?ooo`0i0?ooo`00HP3oool3000000T0oooo00<0AX:d0?ooo`3oool0o`3ooooA
0?ooo`030000003oool0oooo03T0oooo001G0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool00`16P[@0oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool0>@3oool005L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`0304J2]03oool0oooo0?l0
ooood@3oool00`000000oooo0?ooo`0i0?ooo`00E`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00L0oooo1016P[Co0?ooom80oooo00<000000?ooo`3oool0>@3oool005L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`H0AX:do`3ooooA0?ooo`030000003o
ool0oooo03T0oooo001G0?ooo`030000003oool0oooo00P0oooo100000060?ooo`D0AX:do`3ooooA
0?ooo`030000003oool0oooo03T0oooo001G0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool504J2]?l0ooood@3oool00`000000oooo0?ooo`0i0?ooo`00E`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo1016P[Co0?ooom80oooo00<000000?ooo`3o
ool0>@3oool005D0oooo00<000000?ooo`0000002P3ooooo00000>400000>`3oool005H0oooo0P00
003o0?ooool0oooo9`3oool005L0oooo00<000000?ooo`3oool0o`3ooooo0?ooobD0oooo003o0?oo
ool0ooooO`3oool00?l0ooooo`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo0000\
\>"],
  ImageRangeCache->{{{0, 636.875}, {190.375, 0}} -> {-7.26773, -0.803904, \
0.0658832, 0.00993897}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Controlling for holidays", "Subsection"],

Cell[TextData[{
  "From the observation, that Sundays have special prices one might also \
conclude special prices on holidays. To explore this idea first we use the ",
  StyleBox["HolidayQ", "MR"],
  " function which comes with our package ",
  StyleBox["Finance", "MR"],
  ", which was loaded in the beginning. We do not have a holiday calendar for \
Leipzig available so we take Frankfurt instead."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hol\  = 
        Position[dates, x_ /; \ HolidayQ["\<FRA\>", x]]\  // \ 
          Flatten;\)\), "\n", 
    \(dates[\([hol]\)]\)}], "Input"],

Cell[BoxData[
    \({{2000, 6, 22}, {2000, 10, 3}, {2000, 12, 24}, {2000, 12, 25}, {2000, 
        12, 26}, {2001, 1, 1}, {2001, 4, 13}, {2001, 4, 16}, {2001, 5, 
        1}, {2001, 5, 24}, {2001, 6, 4}, {2001, 6, 14}, {2001, 10, 3}, {2001, 
        12, 24}, {2001, 12, 25}, {2001, 12, 26}, {2002, 1, 1}, {2002, 3, 
        29}, {2002, 4, 1}}\)], "Output"]
}, Open  ]],

Cell["\<\
Marking the holidays in the time series with a green point convinces us that \
our conclusion about holidays is not false: \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[
        ListPlot[peak1, PlotJoined \[Rule] True, AspectRatio \[Rule] \ 0.2, 
          Frame \[Rule] True, PlotRange \[Rule] \ {0, 70}, 
          FrameTicks \[Rule] {ticks, Automatic, None, None}, 
          PlotStyle \[Rule] Blue, FrameLabel \[Rule] \ "\<\:f280/MWh\>", 
          Axes \[Rule] None], 
        ListPlot[Transpose[{hol, peak1[\([hol]\)]}], 
          PlotJoined \[Rule] False, 
          PlotStyle \[Rule] {PointSize[0.015], Green}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0238095 0.00139441 5.63785e-018 0.00285714 [
[.0252 -0.0125 -33.7813 -17.75 ]
[.0252 -0.0125 33.7813 0 ]
[.16464 -0.0125 -33.7813 -17.75 ]
[.16464 -0.0125 33.7813 0 ]
[.30409 -0.0125 -29.875 -17.75 ]
[.30409 -0.0125 29.875 0 ]
[.44353 -0.0125 -33.7813 -17.75 ]
[.44353 -0.0125 33.7813 0 ]
[.58297 -0.0125 -33.7813 -17.75 ]
[.58297 -0.0125 33.7813 0 ]
[.72241 -0.0125 -37.6875 -17.75 ]
[.72241 -0.0125 37.6875 0 ]
[.86185 -0.0125 -29.875 -17.75 ]
[.86185 -0.0125 29.875 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02857 -19.625 -8.875 ]
[-0.0125 .02857 0 8.875 ]
[-0.0125 .05714 -19.625 -8.875 ]
[-0.0125 .05714 0 8.875 ]
[-0.0125 .08571 -19.625 -8.875 ]
[-0.0125 .08571 0 8.875 ]
[-0.0125 .11429 -19.625 -8.875 ]
[-0.0125 .11429 0 8.875 ]
[-0.0125 .14286 -19.625 -8.875 ]
[-0.0125 .14286 0 8.875 ]
[-0.0125 .17143 -19.625 -8.875 ]
[-0.0125 .17143 0 8.875 ]
[-0.0125 .2 -19.625 -8.875 ]
[-0.0125 .2 0 8.875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .1 -37.375 -24.8125 ]
[-0.01875 .1 -19.625 24.8125 ]
[ 0 .2 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0252 0 m
.0252 .00625 L
s
gsave
.0252 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16464 0 m
.16464 .00625 L
s
gsave
.16464 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.30409 0 m
.30409 .00625 L
s
gsave
.30409 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.44353 0 m
.44353 .00625 L
s
gsave
.44353 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.58297 0 m
.58297 .00625 L
s
gsave
.58297 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72241 0 m
.72241 .00625 L
s
gsave
.72241 -0.0125 -98.6875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.688 17.625 moveto
(\\220) show
103.125 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
134.375 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86185 0 m
.86185 .00625 L
s
gsave
.86185 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2002) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .02857 m
.00625 .02857 L
s
gsave
-0.0125 .02857 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .05714 m
.00625 .05714 L
s
gsave
-0.0125 .05714 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .08571 m
.00625 .08571 L
s
gsave
-0.0125 .08571 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .11429 m
.00625 .11429 L
s
gsave
-0.0125 .11429 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .14286 m
.00625 .14286 L
s
gsave
-0.0125 .14286 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
0 .17143 m
.00625 .17143 L
s
gsave
-0.0125 .17143 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .00571 m
.00375 .00571 L
s
0 .01143 m
.00375 .01143 L
s
0 .01714 m
.00375 .01714 L
s
0 .02286 m
.00375 .02286 L
s
0 .03429 m
.00375 .03429 L
s
0 .04 m
.00375 .04 L
s
0 .04571 m
.00375 .04571 L
s
0 .05143 m
.00375 .05143 L
s
0 .06286 m
.00375 .06286 L
s
0 .06857 m
.00375 .06857 L
s
0 .07429 m
.00375 .07429 L
s
0 .08 m
.00375 .08 L
s
0 .09143 m
.00375 .09143 L
s
0 .09714 m
.00375 .09714 L
s
0 .10286 m
.00375 .10286 L
s
0 .10857 m
.00375 .10857 L
s
0 .12 m
.00375 .12 L
s
0 .12571 m
.00375 .12571 L
s
0 .13143 m
.00375 .13143 L
s
0 .13714 m
.00375 .13714 L
s
0 .14857 m
.00375 .14857 L
s
0 .15429 m
.00375 .15429 L
s
0 .16 m
.00375 .16 L
s
0 .16571 m
.00375 .16571 L
s
0 .17714 m
.00375 .17714 L
s
0 .18286 m
.00375 .18286 L
s
0 .18857 m
.00375 .18857 L
s
0 .19429 m
.00375 .19429 L
s
.25 Mabswid
0 0 m
0 .2 L
s
gsave
-0.01875 .1 -114.313 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.8125 12.875 translate
90 rotate
-85.8125 -12.875 translate
0 25.75 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
%%BeginResource: font Arial-MISO
%%BeginFont: Arial-MISO
/Arial /Arial-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
currentpoint currentpoint
newpath
 moveto
 0.813 0.000 rmoveto
 0 -10.063 rlineto
 6.688 0 rlineto
 0 10.063 rlineto
 -6.688 0 rlineto
closepath
fill moveto
8.313 0.000 rmoveto
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.313 17.625 moveto
(\\220) show
75.750 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MWh) show
108.625 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
1 .2 L
s
1 0 m
1 .2 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.0252 .06148 m
.0266 .05856 L
.02799 .0689 L
.02939 .04425 L
.03078 .04974 L
.03218 .05235 L
.03357 .03673 L
.03496 .05136 L
.03636 .05503 L
.03775 .06761 L
.03915 .04595 L
.04054 .04082 L
.04194 .04438 L
.04333 .05869 L
.04473 .05688 L
.04612 .0548 L
.04751 .06817 L
.04891 .03976 L
.0503 .04738 L
.0517 .04804 L
.05309 .05848 L
.05449 .06218 L
.05588 .05641 L
.05728 .06505 L
.05867 .04384 L
.06006 .04957 L
.06146 .05315 L
.06285 .05176 L
.06425 .05531 L
.06564 .05389 L
.06704 .06539 L
.06843 .03529 L
.06983 .03416 L
.07122 .03853 L
.07261 .0448 L
.07401 .05806 L
.0754 .05873 L
.0768 .06643 L
.07819 .03519 L
.07959 .0338 L
.08098 .04445 L
.08237 .04465 L
.08377 .0538 L
.08516 .05557 L
.08656 .0681 L
.08795 .03577 L
.08935 .03542 L
.09074 .036 L
.09214 .04801 L
.09353 .05705 L
Mistroke
.09492 .05767 L
.09632 .0658 L
.09771 .02759 L
.09911 .03401 L
.1005 .03566 L
.1019 .04504 L
.10329 .05047 L
.10469 .05736 L
.10608 .06596 L
.10747 .03369 L
.10887 .02999 L
.11026 .04623 L
.11166 .05308 L
.11305 .05795 L
.11445 .06318 L
.11584 .06963 L
.11723 .04949 L
.11863 .06585 L
.12002 .04525 L
.12142 .06838 L
.12281 .06822 L
.12421 .05667 L
.1256 .06302 L
.127 .05167 L
.12839 .05756 L
.12978 .07455 L
.13118 .06802 L
.13257 .08434 L
.13397 .06561 L
.13536 .07468 L
.13676 .06038 L
.13815 .07409 L
.13955 .07385 L
.14094 .08291 L
.14233 .09362 L
.14373 .06323 L
.14512 .06768 L
.14652 .06382 L
.14791 .0753 L
.14931 .08031 L
.1507 .10848 L
.1521 .08135 L
.15349 .06902 L
.15488 .07349 L
.15628 .06063 L
.15767 .06494 L
.15907 .07287 L
.16046 .10473 L
.16186 .08185 L
.16325 .07201 L
Mistroke
.16464 .07344 L
.16604 .05925 L
.16743 .06486 L
.16883 .06531 L
.17022 .07507 L
.17162 .07757 L
.17301 .07279 L
.17441 .06697 L
.1758 .04903 L
.17719 .04124 L
.17859 .06584 L
.17998 .06122 L
.18138 .06749 L
.18277 .06898 L
.18417 .06811 L
.18556 .0627 L
.18696 .05612 L
.18835 .08493 L
.18974 .07718 L
.19114 .07806 L
.19253 .05455 L
.19393 .06207 L
.19532 .03995 L
.19672 .06324 L
.19811 .05601 L
.1995 .06375 L
.2009 .06881 L
.20229 .06252 L
.20369 .06677 L
.20508 .06272 L
.20648 .06382 L
.20787 .06268 L
.20927 .07204 L
.21066 .08118 L
.21205 .07248 L
.21345 .07333 L
.21484 .07603 L
.21624 .06852 L
.21763 .05474 L
.21903 .11131 L
.22042 .06711 L
.22182 .07653 L
.22321 .07359 L
.2246 .06557 L
.226 .07088 L
.22739 .07297 L
.22879 .05858 L
.23018 .07456 L
.23158 .06623 L
.23297 .07495 L
Mistroke
.23437 .06992 L
.23576 .06591 L
.23715 .08005 L
.23855 .08427 L
.23994 .09333 L
.24134 .07592 L
.24273 .09087 L
.24413 .07358 L
.24552 .07091 L
.24691 .08149 L
.24831 .08939 L
.2497 .08476 L
.2511 .08979 L
.25249 .07905 L
.25389 .07875 L
.25528 .07263 L
.25668 .07854 L
.25807 .1022 L
.25946 .08582 L
.26086 .06998 L
.26225 .08821 L
.26365 .08233 L
.26504 .06753 L
.26644 .09696 L
.26783 .08443 L
.26923 .05739 L
.27062 .08193 L
.27201 .08712 L
.27341 .07105 L
.2748 .07442 L
.2762 .06039 L
.27759 .07625 L
.27899 .09304 L
.28038 .07601 L
.28178 .0849 L
.28317 .09556 L
.28456 .11787 L
.28596 .10917 L
.28735 .08541 L
.28875 .0759 L
.29014 .07492 L
.29154 .08412 L
.29293 .02644 L
.29432 .02905 L
.29572 .05789 L
.29711 .05619 L
.29851 .06062 L
.2999 .07371 L
.3013 .08611 L
.30269 .0153 L
Mistroke
.30409 .04667 L
.30548 .04706 L
.30687 .06406 L
.30827 .07108 L
.30966 .06746 L
.31106 .08248 L
.31245 .06642 L
.31385 .07084 L
.31524 .07927 L
.31664 .08341 L
.31803 .08345 L
.31942 .08502 L
.32082 .09576 L
.32221 .08718 L
.32361 .08385 L
.325 .09617 L
.3264 .08597 L
.32779 .10691 L
.32918 .08566 L
.33058 .08836 L
.33197 .0888 L
.33337 .07274 L
.33476 .05502 L
.33616 .08389 L
.33755 .08311 L
.33895 .06934 L
.34034 .08188 L
.34173 .064 L
.34313 .07735 L
.34452 .07416 L
.34592 .07558 L
.34731 .10539 L
.34871 .08547 L
.3501 .0921 L
.3515 .07871 L
.35289 .05657 L
.35428 .069 L
.35568 .07162 L
.35707 .07876 L
.35847 .07897 L
.35986 .08352 L
.36126 .05621 L
.36265 .05401 L
.36405 .05818 L
.36544 .08287 L
.36683 .07704 L
.36823 .07558 L
.36962 .08431 L
.37102 .05281 L
.37241 .05681 L
Mistroke
.37381 .05872 L
.3752 .0642 L
.37659 .08649 L
.37799 .08856 L
.37938 .08657 L
.38078 .07348 L
.38217 .09587 L
.38357 .08747 L
.38496 .13863 L
.38636 .09217 L
.38775 .09385 L
.38914 .08886 L
.39054 .0771 L
.39193 .09997 L
.39333 .0815 L
.39472 .08069 L
.39612 .06666 L
.39751 .07512 L
.39891 .08237 L
.4003 .05752 L
.40169 .03795 L
.40309 .05757 L
.40448 .0648 L
.40588 .06952 L
.40727 .07268 L
.40867 .07888 L
.41006 .04007 L
.41146 .05659 L
.41285 .04855 L
.41424 .06298 L
.41564 .06411 L
.41703 .07019 L
.41843 .0586 L
.41982 .04466 L
.42122 .05531 L
.42261 .04454 L
.424 .06021 L
.4254 .07533 L
.42679 .06934 L
.42819 .08148 L
.42958 .07175 L
.43098 .06587 L
.43237 .0509 L
.43377 .06875 L
.43516 .08101 L
.43655 .0796 L
.43795 .08351 L
.43934 .0543 L
.44074 .07017 L
.44213 .07419 L
Mistroke
.44353 .0581 L
.44492 .04999 L
.44632 .07722 L
.44771 .07988 L
.4491 .01735 L
.4505 .08022 L
.45189 .07882 L
.45329 .14375 L
.45468 .09608 L
.45608 .08255 L
.45747 .09282 L
.45886 .11358 L
.46026 .0891 L
.46165 .07381 L
.46305 .07855 L
.46444 .11487 L
.46584 .08083 L
.46723 .08765 L
.46863 .05591 L
.47002 .02611 L
.47141 .10656 L
.47281 .06615 L
.4742 .07401 L
.4756 .07407 L
.47699 .08686 L
.47839 .07237 L
.47978 .06342 L
.48118 .05834 L
.48257 .07753 L
.48396 .06461 L
.48536 .07704 L
.48675 .07764 L
.48815 .07096 L
.48954 .07216 L
.49094 .08195 L
.49233 .06971 L
.49373 .08359 L
.49512 .07045 L
.49651 .08319 L
.49791 .09086 L
.4993 .08953 L
.5007 .07096 L
.50209 .03882 L
.50349 .0572 L
.50488 .06343 L
.50627 .06811 L
.50767 .06927 L
.50906 .06959 L
.51046 .07901 L
.51185 .09445 L
Mistroke
.51325 .06595 L
.51464 .06043 L
.51604 .06103 L
.51743 .01778 L
.51882 .07232 L
.52022 .09912 L
.52161 .06469 L
.52301 .08106 L
.5244 .09066 L
.5258 .07926 L
.52719 .062 L
.52859 .07272 L
.52998 .10893 L
.53137 .06082 L
.53277 .06737 L
.53416 .08397 L
.53556 .07568 L
.53695 .08767 L
.53835 .07426 L
.53974 .09224 L
.54114 .08082 L
.54253 .075 L
.54392 .06709 L
.54532 .07125 L
.54671 .07456 L
.54811 .09973 L
.5495 .08057 L
.5509 .11745 L
.55229 .09919 L
.55368 .07131 L
.55508 .06682 L
.55647 .11252 L
.55787 .08544 L
.55926 .08884 L
.56066 .11568 L
.56205 .09969 L
.56345 .0893 L
.56484 .06869 L
.56623 .09152 L
.56763 .07712 L
.56902 .08078 L
.57042 .07474 L
.57181 .08301 L
.57321 .06416 L
.5746 .07016 L
.576 .07913 L
.57739 .06231 L
.57878 .0558 L
.58018 .07188 L
.58157 .07895 L
Mistroke
.58297 .05942 L
.58436 .06464 L
.58576 .0497 L
.58715 .0548 L
.58854 .04782 L
.58994 .06764 L
.59133 .06256 L
.59273 .06157 L
.59412 .06504 L
.59552 .05383 L
.59691 .06034 L
.59831 .04914 L
.5997 .06395 L
.60109 .0684 L
.60249 .06507 L
.60388 .06474 L
.60528 .06371 L
.60667 .05369 L
.60807 .0617 L
.60946 .05616 L
.61086 .08014 L
.61225 .04651 L
.61364 .05241 L
.61504 .04187 L
.61643 .04988 L
.61783 .04705 L
.61922 .08495 L
.62062 .09527 L
.62201 .07325 L
.62341 .07082 L
.6248 .06725 L
.62619 .09016 L
.62759 .0753 L
.62898 .10199 L
.63038 .09632 L
.63177 .08282 L
.63317 .08474 L
.63456 .0801 L
.63595 .07592 L
.63735 .18331 L
.63874 .08911 L
.64014 .08059 L
.64153 .07635 L
.64293 .08188 L
.64432 .0941 L
.64572 .06944 L
.64711 .06961 L
.6485 .08054 L
.6499 .07917 L
.65129 .07298 L
Mistroke
.65269 .07817 L
.65408 .0651 L
.65548 .06929 L
.65687 .09083 L
.65827 .0798 L
.65966 .10945 L
.66105 .07238 L
.66245 .08017 L
.66384 .06734 L
.66524 .07526 L
.66663 .07891 L
.66803 .08159 L
.66942 .0922 L
.67082 .07999 L
.67221 .09032 L
.6736 .07234 L
.675 .07531 L
.67639 .08257 L
.67779 .07636 L
.67918 .08513 L
.68058 .07724 L
.68197 .08848 L
.68336 .10597 L
.68476 .07119 L
.68615 .05486 L
.68755 .07328 L
.68894 .0764 L
.69034 .07615 L
.69173 .07771 L
.69313 .05788 L
.69452 .05928 L
.69591 .06673 L
.69731 .08631 L
.6987 .06899 L
.7001 .07027 L
.70149 .08665 L
.70289 .06356 L
.70428 .06754 L
.70568 .07442 L
.70707 .07708 L
.70846 .0861 L
.70986 .08054 L
.71125 .09372 L
.71265 .07034 L
.71404 .07897 L
.71544 .08713 L
.71683 .09583 L
.71822 .08322 L
.71962 .08801 L
.72101 .08788 L
Mistroke
.72241 .10614 L
.7238 .08493 L
.7252 .06957 L
.72659 .0525 L
.72799 .08724 L
.72938 .08833 L
.73077 .09116 L
.73217 .08476 L
.73356 .07963 L
.73496 .08768 L
.73635 .09265 L
.73775 .10942 L
.73914 .09104 L
.74054 .09034 L
.74193 .08504 L
.74332 .1704 L
.74472 .14993 L
.74611 .12359 L
.74751 .14687 L
.7489 .12242 L
.7503 .11336 L
.75169 .11205 L
.75309 .12161 L
.75448 .11856 L
.75587 .11068 L
.75727 .13719 L
.75866 .09876 L
.76006 .08831 L
.76145 .11193 L
.76285 .10585 L
.76424 .10558 L
.76563 .1069 L
.76703 .09823 L
.76842 .07668 L
.76982 .08681 L
.77121 .13856 L
.77261 .10957 L
.774 .08923 L
.7754 .09048 L
.77679 .1069 L
.77818 .09931 L
.77958 .09957 L
Mfstroke
.77958 .09957 m
.78037 .2 L
s
.78194 .2 m
.78237 .16589 L
s
.78237 .16589 m
.78313 .2 L
s
.78702 .2 m
.78795 .13355 L
.78934 .11168 L
s
.78934 .11168 m
.78945 .2 L
s
.79338 .2 m
.79352 .13741 L
s
.79352 .13741 m
.79491 .2 L
s
.79492 .2 m
.79631 .1025 L
.79771 .11467 L
.7991 .1064 L
.8005 .05883 L
.80189 .03348 L
.80328 .04626 L
.80468 .10247 L
.80607 .05429 L
.80747 .07792 L
.80886 .08792 L
.81026 .06099 L
.81165 .02658 L
.81304 .0957 L
.81444 .1086 L
.81583 .11273 L
.81723 .1041 L
.81862 .09908 L
.82002 .1716 L
s
.82002 .1716 m
.821 .2 L
s
.82217 .2 m
.82281 .1899 L
.8242 .18205 L
.82559 .1457 L
.82699 .12873 L
.82838 .12115 L
.82978 .12601 L
.83117 .0945 L
.83257 .10975 L
.83396 .1099 L
.83536 .11178 L
.83675 .06784 L
.83814 .08773 L
.83954 .08319 L
.84093 .08209 L
.84233 .08031 L
.84372 .08642 L
.84512 .08775 L
.84651 .07855 L
.8479 .0872 L
.8493 .07282 L
.85069 .05228 L
.85209 .0722 L
.85348 .06776 L
.85488 .0736 L
.85627 .06573 L
.85767 .07708 L
.85906 .057 L
.86045 .05901 L
.86185 .05898 L
.86324 .06294 L
.86464 .066 L
.86603 .07178 L
.86743 .08135 L
.86882 .04675 L
.87022 .03823 L
.87161 .06383 L
.873 .07484 L
.8744 .06055 L
.87579 .09092 L
.87719 .08989 L
.87858 .06182 L
.87998 .05885 L
.88137 .06713 L
.88277 .08463 L
.88416 .07207 L
.88555 .07411 L
.88695 .09111 L
.88834 .06348 L
.88974 .06158 L
Mistroke
.89113 .05698 L
.89253 .07095 L
.89392 .09976 L
.89531 .07542 L
.89671 .08382 L
.8981 .0621 L
.8995 .06932 L
.90089 .06568 L
.90229 .06699 L
.90368 .07071 L
.90508 .07993 L
.90647 .08798 L
.90786 .05341 L
.90926 .05798 L
.91065 .05256 L
.91205 .06487 L
.91344 .06231 L
.91484 .07057 L
.91623 .07969 L
.91763 .05178 L
.91902 .05316 L
.92041 .0602 L
.92181 .06135 L
.9232 .06854 L
.9246 .06318 L
.92599 .06986 L
.92739 .05695 L
.92878 .06229 L
.93017 .07068 L
.93157 .07162 L
.93296 .04832 L
.93436 .06508 L
.93575 .06104 L
.93715 .00178 L
.93854 .05508 L
.93994 .04972 L
.94133 .06124 L
.94272 .06046 L
.94412 .07233 L
.94551 .07716 L
.94691 .077 L
.9483 .06772 L
.9497 .07201 L
.95109 .09236 L
.95249 .09085 L
.95388 .07782 L
.95527 .0807 L
.95667 .07806 L
.95806 .09688 L
.95946 .08835 L
Mistroke
.96085 .09 L
.96225 .08619 L
.96364 .08812 L
.96504 .07757 L
.96643 .06531 L
.96782 .07774 L
.96922 .09422 L
.97061 .07407 L
.97201 .07441 L
.9734 .03426 L
.9748 .02796 L
.97619 .06915 L
Mfstroke
0 1 0 r
.015 w
.03357 .03673 Mdot
.17719 .04124 Mdot
.29154 .08412 Mdot
.29293 .02644 Mdot
.29432 .02905 Mdot
.30269 .0153 Mdot
.44492 .04999 Mdot
.4491 .01735 Mdot
.47002 .02611 Mdot
.50209 .03882 Mdot
.51743 .01778 Mdot
.53137 .06082 Mdot
.68615 .05486 Mdot
.8005 .05883 Mdot
.80189 .03348 Mdot
.80328 .04626 Mdot
.81165 .02658 Mdot
.93296 .04832 Mdot
.93715 .00178 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{756.25, 151.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;d0000Ub000`400?l00000o`00003oo`3ooooo
0?ooooH0oooo003o0?ooool0oooomP3oool006d0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`2E0?ooo`00K@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo09D0oooo
001]0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0U@3oool00640oooo00<00000
0?ooo`3oool00`3oool4000000<0oooo00<000000?ooo`3oool00P3oool4000000<0oooo00<00000
0?ooo`3oool00P3oool6000000<0oooo100000040?ooo`@00000103oool4000001<0oooo1P000006
0?ooo`050000003oool0oooo0?ooo`000000103oool3000000@0oooo00<000000?ooo`3oool00P3o
ool6000000<0oooo100000040?ooo`@00000103oool4000001L0oooo1P0000020?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo000000040?ooo`H000000`3oool4000000@0oooo
100000060?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool6000000030?oo
o`000000oooo00L0oooo00@000000?ooo`3oool00000103oool6000000<0oooo100000040?ooo`@0
00001P3oool00`000000oooo0?ooo`0C0?ooo`H000001@3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool6000000<0oooo10000004
0?ooo`@000001P3oool00`000000oooo0?ooo`0?0?ooo`H000000`3oool3000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`@000000`3oool010000000oooo0?ooo`3o
ool6000000<0oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`0D0?ooo`@000000`3o
ool010000000oooo0?ooo`3oool600000080oooo00@000000?ooo`3oool0oooo1P0000030?ooo`@0
0000103oool4000000<0oooo1P00001e0?ooo`00H@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D0
00000?ooo`3oool0oooo0000001i0?ooo`00H@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0080oooo1`0000020?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`L0000000<0
oooo0000003oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1f0?ooo`00H@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo07D0oooo001Q0?ooo`030000003oool0oooo0080oooo0P000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000<0oooo00D000000?ooo`3oool0oooo
000000070?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000030?oo
o`000000oooo0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000@0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000@0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool3000000030?ooo`000000oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3o
ool2000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07@0oooo001Q0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000000P0000040?ooo`050000003oool0oooo0000
003oool00`0000040?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000030?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo01T0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00H0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool010000000oooo0?oo
o`0000030?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo00000002000000@0oooo00<000000?ooo`3oool01@3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L`3oool00640oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000T0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00L0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo07<0oooo001O0?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo000000090?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0
oooo00@000000?ooo`3oool00000103oool01`000000oooo0?ooo`3oool000000?ooo`0000006P3o
ool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0oooo0000
003oool0000001D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00L0
00000?ooo`3oool0oooo0000003oool000000140oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`00
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool01`000000
oooo0?ooo`3oool000000?ooo`0000005@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo07<0oooo001P0?ooo`8000001@3oool01@000000oooo0?ooo`3oool0000000@0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0P0000050?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P00000K0?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000@0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00P3oool2000001D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00P3oool200000140oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`020?ooo`8000005P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0L`3oool00640oooo00<000000?ooo`3oool0103oool3000000H0
oooo00<000000?ooo`3oool00`0000060?ooo`030000003oool0oooo00@00000103oool4000000@0
oooo100000040?ooo`@00000503oool4000000L0oooo00<000000?ooo`3oool0103oool00`000000
oooo00000003000000H0oooo00<000000?ooo`3oool0100000040?ooo`@00000103oool4000000@0
oooo1000000H0?ooo`@000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0100000040?ooo`@00000103oool4000000H0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`030?ooo`@000001@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0100000040?ooo`@00000103oool4000000H0
oooo00<000000?ooo`3oool0503oool4000000H0oooo00<000000?ooo`3oool0103oool00`000000
oooo00000005000000D0oooo00<000000?ooo`0000000`0000040?ooo`@00000103oool4000000H0
oooo00<000000?ooo`3oool0403oool4000000@0oooo100000060?ooo`050000003oool0oooo0?oo
o`0000001@3oool4000000H0oooo00<000000?ooo`0000000`0000040?ooo`@00000103oool40000
00H0oooo00<000000?ooo`3oool05@3oool3000000H0oooo00<000000?ooo`0000000`0000060?oo
o`030000003oool0000000<00000103oool4000000@0oooo100000040?ooo`@00000MP3oool00?l0
ooooo`3oooof0?ooo`00o`3ooooo0?ooooH0oooo003o0?ooool0oooomP3oool00?l0ooooo`3oooof
0?ooo`00o`3ooooo0?ooooH0oooo003o0?ooool0oooomP3oool00?l0ooooo`3oooof0?ooo`00o`3o
oooo0?ooooH0oooo003o0?ooool0ooooT@3oool2003o06<0oooo003o0?ooool0ooooS`3oool6003o
0640oooo001^0?ooool00000o`00000Q000000H00?l08P00000o0?ooo`00KP3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo02D0oooo2000o`0P0?ooo`030000003oool0oooo03d0oooo
001^0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool09@3oool8003o0200oooo00<0
00000?ooo`3oool0?@3oool006h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0V
0?ooo`H00?l08@3oool00`000000oooo0?ooo`0m0?ooo`00KP3oool4000000/0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool09P3oool6003o0240oooo00<000000?ooo`3oool0?@3oool006h0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooob00oooo0P00o`0S0?ooo`030000003oool0oooo03d0oooo001^0?ooo`030000
003oool0oooo0:d0oooo0P00o`3o0?ooog40oooo00<0003o0?ooo`3oool08@3oool00`000000oooo
0?ooo`0m0?ooo`00KP3oool400000:X0oooo1P00o`1A0?ooo`800?l09P3oool2003o0?<0oooo00<0
003o0?ooo`3oool08@3oool00`000000oooo0?ooo`0m0?ooo`00KP3oool00`000000oooo0?ooo`2[
0?ooo`H00?l0C`3oool6003o0280oooo1P00o`3a0?ooo`030000o`3oool0oooo0240oooo00<00000
0?ooo`3oool0?@3oool006h0oooo00<000000?ooo`3oool0ZP3oool8003o04h0oooo1P00o`0R0?oo
o`H00?l0l@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo03d0oooo001^0?ooo`@0
0000Z@3oool8003o04d0oooo2000o`0P0?ooo`P00?l0l03oool00`000?l0oooo0?ooo`0Q0?ooo`03
0000003oool0oooo03d0oooo001^0?ooo`030000003oool0oooo0:/0oooo1P00o`1>0?ooo`P00?l0
803oool8003o0?00oooo00<0003o0?ooo`3oool08@3oool00`000000oooo0?ooo`0m0?ooo`00KP3o
ool00`000000oooo0?ooo`2W0?ooo`800?l00P3oool6003o04l0oooo1P00o`080?ooo`800?l0603o
ool6003o0?40oooo00<0003o0?ooo`3oool08@3oool00`000000oooo0?ooo`0m0?ooo`00F@3oool0
0`000000oooo0?ooo`030?ooo`@000002`3oool00`000000oooo0?ooo`2U0?ooo`H00?l00P3oool2
003o0540oooo1P00o`060?ooo`H00?l05P3oool6003o0:L0oooo0P00o`180?ooo`030000o`3oool0
oooo0240oooo00<000000?ooo`3oool0?@3oool005T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo1000002T0?ooo`H00?l00P3oool00`00
0?l0oooo0?ooo`1B0?ooo`800?l0203oool6003o01P0oooo0P00o`2W0?ooo`H00?l0AP3oool00`00
0?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo03d0oooo001I0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0:@0
oooo2000o`000`3oool0003o0?ooo`1D0?ooo`030000o`3oool0oooo00D0oooo2000o`0G0?ooo`03
0000o`3oool0oooo0:H0oooo1P00o`160?ooo`030000o`3oool0oooo0240oooo00<000000?ooo`3o
ool0?@3oool005T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`1[0?ooo`P00?l0
00<0oooo0000o`3oool0E03oool00`000?l0oooo0?ooo`050?ooo`P00?l05`3oool00`000?l0oooo
0?ooo`2U0?ooo`P00?l0A@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo03d0oooo
001I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`D00000=03oool00`000?l0oooo0?ooo`1/0?ooo`P00?l000<0003o0?ooo`3oool0D`3o
ool00`000?l0oooo0?ooo`060?ooo`H00?l0603oool00`000?l0oooo0?ooo`2R0?ooo`800?l000<0
oooo003o0000o`001P00o`150?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0303o
ool00`000000oooo0?ooo`0m0?ooo`00F@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`800?l0903oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo06D0oooo2000o`000`000?l0oooo0?ooo`1C
0?ooo`030000o`3oool0oooo00H0oooo1P00o`0H0?ooo`030000o`3oool0oooo0:00oooo3000o`16
0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`0m
0?ooo`00F@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0>0?ooo`H00?l08P3oool20000o`@0oooo0P000?mX0?oo
o`H00?l000<0oooo0000o`000?l0E03oool00`000?l0oooo0?ooo`080?ooo`800?l06P3oool00`00
0?l0oooo0?ooo`2P0?ooo``00?l0A@3oool20000oa@0oooo00<0003o0?ooo`3oool0303oool00`00
0000oooo0?ooo`0m0?ooo`00E`3oool00`000000oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool4000000d0oooo1P00o`0B0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool01`3oool20000o`@0oooo0P000?mX0?ooo`H00?l000<0oooo0000o`00
0?l0E03oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00l0oooo0P00o`070?ooo`03
0000o`3oool0oooo09l0oooo2000o`000`3oool00?l0003o00170?ooo`80003o503oool00`000?l0
oooo0?ooo`0<0?ooo`030000003oool0oooo03d0oooo001H0?ooo`800000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool8003o0100oooo
0P000?l40?ooo`80003o0`3oool30000o`<0oooo00<0003o0?ooo`000?l00`3oool20000obH0oooo
0P00o`120?ooo`800?l00`3oool20000oe@0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0=0?ooo`H00?l01@3oool00`000?l0oooo0?ooo`2O0?ooo`P00?l00P3oool00`000?l0oooo
0?ooo`150?ooo`80003o503oool00`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo03d0oooo
001I0?ooo`030000003oool0oooo00<0oooo1000000;0?ooo`030000003oool0oooo00d0oooo2000
o`0@0?ooo`030000o`3oool0003o00<0oooo0P000?l30?ooo`030000o`3oool0003o00<0oooo00<0
003o0?ooo`000?l00`3oool20000ob@0oooo1P00o`100?ooo`80003o0`3oool20000ocP0oooo00<0
003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo1P00
o`050?ooo`030000o`3oool0oooo0:00oooo1P00o`030?ooo`030000o`3oool0oooo04D0oooo0P00
0?lD0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0?@3oool006h0oooo00<00000
0?ooo`3oool03P3oool6003o00H0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0000o`03
0?ooo`80003o0`3oool00`000?l0oooo0000o`030?ooo`030000o`3oool0003o00<0oooo0P000?lT
0?ooo`H00?l0@03oool20000o`<0oooo0P000?lh0?ooo`030000o`3oool0oooo01T0oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0<0?ooo`P00?l0103oool00`000?l0oooo0?ooo`2P
0?ooo`H00?l00`3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo02<0oooo0P000?lD
0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0?@3oool006h0oooo1000000=0?oo
o`H00?l000<0oooo0000o`3oool00`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0003o
00<0oooo0P000?l30?ooo`030000o`3oool0003o00<0oooo00@0003o0?ooo`3oool0003o0P3oool2
0000ob<0oooo2000o`060?ooo`030000o`3oool0oooo03H0oooo0P000?l30?ooo`80003o>03oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0203oool2
0000o`h0oooo2000o`040?ooo`030000o`3oool0oooo0:80oooo0`00o`040?ooo`030000o`3oool0
oooo01l0oooo00<0003o0?ooo`3oool08`3oool20000oa@0oooo00<0003o0?ooo`3oool0303oool0
0`000000oooo0?ooo`0m0?ooo`00KP3oool00`000000oooo0?ooo`0@0?ooo`800?l00`3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0003o0P3oool2
0000o`<0oooo00@0003o0?ooo`3oool0003o0P3oool010000?l0oooo0?ooo`000?l20?ooo`80003o
8`3oool8003o00H0oooo00<0003o0?ooo`3oool0=P3oool20000o`<0oooo0P000?lh0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`080?ooo`80003o
3`3oool6003o00D0oooo00<0003o0?ooo`3oool0=P3oool00`000?l0oooo0?ooo`1X0?ooo`H00?l0
0P3oool00`000?l0oooo0?ooo`0N0?ooo`80003o8P3oool2003o00030?ooo`000?l0003o01@0oooo
00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`0m0?ooo`00KP3oool00`000000oooo0?oo
o`0>0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`000?l00`3oool20000o`<0oooo
00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`000?l20?ooo`<0003o0P3oool010000?l0
oooo0?ooo`000?l20?ooo`040000o`3oool0oooo0000o`80oooo0P000?lT0?ooo`H00?l01`3oool0
0`000?l0oooo0?ooo`0f0?ooo`80003o0`3oool20000ocP0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`030?ooo`80003o2`3oool2003o0080oooo00<0003o0?ooo`3oool0203oool2
0000o`l0oooo1P00o`050?ooo`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool0J03oool6
003o00030?ooo`000?l0003o0200oooo0P000?lP0?ooo`H00?l000<0003o0?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo03d0oooo001^0?ooo`@000003@3oool02@00
0?l0oooo0000o`3oool0003o0?ooo`000?l0oooo0000o`030?ooo`80003o0`3oool00`000?l0oooo
0?ooo`030?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`000?l00P3oool010000?l0
oooo0?ooo`000?l20?ooo`040000o`3oool0oooo0000o`80oooo0P000?l50?ooo`030000o`3oool0
oooo01`0oooo1P00o`070?ooo`030000o`3oool0oooo03H0oooo0P000?l30?ooo`80003o>03oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo0P000?l90?ooo`H00?l000<0003o
0?ooo`3oool0203oool20000oa40oooo0P00o`070?ooo`80003o=P3oool20000ofT0oooo2000o`02
0000ob00oooo0P000?lP0?ooo`H00?l000<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0<
0?ooo`030000003oool0oooo03d0oooo001^0?ooo`030000003oool0oooo00h0oooo0`000?l01P3o
ool0003o0?ooo`000?l0oooo0000o`<0oooo0P000?l30?ooo`80003o103oool010000?l0oooo0?oo
o`000?l20?ooo`030000o`3oool0003o0080oooo00H0003o0?ooo`3oool0003o0?ooo`000?l30?oo
o`030000o`3oool0oooo0080003o1@3oool00`000?l0oooo0?ooo`0N0?ooo`800?l02@3oool00`00
0?l0oooo0?ooo`0f0?ooo`80003o0`3oool00`000?l0oooo0000o`0f0?ooo`80003o103oool00`00
0?l0oooo0?ooo`030?ooo`80003o2@3oool6003o00030000o`3oool0oooo00P0oooo0P000?lA0?oo
o`030000o`3oool0oooo00H0oooo0P000?lX0?ooo`030000o`3oool0oooo00/0oooo00@0003o0?oo
o`000?l0003oI`3oool8003o0080003o803oool20000oal0oooo2000o`0D0?ooo`030000o`3oool0
oooo00`0oooo00<000000?ooo`3oool0?@3oool006h0oooo00<000000?ooo`3oool03P3oool30000
o`060?ooo`000?l0oooo0000o`3oool0003o0`3oool20000o`<0oooo0P000?l40?ooo`040000o`3o
ool0oooo0000o`80oooo00<0003o0?ooo`000?l00P3oool01P000?l0oooo0?ooo`000?l0oooo0000
o`<0oooo00<0003o0?ooo`3oool00P000?l40?ooo`80003o803oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo03H0oooo0P000?l30?ooo`030000o`3oool0003o03H0oooo00<0003o0?oo
o`000?l00`3oool30000o`<0oooo0P000?l80?ooo`P00?l02P3oool20000oa40oooo0P000?l70?oo
o`80003o9P3oool00`000?l0oooo0000o`040?ooo`030000o`3oool0oooo00H0oooo00@0003o0?oo
o`000?l0003o9P3oool2003o0400oooo1P00o`000`3oool0003o0000o`0P0?ooo`80003o7`3oool8
003o00030000o`3oool0oooo0140oooo0P000?l=0?ooo`030000003oool0oooo03d0oooo001F0?oo
o`H000000`3oool4000000/0oooo1000000=0?ooo`<0003o00H0oooo0000o`3oool0003o0?ooo`00
0?l30?ooo`80003o0`3oool20000o`040?ooo`000?l0oooo0000o`<0oooo00<0003o0?ooo`000?l0
0`3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0003o00<0oooo00<0003o0?ooo`000?l0
0P3oool010000?l0oooo0?ooo`3oool20000o`<0oooo00<0003o0?ooo`3oool06P3oool00`000?l0
oooo0?ooo`070?ooo`80003o>03oool20000o`<0oooo00<0003o0?ooo`000?l0=P3oool00`000?l0
oooo0000o`030?ooo`<0003o0P3oool30000o`D0oooo00<0003o0?ooo`3oool02000o`0:0?ooo`80
003o4@3oool20000o`L0oooo0P000?lV0?ooo`<0003o103oool00`000?l0oooo0?ooo`060?ooo`04
0000o`3oool0oooo0000ob@0oooo1P00o`0n0?ooo`H00?l000<0oooo0000o`000?l0803oool20000
oaX0oooo00<0003o0?ooo`3oool00`3oool6003o0080003o4`3oool20000o`d0oooo00<000000?oo
o`3oool0?@3oool005L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool01`000?l0oooo0000o`3oool0003o
0?ooo`000?l00P3oool00`000?l0oooo0?ooo`020000o`<0oooo00H0003o0?ooo`000?l0003o0?oo
o`000?l30?ooo`030000o`3oool0003o00<0oooo00<0003o0?ooo`000?l00`3oool20000o`<0oooo
00<0003o0?ooo`000?l00P3oool010000?l0oooo0?ooo`3oool20000o`<0oooo00<0003o0?ooo`3o
ool06P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0003o03L0oooo0P000?l30?ooo`03
0000o`3oool0003o02D0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0000o`030?ooo`<0
003o0P3oool20000o`030?ooo`000?l0oooo00<0oooo00@0003o0?ooo`3oool0oooo1P00o`000`00
0?l0oooo0?ooo`080?ooo`80003o4@3oool20000o`L0oooo0P000?lV0?ooo`<0003o103oool00`00
0?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0000ob@0oooo1P00o`0D0?ooo`030000o`3oool0
oooo02L0oooo1000o`030?ooo`80003o5@3oool00`000?l0oooo0?ooo`080?ooo`80003o503oool0
0`000?l0oooo0000o`030?ooo`80003o103oool6003o0080003o4`3oool20000o`d0oooo00<00000
0?ooo`3oool0?@3oool005P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool01`000?l0oooo0?ooo`3oool0
003o0?ooo`000?l00P3oool30000o`80oooo00@0003o0?ooo`3oool0003o0`3oool20000o`<0oooo
00<0003o0?ooo`000?l00`3oool00`000?l0oooo0000o`030?ooo`80003o0`3oool00`000?l0oooo
0000o`020?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool00`000?l0oooo0?ooo`0J0?ooo`80
003o1`3oool20000o`030?ooo`000?l0oooo00X0oooo00<0003o0?ooo`3oool0:@3oool20000o`<0
oooo00<0003o0?ooo`000?l0403oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0000o`030?ooo`<0003o0P3oool20000o`03
0?ooo`000?l0oooo00<0oooo00@0003o0?ooo`3oool0oooo1P00o`000`000?l0oooo0?ooo`080?oo
o`80003o4@3oool20000o`L0oooo0P000?l60?ooo`800?l07P3oool30000o`<0oooo0P000?l40?oo
o`050000o`3oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0Q0?ooo`P00?l04`3oool0
0`000?l0oooo0?ooo`0U0?ooo`H00?l000<0003o0?ooo`3oool00P000?lE0?ooo`030000o`3oool0
oooo00P0oooo0P000?lD0?ooo`030000o`3oool0003o00<0oooo0P000?l60?ooo`800?l000@0oooo
0000o`000?l0003o4P3oool00`000?l0oooo0000o`0=0?ooo`030000003oool0oooo03d0oooo001I
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00h0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo
0`000?l20?ooo`040000o`3oool0003o0000o`@0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0
003o00@0oooo0P000?l30?ooo`80003o103oool20000o`<0oooo00<0003o0?ooo`3oool00P000?l2
0?ooo`<0003o6`3oool20000o`@0oooo00<0003o0?ooo`3oool00P000?l00`3oool0003o0000o`0:
0?ooo`030000o`3oool0oooo02P0oooo00@0003o0?ooo`000?l0003o0P3oool00`000?l0oooo0000
o`0@0?ooo`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0oooo0P000?l40?ooo`80003o
3`3oool00`000?l0oooo0000o`030?ooo`<0003o0P3oool010000?l0oooo0?ooo`000?l40?ooo`06
0000o`3oool0oooo0?ooo`000?l0oooo0P00o`000`3oool0003o0000o`0:0?ooo`80003o4@3oool2
0000o`L0oooo0P000?l40?ooo`H00?l0603oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0
0`3oool20000o`@0oooo00D0003o0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo0240
oooo2000o`0C0?ooo`030000o`3oool0oooo02D0oooo1P00o`000`000?l0oooo0?ooo`020000oaD0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`80003o2`3oool00`000?l0
oooo0?ooo`060?ooo`<0003o0`3oool20000o`@0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l2
0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`000?l03@3oool00`000000oooo0?ooo`0m
0?ooo`00FP3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0203oool5
000000/0oooo0P000?l30?ooo`80003o0`3oool30000o`80oooo00@0003o0?ooo`000?l0003o103o
ool010000?l0oooo0?ooo`3oool30000o`@0oooo0P000?l40?ooo`030000o`3oool0oooo0080oooo
0P000?l30?ooo`0:0000o`3oool0oooo0000o`3oool0003o0?ooo`000?l0oooo0000oaX0oooo00<0
003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`020000o`030?ooo`000?l0003o00X0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo00X0oooo00@0
003o0?ooo`000?l0003o0P3oool010000?l0oooo0?ooo`000?l?0?ooo`030000o`3oool0oooo00P0
oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o00<0oooo00<0003o0?ooo`000?l03P3oool0
0`000?l0oooo0000o`030?ooo`030000o`3oool0003o0080oooo00@0003o0?ooo`3oool0003o103o
ool01P000?l0oooo0?ooo`3oool0003o0?ooo`80003o00<0oooo0000o`000?l02P3oool20000o`D0
oooo00<0003o0?ooo`3oool02@3oool20000o`L0oooo0P000?l40?ooo`H00?l0603oool010000?l0
oooo0?ooo`000?l20?ooo`040000o`3oool0oooo0?ooo`<0003o0`3oool01@000?l0oooo0000o`3o
ool0003o0080oooo00<0003o0?ooo`3oool08P3oool6003o00030?ooo`000?l0oooo0140oooo00<0
003o0?ooo`3oool0903oool8003o0080oooo0P000?lE0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool20000o`/0oooo00<0003o0?ooo`3oool01P3oool30000o`<0oooo00<0
003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`030000o`80oooo00<0003o0?ooo`3oool03`3o
ool00`000?l0oooo0000o`0=0?ooo`030000003oool0oooo03d0oooo001K0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`<0003o0`3o
ool20000o`@0oooo0P000?l20?ooo`@0003o103oool00`000?l0oooo0?ooo`020?ooo`80003o103o
ool20000o`@0oooo00<0003o0?ooo`3oool00P3oool20000o`<0oooo00X0003o0?ooo`000?l0003o
0?ooo`000?l0oooo0000o`3oool0003o103oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`000?l00`3oool20000o`80oooo0P000?l00`3oool0003o0000o`0:
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05@3oool01@000?l0oooo0?ooo`3o
ool0003o00P0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`080?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`03
0?ooo`030000o`3oool0003o00h0oooo00<0003o0?ooo`000?l00P3oool010000?l0oooo0?ooo`00
0?l20?ooo`040000o`3oool0oooo0000o`<0oooo0P000?l30?ooo`050000o`3oool0003o0000o`3o
ool00P000?l:0?ooo`80003o1@3oool00`000?l0oooo0?ooo`090?ooo`80003o1P3oool30000o`<0
oooo2000o`0F0?ooo`80003o00<0oooo0000o`000?l00`3oool010000?l0oooo0000o`3oool20000
o`80oooo00H0003o0?ooo`000?l0003o0?ooo`000?l20?ooo`030000o`3oool0oooo0280oooo1P00
o`000`3oool0003o0?ooo`0A0?ooo`030000o`3oool0oooo02@0oooo2000o`020?ooo`80003o5@3o
ool00`000?l0oooo0?ooo`020?ooo`<0003o0`3oool20000o`050?ooo`000?l0oooo0?ooo`000?l0
1@3oool20000o`P0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0000o`030?ooo`04
0000o`3oool0003o0?ooo`80003o0P3oool20000oa00oooo00<0003o0?ooo`000?l03@3oool00`00
0000oooo0?ooo`0m0?ooo`00F`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0303oool30000o`<0oooo0P000?l40?ooo`80003o0`3oool00`00
0?l0oooo0000o`040?ooo`030000o`3oool0oooo0080oooo0P000?l40?ooo`80003o103oool00`00
0?l0oooo0?ooo`020?ooo`80003o103oool30000o`060?ooo`000?l0oooo0000o`3oool0003o103o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool010000?l0oooo0000o`000?l20?ooo`80003o0P3oool20000o`030?ooo`000?l0003o00T0oooo
0P000?l50?ooo`030000o`3oool0oooo01D0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`07
0000o`3oool0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo00d0oooo00<0003o
0?ooo`3oool0203oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00`3oool00`000?l0oooo
0000o`0>0?ooo`030000o`3oool0003o0080oooo00@0003o0?ooo`3oool0003o0P3oool010000?l0
oooo0?ooo`000?l30?ooo`030000o`3oool0003o0080oooo00D0003o0?ooo`000?l0003o0?ooo`02
0000o`X0oooo0P000?l40?ooo`80003o2`3oool00`000?l0oooo0000o`050?ooo`<0003o0`3oool8
003o01H0oooo0P000?l00`3oool0003o0000o`030?ooo`<0003o0P3oool01@000?l0oooo0?ooo`00
0?l0oooo0080003o00D0oooo0000o`3oool0oooo0000o`0V0?ooo`800?l00`3oool00`000?l0oooo
0?ooo`0?0?ooo`80003o9`3oool6003o00030000o`3oool0oooo0080003o5@3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0003o00<0oooo0P000?l00`3oool0003o0?ooo`020000o`D0oooo
0P000?l30?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0003o0P3oool010000?l0
oooo0?ooo`000?l20?ooo`<0003o00<0oooo0000o`000?l00P3oool20000oa00oooo00<0003o0?oo
o`000?l03@3oool00`000000oooo0?ooo`0m0?ooo`00@P3oool:000000X0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo1000000<0?oo
o`80003o103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo0`000?l01P3o
ool0003o0000o`000?l0oooo0000o`@0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o00@0
oooo00<0003o0?ooo`3oool00`3oool20000o`<0oooo00@0003o0?ooo`000?l0003o0P3oool20000
o`80oooo00<0003o0?ooo`3oool00P000?l00`3oool0003o0?ooo`020000o`@0oooo0P000?l50?oo
o`030000o`3oool0oooo01D0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`070000o`3oool0
oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0
203oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00`3oool010000?l0oooo0?ooo`000?l=
0?ooo`060000o`3oool0oooo0000o`3oool0003o0P3oool010000?l0oooo0?ooo`000?l20?ooo`07
0000o`3oool0oooo0?ooo`000?l0oooo0000o`020?ooo`@0003o00<0oooo0000o`000?l02P3oool2
0000o`@0oooo0P000?l;0?ooo`030000o`3oool0003o00@0oooo00@0003o0?ooo`3oool0003o103o
ool6003o01L0oooo0P000?l00`3oool0003o0000o`030?ooo`<0003o0P3oool010000?l0oooo0?oo
o`000?l20?ooo`80003o0`3oool00`000?l0oooo0?ooo`0T0?ooo`80003o0`3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00X0oooo0P000?lW0?ooo`H00?l000<0003o0?ooo`3oool0
0P000?lD0?ooo`030000o`3oool0003o00<0oooo00@0003o0?ooo`3oool0003o0P3oool20000o`03
0?ooo`000?l0oooo0080003o103oool00`000?l0oooo0000o`030?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00P000?l0103oool0003o0?ooo`3oool30000o`050?ooo`000?l0003o
0?ooo`000?l0103oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0003o00d0oooo00<00000
0?ooo`3oool0?@3oool00480oooo2P00000:0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo0`000?l0
0`3oool0003o0000o`020?ooo`060000o`3oool0oooo0000o`3oool0003o0`3oool00`000?l0oooo
0000o`040?ooo`80003o103oool30000o`80oooo00@0003o0?ooo`000?l0003o0P3oool20000o`80
oooo00H0003o0?ooo`3oool0oooo0000o`3oool20000o`030?ooo`000?l0oooo00<0oooo0P000?l3
0?ooo`030000o`3oool0003o01L0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`070000o`3o
ool0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo00`0oooo0P000?l30?ooo`03
0000o`3oool0oooo00@0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o00<0oooo00@0003o
0?ooo`3oool0003o3@3oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo0P000?l30?ooo`07
0000o`3oool0oooo0?ooo`000?l0oooo0000o`020?ooo`<0003o00@0oooo0000o`000?l0003o2P3o
ool20000o`@0oooo0P000?l00`3oool0003o0?ooo`080?ooo`030000o`3oool0003o00@0oooo00H0
003o0?ooo`3oool0003o0?ooo`000?l20?ooo`H00?l05@3oool010000?l0oooo0000o`3oool30000
o`<0oooo00<0003o0?ooo`000?l00P3oool010000?l0oooo0000o`000?l20?ooo`80003o0`3oool0
0`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00l0oooo0P000?l30?ooo`80003o0`3oool0
0`000?l0oooo0?ooo`0:0?ooo`80003o:@3oool2003o00030?ooo`000?l0003o0080oooo0P000?lD
0?ooo`030000o`3oool0003o00<0oooo00h0003o0?ooo`3oool0003o0?ooo`000?l0oooo0000o`3o
ool0003o0?ooo`000?l0oooo0000o`<0oooo00@0003o0?ooo`3oool0003o0P3oool20000o`<0oooo
00<0003o0?ooo`3oool00P000?l0103oool0003o0?ooo`3oool30000o`050?ooo`000?l0003o0?oo
o`000?l0103oool00`000?l0oooo0?ooo`0;0?ooo`060000o`3oool0oooo0000o`3oool0003o3@3o
ool00`000000oooo0?ooo`0m0?ooo`00@P3oool:000000/0oooo100000040?ooo`@000002`3oool0
0`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo0`000?l00`3oool0003o0000o`02
0?ooo`060000o`3oool0oooo0000o`3oool0003o0`3oool30000o`@0oooo0P000?l30?ooo`040000
o`3oool0oooo0000o`80oooo00@0003o0?ooo`000?l0oooo0P000?l01@3oool0003o0?ooo`3oool0
003o00@0oooo00D0003o0?ooo`000?l0oooo0000o`040?ooo`80003o00X0oooo0000o`3oool0003o
0?ooo`000?l0oooo0000o`3oool0003o4`3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo00L0
003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00@0003o0?ooo`3oool0003o2`3oool20000
o`<0oooo00<0003o0?ooo`3oool0103oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00`3o
ool010000?l0oooo0?ooo`000?l;0?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`000?l0
0`3oool20000o`<0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo0`000?l0103o
ool0003o0000o`000?l:0?ooo`030000o`3oool0003o00<0oooo0P000?l00`3oool0003o0?ooo`08
0?ooo`040000o`3oool0oooo0000o`<0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`04
0000o`3oool00?l0003o00H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`080?oo
o`040000o`3oool0003o0?ooo`80003o103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo0P000?l30?ooo`050000o`3oool0oooo0?ooo`000?l0403oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00T0oooo0P000?l30?ooo`80003o0`3oool20000o`/0oooo0P00
0?lZ0?ooo`040000o`3oool0003o0000o`80oooo0P000?lD0?ooo`040000o`3oool0003o0?ooo`80
003o0`3oool02`000?l0oooo0000o`3oool0003o0?ooo`000?l0oooo0000o`3oool0003o00<0oooo
00@0003o0?ooo`3oool0003o0P3oool30000o`80oooo00@0003o0?ooo`3oool0oooo0P000?l30?oo
o`<0003o00<0oooo0000o`000?l01`3oool00`000?l0oooo0?ooo`0:0?ooo`060000o`3oool0oooo
0000o`3oool0003o3@3oool00`000000oooo0?ooo`0m0?ooo`00@P3oool:00000280oooo1000000=
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D
0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool00P000?l30?ooo`@0003o00@0oooo
0000o`3oool0oooo0`000?l30?ooo`030000o`3oool0003o00<0oooo00@0003o0?ooo`3oool0003o
0P3oool010000?l0oooo0?ooo`3oool20000o`050?ooo`000?l0oooo0?ooo`000?l0103oool00`00
0?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`80003o00D0oooo0000o`3oool0003o0?oo
o`030000o`030?ooo`000?l0oooo0100oooo00<0003o0?ooo`000?l00P3oool20000o`P0oooo00<0
003o0?ooo`3oool00P3oool20000o`80oooo0P000?l00`3oool0003o0?ooo`0:0?ooo`80003o0`3o
ool00`000?l0oooo0?ooo`030?ooo`80003o0`3oool00`000?l0oooo0000o`020?ooo`050000o`3o
ool0oooo0?ooo`000?l02`3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0003o00@0oooo
00<0003o0?ooo`3oool00P3oool01P000?l0oooo0?ooo`000?l0oooo0000o`80oooo0`000?l0103o
ool0003o0000o`000?l:0?ooo`030000o`3oool0003o00<0oooo00@0003o0?ooo`000?l0003o2@3o
ool010000?l0oooo0?ooo`000?l30?ooo`060000o`3oool0oooo0000o`3oool0003o0P3oool40000
o`H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo0`000?l00`3oool0003o0000o`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool00P3oool20000o`@0oooo00@0003o0?ooo`000?l0003o403oool20000o`@0oooo00<0003o
0?ooo`3oool02@3oool20000o`80oooo00H0003o0?ooo`000?l0oooo0000o`3oool20000o`/0oooo
0P000?lZ0?ooo`030000o`3oool0003o0080003o00<0oooo0000o`000?l03@3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0003o00<0003o0`3oool010000?l0oooo0000o`3oool30000o`04
0?ooo`000?l0oooo0000o`<0oooo00@0003o0?ooo`3oool0003o0P3oool30000o`80oooo00<0003o
0?ooo`3oool00P3oool020000?l0oooo0?ooo`3oool0003o0?ooo`000?l0oooo0P000?l70?ooo`03
0000o`3oool0003o00X0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l=0?ooo`030000003oool0
oooo03d0oooo00120?ooo`X000008P3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo
00D0oooo10000?l01`3oool0003o0?ooo`3oool0003o0?ooo`000?l00`3oool010000?l0oooo0?oo
o`000?l20?ooo`060000o`3oool0oooo0000o`3oool0003o1`3oool010000?l0oooo0?ooo`000?l9
0?ooo`040000o`3oool0oooo0?ooo`80003o00@0oooo0000o`000?l0oooo10000?l00`3oool0003o
0?ooo`0=0?ooo`060000o`3oool0oooo0000o`3oool0003o0P3oool00`000?l0oooo0000o`070?oo
o`030000o`3oool0oooo0080oooo0P000?l30?ooo`040000o`3oool0003o0000o`X0oooo00@0003o
0?ooo`000?l0oooo0P000?l50?ooo`80003o0`3oool00`000?l0oooo0000o`020?ooo`050000o`3o
ool0oooo0?ooo`000?l02`3oool20000o`<0oooo00<0003o0?ooo`000?l0103oool00`000?l0oooo
0?ooo`020?ooo`<0003o0P3oool010000?l0oooo0000o`3oool20000o`040?ooo`000?l0003o0000
o`X0oooo00<0003o0?ooo`000?l00`3oool010000?l0oooo0000o`000?l40?ooo`80003o0`3oool0
1@000?l0oooo0?ooo`3oool0003o0080oooo00T0003o0?ooo`3oool0003o0?ooo`000?l0oooo0000
o`3oool00`000?l60?ooo`80003o0`3oool20000o`D0oooo00<0003o0?ooo`3oool00P3oool30000
o`030?ooo`000?l0003o0100oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0000o`000?l;
0?ooo`80003o0`3oool20000o`@0oooo00<0003o0?ooo`3oool02@3oool20000o`80oooo00@0003o
0?ooo`000?l0oooo10000?l40?ooo`030000o`3oool0oooo00@0oooo0P000?lZ0?ooo`030000o`3o
ool0003o0080003o00<0oooo0000o`000?l03@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0003o00<0003o103oool20000o`80oooo0P000?l0103oool0003o0?ooo`000?l30?ooo`040000
o`3oool0oooo0000o`80oooo0P000?l0103oool0003o0?ooo`000?l40?ooo`030000o`3oool0oooo
00<0oooo00@0003o0?ooo`000?l0003o1`3oool00`000?l0oooo0000o`0:0?ooo`040000o`3oool0
oooo0000o`l0oooo00<000000?ooo`3oool0?@3oool00480oooo2P00000R0?ooo`030000003oool0
oooo04T0oooo10000?l01`3oool0003o0?ooo`3oool0003o0?ooo`000?l00`3oool01@000?l0oooo
0?ooo`000?l0oooo0080003o0P3oool00`000?l0oooo0000o`080?ooo`030000o`3oool0003o00T0
oooo00@0003o0?ooo`000?l0oooo0P000?l0103oool0003o0000o`3oool30000o`030?ooo`000?l0
003o00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020000o`060?ooo`000?l0
003o0000o`3oool0003o1`3oool00`000?l0oooo0?ooo`020?ooo`80003o0`3oool010000?l0oooo
0000o`000?l:0?ooo`040000o`3oool0003o0?ooo`<0003o103oool00`000?l0oooo0000o`020?oo
o`060000o`3oool0oooo0000o`3oool0003o0`3oool00`000?l0oooo0?ooo`090?ooo`80003o0`3o
ool00`000?l0oooo0000o`090?ooo`<0003o0P3oool010000?l0oooo0000o`3oool20000o`040?oo
o`000?l0003o0000o`T0oooo00<0003o0?ooo`3oool00P000?l20?ooo`040000o`3oool0003o0?oo
o`<0003o00<0oooo0000o`000?l00`3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00T0003o
0?ooo`3oool0003o0?ooo`000?l0oooo0000o`3oool00`000?l50?ooo`030000o`3oool0003o00<0
oooo0P000?l50?ooo`030000o`3oool0oooo0080oooo0P000?l20?ooo`80003o403oool00`000?l0
oooo0?ooo`020?ooo`80003o00<0oooo0000o`3oool02P3oool20000o`80oooo00<0003o0?ooo`00
0?l00P3oool00`000?l0oooo0000o`040?ooo`030000o`3oool0oooo00@0oooo0P000?l20?ooo`04
0000o`3oool0003o0?ooo`@0003o103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0003o
02T0oooo00<0003o0?ooo`000?l00P000?l00`3oool0003o0000o`0=0?ooo`030000o`3oool0oooo
00@0oooo00@0003o0?ooo`000?l0oooo0P000?l40?ooo`80003o0P3oool20000o`080?ooo`000?l0
oooo0000o`3oool0003o0?ooo`000?l20?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?oo
o`000?l0103oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00@0003o0?oo
o`000?l0003o203oool20000o`80oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`0m
0?ooo`00@P3oool:00000280oooo100000180?ooo`@0003o00L0oooo0000o`000?l0oooo0000o`3o
ool0003o00<0oooo00D0003o0?ooo`3oool0003o0?ooo`020000o`80oooo00<0003o0?ooo`000?l0
203oool00`000?l0oooo0000o`090?ooo`070000o`3oool0003o0000o`3oool0003o0?ooo`020000
o`80oooo0P000?l00`3oool0003o0000o`040?ooo`80003o1@3oool010000?l0oooo0?ooo`000?l2
0?ooo`80003o00H0oooo0000o`000?l0003o0?ooo`000?l70?ooo`030000o`3oool0oooo0080oooo
0P000?l30?ooo`040000o`3oool0003o0000o`X0oooo00H0003o0?ooo`000?l0oooo0000o`3oool2
0000o`<0oooo00<0003o0?ooo`000?l00P3oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo
00@0003o0?ooo`3oool0003o1`3oool00`000?l0oooo0000o`040?ooo`80003o2@3oool30000o`80
oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0000o`020000o`H0oooo00@0003o0?ooo`3o
ool0003o0P3oool30000o`050?ooo`000?l0oooo0000o`3oool00`000?l00`3oool0003o0000o`03
0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool01@000?l0oooo0?ooo`000?l0oooo00<0003o
00@0oooo0000o`000?l0003o0`3oool01@000?l0oooo0000o`3oool0003o00<0oooo0P000?l50?oo
o`030000o`3oool0oooo0080oooo0P000?l20?ooo`80003o403oool00`000?l0oooo0?ooo`020?oo
o`80003o00<0oooo0000o`3oool02P3oool20000o`050?ooo`000?l0003o0?ooo`000?l00P3oool3
0000o`@0oooo00<0003o0?ooo`3oool0103oool20000o`80oooo00@0003o0?ooo`000?l0oooo0`00
0?l00`3oool0003o0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`000?l0:@3o
ool00`000?l0oooo0000o`020000o`030?ooo`000?l0003o00d0oooo00<0003o0?ooo`3oool0103o
ool010000?l0oooo0?ooo`3oool20000o`@0oooo0P000?l20?ooo`80003o00D0oooo0000o`3oool0
003o0?ooo`030000o`80oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0000o`040?ooo`03
0000o`3oool0oooo00h0oooo0P000?l00`3oool0003o0?ooo`070?ooo`80003o00<0oooo0000o`00
0?l03`3oool00`000000oooo0?ooo`0m0?ooo`00KP3oool00`000000oooo0?ooo`190?ooo`80003o
00T0oooo0000o`3oool0oooo0000o`3oool0003o0?ooo`000?l00P3oool01`000?l0oooo0?ooo`3o
ool0003o0?ooo`000?l00`3oool20000o`T0oooo00<0003o0?ooo`000?l02@3oool020000?l0oooo
0000o`000?l0oooo0000o`3oool0003o103oool01@000?l0oooo0000o`3oool0003o0080oooo0`00
0?l50?ooo`050000o`3oool0oooo0000o`3oool00`000?l01@3oool0003o0000o`000?l0oooo0080
003o103oool30000o`@0oooo0P000?l30?ooo`80003o0P3oool00`000?l0oooo0?ooo`070?ooo`09
0000o`3oool0003o0?ooo`000?l0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`000?l00P3o
ool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo00@0003o0?ooo`3oool0003o1`3oool00`00
0?l0oooo0000o`040?ooo`80003o2@3oool30000o`80oooo00<0003o0?ooo`000?l0103oool30000
o`H0oooo00@0003o0?ooo`3oool0003o0P3oool030000?l0oooo0000o`3oool0003o0?ooo`000?l0
oooo0000o`3oool0003o0?ooo`80003o0`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
003o0080oooo00<0003o0?ooo`000?l00P000?l0303oool0003o0000o`000?l0oooo0000o`3oool0
003o0?ooo`000?l0oooo0000o`<0oooo0P000?l50?ooo`030000o`3oool0oooo0080003o00@0oooo
0000o`3oool0oooo0P000?l@0?ooo`030000o`3oool0oooo0080oooo0P000?l00`3oool0003o0000
o`040?ooo`030000o`3oool0oooo00<0oooo0P000?l01@3oool0003o0000o`3oool0003o0080oooo
0`000?l40?ooo`80003o1@3oool20000o`80oooo00@0003o0?ooo`000?l0oooo0P000?l20?ooo`04
0000o`3oool0oooo0?ooo`80003o1@3oool00`000?l0oooo0000o`0Y0?ooo`030000o`3oool0003o
00<0003o00<0oooo0000o`3oool0303oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool20000o`80oooo0P000?l01@3oool0003o0?ooo`000?l0
oooo00<0003o0P3oool30000o`<0oooo00<0003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`0>
0?ooo`80003o00<0oooo0000o`3oool01`3oool20000o`030?ooo`000?l0003o00l0oooo00<00000
0?ooo`3oool0?@3oool004`0oooo0`00000O0?ooo`030000003oool0oooo04X0oooo00<0003o0?oo
o`3oool00P3oool01@000?l0oooo0000o`3oool0003o0080oooo00@0003o0?ooo`3oool0oooo0P00
0?l50?ooo`030000o`3oool0oooo00L0oooo0`000?l:0?ooo`070000o`3oool0003o0?ooo`000?l0
oooo0000o`080?ooo`030000o`3oool0oooo00<0003o103oool01P000?l0oooo0000o`3oool0003o
0?ooo`<0003o00<0oooo0000o`000?l00P3oool20000o`@0oooo0`000?l40?ooo`80003o103oool0
10000?l0oooo0?ooo`000?l90?ooo`030000o`3oool0003o0080003o00@0oooo0000o`3oool0003o
0P3oool01P000?l0oooo0?ooo`000?l0oooo0000o`80oooo0`000?l30?ooo`040000o`3oool0oooo
0000o`D0oooo00D0003o0?ooo`000?l0oooo0000o`050?ooo`030000o`3oool0oooo00P0oooo00L0
003o0?ooo`3oool0oooo0000o`3oool0003o00@0oooo0`000?l60?ooo`80003o00h0oooo0000o`3o
ool0oooo0000o`3oool0003o0?ooo`000?l0oooo0000o`3oool0003o0?ooo`@0003o0`3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`000?l00P000?l0103o
ool0003o0000o`3oool20000o`060?ooo`000?l0oooo0000o`3oool0003o0`3oool20000o`D0oooo
00<0003o0?ooo`000?l00P000?l00`3oool0003o0?ooo`020?ooo`030000o`3oool0oooo00h0oooo
00<0003o0?ooo`3oool00P3oool20000o`030?ooo`000?l0003o00@0oooo00d0003o0?ooo`3oool0
oooo0000o`3oool0003o0?ooo`000?l0oooo0000o`3oool0003o0080oooo0`000?l40?ooo`80003o
00<0oooo0000o`000?l00P3oool00`000?l0oooo0000o`020000o`80oooo00<0003o0?ooo`000?l0
0`3oool00`000?l0oooo0?ooo`020000o`D0oooo00<0003o0?ooo`000?l05P3oool00`000?l0oooo
0?ooo`0@0?ooo`030000o`3oool0003o00<0003o00<0oooo0000o`3oool0303oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo
0P000?l20?ooo`<0003o0`3oool30000o`@0oooo0P000?l40?ooo`030000o`3oool0oooo00h0oooo
0P000?l00`3oool0003o0?ooo`070?ooo`80003o00<0oooo0000o`3oool03`3oool00`000000oooo
0?ooo`0m0?ooo`00B@3oool3000000/0oooo100000040?ooo`@000002`3oool00`000000oooo0?oo
o`1:0?ooo`030000o`3oool0oooo0080oooo0P000?l30?ooo`030000o`3oool0003o00<0oooo0P00
0?l?0?ooo`<0003o2P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0203oool00`000?l0
oooo0?ooo`020000o`040?ooo`000?l0oooo0?ooo`80003o00D0oooo0000o`000?l0003o0?ooo`03
0000o`030?ooo`000?l0003o0080oooo0P000?l40?ooo`030000o`00o`000?l000@0oooo0P000?l4
0?ooo`040000o`3oool0oooo0000o`T0oooo00<0003o0?ooo`000?l00P000?l30?ooo`040000o`3o
ool0oooo0000o`80oooo0`000?l20?ooo`<0003o0`3oool010000?l0oooo0?ooo`000?l50?ooo`05
0000o`3oool0003o0?ooo`000?l01@3oool00`000?l0oooo0?ooo`080?ooo`070000o`3oool0oooo
0?ooo`000?l0oooo0000o`040?ooo`@0003o1@3oool20000o`090?ooo`000?l0oooo0?ooo`000?l0
oooo0000o`3oool0003o00H0oooo00@0003o0?ooo`000?l0003o0P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`000?l00P000?l0103oool0003o0000o`3o
ool20000o`030?ooo`000?l0003o0080oooo00@0003o0?ooo`3oool0oooo0P000?l40?ooo`80003o
00H0oooo0000o`000?l0003o0?ooo`000?l30?ooo`030000o`3oool0oooo00h0oooo00<0003o0?oo
o`3oool00P3oool20000o`030?ooo`000?l0003o00<0oooo0P000?l20?ooo`80003o00P0oooo0000
o`3oool0003o0?ooo`000?l0oooo0000o`80oooo0P000?l00`3oool0003o0?ooo`020?ooo`80003o
00<0oooo0000o`000?l00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0003o00<0oooo
00<0003o0?ooo`3oool00P000?l40?ooo`040000o`3oool0oooo0000oaH0oooo00<0003o0?ooo`3o
ool0403oool010000?l0oooo0000o`3oool20000o`030?ooo`000?l0oooo00`0oooo0P000?l40?oo
o`80003o2P3oool00`000?l0oooo0?ooo`020?ooo`80003o0P3oool00`000?l0oooo0000o`030?oo
o`<0003o103oool20000o`@0oooo00<0003o0?ooo`3oool04@3oool01@000?l0oooo0000o`3oool0
003o00@0oooo0P000?l00`3oool0003o0?ooo`0?0?ooo`030000003oool0oooo03d0oooo00160?oo
o`<000003@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0203oool4000004T0oooo00<0003o0?ooo`3oool00P3oool20000o`<0oooo00<0003o
0?ooo`000?l00`3oool20000o`l0oooo0P000?l;0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo
0000o`080?ooo`030000o`3oool0oooo0080003o00D0oooo0000o`3oool0oooo0000o`020?ooo`80
003o00<0oooo0000o`000?l00P000?l00`3oool0003o0000o`020?ooo`80003o0`3oool6003o00<0
oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l90?ooo`030000o`3oool0003o
0080003o0`3oool010000?l0oooo0?ooo`000?l30?ooo`80003o0P3oool00`000?l0oooo0000o`03
0?ooo`040000o`3oool0003o0000o`D0oooo00D0003o0?ooo`000?l0oooo0000o`0@0?ooo`040000
o`3oool0oooo0?ooo`<0003o1@3oool30000o`D0oooo10000?l20?ooo`040000o`3oool0003o0000
o`L0oooo00H0003o0?ooo`000?l0003o0?ooo`000?l50?ooo`80003o0`3oool00`000?l0oooo0000
o`020000o`040?ooo`000?l0003o0?ooo`D0003o0P3oool010000?l0oooo0000o`3oool20000o`@0
oooo0P000?l0103oool0003o0?ooo`000?lF0?ooo`030000o`3oool0oooo0080oooo0P000?l20?oo
o`040000o`3oool0oooo0?ooo`80003o0P3oool20000o`040?ooo`000?l0oooo0000o`<0oooo0P00
0?l01@3oool0003o0000o`3oool0003o0080oooo0P000?l0103oool0003o0000o`000?l20?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`000?l00`3oool20000o`030?ooo`000?l0003o00@0
oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0100oooo00@0003o0?ooo`000?l0oooo0P000?l00`3oool0003o0?ooo`0<0?ooo`80003o00@0oooo
0000o`3oool0oooo0P000?l:0?ooo`030000o`3oool0oooo0080oooo0P000?l20?ooo`030000o`3o
ool0003o00<0oooo0`000?l40?ooo`80003o103oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3o
ool0003o0080003o103oool20000o`030?ooo`000?l0oooo00l0oooo00<000000?ooo`3oool0?@3o
ool004<0oooo0`00000@0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool00P3o
ool20000o`<0oooo00<0003o0?ooo`000?l00`3oool20000o`l0oooo00<0003o0?ooo`3oool03P3o
ool00`000?l0oooo0000o`080?ooo`030000o`3oool0oooo0080003o00D0oooo0000o`3oool0oooo
0000o`020?ooo`80003o00<0oooo0000o`000?l00P000?l00`3oool0003o0000o`020?ooo`<0003o
0P3oool6003o00<0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00L0
oooo00<0003o0?ooo`3oool00`000?l30?ooo`040000o`3oool0oooo0000o`@0oooo00H0003o0?oo
o`3oool0003o0?ooo`000?l30?ooo`040000o`3oool0003o0000o`D0oooo0P000?l20?ooo`030000
o`3oool0oooo00h0oooo00<0003o0?ooo`3oool00P3oool20000o`L0oooo00L0003o0?ooo`3oool0
003o0?ooo`000?l0oooo00<0003o0P3oool010000?l0oooo0?ooo`000?l70?ooo`060000o`3oool0
003o0000o`3oool0003o1@3oool20000o`<0oooo0P000?l0103oool0003o0000o`3oool20000o`03
0?ooo`000?l0oooo00<0003o0P3oool010000?l0oooo0000o`3oool20000o`@0oooo00H0003o0?oo
o`000?l0003o0?ooo`000?lK0?ooo`80003o0P3oool00`000?l0oooo0?ooo`030000o`80oooo0`00
0?l60?ooo`80003o00<0oooo0000o`3oool00P3oool00`000?l0oooo0000o`020?ooo`<0003o0P3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0003o00<0oooo0`000?l00`3oool0003o0?oo
o`030?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0?0?ooo`050000o`3oool0oooo0000o`3oool00P000?l00`3oool0003o0?ooo`0<0?ooo`80
003o00@0oooo0000o`3oool0oooo0P000?l:0?ooo`030000o`3oool0oooo0080oooo0P000?l20?oo
o`030000o`3oool0003o00<0oooo0`000?l40?ooo`80003o603oool01@000?l0oooo0000o`3oool0
003o00@0oooo0P000?l00`3oool0003o0?ooo`0?0?ooo`030000003oool0oooo03d0oooo00120?oo
o`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool00P3oool20000o`<0oooo00<0003o
0?ooo`000?l00`3oool20000o`l0oooo00<0003o0?ooo`3oool03`3oool20000o`T0oooo00H0003o
0?ooo`000?l0003o0?ooo`000?l20?ooo`030000o`3oool0oooo0080003o00<0oooo0000o`000?l0
0P000?l00`3oool0003o0000o`020?ooo`<0003o00<0oooo003o0000o`001P00o`020?ooo`030000
o`3oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo0080
003o103oool010000?l0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo0080oooo00H0003o0?oo
o`3oool0oooo0000o`3oool20000o`@0oooo0`000?lI0?ooo`030000o`3oool0oooo00D0oooo00L0
003o0?ooo`3oool0003o0?ooo`000?l0oooo00<0003o0P3oool010000?l0oooo0?ooo`000?l90?oo
o`80003o00<0oooo0000o`3oool0103oool20000o`<0oooo0P000?l0103oool0003o0000o`3oool2
0000o`030?ooo`000?l0oooo00<0003o0P3oool010000?l0oooo0000o`3oool20000o`@0oooo00H0
003o0?ooo`000?l0003o0?ooo`000?lK0?ooo`80003o0P3oool00`000?l0oooo0?ooo`030000o`80
oooo0`000?l60?ooo`80003o00<0oooo0000o`3oool00P3oool00`000?l0oooo0000o`030?ooo`05
0000o`3oool0003o0?ooo`000?l01P3oool00`000?l0oooo0000o`030?ooo`<0003o0P3oool20000
o`80oooo00D0003o0?ooo`3oool0003o0?ooo`020000oa<0oooo0P000?l@0?ooo`040000o`3oool0
oooo0000o`80oooo00<0003o0?ooo`000?l03@3oool40000o`040?ooo`000?l0oooo0000o`l0oooo
0P000?l20?ooo`030000o`3oool0003o00<0oooo0`000?l40?ooo`80003o6@3oool20000o`030?oo
o`000?l0oooo0080oooo00@0003o0?ooo`000?l0003o4@3oool00`000000oooo0?ooo`0m0?ooo`00
@P3oool:000000l0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`D0
0000C@3oool20000o`<0oooo00<0003o0?ooo`000?l00`3oool20000o`l0oooo00<0003o0?ooo`3o
ool03`3oool20000o`T0oooo0P000?l01P3oool0003o0?ooo`000?l0oooo0000o`<0oooo0P000?l0
0`3oool0003o0?ooo`020000o`80oooo00@0003o0?ooo`3oool0oooo0P000?l00`3oool00?l0003o
0006003o0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0000o`020000o`030?ooo`00
0?l0003o00P0oooo0`000?l>0?ooo`050000o`3oool0003o0?ooo`000?l00`3oool30000ob40oooo
00L0003o0?ooo`3oool0003o0?ooo`000?l0oooo00<0003o0P3oool010000?l0oooo0?ooo`000?l:
0?ooo`030000o`3oool0003o00D0oooo0P000?l30?ooo`80003o00@0oooo0000o`3oool0oooo0P00
0?l30?ooo`<0003o0P3oool010000?l0oooo0000o`3oool20000o`070?ooo`000?l0oooo0?ooo`00
0?l0oooo0000o`0N0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool30000o`030?ooo`000?l0
oooo0080003o1P3oool20000o`030?ooo`000?l0oooo0080oooo00<0003o0?ooo`000?l00`3oool0
1@000?l0oooo0000o`3oool0003o00H0oooo00<0003o0?ooo`000?l00`3oool30000o`80oooo0P00
0?l20?ooo`080000o`3oool0oooo0000o`3oool0003o0?ooo`000?l30?ooo`030000o`3oool0oooo
00`0oooo0P000?l@0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`000?l03@3oool2
0000o`80oooo0P000?l00`3oool0003o0?ooo`0>0?ooo`80003o0P3oool00`000?l0oooo0000o`03
0?ooo`80003o1P3oool00`000?l0oooo0?ooo`0G0?ooo`040000o`3oool0oooo0000o`80oooo0P00
0?l00`3oool0003o0000o`0A0?ooo`030000003oool0oooo03d0oooo00130?ooo`8000004`3oool3
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo04l0oooo0P000?l30?ooo`030000o`3oool0003o00<0oooo0P000?lQ0?ooo`80003o2@3oool2
0000o`040?ooo`000?l0oooo0?ooo`80003o0`3oool20000o`030?ooo`000?l0oooo0080003o0P3o
ool010000?l0oooo0?ooo`3oool20000o`80oooo1P00o`0=0?ooo`030000o`3oool0003o0080003o
00<0oooo0000o`000?l0203oool30000o`h0oooo00D0003o0?ooo`000?l0oooo0000o`030?ooo`<0
003o8@3oool01`000?l0oooo0?ooo`000?l0oooo0000o`3oool00`000?l20?ooo`040000o`3oool0
oooo0000o`X0oooo00<0003o0?ooo`000?l01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0003o0080oooo0P000?l30?ooo`80003o0`3oool010000?l0oooo0000o`3oool20000o`070?oo
o`000?l0oooo0?ooo`000?l0oooo0000o`0N0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool0
1P000?l0oooo0000o`3oool0003o0?ooo`80003o1P3oool20000o`030?ooo`000?l0oooo0080oooo
0`000?l50?ooo`030000o`3oool0003o00P0oooo00<0003o0?ooo`3oool00P3oool20000o`80oooo
1@000?l20?ooo`050000o`3oool0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0<0?ooo`80
003o403oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0003o00d0oooo0P000?l20?oo
o`80003o00<0oooo0000o`3oool03P3oool20000o`@0oooo00D0003o0?ooo`3oool0oooo0000o`07
0?ooo`030000o`3oool0oooo01L0oooo00@0003o0?ooo`3oool0003o0P3oool20000o`80oooo00<0
003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0m0?ooo`00A@3oool2000001@0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04l0oooo0P00
0?l30?ooo`030000o`3oool0003o00<0oooo0P000?lQ0?ooo`030000o`3oool0oooo00P0oooo0P00
0?l0103oool0003o0?ooo`3oool20000o`<0oooo0P000?l00`3oool0003o0?ooo`020000o`H0oooo
0P000?l20?ooo`H00?l03@3oool00`000?l0oooo0000o`020000o`030?ooo`000?l0003o00P0oooo
0`000?l?0?ooo`040000o`3oool0oooo0000o`<0oooo0`000?lQ0?ooo`070000o`3oool0003o0000
o`3oool0003o0?ooo`020000o`<0oooo00<0003o0?ooo`3oool0303oool20000o`H0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0000o`020?ooo`80003o103oool00`000?l0oooo0?ooo`02
0?ooo`80003o00@0oooo0000o`000?l0oooo0P000?l0103oool0003o0?ooo`000?lN0?ooo`070000
o`3oool0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0003o0080oooo00<0003o0?oo
o`3oool0103oool20000o`030?ooo`000?l0oooo00<0oooo0P000?l50?ooo`80003o3`3oool00`00
0?l0oooo0?ooo`020000o`030?ooo`000?l0003o00<0oooo00@0003o0?ooo`3oool0003o0P3oool2
0000o`T0oooo00<0003o0?ooo`3oool00P3oool20000o`80oooo00<0003o0?ooo`3oool02`3oool0
10000?l0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0503o
ool20000o`@0oooo00D0003o0?ooo`3oool0oooo0000o`0Q0?ooo`040000o`3oool0oooo0?ooo`80
003o00D0oooo0000o`3oool0oooo0000o`0A0?ooo`030000003oool0oooo03d0oooo00170?ooo`<0
0000303oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0203oool4000004l0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o00@0oooo00<0
003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0003o00<0oooo00@0
003o0?ooo`3oool0oooo0P000?l30?ooo`030000o`3oool0oooo00D0oooo0P000?l20?ooo`040000
o`3oool00?l0003o00l0oooo00<0003o0?ooo`000?l00P000?l00`3oool0003o0?ooo`080?ooo`<0
003o4P3oool010000?l0oooo0?ooo`3oool20000ob80oooo00L0003o0?ooo`000?l0003o0?ooo`00
0?l0oooo0080003o0`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0000o`020?ooo`80003o103oool00`000?l0oooo0?oo
o`020?ooo`80003o00<0oooo0000o`3oool00`000?l0103oool0003o0?ooo`000?lN0?ooo`040000
o`3oool0oooo0?ooo`<0003o0P3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo00@0
oooo0`000?l50?ooo`80003o1@3oool20000o`l0oooo00@0003o0?ooo`3oool0003o0P3oool20000
o`<0oooo00@0003o0?ooo`3oool0oooo10000?l90?ooo`030000o`3oool0oooo0080oooo0P000?l2
0?ooo`030000o`3oool0oooo00/0oooo00@0003o0?ooo`3oool0003o103oool00`000?l0oooo0?oo
o`0:0?ooo`030000o`3oool0oooo01D0oooo0P000?l40?ooo`050000o`3oool0oooo0?ooo`000?l0
8@3oool010000?l0oooo0?ooo`3oool20000o`@0oooo00<0003o0?ooo`3oool03`3oool00`000000
oooo0?ooo`0m0?ooo`00BP3oool2000000X0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0D03oool01`000?l0
oooo0?ooo`3oool0003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool01`3oool20000o`<0oooo00<0003o0?ooo`3oool01@3oool0
1@000?l0oooo0000o`3oool0003o01<0oooo00H0003o0?ooo`000?l0003o0?ooo`000?l90?ooo`<0
003o4P3oool01P000?l0oooo0000o`000?l0oooo0000ob80oooo00L0003o0?ooo`000?l0003o0?oo
o`000?l0oooo0080003o0`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
0P000?l00`3oool0003o0?ooo`030000o`040?ooo`000?l0oooo0000oah0oooo00<0003o0?ooo`3o
ool00P3oool20000o`80oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`050?ooo`80
003o1@3oool00`000?l0oooo0?ooo`040?ooo`80003o3`3oool010000?l0oooo0?ooo`000?l20?oo
o`80003o1`3oool20000o`030?ooo`000?l0oooo00P0oooo00<0003o0?ooo`3oool00P3oool20000
o`80oooo00<0003o0?ooo`3oool02`3oool010000?l0oooo0?ooo`000?l40?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0O0?ooo`040000o`3oool0
oooo0?ooo`80003o103oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo03d0oooo0017
0?ooo`<000003@3oool4000000@0oooo1000000;0?ooo`030000003oool0oooo0500oooo00L0003o
0?ooo`3oool0oooo0000o`3oool0003o00@0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0003o01<0oooo00H0003o0?ooo`000?l0003o0?ooo`000?l90?oo
o`80003o4`3oool01P000?l0oooo0000o`000?l0oooo0000ob80oooo00L0003o0?ooo`000?l0003o
0?ooo`000?l0oooo0080003o0`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`80003o00<0oooo0000o`3o
ool010000?lQ0?ooo`030000o`3oool0oooo0080oooo0P000?l20?ooo`030000o`3oool0003o0080
oooo00<0003o0?ooo`3oool01@3oool20000o``0oooo0P000?l?0?ooo`040000o`3oool0oooo0000
o`80oooo0P000?l70?ooo`80003o00<0oooo0000o`3oool0203oool00`000?l0oooo0?ooo`020?oo
o`80003o0P3oool00`000?l0oooo0?ooo`0;0?ooo`040000o`3oool0oooo0000o`@0oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0000o`0Q0?ooo`030000o`3oool0oooo02<0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo03d0oooo00150?oo
o`8000009`3oool00`000000oooo0?ooo`1E0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool07`3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0000o`0C0?ooo`030000o`3oool0003o0080003o2P3oool00`00
0?l0oooo0?ooo`0B0?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool0803oool01`00
0?l0oooo0000o`000?l0oooo0000o`3oool00P000?l30?ooo`030000o`3oool0oooo01T0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`80003o00<0oooo0000o`3oool01000
0?lQ0?ooo`030000o`3oool0oooo0080oooo0P000?l20?ooo`030000o`3oool0003o00/0oooo00<0
003o0?ooo`3oool02P3oool20000oa80oooo00<0003o0?ooo`3oool00P000?l70?ooo`80003o00<0
oooo0000o`3oool0203oool00`000?l0oooo0?ooo`020?ooo`80003o0P3oool00`000?l0oooo0?oo
o`0;0?ooo`040000o`3oool0oooo0000o`@0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0000o`0Q0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo
0?ooo`0m0?ooo`00@`3oool2000002T0oooo1000001D0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0000o`0G0?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`3oool04P3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo0200oooo00H0
003o0?ooo`000?l0003o0?ooo`000?l20?ooo`050000o`3oool0oooo0?ooo`000?l06`3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo0P000?l00`3oool0003o0?ooo`040000
obH0oooo0P000?l20?ooo`030000o`3oool0003o00/0oooo00<0003o0?ooo`3oool02P3oool20000
oaH0oooo00<0003o0?ooo`3oool01@3oool20000o`030?ooo`000?l0oooo00P0oooo00<0003o0?oo
o`3oool00P3oool20000o`80oooo00<0003o0?ooo`3oool02`3oool010000?l0oooo0?ooo`000?l4
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`000?l08@3oool00`000?l0oooo0?ooo`0S
0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0?@3oool00480oooo2P00000R0?oo
o`030000003oool0oooo05D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0O0?oo
o`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0000o`0G0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0000o`020?oo
o`030000o`3oool0oooo0200oooo00H0003o0?ooo`000?l0003o0?ooo`000?l20?ooo`050000o`3o
ool0oooo0?ooo`000?l06`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo
0P000?l01@3oool0003o0?ooo`000?l0oooo0080003o9P3oool01`000?l0oooo0?ooo`3oool0003o
0?ooo`000?l02`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo01@0oooo00<0003o
0?ooo`3oool01@3oool20000o`030?ooo`000?l0oooo00P0oooo00<0003o0?ooo`3oool00P3oool2
0000o`030?ooo`000?l0oooo00<0003o2P3oool010000?l0oooo0?ooo`000?l40?ooo`050000o`3o
ool0oooo0?ooo`000?l01P3oool00`000?l0oooo0000o`0Q0?ooo`030000o`3oool0oooo03/0oooo
00<000000?ooo`3oool0?@3oool006h0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0<0?ooo`030000o`3oool0003o01L0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`0B0?ooo`030000o`3oool0003o02D0oooo00<0003o0?ooo`000?l00P000?l30?ooo`050000o`3o
ool0oooo0?ooo`000?l08@3oool00`000?l0oooo0?ooo`090?ooo`80003o00<0oooo0000o`3oool0
0P000?lV0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`0;0?ooo`030000o`3oool0oooo
00/0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`050?ooo`80003o00<0oooo0000
o`3oool0203oool20000o`<0oooo0P000?l00`3oool0003o0?ooo`030000o`X0oooo00@0003o0?oo
o`3oool0003o103oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`000?l0G`3o
ool00`000000oooo0?ooo`0m0?ooo`00KP3oool4000005@0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0303oool0
0`000?l0oooo0000o`0G0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool04P3oool0
0`000?l0oooo0000o`0U0?ooo`030000o`3oool0003o0080003o0`3oool01@000?l0oooo0?ooo`3o
ool0003o0240oooo00<0003o0?ooo`3oool02@3oool20000o`030?ooo`000?l0oooo0080003o9P3o
ool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l02`3oool00`000?l0oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0000o`090?ooo`80
003o0P3oool02@000?l0oooo0000o`3oool0003o0?ooo`000?l0oooo0000o`090?ooo`80003o0P3o
ool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0003o0000o`H0oooo0`000?mO0?ooo`030000
003oool0oooo03d0oooo00120?ooo`800000:P3oool00`000000oooo0?ooo`1E0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0R0?ooo`030000o`3o
ool0003o01L0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3o
ool0003o02D0oooo00D0003o0?ooo`000?l0oooo0000o`030?ooo`050000o`3oool0oooo0?ooo`00
0?l08@3oool00`000?l0oooo0?ooo`090?ooo`80003o00<0oooo0000o`3oool00P000?lZ0?ooo`03
0000o`3oool0003o00/0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`000?l02@3oool20000o`80oooo00T0003o0?ooo`00
0?l0oooo0000o`3oool0003o0?ooo`000?l02@3oool20000o`P0oooo00@0003o0?ooo`000?l0003o
1P3oool30000oel0oooo00<000000?ooo`3oool0?@3oool004@0oooo0`00000W0?ooo`030000003o
ool0oooo05D0oooo00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`0R0?ooo`030000o`3o
ool0003o01L0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3o
ool0003o02D0oooo00D0003o0?ooo`000?l0oooo0000o`030?ooo`050000o`3oool0oooo0?ooo`00
0?l08@3oool00`000?l0oooo0?ooo`090?ooo`80003o00<0oooo0000o`3oool00P000?lZ0?ooo`03
0000o`3oool0003o00/0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`000?l02@3oool50000o`080?ooo`000?l0oooo0000
o`3oool0003o0?ooo`000?l90?ooo`80003o203oool010000?l0oooo0000o`000?l60?ooo`<0003o
G`3oool00`000000oooo0?ooo`0m0?ooo`00A`3oool300000100oooo00<000000?ooo`3oool00P3o
ool4000000/0oooo1000001D0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool08`3o
ool20000ocL0oooo00<0003o0?ooo`000?l09@3oool01@000?l0oooo0000o`3oool0003o00<0oooo
00<0003o0?ooo`3oool08`3oool00`000?l0oooo0?ooo`090?ooo`80003o00@0oooo0000o`3oool0
003o:`3oool00`000?l0oooo0000o`0;0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`00
0?l02@3oool30000o`<0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`070?ooo`80
003o203oool010000?l0oooo0000o`000?l60?ooo`<0003oG`3oool00`000000oooo0?ooo`0m0?oo
o`00BP3oool2000000h0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0O@3oool00`000?l0oooo0?ooo`0S0?ooo`80003o=`3oool00`00
0?l0oooo0000o`0U0?ooo`050000o`3oool0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0S
0?ooo`030000o`3oool0oooo00T0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l[0?ooo`030000
o`3oool0003o00/0oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0000o`090?ooo`80003o
103oool00`000?l0oooo0000o`030?ooo`030000o`3oool0oooo00L0oooo0P000?l80?ooo`80003o
00<0oooo0000o`3oool01@3oool30000oel0oooo00<000000?ooo`3oool0?@3oool004L0oooo0`00
000;0?ooo`L000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0O@3oool00`000?l0oooo0?ooo`0S0?ooo`80003o=`3oool00`000?l0oooo0000
o`0U0?ooo`050000o`3oool0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0_0?ooo`060000
o`3oool0oooo0000o`3oool0003o:`3oool00`000?l0oooo0000o`0k0?ooo`030000o`3oool0oooo
00<0oooo00@0003o0?ooo`000?l0oooo0P000?l40?ooo`030000o`3oool0003o00<0oooo00<0003o
0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00X0oooo00<0003o0?ooo`000?l01@3o
ool010000?l0oooo0?ooo`000?mO0?ooo`030000003oool0oooo03d0oooo00130?ooo`@000003P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0:<0oooo0P000?lg0?ooo`030000o`3oool0003o02H0oooo
0P000?l00`3oool0003o0?ooo`020?ooo`030000o`3oool0oooo02l0oooo00H0003o0?ooo`3oool0
003o0?ooo`000?l[0?ooo`030000o`3oool0003o03/0oooo00<0003o0?ooo`3oool00P3oool20000
o`040?ooo`000?l0oooo0000o`D0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`03
0?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool00`000?l0oooo0000o`050?ooo`030000o`3o
ool0oooo0600oooo00<000000?ooo`3oool0?@3oool00480oooo00<000000?ooo`3oool04@3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`D00000X@3oool00`000?l0oooo0?ooo`0g0?ooo`80003o9P3oool20000o`D0oooo00<0
003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02T0oooo00<0
003o0?ooo`000?l0>`3oool00`000?l0oooo0?ooo`020?ooo`@0003o00<0oooo0000o`3oool01@3o
ool20000o`<0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00`0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo03d0oooo
00130?ooo`@00000403oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2S0?ooo`030000o`3oool0oooo03L0oooo
00<0003o0?ooo`3oool09@3oool20000ocL0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0Y0?ooo`030000o`3oool0003o03/0oooo00<0003o0?ooo`3oool00P3oool40000o`030?oo
o`000?l0oooo00D0oooo0P000?l30?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0
oooo0000o`0<0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0H03oool00`000000
oooo0?ooo`0m0?ooo`00A`3oool3000000d0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0X`3oool00`000?l0
oooo0?ooo`0g0?ooo`030000o`3oool0oooo02D0oooo0P000?lg0?ooo`030000o`3oool0oooo02h0
oooo00<0003o0?ooo`000?l0>`3oool01P000?l0oooo0?ooo`3oool0003o0?ooo`@0003o1`3oool2
0000o`<0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00`0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo03d0oooo001:
0?ooo`800000303oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0203oool400000=`0oooo00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`1W
0?ooo`030000o`3oool0003o03/0oooo00P0003o0?ooo`3oool0oooo0000o`3oool0003o0?ooo`80
003o1`3oool20000o`<0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o
00`0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo
03d0oooo00170?ooo`<000003`3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0=d0oooo00<0003o0?ooo`3oool09@3oool00`000?l0
oooo0?ooo`1W0?ooo`030000o`3oool0003o03/0oooo00P0003o0?ooo`3oool0oooo0000o`3oool0
003o0?ooo`80003o1`3oool20000o`<0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?oo
o`3oool0003o00`0oooo00<0003o0?ooo`3oool00P3oool20000of80oooo00<000000?ooo`3oool0
?@3oool004@0oooo0`00000C0?ooo`030000003oool0oooo0080oooo1000000;0?ooo`030000003o
ool0oooo0=d0oooo00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`1W0?ooo`030000o`3o
ool0003o03/0oooo00D0003o0?ooo`000?l0oooo0000o`030?ooo`80003o1`3oool20000o`<0oooo
00<0003o0?ooo`3oool00P3oool20000o`<0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`020?ooo`80003oHP3oool00`000000oooo0?ooo`0m0?ooo`00@P3oool2000002X0oooo1000
003L0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0I`3oool00`000?l0oooo0000
o`0k0?ooo`050000o`3oool0003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool20000o`<0oooo00<0003o0?ooo`3oool0
2P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0HP3oool00`000000oooo0?ooo`0m0?oo
o`00KP3oool00`000000oooo0?ooo`3M0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3o
ool0I`3oool00`000?l0oooo0000o`0k0?ooo`050000o`3oool0003o0?ooo`000?l0103oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool20000
o`<0oooo00<0003o0?ooo`3oool02P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0HP3o
ool00`000000oooo0?ooo`0m0?ooo`00@P3oool:00000280oooo00<000000?ooo`3oool0g@3oool0
0`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo06L0oooo00<0003o0?ooo`000?l0?03oool2
0000o`030?ooo`000?l0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo0P000?l30?ooo`030000o`3oool0oooo00X0oooo00D0003o
0?ooo`3oool0oooo0000o`1T0?ooo`030000003oool0oooo03d0oooo00150?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0g@3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0
oooo06P0oooo0P000?ll0?ooo`80003o00<0oooo0000o`3oool00`3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool20000o`<0oooo00<0003o
0?ooo`3oool02P3oool01@000?l0oooo0?ooo`3oool0003o06@0oooo00<000000?ooo`3oool0?@3o
ool004@0oooo00<000000?ooo`3oool09`3oool400000=`0oooo00<0003o0?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`1X0?ooo`80003o?03oool20000o`030?ooo`000?l0oooo00<0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo0P000?l3
0?ooo`030000o`3oool0oooo00X0oooo00D0003o0?ooo`3oool0oooo0000o`1T0?ooo`030000003o
ool0oooo03d0oooo00140?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0g@3oool0
0`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo06P0oooo0P000?ll0?ooo`80003o00<0oooo
0000o`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool20000o`<0oooo00<0003o0?ooo`3oool02P3oool01@000?l0oooo0?ooo`3o
ool0003o06@0oooo00<000000?ooo`3oool0?@3oool004@0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`3M0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0J03oool2
0000oc`0oooo0`000?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`80003o0`3oool00`000?l0oooo0?ooo`0:0?ooo`050000o`3oool0
oooo0?ooo`000?l0I03oool00`000000oooo0?ooo`0m0?ooo`00A@3oool7000000/0oooo10000004
0?ooo`@000002`3oool400000=`0oooo00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`1X
0?ooo`030000o`3oool0oooo03/0oooo0`000?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`80003o00@0oooo0000o`3oool0003o303o
ool01@000?l0oooo0?ooo`3oool0003o06@0oooo00<000000?ooo`3oool0?@3oool005H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`3M0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0
J03oool00`000?l0oooo0?ooo`0k0?ooo`<0003o3@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo0P000?l0103oool0003o0?ooo`000?l<0?ooo`050000o`3oool0oooo0?oo
o`000?l0I03oool00`000000oooo0?ooo`0m0?ooo`00EP3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oo
o`H0oooo00<0003o0?ooo`3oool0J03oool00`000?l0oooo0?ooo`0k0?ooo`<0003o4P3oool00`00
0?l0oooo0?ooo`020?ooo`80003o00@0oooo0000o`3oool0003o303oool01@000?l0oooo0?ooo`3o
ool0003o06@0oooo00<000000?ooo`3oool0?@3oool005/0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`080?ooo`D00000o`3oool40?ooo`030000o`3oool0oooo06P0oooo00<0
003o0?ooo`3oool0>`3oool30000oa80oooo00<0003o0?ooo`3oool00P3oool20000o`040?ooo`00
0?l0oooo0000o``0oooo00D0003o0?ooo`3oool0oooo0000o`1T0?ooo`030000003oool0oooo03d0
oooo001K0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`3o0?ooo`H0oooo00<0003o0?ooo`3oool0J03oool00`000?l0oooo0?ooo`0k0?ooo`<0
003o4P3oool00`000?l0oooo0?ooo`020?ooo`80003o00@0oooo0000o`3oool0003o303oool01@00
0?l0oooo0?ooo`3oool0003o06@0oooo00<000000?ooo`3oool0?@3oool005H0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0o`3oooma0?ooo`030000o`3oool0oooo03/0oooo0`000?lB0?ooo`030000o`3oool0
oooo0080oooo0P000?l0103oool0003o0?ooo`000?l<0?ooo`050000o`3oool0oooo0?ooo`000?l0
I03oool00`000000oooo0?ooo`0m0?ooo`00EP3oool5000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooL@3oool00`000?l0oooo0?oo
o`0k0?ooo`<0003o4P3oool00`000?l0oooo0?ooo`020?ooo`80003o00@0oooo0000o`3oool0003o
303oool01@000?l0oooo0?ooo`3oool0003o06@0oooo00<000000?ooo`3oool0?@3oool005H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
1000003o0?ooog00oooo00<0003o0?ooo`3oool0>`3oool20000oa<0oooo00<0003o0?ooo`3oool0
0P3oool20000o`040?ooo`000?l0oooo0000o``0oooo00D0003o0?ooo`3oool0oooo0000o`1T0?oo
o`030000003oool0oooo03d0oooo001G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooL@3oool00`000?l0
oooo0?ooo`0k0?ooo`80003o4`3oool00`000?l0oooo0?ooo`020?ooo`80003o00@0oooo0000o`3o
ool0003o303oool01@000?l0oooo0?ooo`3oool0003o06@0oooo00<000000?ooo`3oool0?@3oool0
05L0oooo1@0000030?ooo`@000002`3oool00`000000oooo0?ooo`3o0?ooog40oooo00<0003o0?oo
o`3oool0>`3oool20000oa<0oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`000?l0003o
00d0oooo00D0003o0?ooo`3oool0oooo0000o`1T0?ooo`030000003oool0oooo03d0oooo001^0?oo
o`@00000o`3ooom`0?ooo`030000o`3oool0oooo03/0oooo0P000?lC0?ooo`030000o`3oool0oooo
0080oooo0P000?l00`3oool0003o0000o`0=0?ooo`050000o`3oool0oooo0?ooo`000?l0I03oool0
0`000000oooo0?ooo`0m0?ooo`00KP3oool00`000000oooo0?ooo`3o0?ooog40oooo00<0003o0?oo
o`3oool0>`3oool20000oa<0oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`000?l0003o
00d0oooo00D0003o0?ooo`3oool0oooo0000o`1T0?ooo`030000003oool0oooo03d0oooo001^0?oo
o`030000003oool0oooo0?l0ooooL@3oool00`000?l0oooo0?ooo`0k0?ooo`80003o4`3oool00`00
0?l0oooo0?ooo`020?ooo`80003o00<0oooo0000o`000?l03@3oool01@000?l0oooo0?ooo`3oool0
003o06@0oooo00<000000?ooo`3oool0?@3oool006h0oooo1000003o0?ooog00oooo00<0003o0?oo
o`3oool0>`3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo0080oooo0P000?l00`3o
ool0003o0000o`0=0?ooo`050000o`3oool0oooo0?ooo`000?l0I03oool00`000000oooo0?ooo`0m
0?ooo`00KP3oool00`000000oooo0?ooo`3o0?ooog40oooo00<0003o0?ooo`3oool0>`3oool00`00
0?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo0080oooo0P000?l00`3oool0003o0000o`0=0?oo
o`050000o`3oool0oooo0?ooo`000?l0I03oool00`000000oooo0?ooo`0m0?ooo`00KP3oool00`00
0000oooo0?ooo`3o0?ooog40oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0B0?oo
o`030000o`3oool0oooo0080oooo0P000?l00`3oool0003o0000o`0=0?ooo`050000o`3oool0oooo
0?ooo`000?l0I03oool00`000000oooo0?ooo`0m0?ooo`00E`3oool4000000@0oooo1000000;0?oo
o`030000003oool0oooo0?l0ooooL@3oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo
0180oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`000?l0003o00d0oooo00@0003o0?oo
o`3oool0003oI@3oool00`000000oooo0?ooo`0m0?ooo`00EP3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool400000?l0ooooL03oool0
0`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo0180oooo0P000?l30?ooo`80003o00<0oooo
0000o`000?l03@3oool010000?l0oooo0?ooo`000?mU0?ooo`030000003oool0oooo03d0oooo001F
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0?l0ooooL@3oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3o
ool0oooo0180oooo0P000?l20?ooo`040000o`3oool0003o0?ooo`80003o3@3oool010000?l0oooo
0?ooo`000?mU0?ooo`030000003oool0oooo03d0oooo001F0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0
ooooL@3oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo0180oooo0P000?l20?ooo`04
0000o`3oool0003o0?ooo`80003o3@3oool010000?l0oooo0?ooo`000?mU0?ooo`030000003oool0
oooo03d0oooo001F0?ooo`8000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00P0oooo1@00003o0?ooofl0oooo00<0003o0?ooo`3oool0D03oool20000o`80oooo00@0003o
0?ooo`000?l0oooo0P000?l=0?ooo`040000o`3oool0oooo0000ofD0oooo00<000000?ooo`3oool0
?@3oool005H0oooo00<000000?ooo`0000000P0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooog40oooo00<0003o0?ooo`3oool0D03o
ool20000o`80oooo00@0003o0?ooo`000?l0oooo0P000?l=0?ooo`040000o`3oool0oooo0000ofD0
oooo00<000000?ooo`3oool0?@3oool005H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3oooma0?ooo`030000
o`3oool0oooo0500oooo0P000?l20?ooo`040000o`3oool0003o0?ooo`80003o3@3oool010000?l0
oooo0?ooo`000?mU0?ooo`030000003oool0oooo03d0oooo001F0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`@00000o`3ooom`0?ooo`03
0000o`3oool0oooo0500oooo0P000?l20?ooo`040000o`3oool0003o0?ooo`80003o3@3oool01000
0?l0oooo0?ooo`000?mU0?ooo`030000003oool0oooo03d0oooo001G0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0o`3oooma0?ooo`030000o`3oool0oooo0500oooo0P000?l20?ooo`040000o`3oool0
003o0?ooo`80003o3@3oool010000?l0oooo0?ooo`000?mU0?ooo`030000003oool0oooo03d0oooo
001H0?ooo`<00000103oool4000000/0oooo00<000000?ooo`3oool0o`3oooma0?ooo`030000o`3o
ool0oooo0500oooo0P000?l20?ooo`040000o`3oool0003o0?ooo`80003o3@3oool010000?l0oooo
0?ooo`000?mU0?ooo`030000003oool0oooo03d0oooo001^0?ooo`030000003oool0oooo0?l0oooo
L@3oool00`000?l0oooo0?ooo`1@0?ooo`80003o0P3oool010000?l0oooo0000o`3oool20000o`d0
oooo00@0003o0?ooo`3oool0003oI@3oool00`000000oooo0?ooo`0m0?ooo`00KP3oool400000?l0
ooooL03oool00`000?l0oooo0?ooo`1@0?ooo`80003o0P3oool010000?l0oooo0000o`3oool20000
o`d0oooo00@0003o0?ooo`3oool0003oI@3oool00`000000oooo0?ooo`0m0?ooo`00KP3oool00`00
0000oooo0?ooo`3o0?oool@0oooo0`000?l01@3oool0003o0?ooo`000?l0oooo0080003o3@3oool0
10000?l0oooo0?ooo`000?mU0?ooo`030000003oool0oooo03d0oooo001^0?ooo`030000003oool0
oooo0?l0ooooa03oool30000o`050?ooo`000?l0oooo0000o`3oool00P000?l>0?ooo`80003oIP3o
ool00`000000oooo0?ooo`0m0?ooo`00KP3oool400000?l0oooo``3oool30000o`050?ooo`000?l0
oooo0000o`3oool00P000?l>0?ooo`80003oIP3oool00`000000oooo0?ooo`0m0?ooo`00KP3oool0
0`000000oooo0?ooo`3o0?oool@0oooo0`000?l01@3oool0003o0?ooo`000?l0oooo0080003o3P3o
ool20000ofH0oooo00<000000?ooo`3oool0?@3oool006h0oooo00<000000?ooo`3oool0o`3oooo4
0?ooo`<0003o00D0oooo0000o`3oool0003o0?ooo`020000o`h0oooo0P000?mV0?ooo`030000003o
ool0oooo03d0oooo001H0?ooo`030000003oool0oooo00@0oooo1000000;0?ooo`@00000o`3oooo3
0?ooo`<0003o00D0oooo0000o`3oool0003o0?ooo`020000o`h0oooo0P000?mV0?ooo`030000003o
ool0oooo03d0oooo001H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooa03oool30000o`050?ooo`000?l0
oooo0000o`3oool00P000?l>0?ooo`80003oIP3oool00`000000oooo0?ooo`0m0?ooo`00F03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`3o0?oool@0oooo0`000?l01@3oool0003o0?ooo`000?l0oooo0080003o3P3o
ool20000ofH0oooo00<000000?ooo`3oool0?@3oool005T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3oooo4
0?ooo`<0003o00D0oooo0000o`3oool0003o0?ooo`020000o`h0oooo0P000?mV0?ooo`030000003o
ool0oooo03d0oooo001I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooool00000a`0000030000o`05000000000?l000000000o`0000000P00
0?l>00000080003oI`00000o0?ooo`00F@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0o`3ooooo0?oooi00oooo001J0?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`3o0?ooool0ooooT03oool005X0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0?l0ooooo`3ooon@0?ooo`00F`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0ooooo`3ooon@0?ooo`00EP3oool60000
00<0oooo1000003o0?ooool0ooooT`3oool00?l0ooooo`3oooof0?ooo`00o`3ooooo0?ooooH0oooo
003o0?ooool0oooomP3oool00001\
\>"],
  ImageRangeCache->{{{96, 851.25}, {592.688, 442.438}} -> {-272.033, 251.127, \
1.23273, 0.601624}}]
}, Open  ]],

Cell["\<\
We calculate the relative mean price decrease due to a holiday.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(prev\  = 
      Mean[\(peak1\[LeftDoubleBracket]hol - 1\[RightDoubleBracket] - peak1\
\[LeftDoubleBracket]hol\[RightDoubleBracket]\)\/peak1\[LeftDoubleBracket]hol \
- 1\[RightDoubleBracket]]\)], "Input"],

Cell[BoxData[
    \(0.38886843652849873`\)], "Output"]
}, Open  ]],

Cell["and the relative price increase after a holiday.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(next\  = 
      Mean[\(peak1\[LeftDoubleBracket]hol + 1\[RightDoubleBracket] - peak1\
\[LeftDoubleBracket]hol\[RightDoubleBracket]\)\/peak1\[LeftDoubleBracket]hol \
+ 1\[RightDoubleBracket]]\)], "Input"],

Cell[BoxData[
    \(0.2667105172557222`\)], "Output"]
}, Open  ]],

Cell["\<\
The simplest approach controlling for holidays is to get rid of them. \
Therefore we throw them away\
\>", "Text"],

Cell[BoxData[{
    \(\(peak2\  = Delete[peak1, Map[List, hol]];\)\), "\[IndentingNewLine]", 
    \(\(dates2\  = \ Delete[dates, Map[List, hol]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Estimating seasonal effects", "Subsection"],

Cell["\<\
In the autocorrelation analysis were seasonal effects visible at least when \
looking on the Sunday's prices. Other studies of electricity prices from \
other countries also regulary find seasonal pattern. To estimate seasonal \
patterns the dates are expressed as fractional years.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(t\  = YearsBetween[{2000, 1, 1}, dates2];\)\), "\n", 
    \(t\  // \ Shallow\)}], "Input"],

Cell[BoxData[
    \({0.4575342465753425`, 0.4602739726027397`, 0.46301369863013697`, 
      0.4657534246575343`, 0.4684931506849315`, 0.4712328767123288`, 
      0.4767123287671233`, 0.4794520547945206`, 0.4821917808219178`, 
      0.4849315068493151`, \[LeftSkeleton]654\[RightSkeleton]}\)], "Output"]
}, Open  ]],

Cell["and the prices are calculated relative to the mean.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m\  = \ Mean[peak2];\)\), "\[IndentingNewLine]", 
    \(\(data\  = \ 
        MapThread[{#1, #2 - m} &, {t, peak2}];\)\), "\[IndentingNewLine]", 
    \(data\  // \ Shallow\)}], "Input"],

Cell[BoxData[
    \({{0.4575342465753425`, \(-6.467354345755037`\)}, {0.4602739726027397`, \
\(-7.487754890966901`\)}, {0.46301369863013697`, \(-3.869315143299165`\)}, \
{0.4657534246575343`, \(-12.497343839277125`\)}, {0.4684931506849315`, \
\(-10.574400738307691`\)}, {0.4712328767123288`, \(-9.662393023424816`\)}, \
{0.4767123287671233`, \(-10.009021012421709`\)}, {0.4794520547945206`, \
\(-8.7227548909669`\)}, {0.4821917808219178`, \(-4.321815143299165`\)}, \
{0.4849315068493151`, \(-11.901510505943794`\)}, \[LeftSkeleton]654\
\[RightSkeleton]}\)], "Output"]
}, Open  ]],

Cell["\<\
For estimating a functionf for the seasonal effects a non-linear curve is \
fitted on this data. The template for the function was taken from Pilipovic \
(1997).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(yfkt[y_]\  = 
      NonlinearFit[data\ , \ a\ y + b\ Cos[c\ \[Pi]\ y], 
        y, {a, b, c}]\)], "Input"],

Cell[BoxData[
    \(0.23706683036304113`\ y + 
      5.527979368940492`\ Cos[3.362241764261944`\ y]\)], "Output"]
}, Open  ]],

Cell["\<\
To compare visually the estimated curve with the data the following graph is \
constructed \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ticks2\  = \ 
        Map[{#, StringForm["\<`3`/`2`/`1`\>", 
                Sequence @@ dates2[\([#]\)]]} &, 
          Range[1, Length[dates2], 75]];\)\), "\[IndentingNewLine]", 
    \(\(DisplayTogether[
        ListPlot[peak2, AspectRatio \[Rule] \ 0.2, Frame \[Rule] True, 
          FrameTicks \[Rule] {ticks2, Automatic, None, None}, 
          PlotStyle \[Rule] Red, FrameLabel \[Rule] \ "\<\:f280/MWh\>", 
          Axes \[Rule] None, 
          PlotRange \[Rule] Automatic], \[IndentingNewLine]ListPlot[
          m\  + Map[yfkt, t], 
          PlotStyle \[Rule] {Thickness[0.005], Blue}]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0238095 0.00143431 -0.0432852 0.00497643 [
[.02524 -0.0125 -33.7813 -17.75 ]
[.02524 -0.0125 33.7813 0 ]
[.13282 -0.0125 -33.7813 -17.75 ]
[.13282 -0.0125 33.7813 0 ]
[.24039 -0.0125 -37.6875 -17.75 ]
[.24039 -0.0125 37.6875 0 ]
[.34796 -0.0125 -29.875 -17.75 ]
[.34796 -0.0125 29.875 0 ]
[.45554 -0.0125 -33.7813 -17.75 ]
[.45554 -0.0125 33.7813 0 ]
[.56311 -0.0125 -29.875 -17.75 ]
[.56311 -0.0125 29.875 0 ]
[.67068 -0.0125 -33.7813 -17.75 ]
[.67068 -0.0125 33.7813 0 ]
[.77826 -0.0125 -33.7813 -17.75 ]
[.77826 -0.0125 33.7813 0 ]
[.88583 -0.0125 -33.7813 -17.75 ]
[.88583 -0.0125 33.7813 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00648 -19.625 -8.875 ]
[-0.0125 .00648 0 8.875 ]
[-0.0125 .05624 -19.625 -8.875 ]
[-0.0125 .05624 0 8.875 ]
[-0.0125 .10601 -19.625 -8.875 ]
[-0.0125 .10601 0 8.875 ]
[-0.0125 .15577 -19.625 -8.875 ]
[-0.0125 .15577 0 8.875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .1 -37.375 -24.8125 ]
[-0.01875 .1 -19.625 24.8125 ]
[ 0 .2 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02524 0 m
.02524 .00625 L
s
gsave
.02524 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.13282 0 m
.13282 .00625 L
s
gsave
.13282 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.24039 0 m
.24039 .00625 L
s
gsave
.24039 -0.0125 -98.6875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.688 17.625 moveto
(\\220) show
103.125 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
134.375 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34796 0 m
.34796 .00625 L
s
gsave
.34796 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.45554 0 m
.45554 .00625 L
s
gsave
.45554 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.56311 0 m
.56311 .00625 L
s
gsave
.56311 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.67068 0 m
.67068 .00625 L
s
gsave
.67068 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.77826 0 m
.77826 .00625 L
s
gsave
.77826 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.88583 0 m
.88583 .00625 L
s
gsave
.88583 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2002) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .00648 m
.00625 .00648 L
s
gsave
-0.0125 .00648 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .05624 m
.00625 .05624 L
s
gsave
-0.0125 .05624 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .10601 m
.00625 .10601 L
s
gsave
-0.0125 .10601 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .15577 m
.00625 .15577 L
s
gsave
-0.0125 .15577 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01643 m
.00375 .01643 L
s
0 .02638 m
.00375 .02638 L
s
0 .03634 m
.00375 .03634 L
s
0 .04629 m
.00375 .04629 L
s
0 .0662 m
.00375 .0662 L
s
0 .07615 m
.00375 .07615 L
s
0 .0861 m
.00375 .0861 L
s
0 .09605 m
.00375 .09605 L
s
0 .11596 m
.00375 .11596 L
s
0 .12591 m
.00375 .12591 L
s
0 .13587 m
.00375 .13587 L
s
0 .14582 m
.00375 .14582 L
s
0 .16572 m
.00375 .16572 L
s
0 .17568 m
.00375 .17568 L
s
0 .18563 m
.00375 .18563 L
s
0 .19558 m
.00375 .19558 L
s
.25 Mabswid
0 0 m
0 .2 L
s
gsave
-0.01875 .1 -114.313 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.8125 12.875 translate
90 rotate
-85.8125 -12.875 translate
0 25.75 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
%%BeginResource: font Arial-MISO
%%BeginFont: Arial-MISO
/Arial /Arial-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
currentpoint currentpoint
newpath
 moveto
 0.813 0.000 rmoveto
 0 -10.063 rlineto
 6.688 0 rlineto
 0 10.063 rlineto
 -6.688 0 rlineto
closepath
fill moveto
8.313 0.000 rmoveto
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.313 17.625 moveto
(\\220) show
75.750 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MWh) show
108.625 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
1 .2 L
s
1 0 m
1 .2 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02524 .06379 m
.02668 .05871 L
.02811 .07672 L
.02955 .03378 L
.03098 .04335 L
.03242 .04789 L
.03385 .04617 L
.03528 .05257 L
.03672 .07447 L
.03815 .03675 L
.03959 .02781 L
.04102 .03402 L
.04246 .05893 L
.04389 .05578 L
.04532 .05216 L
.04676 .07545 L
.04819 .02597 L
.04963 .03925 L
.05106 .04038 L
.0525 .05857 L
.05393 .06502 L
.05536 .05496 L
.0568 .07001 L
.05823 .03308 L
.05967 .04306 L
.0611 .0493 L
.06254 .04687 L
.06397 .05305 L
.0654 .05058 L
.06684 .07061 L
.06827 .01818 L
.06971 .01621 L
.07114 .02382 L
.07258 .03475 L
.07401 .05784 L
.07544 .059 L
.07688 .07241 L
.07831 .018 L
.07975 .01558 L
.08118 .03414 L
.08262 .03449 L
.08405 .05043 L
.08548 .0535 L
.08692 .07532 L
.08835 .01902 L
.08979 .01841 L
.09122 .01942 L
.09266 .04034 L
.09409 .05607 L
.09552 .05717 L
Mistroke
.09696 .07133 L
.09839 .00476 L
.09983 .01595 L
.10126 .01882 L
.1027 .03516 L
.10413 .04462 L
.10557 .05661 L
.107 .07159 L
.10843 .01539 L
.10987 .00895 L
.1113 .03724 L
.11274 .04917 L
.11417 .05764 L
.11561 .06676 L
.11704 .07798 L
.11847 .04292 L
.11991 .07142 L
.12134 .03552 L
.12278 .07582 L
.12421 .07554 L
.12565 .05541 L
.12708 .06648 L
.12851 .0467 L
.12995 .05697 L
.13138 .08656 L
.13282 .07519 L
.13425 .10361 L
.13569 .07099 L
.13712 .08678 L
.13855 .06187 L
.13999 .08576 L
.14142 .08535 L
.14286 .10113 L
.14429 .11978 L
.14573 .06685 L
.14716 .0746 L
.14859 .06787 L
.15003 .08787 L
.15146 .09659 L
.1529 .14566 L
.15433 .09841 L
.15577 .07694 L
.1572 .08471 L
.15863 .06231 L
.16007 .06982 L
.1615 .08364 L
.16294 .13913 L
.16437 .09929 L
.16581 .08214 L
.16724 .08463 L
Mistroke
.16867 .05991 L
.17011 .06969 L
.17154 .07047 L
.17298 .08747 L
.17441 .09182 L
.17585 .0835 L
.17728 .07336 L
.17871 .04211 L
.18015 .0714 L
.18158 .06334 L
.18302 .07427 L
.18445 .07686 L
.18589 .07535 L
.18732 .06592 L
.18876 .05446 L
.19019 .10463 L
.19162 .09114 L
.19306 .09268 L
.19449 .05173 L
.19593 .06482 L
.19736 .0263 L
.1988 .06686 L
.20023 .05427 L
.20166 .06776 L
.2031 .07657 L
.20453 .06561 L
.20597 .07301 L
.2074 .06596 L
.20884 .06787 L
.21027 .06589 L
.2117 .08219 L
.21314 .09811 L
.21457 .08296 L
.21601 .08444 L
.21744 .08914 L
.21888 .07606 L
.22031 .05205 L
.22174 .15059 L
.22318 .07361 L
.22461 .09001 L
.22605 .0849 L
.22748 .07092 L
.22892 .08017 L
.23035 .08382 L
.23178 .05874 L
.23322 .08658 L
.23465 .07207 L
.23609 .08726 L
.23752 .0785 L
.23896 .07151 L
Mistroke
.24039 .09614 L
.24182 .10349 L
.24326 .11927 L
.24469 .08894 L
.24613 .11499 L
.24756 .08487 L
.249 .08022 L
.25043 .09865 L
.25186 .11242 L
.2533 .10434 L
.25473 .11311 L
.25617 .0944 L
.2576 .09388 L
.25904 .08322 L
.26047 .09351 L
.2619 .13472 L
.26334 .10619 L
.26477 .07861 L
.26621 .11036 L
.26764 .10011 L
.26908 .07433 L
.27051 .1256 L
.27194 .10378 L
.27338 .05667 L
.27481 .09942 L
.27625 .10846 L
.27768 .08047 L
.27912 .08634 L
.28055 .06191 L
.28199 .08952 L
.28342 .11876 L
.28485 .08911 L
.28629 .10459 L
.28772 .12316 L
.28916 .16201 L
.29059 .14686 L
.29203 .10548 L
.29346 .08891 L
.29489 .08721 L
.29633 .05754 L
.29776 .05459 L
.2992 .0623 L
.30063 .0851 L
.30207 .1067 L
.3035 .03799 L
.30493 .03868 L
.30637 .0683 L
.3078 .08051 L
.30924 .07421 L
.31067 .10038 L
Mistroke
.31211 .07241 L
.31354 .0801 L
.31497 .09479 L
.31641 .10199 L
.31784 .10206 L
.31928 .1048 L
.32071 .1235 L
.32215 .10857 L
.32358 .10276 L
.32501 .12422 L
.32645 .10645 L
.32788 .14293 L
.32932 .10591 L
.33075 .11061 L
.33219 .11138 L
.33362 .0834 L
.33505 .05255 L
.33649 .10282 L
.33792 .10148 L
.33936 .07749 L
.34079 .09933 L
.34223 .06818 L
.34366 .09144 L
.34509 .08588 L
.34653 .08835 L
.34796 .14028 L
.3494 .10558 L
.35083 .11713 L
.35227 .09382 L
.3537 .05524 L
.35513 .0769 L
.35657 .08146 L
.358 .09389 L
.35944 .09427 L
.36087 .10218 L
.36231 .05461 L
.36374 .05079 L
.36517 .05804 L
.36661 .10106 L
.36804 .0909 L
.36948 .08836 L
.37091 .10357 L
.37235 .0487 L
.37378 .05566 L
.37522 .05899 L
.37665 .06853 L
.37808 .10736 L
.37952 .11097 L
.38095 .1075 L
.38239 .0847 L
Mistroke
.38382 .1237 L
.38526 .10907 L
.38669 .19818 L
.38812 .11726 L
.38956 .12018 L
.39099 .11149 L
.39243 .091 L
.39386 .13084 L
.3953 .09866 L
.39673 .09727 L
.39816 .07282 L
.3996 .08755 L
.40103 .10018 L
.40247 .05691 L
.4039 .02282 L
.40534 .05699 L
.40677 .06958 L
.4082 .07781 L
.40964 .0833 L
.41107 .0941 L
.41251 .0265 L
.41394 .05529 L
.41538 .04128 L
.41681 .06642 L
.41824 .06838 L
.41968 .07896 L
.42111 .05879 L
.42255 .03451 L
.42398 .05305 L
.42542 .03429 L
.42685 .06159 L
.42828 .08792 L
.42972 .07748 L
.43115 .09862 L
.43259 .08169 L
.43402 .07145 L
.43546 .04538 L
.43689 .07646 L
.43832 .09782 L
.43976 .09536 L
.44119 .10217 L
.44263 .05129 L
.44406 .07893 L
.4455 .08593 L
.44693 .05791 L
.44836 .09122 L
.4498 .09584 L
.45123 .09644 L
.45267 .09399 L
Mfstroke
.45267 .09399 m
.45401 .2 L
s
.45422 .2 m
.45554 .12406 L
.45697 .1005 L
.45841 .11839 L
.45984 .15454 L
.46127 .11191 L
.46271 .08528 L
.46414 .09354 L
.46558 .15678 L
.46701 .0975 L
.46845 .10938 L
.46988 .0541 L
.47131 .14231 L
.47275 .07193 L
.47418 .08562 L
.47562 .08573 L
.47705 .108 L
.47849 .08277 L
.47992 .06717 L
.48135 .05832 L
.48279 .09175 L
.48422 .06925 L
.48566 .0909 L
.48709 .09195 L
.48853 .08031 L
.48996 .0824 L
.49139 .09946 L
.49283 .07813 L
.49426 .1023 L
.4957 .07942 L
.49713 .10161 L
.49857 .11498 L
.5 .11266 L
.50143 .08031 L
.50287 .05633 L
.5043 .0672 L
.50574 .07535 L
.50717 .07737 L
.50861 .07793 L
.51004 .09432 L
.51147 .12122 L
.51291 .07159 L
.51434 .06196 L
.51578 .06302 L
.51721 .08268 L
.51865 .12936 L
.52008 .06939 L
.52151 .0979 L
.52295 .11461 L
.52438 .09477 L
Mistroke
.52582 .06471 L
.52725 .08338 L
.52869 .14645 L
.53012 .07405 L
.53155 .10298 L
.53299 .08853 L
.53442 .10942 L
.53586 .08605 L
.53729 .11738 L
.53873 .09748 L
.54016 .08735 L
.54159 .07358 L
.54303 .08081 L
.54446 .08657 L
.5459 .13042 L
.54733 .09705 L
.54877 .16129 L
.5502 .12948 L
.55164 .08092 L
.55307 .0731 L
.5545 .15269 L
.55594 .10554 L
.55737 .11144 L
.55881 .15819 L
.56024 .13035 L
.56168 .11225 L
.56311 .07636 L
.56454 .11612 L
.56598 .09103 L
.56741 .09741 L
.56885 .08689 L
.57028 .1013 L
.57172 .06846 L
.57315 .07892 L
.57458 .09454 L
.57602 .06524 L
.57745 .0539 L
.57889 .0819 L
.58032 .09423 L
.58176 .06021 L
.58319 .0693 L
.58462 .04329 L
.58606 .05216 L
.58749 .04001 L
.58893 .07453 L
.59036 .06568 L
.5918 .06396 L
.59323 .07 L
.59466 .05047 L
.5961 .06182 L
Mistroke
.59753 .04231 L
.59897 .0681 L
.6004 .07585 L
.60184 .07004 L
.60327 .06947 L
.6047 .06769 L
.60614 .05024 L
.60757 .06418 L
.60901 .05453 L
.61044 .0963 L
.61188 .03772 L
.61331 .04801 L
.61474 .02964 L
.61618 .04359 L
.61761 .03866 L
.61905 .10468 L
.62048 .12265 L
.62192 .08429 L
.62335 .08006 L
.62478 .07385 L
.62622 .11374 L
.62765 .08787 L
.62909 .13436 L
.63052 .12448 L
.63196 .10096 L
.63339 .10431 L
.63483 .09624 L
.63626 .08894 L
Mfstroke
.63626 .08894 m
.63711 .2 L
s
.63836 .2 m
.63913 .11193 L
.64056 .09708 L
.642 .0897 L
.64343 .09933 L
.64487 .12061 L
.6463 .07767 L
.64773 .07796 L
.64917 .097 L
.6506 .09461 L
.65204 .08383 L
.65347 .09287 L
.65491 .07009 L
.65634 .0774 L
.65777 .11491 L
.65921 .09571 L
.66064 .14735 L
.66208 .08278 L
.66351 .09635 L
.66495 .074 L
.66638 .0878 L
.66781 .09415 L
.66925 .09883 L
.67068 .11731 L
.67212 .09604 L
.67355 .11403 L
.67499 .08271 L
.67642 .08789 L
.67785 .10053 L
.67929 .08971 L
.68072 .10498 L
.68216 .09125 L
.68359 .11082 L
.68503 .14129 L
.68646 .08072 L
.68789 .08434 L
.68933 .08979 L
.69076 .08935 L
.6922 .09207 L
.69363 .05753 L
.69507 .05997 L
.6965 .07294 L
.69793 .10704 L
.69937 .07687 L
.7008 .07911 L
.70224 .10763 L
.70367 .06742 L
.70511 .07435 L
.70654 .08634 L
.70797 .09097 L
Mistroke
.70941 .10668 L
.71084 .09699 L
.71228 .11996 L
.71371 .07923 L
.71515 .09427 L
.71658 .10847 L
.71801 .12362 L
.71945 .10167 L
.72088 .11001 L
.72232 .10978 L
.72375 .14158 L
.72519 .10464 L
.72662 .07789 L
.72806 .04816 L
.72949 .10867 L
.73092 .11057 L
.73236 .11549 L
.73379 .10434 L
.73523 .09541 L
.73666 .10944 L
.7381 .11808 L
.73953 .14729 L
.74096 .11529 L
.7424 .11407 L
.74383 .10484 L
Mfstroke
.74383 .10484 m
.74475 .2 L
s
.74726 .2 m
.74814 .17198 L
s
.74814 .17198 m
.74913 .2 L
s
.74999 .2 m
.751 .16993 L
.75244 .15415 L
.75387 .15187 L
.75531 .16853 L
.75674 .16322 L
.75818 .1495 L
.75961 .19566 L
.76104 .12874 L
.76248 .11053 L
.76391 .15167 L
.76535 .14109 L
.76678 .14061 L
.76822 .1429 L
.76965 .12781 L
.77108 .09027 L
.77252 .10791 L
.77395 .19806 L
.77539 .14755 L
.77682 .11213 L
.77826 .11431 L
.77969 .14292 L
.78112 .12968 L
.78256 .13014 L
s
.78256 .13014 m
.78288 .2 L
s
.79108 .2 m
.79116 .18933 L
.7926 .15124 L
s
.7926 .15124 m
.79263 .2 L
s
.7969 .2 m
.7969 .19606 L
s
.7969 .19606 m
.79695 .2 L
s
.79922 .2 m
.79977 .13524 L
.8012 .15644 L
.80264 .14204 L
.80407 .13519 L
.80551 .05127 L
.80694 .09243 L
.80838 .10985 L
.80981 .06294 L
.81124 .1234 L
.81268 .14588 L
.81411 .15306 L
.81555 .13803 L
.81698 .12929 L
s
.81698 .12929 m
.81779 .2 L
s
.82466 .2 m
.82559 .18093 L
.82702 .16773 L
.82846 .17619 L
.82989 .12131 L
.83133 .14787 L
.83276 .14814 L
.83419 .1514 L
.83563 .07488 L
.83706 .10952 L
.8385 .1016 L
.83993 .0997 L
.84137 .09659 L
.8428 .10724 L
.84423 .10955 L
.84567 .09353 L
.8471 .10859 L
.84854 .08355 L
.84997 .04777 L
.85141 .08247 L
.85284 .07473 L
.85427 .0849 L
.85571 .0712 L
.85714 .09096 L
.85858 .056 L
.86001 .05949 L
.86145 .05944 L
.86288 .06634 L
.86431 .07168 L
.86575 .08173 L
.86718 .09841 L
.86862 .03814 L
.87005 .0233 L
.87149 .06788 L
.87292 .08706 L
.87435 .06217 L
.87579 .11508 L
.87722 .11328 L
.87866 .06439 L
.88009 .05922 L
.88153 .07364 L
.88296 .10411 L
.88439 .08224 L
.88583 .0858 L
.88726 .1154 L
.8887 .06728 L
.89013 .06398 L
.89157 .05596 L
.893 .0803 L
.89443 .13048 L
Mistroke
.89587 .08807 L
.8973 .1027 L
.89874 .06488 L
.90017 .07744 L
.90161 .07111 L
.90304 .0734 L
.90448 .07988 L
.90591 .09593 L
.90734 .10995 L
.90878 .04975 L
.91021 .0577 L
.91165 .04827 L
.91308 .06971 L
.91452 .06524 L
.91595 .07964 L
.91738 .09552 L
.91882 .04691 L
.92025 .0493 L
.92169 .06157 L
.92312 .06357 L
.92456 .07609 L
.92599 .06676 L
.92742 .07839 L
.92886 .05591 L
.93029 .0652 L
.93173 .07982 L
.93316 .08147 L
.9346 .07008 L
.93603 .06304 L
.93746 .05266 L
.9389 .04331 L
.94033 .06338 L
.94177 .06203 L
.9432 .08269 L
.94464 .09111 L
.94607 .09083 L
.9475 .07466 L
.94894 .08213 L
.95037 .11759 L
.95181 .11495 L
.95324 .09226 L
.95468 .09728 L
.95611 .09267 L
.95754 .12546 L
.95898 .1106 L
.96041 .11348 L
.96185 .10684 L
.96328 .11019 L
.96472 .09183 L
.96615 .07047 L
Mistroke
.96758 .09212 L
.96902 .12082 L
.97045 .08572 L
.97189 .08633 L
.97332 .01639 L
.97476 .00542 L
.97619 .07716 L
Mfstroke
0 0 1 r
.005 w
.02524 .09741 m
.02668 .09716 L
.02811 .09691 L
.02955 .09666 L
.03098 .09641 L
.03242 .09616 L
.03385 .09566 L
.03528 .09541 L
.03672 .09516 L
.03815 .09491 L
.03959 .09466 L
.04102 .09441 L
.04246 .09416 L
.04389 .09391 L
.04532 .09366 L
.04676 .09341 L
.04819 .09316 L
.04963 .09292 L
.05106 .09267 L
.0525 .09242 L
.05393 .09217 L
.05536 .09193 L
.0568 .09168 L
.05823 .09143 L
.05967 .09119 L
.0611 .09094 L
.06254 .0907 L
.06397 .09046 L
.0654 .09021 L
.06684 .08997 L
.06827 .08973 L
.06971 .08948 L
.07114 .08924 L
.07258 .089 L
.07401 .08876 L
.07544 .08852 L
.07688 .08828 L
.07831 .08805 L
.07975 .08781 L
.08118 .08757 L
.08262 .08734 L
.08405 .0871 L
.08548 .08687 L
.08692 .08664 L
.08835 .0864 L
.08979 .08617 L
.09122 .08594 L
.09266 .08571 L
.09409 .08548 L
.09552 .08526 L
Mistroke
.09696 .08503 L
.09839 .0848 L
.09983 .08458 L
.10126 .08435 L
.1027 .08413 L
.10413 .08391 L
.10557 .08369 L
.107 .08347 L
.10843 .08325 L
.10987 .08303 L
.1113 .08282 L
.11274 .0826 L
.11417 .08239 L
.11561 .08218 L
.11704 .08197 L
.11847 .08176 L
.11991 .08155 L
.12134 .08134 L
.12278 .08113 L
.12421 .08093 L
.12565 .08073 L
.12708 .08052 L
.12851 .08032 L
.12995 .08012 L
.13138 .07993 L
.13282 .07973 L
.13425 .07953 L
.13569 .07934 L
.13712 .07915 L
.13855 .07896 L
.13999 .07877 L
.14142 .07858 L
.14286 .07839 L
.14429 .07821 L
.14573 .07803 L
.14716 .07785 L
.14859 .07767 L
.15003 .07749 L
.15146 .07731 L
.1529 .07714 L
.15433 .07696 L
.15577 .07679 L
.1572 .07662 L
.15863 .07645 L
.16007 .07629 L
.1615 .07612 L
.16294 .07596 L
.16437 .0758 L
.16581 .07564 L
.16724 .07548 L
Mistroke
.16867 .07533 L
.17011 .07517 L
.17154 .07502 L
.17298 .07487 L
.17441 .07472 L
.17585 .07458 L
.17728 .07443 L
.17871 .07429 L
.18015 .07401 L
.18158 .07387 L
.18302 .07374 L
.18445 .07361 L
.18589 .07348 L
.18732 .07335 L
.18876 .07322 L
.19019 .07309 L
.19162 .07297 L
.19306 .07285 L
.19449 .07273 L
.19593 .07262 L
.19736 .0725 L
.1988 .07239 L
.20023 .07228 L
.20166 .07217 L
.2031 .07206 L
.20453 .07196 L
.20597 .07186 L
.2074 .07176 L
.20884 .07166 L
.21027 .07156 L
.2117 .07147 L
.21314 .07138 L
.21457 .07129 L
.21601 .0712 L
.21744 .07112 L
.21888 .07103 L
.22031 .07095 L
.22174 .07088 L
.22318 .0708 L
.22461 .07073 L
.22605 .07065 L
.22748 .07058 L
.22892 .07052 L
.23035 .07045 L
.23178 .07039 L
.23322 .07033 L
.23465 .07027 L
.23609 .07022 L
.23752 .07016 L
.23896 .07011 L
Mistroke
.24039 .07006 L
.24182 .07002 L
.24326 .06997 L
.24469 .06993 L
.24613 .06989 L
.24756 .06985 L
.249 .06982 L
.25043 .06978 L
.25186 .06975 L
.2533 .06972 L
.25473 .0697 L
.25617 .06967 L
.2576 .06965 L
.25904 .06963 L
.26047 .06962 L
.2619 .0696 L
.26334 .06959 L
.26477 .06958 L
.26621 .06957 L
.26764 .06957 L
.26908 .06957 L
.27051 .06957 L
.27194 .06957 L
.27338 .06957 L
.27481 .06958 L
.27625 .06959 L
.27768 .0696 L
.27912 .06961 L
.28055 .06963 L
.28199 .06965 L
.28342 .06967 L
.28485 .06969 L
.28629 .06972 L
.28772 .06974 L
.28916 .06977 L
.29059 .06981 L
.29203 .06984 L
.29346 .06988 L
.29489 .06992 L
.29633 .0701 L
.29776 .07015 L
.2992 .0702 L
.30063 .07025 L
.30207 .07031 L
.3035 .07043 L
.30493 .0705 L
.30637 .07057 L
.3078 .07063 L
.30924 .07071 L
.31067 .07078 L
Mistroke
.31211 .07085 L
.31354 .07093 L
.31497 .07101 L
.31641 .07109 L
.31784 .07118 L
.31928 .07127 L
.32071 .07135 L
.32215 .07145 L
.32358 .07154 L
.32501 .07163 L
.32645 .07173 L
.32788 .07183 L
.32932 .07193 L
.33075 .07204 L
.33219 .07214 L
.33362 .07225 L
.33505 .07236 L
.33649 .07248 L
.33792 .07259 L
.33936 .07271 L
.34079 .07283 L
.34223 .07295 L
.34366 .07307 L
.34509 .0732 L
.34653 .07332 L
.34796 .07345 L
.3494 .07358 L
.35083 .07372 L
.35227 .07385 L
.3537 .07399 L
.35513 .07413 L
.35657 .07427 L
.358 .07441 L
.35944 .07456 L
.36087 .0747 L
.36231 .07485 L
.36374 .075 L
.36517 .07516 L
.36661 .07531 L
.36804 .07547 L
.36948 .07562 L
.37091 .07578 L
.37235 .07595 L
.37378 .07611 L
.37522 .07628 L
.37665 .07644 L
.37808 .07661 L
.37952 .07678 L
.38095 .07696 L
.38239 .07713 L
Mistroke
.38382 .07731 L
.38526 .07748 L
.38669 .07766 L
.38812 .07784 L
.38956 .07803 L
.39099 .07821 L
.39243 .0784 L
.39386 .07859 L
.3953 .07877 L
.39673 .07897 L
.39816 .07916 L
.3996 .07935 L
.40103 .07955 L
.40247 .07974 L
.4039 .07994 L
.40534 .08014 L
.40677 .08034 L
.4082 .08055 L
.40964 .08075 L
.41107 .08096 L
.41251 .08116 L
.41394 .08137 L
.41538 .08158 L
.41681 .08179 L
.41824 .08201 L
.41968 .08222 L
.42111 .08243 L
.42255 .08265 L
.42398 .08287 L
.42542 .08309 L
.42685 .08331 L
.42828 .08353 L
.42972 .08375 L
.43115 .08397 L
.43259 .0842 L
.43402 .08442 L
.43546 .08465 L
.43689 .08488 L
.43832 .08511 L
.43976 .08534 L
.44119 .08557 L
.44263 .0858 L
.44406 .08604 L
.4455 .08627 L
.44693 .0865 L
.44836 .08698 L
.4498 .08722 L
.45123 .08769 L
.45267 .08793 L
.4541 .08818 L
Mistroke
.45554 .08842 L
.45697 .08866 L
.45841 .0889 L
.45984 .08915 L
.46127 .08939 L
.46271 .08964 L
.46414 .08988 L
.46558 .09013 L
.46701 .09038 L
.46845 .09063 L
.46988 .09088 L
.47131 .09138 L
.47275 .09163 L
.47418 .09188 L
.47562 .09213 L
.47705 .09238 L
.47849 .09263 L
.47992 .09289 L
.48135 .09314 L
.48279 .09339 L
.48422 .09365 L
.48566 .0939 L
.48709 .09415 L
.48853 .09441 L
.48996 .09466 L
.49139 .09492 L
.49283 .09518 L
.49426 .09543 L
.4957 .09569 L
.49713 .09594 L
.49857 .0962 L
.5 .09646 L
.50143 .09671 L
.50287 .09723 L
.5043 .09748 L
.50574 .09774 L
.50717 .098 L
.50861 .09825 L
.51004 .09851 L
.51147 .09877 L
.51291 .09902 L
.51434 .09928 L
.51578 .09953 L
.51721 .10005 L
.51865 .1003 L
.52008 .10056 L
.52151 .10081 L
.52295 .10107 L
.52438 .10132 L
.52582 .10158 L
Mistroke
.52725 .10183 L
.52869 .10208 L
.53012 .10259 L
.53155 .10284 L
.53299 .10309 L
.53442 .10334 L
.53586 .1036 L
.53729 .10385 L
.53873 .1041 L
.54016 .10435 L
.54159 .10459 L
.54303 .10484 L
.54446 .10509 L
.5459 .10534 L
.54733 .10558 L
.54877 .10583 L
.5502 .10607 L
.55164 .10632 L
.55307 .10656 L
.5545 .10681 L
.55594 .10705 L
.55737 .10729 L
.55881 .10753 L
.56024 .10777 L
.56168 .10801 L
.56311 .10825 L
.56454 .10848 L
.56598 .10872 L
.56741 .10895 L
.56885 .10919 L
.57028 .10942 L
.57172 .10965 L
.57315 .10989 L
.57458 .11012 L
.57602 .11035 L
.57745 .11057 L
.57889 .1108 L
.58032 .11103 L
.58176 .11125 L
.58319 .11148 L
.58462 .1117 L
.58606 .11192 L
.58749 .11214 L
.58893 .11236 L
.59036 .11258 L
.5918 .11279 L
.59323 .11301 L
.59466 .11322 L
.5961 .11343 L
.59753 .11365 L
Mistroke
.59897 .11386 L
.6004 .11406 L
.60184 .11427 L
.60327 .11448 L
.6047 .11468 L
.60614 .11489 L
.60757 .11509 L
.60901 .11529 L
.61044 .11549 L
.61188 .11568 L
.61331 .11588 L
.61474 .11607 L
.61618 .11626 L
.61761 .11646 L
.61905 .11665 L
.62048 .11683 L
.62192 .11702 L
.62335 .1172 L
.62478 .11739 L
.62622 .11757 L
.62765 .11775 L
.62909 .11793 L
.63052 .1181 L
.63196 .11828 L
.63339 .11845 L
.63483 .11862 L
.63626 .11879 L
.63769 .11896 L
.63913 .11912 L
.64056 .11929 L
.642 .11945 L
.64343 .11961 L
.64487 .11977 L
.6463 .11992 L
.64773 .12008 L
.64917 .12023 L
.6506 .12038 L
.65204 .12053 L
.65347 .12068 L
.65491 .12083 L
.65634 .12097 L
.65777 .12111 L
.65921 .12125 L
.66064 .12139 L
.66208 .12152 L
.66351 .12166 L
.66495 .12179 L
.66638 .12192 L
.66781 .12204 L
.66925 .12217 L
Mistroke
.67068 .12229 L
.67212 .12241 L
.67355 .12253 L
.67499 .12265 L
.67642 .12277 L
.67785 .12288 L
.67929 .12299 L
.68072 .1231 L
.68216 .1232 L
.68359 .12331 L
.68503 .12341 L
.68646 .12351 L
.68789 .1237 L
.68933 .1238 L
.69076 .12389 L
.6922 .12398 L
.69363 .12407 L
.69507 .12415 L
.6965 .12423 L
.69793 .12431 L
.69937 .12439 L
.7008 .12447 L
.70224 .12454 L
.70367 .12461 L
.70511 .12468 L
.70654 .12475 L
.70797 .12481 L
.70941 .12488 L
.71084 .12494 L
.71228 .12499 L
.71371 .12505 L
.71515 .1251 L
.71658 .12515 L
.71801 .1252 L
.71945 .12525 L
.72088 .12529 L
.72232 .12534 L
.72375 .12537 L
.72519 .12541 L
.72662 .12545 L
.72806 .12548 L
.72949 .12551 L
.73092 .12554 L
.73236 .12556 L
.73379 .12559 L
.73523 .12561 L
.73666 .12563 L
.7381 .12564 L
.73953 .12566 L
.74096 .12567 L
Mistroke
.7424 .12568 L
.74383 .12568 L
.74527 .12569 L
.7467 .12569 L
.74814 .12569 L
.74957 .12569 L
.751 .12568 L
.75244 .12568 L
.75387 .12567 L
.75531 .12566 L
.75674 .12564 L
.75818 .12563 L
.75961 .12561 L
.76104 .12559 L
.76248 .12556 L
.76391 .12554 L
.76535 .12551 L
.76678 .12548 L
.76822 .12545 L
.76965 .12541 L
.77108 .12537 L
.77252 .12533 L
.77395 .12529 L
.77539 .12525 L
.77682 .1252 L
.77826 .12515 L
.77969 .1251 L
.78112 .12505 L
.78256 .12499 L
.78399 .12494 L
.78543 .12488 L
.78686 .12481 L
.7883 .12475 L
.78973 .12468 L
.79116 .12461 L
.7926 .12454 L
.79403 .12447 L
.79547 .12439 L
.7969 .12431 L
.79834 .12423 L
.79977 .12415 L
.8012 .12407 L
.80264 .12398 L
.80407 .12361 L
.80551 .12351 L
.80694 .12341 L
.80838 .12331 L
.80981 .12321 L
.81124 .12299 L
.81268 .12288 L
Mistroke
.81411 .12277 L
.81555 .12266 L
.81698 .12254 L
.81842 .12242 L
.81985 .1223 L
.82129 .12218 L
.82272 .12205 L
.82415 .12193 L
.82559 .1218 L
.82702 .12167 L
.82846 .12154 L
.82989 .1214 L
.83133 .12127 L
.83276 .12113 L
.83419 .12099 L
.83563 .12084 L
.83706 .1207 L
.8385 .12055 L
.83993 .12041 L
.84137 .12026 L
.8428 .1201 L
.84423 .11995 L
.84567 .1198 L
.8471 .11964 L
.84854 .11948 L
.84997 .11932 L
.85141 .11916 L
.85284 .11899 L
.85427 .11883 L
.85571 .11866 L
.85714 .11849 L
.85858 .11832 L
.86001 .11814 L
.86145 .11797 L
.86288 .11779 L
.86431 .11762 L
.86575 .11744 L
.86718 .11726 L
.86862 .11707 L
.87005 .11689 L
.87149 .1167 L
.87292 .11652 L
.87435 .11633 L
.87579 .11614 L
.87722 .11594 L
.87866 .11575 L
.88009 .11556 L
.88153 .11536 L
.88296 .11516 L
.88439 .11496 L
Mistroke
.88583 .11476 L
.88726 .11456 L
.8887 .11436 L
.89013 .11415 L
.89157 .11395 L
.893 .11374 L
.89443 .11353 L
.89587 .11332 L
.8973 .11311 L
.89874 .1129 L
.90017 .11268 L
.90161 .11247 L
.90304 .11225 L
.90448 .11204 L
.90591 .11182 L
.90734 .1116 L
.90878 .11138 L
.91021 .11116 L
.91165 .11093 L
.91308 .11071 L
.91452 .11049 L
.91595 .11026 L
.91738 .11003 L
.91882 .10981 L
.92025 .10958 L
.92169 .10935 L
.92312 .10912 L
.92456 .10889 L
.92599 .10865 L
.92742 .10842 L
.92886 .10819 L
.93029 .10795 L
.93173 .10772 L
.93316 .10748 L
.9346 .10701 L
.93603 .10677 L
.93746 .10629 L
.9389 .10605 L
.94033 .10581 L
.94177 .10556 L
.9432 .10532 L
.94464 .10508 L
.94607 .10484 L
.9475 .10459 L
.94894 .10435 L
.95037 .1041 L
.95181 .10386 L
.95324 .10361 L
.95468 .10337 L
.95611 .10312 L
Mistroke
.95754 .10287 L
.95898 .10262 L
.96041 .10238 L
.96185 .10213 L
.96328 .10188 L
.96472 .10163 L
.96615 .10138 L
.96758 .10113 L
.96902 .10088 L
.97045 .10063 L
.97189 .10039 L
.97332 .10014 L
.97476 .09989 L
.97619 .09964 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{720, 143.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;@0000Sb000`400?l00000o`00003oo`3ooooo
0?ooom80oooo003o0?ooool0oooodP3oool005L0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo06l0oooo001G0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1_0?ooo`00E`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0K`3oool004`0oooo00<00000
0?ooo`3oool00`3oool400000080oooo00<000000?ooo`3oool00`3oool4000000<0oooo00@00000
0?ooo`3oool0oooo1P0000030?ooo`@00000103oool4000000@0oooo100000030?ooo`@000001P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo100000030?ooo`040000003o
ool0oooo0?ooo`H000000`3oool4000000@0oooo100000040?ooo`@000000P3oool00`000000oooo
0?ooo`030?ooo`@000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00D000000?ooo`3oool0oooo000000040?ooo`H000000`3oool4000000@0oooo100000040?ooo`@0
00000P3oool600000080oooo00@000000?ooo`3oool0oooo1P0000020?ooo`040000003oool0oooo
0?ooo`H000000`3oool4000000@0oooo100000060?ooo`030000003oool0oooo00D0oooo1P000003
0?ooo`@000000`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000`3o
ool6000000<0oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`060?ooo`@000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool6000000<0oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`050?ooo`H000001@3o
ool01@000000oooo0?ooo`3oool0000000D0oooo0`0000040?ooo`040000003oool0oooo0?ooo`H0
00000`3oool4000000@0oooo100000060?ooo`030000003oool0oooo0080oooo100000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool600000080oooo00<000000?ooo`3o
ool00P3oool6000000<0oooo100000040?ooo`@000001P3oool010000000oooo0?ooo`3oool60000
00<0oooo100000020?ooo`030000003oool0oooo0080oooo1P0000000`3oool000000?ooo`030?oo
o`H000000`3oool4000000@0oooo100000030?ooo`H00000CP3oool004`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo0000001B0?ooo`00C03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000070?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool700000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000T0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
0000103oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1?0?ooo`00C03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`0000002@3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool00000
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`1>0?ooo`00C03oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000
oooo0?ooo`0000030?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`030000003oool0000000T0oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool3000000030?ooo`000000oooo0080oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000000`3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0
000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1=0?ooo`00C03oool00`000000oooo0?oo
o`020?ooo`030000003oool00000008000000`3oool01P000000oooo0?ooo`3oool000000?ooo`<0
0000103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0?ooo`<00000
1P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`@00000103oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0:0?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`@00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo
0P0000030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool0oooo0000003o
ool3000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`050000003o
ool0oooo0?ooo`000000203oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo0`0000030?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1<0?ooo`00C03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`030000003oool0000000@0oooo1@0000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000070?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo04`0oooo001:0?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool01P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000@0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool00`00
0000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
103oool00`000000oooo000000040?ooo`030000003oool0oooo00H0oooo00L000000?ooo`3oool0
oooo0000003oool0000000D0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool010000000
oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0oooo0000
003oool0000000L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00<00000
0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00L000000?ooo`3oool0oooo0000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
103oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool00`000000oooo0?ooo`020?oo
o`070000003oool0oooo0?ooo`000000oooo000000050?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000003oool0oooo000000@0
oooo00@000000?ooo`3oool00000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`070?ooo`060000003oool0oooo0000003oool00000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
04`0oooo001;0?ooo`8000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo0P0000060?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00040?ooo`<000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P00
00060?ooo`8000001@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool2000000D0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P0000070?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000D0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P00
00040?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`3oool2000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0080oooo0P0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`1<0?ooo`00C03oool00`000000oooo0?ooo`040?ooo`<000001@3oool010000000oooo0?oo
o`3oool3000000H0oooo00<000000?ooo`0000000`0000040?ooo`@00000103oool4000000@0oooo
100000030?ooo`@000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000<00000
1P3oool00`000000oooo00000003000000@0oooo100000040?ooo`@00000103oool400000080oooo
00<000000?ooo`3oool00`3oool5000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0100000040?ooo`@00000
103oool4000000@0oooo100000030?ooo`@000001P3oool00`000000oooo00000003000000H0oooo
00<000000?ooo`0000000`0000040?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool0
1P3oool4000000@0oooo100000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo00000003000000@0oooo100000040?ooo`@000001P3oool00`000000oooo
0?ooo`060?ooo`@000001P3oool00`000000oooo00000005000000@0oooo00<000000?ooo`3oool0
100000040?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool01P3oool4000000H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04000000H0oooo00<000000?ooo`000000
0`0000040?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool00`3oool3000000H0oooo
00D000000?ooo`3oool0oooo000000050?ooo`@000001P3oool00`000000oooo0?ooo`04000000@0
oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`020?ooo`@00000103oool4000000D0
oooo00<000000?ooo`3oool0100000050?ooo`030000003oool0oooo00@00000103oool4000000@0
oooo100000040?ooo`@00000C`3oool00?l0ooooo`3ooooB0?ooo`00o`3ooooo0?ooom80oooo003o
0?ooool0oooodP3oool00?l0ooooo`3ooooB0?ooo`00o`3ooooo0?ooom80oooo003o0?ooool0oooo
dP3oool00?l0ooooo`3ooooB0?ooo`00o`3ooooo0?ooom80oooo003o0?ooool0oooodP3oool00?l0
ooooo`3ooooB0?ooo`00A03oool00`000000oooo0?ooo`030?ooo`@000002`3ooooo00000?l00000
D000000Y0?ooo`00A03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02L0oooo0014
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool09`3oool004@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0140oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo00`0oooo00<000000?oo
o`3oool09`3oool004@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo1000000f0?ooo`030?l0003oool0oooo0?l0ooooo`3oool30?ooo`03
0?l0003oool0oooo00`0oooo00<000000?ooo`3oool09`3oool004@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
=`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0ooooo03oool00`3o0000oooo
0?ooo`0<0?ooo`030000003oool0oooo02L0oooo00140?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03L0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?oooo/0oooo0P3o000>0?ooo`030000003o
ool0oooo02L0oooo00120?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo03L0oooo0P3o00040?ooo`030?l0003oool0
oooo0?l0oooon`3oool20?l000h0oooo00<000000?ooo`3oool09`3oool004<0oooo0P0000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0g0?oo
o`80o`00103oool00`3o0000oooo0?ooo`3o0?oooo/0oooo0P3o000>0?ooo`030000003oool0oooo
02L0oooo00140?ooo`030000003oool0oooo00<0oooo1000000;0?ooo`<000009P3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo0P3o00040?ooo`030?l0003oool0oooo0?l0
oooon`3oool20?l000h0oooo00<000000?ooo`3oool09`3oool005T0oooo00<000000?ooo`3oool0
9@3oool20?l000@0oooo0P3o000:0?ooo`80o`00103oool00`3o0000oooo0?ooo`3o0?oooo/0oooo
0P3o000>0?ooo`030000003oool0oooo02L0oooo001I0?ooo`030000003oool0oooo02D0oooo0P3o
00040?ooo`80o`00103oool20?l000@0oooo0P3o00040?ooo`030?l0003oool0oooo0?l0oooon`3o
ool20?l000h0oooo00<000000?ooo`3oool09`3oool005T0oooo00<000000?ooo`3oool09@3oool0
0`3o0000oooo0?l000030?ooo`80o`00103oool20?l000@0oooo0P3o00040?ooo`030?l0003oool0
oooo0?l0oooon`3oool20?l000h0oooo00<000000?ooo`3oool09`3oool005T0oooo00<000000?oo
o`3oool09@3oool00`3o0000oooo0?l000030?ooo`80o`00103oool20?l000@0oooo0P3o00040?oo
o`030?l0003oool0oooo0:/0oooo00<0o`000?ooo`3oool0o`3oool@0?ooo`030?l0003oool0oooo
03X0oooo0P3o000>0?ooo`030000003oool0oooo02L0oooo001I0?ooo`030000003oool0oooo02D0
oooo00<0o`000?ooo`3o00000`3oool20?l000@0oooo0P3o00040?ooo`80o`00103oool20?l00:`0
oooo00<0o`000?ooo`3oool0o`3oool@0?ooo`030?l0003oool0oooo03X0oooo0P3o000>0?ooo`03
0000003oool0oooo02L0oooo001I0?ooo`<000006@3oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0o`0000<0oooo00<0o`000?ooo`3o00000`3oool20?l000@0oooo0P3o00040?ooo`80o`00
<P3oool00`3o0000oooo0?ooo`1g0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
o`3oool;0?ooo`030?l0003oool0oooo03X0oooo0P3o000>0?ooo`030000003oool0oooo02L0oooo
001I0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`090?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o00000`3oool20?l000@0oooo00<0
o`000?ooo`3o00000`3oool20?l00380oooo00<0o`000?ooo`3oool0M`3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo0?l0oooo2`3oool00`3o0000oooo0?ooo`0j0?ooo`80o`003P3o
ool00`000000oooo0?ooo`0W0?ooo`00F@3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0
o`0000<0oooo0P3o00040?ooo`030?l0003oool0o`0000<0oooo0P3o000b0?ooo`030?l0003oool0
oooo07L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`1d0?ooo`030?l0003oool0
oooo09<0oooo00<0o`000?ooo`3oool0>P3oool20?l000h0oooo00<000000?ooo`3oool09`3oool0
05T0oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
00T0oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`00
00<0oooo00<0o`000?ooo`3o00000`3oool20?l00380oooo00<0o`000?ooo`3oool0M`3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo07@0oooo00<0o`000?ooo`3oool0TP3oool20?l0
03`0oooo0P3o000>0?ooo`030000003oool0oooo02L0oooo001I0?ooo`030000003oool0oooo01<0
oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000<0
oooo00<0o`000?ooo`3o00000`3oool20?l00380oooo00<0o`000?ooo`3oool0M`3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo07@0oooo00<0o`000?ooo`3oool0TP3oool20?l003`0
oooo0P3o000>0?ooo`030000003oool0oooo02L0oooo001I0?ooo`030000003oool0oooo00h0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?l000030?ooo`80o`00103oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo
0?l000030?ooo`030?l0003oool0o`0000<0oooo0P3o000b0?ooo`030?l0003oool0oooo07L0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`80o`00K`3oool00`3o0000oooo
0?ooo`2B0?ooo`80o`00?03oool20?l000h0oooo00<000000?ooo`3oool09`3oool005T0oooo0`00
000>0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00000`3oool20?l000@0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000<0oooo00<0
o`000?ooo`3o00000`3oool00`3o0000oooo0?l000030?ooo`80o`001@3oool00`3o0000oooo0?oo
o`0Z0?ooo`030?l0003oool0oooo07L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`80o`00K`3oool00`3o0000oooo0?ooo`2B0?ooo`80o`00?03oool20?l000h0oooo00<0
00000?ooo`3oool09`3oool005T0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0o`0000<0oooo0P3o00040?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3o00000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000<0oooo00<0o`00
0?ooo`3o00000`3oool20?l000D0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0k
0?ooo`030?l0003oool0oooo03T0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`80o`00K@3oool0103o0000oooo0?l0003o002C0?ooo`80o`00?03oool20?l000h0oooo00<0
00000?ooo`3oool09`3oool005T0oooo00<000000?ooo`3oool03P3oool20?l000<0oooo00<0o`00
0?ooo`3o00000`3oool20?l000@0oooo0P3o00040?ooo`030?l0003oool0o`0000<0oooo00<0o`00
0?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?l000<0oooo0P3o
00050?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool0>`3oool20?l003T0oooo0P3o
00040?ooo`030?l0003oool0oooo00<0oooo0P3o001O0?ooo`030?l0003oool0oooo00/0oooo0P3o
00000`3oool0o`000?ooo`2B0?ooo`80o`00?03oool20?l000h0oooo00<000000?ooo`3oool09`3o
ool005T0oooo00<000000?ooo`3oool03P3oool20?l000<0oooo00<0o`000?ooo`3o00000`3oool0
0`3o0000oooo0?l000030?ooo`80o`00103oool00`3o0000oooo0?l000030?ooo`030?l0003oool0
o`0000<0oooo00<0o`000?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`000080oooo0P3o
00050?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool0>`3oool20?l003T0oooo0P3o
00040?ooo`80o`00103oool20?l005l0oooo00<0o`000?ooo`3oool02`3oool20?l000030?ooo`3o
0000oooo0980oooo0P3o000l0?ooo`80o`003P3oool00`000000oooo0?ooo`0W0?ooo`00F@3oool0
0`000000oooo0?ooo`0>0?ooo`80o`000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0
o`0000<0oooo0P3o00040?ooo`030?l0003oool0o`0000<0oooo00@0o`000?ooo`3oool0o`000P3o
ool00`3o0000oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool20?l000<0oooo
00<0o`000?ooo`3o00008@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo03/0oooo
0P3o000i0?ooo`80o`00103oool20?l000@0oooo0P3o001M0?ooo`030?l0003oool0o`0000D0oooo
00<0o`000?ooo`3oool01@3oool20?l000030?ooo`3o0000oooo0980oooo0P3o000X0?ooo`030?l0
003oool0oooo0140oooo00<0o`000?ooo`3o00003@3oool00`000000oooo0?ooo`0W0?ooo`00F@3o
ool00`000000oooo0?ooo`0>0?ooo`80o`000`3oool00`3o0000oooo0?l000030?ooo`030?l0003o
ool0o`0000<0oooo0P3o00030?ooo`040?l0003oool0oooo0?l00080oooo00D0o`000?ooo`3oool0
oooo0?l000020?ooo`030?l0003oool0o`000080oooo00L0o`000?ooo`3oool0oooo0?l0003oool0
o`000080oooo00H0o`000?ooo`3oool0o`000?ooo`3o000Q0?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`3oool0>`3oool20?l003T0oooo0P3o00040?ooo`80o`00103oool20?l000D0oooo
00<0o`000?ooo`3oool0E@3oool00`3o0000oooo0?l000050?ooo`030?l0003oool0oooo00D0oooo
0P3o00000`3oool0o`000?ooo`2B0?ooo`80o`00:03oool00`3o0000oooo0?ooo`0A0?ooo`030?l0
003oool0o`0000d0oooo00<000000?ooo`3oool09`3oool005T0oooo0`00000>0?ooo`080?l0003o
ool0o`000?l0003oool0o`000?ooo`3o00030?ooo`030?l0003oool0o`0000<0oooo0P3o0000103o
ool0o`000?ooo`3o00020?ooo`040?l0003oool0oooo0?l000<0oooo00H0o`000?ooo`3oool0o`00
0?ooo`3o00020?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l000020?ooo`060?l0003oool0
oooo0?l0003oool0o`000`3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo00L0oooo
0P3o000m0?ooo`80o`00>@3oool20?l000@0oooo0P3o00030?ooo`<0o`001@3oool00`3o0000oooo
0?ooo`1E0?ooo`<0o`001@3oool00`3o0000oooo0?ooo`050?ooo`80o`0000<0oooo0?l0003oool0
TP3oool00`3o0000oooo0?l0000K0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0
4@3oool00`3o0000oooo0?l0000=0?ooo`030000003oool0oooo02L0oooo001I0?ooo`030000003o
ool0oooo00h0oooo00H0o`000?ooo`3o0000o`000?ooo`3o00020?ooo`060?l0003oool0oooo0?l0
003oool0o`000`3oool01P3o0000oooo0?l0003o0000oooo0?l000<0oooo00<0o`000?ooo`3o0000
0`3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?l000<0oooo00<0o`000?ooo`3o
00000P3oool01P3o0000oooo0?ooo`3o0000oooo0?l000<0oooo00<0o`000?ooo`3oool06`3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0o`0003`0oooo0P3o000W0?ooo`030?l0003oool0
oooo00l0oooo0P3o00040?ooo`80o`000`3oool30?l000D0oooo00<0o`000?ooo`3oool0E@3oool3
0?l000D0oooo00<0o`000?ooo`3oool01@3oool20?l000030?ooo`3o0000oooo03l0oooo00<0o`00
0?ooo`3oool0A@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0o`0001L0oooo00D0o`00
0?ooo`3oool0oooo0?l0000:0?ooo`80o`004`3oool00`3o0000oooo0?l0000=0?ooo`030000003o
ool0oooo02L0oooo00110?ooo`H000000`3oool4000000/0oooo00<000000?ooo`3oool03P3oool0
1P3o0000oooo0?ooo`3o0000oooo0?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`3o00030?oo
o`060?l0003oool0o`000?l0003oool0o`000`3oool00`3o0000oooo0?l000030?ooo`030?l0003o
ool0o`0000<0oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`060?l0003o
ool0oooo0?l0003oool0o`000`3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3o0000?03oool20?l002L0oooo00<0o`000?ooo`3oool03`3oool20?l000@0
oooo0P3o00030?ooo`80o`0000<0oooo0?l0003oool00`3oool00`3o0000oooo0?ooo`1E0?ooo`<0
o`000`3oool00`3o0000oooo0?l000040?ooo`040?l0003oool0oooo0?l00080oooo00<0o`000?oo
o`3oool0?P3oool00`3o0000oooo0?ooo`150?ooo`030?l0003oool0oooo00P0oooo00<0o`000?oo
o`3o00005@3oool00`3o0000oooo0?l000030?ooo`80o`002@3oool20?l001<0oooo00<0o`000?oo
o`3o00003@3oool00`000000oooo0?ooo`0W0?ooo`00@P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`04
0?l0003oool0oooo0?ooo`80o`000P3oool30?l000<0oooo00<0o`000?ooo`3o00000`3oool30?l0
00<0oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`00
00@0oooo0P3o00020?ooo`060?l0003oool0oooo0?l0003oool0o`000`3oool00`3o0000oooo0?oo
o`0K0?ooo`030?l0003oool0oooo00H0oooo0P3o00000`3oool0o`000?ooo`0:0?ooo`030?l0003o
ool0oooo02h0oooo0P3o000R0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool03`3o
ool20?l000@0oooo0P3o00030?ooo`80o`0000<0oooo0?l0003oool00`3oool01@3o0000oooo0?oo
o`3oool0o`0005<0oooo0`3o00030?ooo`030?l0003oool0o`0000@0oooo00@0o`000?ooo`3oool0
o`000P3oool00`3o0000oooo0?ooo`0n0?ooo`030?l0003oool0oooo02/0oooo00<0o`000?ooo`3o
ool05`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0o`0001D0oooo00<0o`000?ooo`3o
00000`3oool20?l000T0oooo0P3o000B0?ooo`040?l0003oool0oooo0?l000d0oooo00<000000?oo
o`3oool09`3oool004<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool0103o0000oooo0?ooo`3oool20?l0
0080oooo0`3o00030?ooo`030?l0003oool0o`0000<0oooo0`3o00030?ooo`030?l0003oool0o`00
00@0oooo0P3o00030?ooo`030?l0003oool0o`0000@0oooo0P3o00020?ooo`060?l0003oool0oooo
0?l0003oool0o`000`3oool20?l001`0oooo00<0o`000?ooo`3oool01P3oool20?l000030?ooo`3o
0000oooo00X0oooo00<0o`000?ooo`3oool0;P3oool20?l00140oooo00<0o`000?ooo`3oool03@3o
ool20?l000@0oooo0P3o000@0?ooo`80o`00103oool20?l000<0oooo0P3o00000`3oool0o`000?oo
o`030?ooo`050?l0003oool0oooo0?ooo`3o0000C`3oool01`3o0000oooo0?ooo`3oool0o`000?oo
o`3o00000`3oool30?l000@0oooo00@0o`000?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`0n
0?ooo`030?l0003oool0oooo02/0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`08
0?ooo`030?l0003oool0o`0001D0oooo0`3o00030?ooo`80o`002@3oool20?l00180oooo00@0o`00
0?ooo`3oool0o`003@3oool00`000000oooo0?ooo`0W0?ooo`00A03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>
0?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool30?l000<0oooo0`3o00040?ooo`80o`000`3o
ool00`3o0000oooo0?l000040?ooo`80o`000`3oool00`3o0000oooo0?l000040?ooo`80o`000`3o
ool00`3o0000oooo0?l000020?l00080oooo0`3o000L0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3o00000`3oool0o`000?l0000:0?ooo`030?l0003oool0oooo02/0oooo00H0
o`000?ooo`3oool0o`000?ooo`3o000@0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3o
ool00P3oool20?l000@0oooo0P3o000@0?ooo`80o`00103oool00`3o0000oooo0?l000020?ooo`04
0?l0003oool0oooo0?l000@0oooo00D0o`000?ooo`3oool0oooo0?l0000?0?ooo`030?l0003oool0
oooo03d0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`0000<0oooo0`3o00040?ooo`80o`00
00D0oooo0?l0003oool0oooo0?l000100?ooo`030?l0003oool0oooo02/0oooo00<0o`000?ooo`3o
ool05`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0o`0001D0oooo0`3o00030?ooo`80
o`002@3oool20?l00180oooo00@0o`000?ooo`3oool0o`003@3oool00`000000oooo0?ooo`0W0?oo
o`00A@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0203oool40000
00`0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool30?l000<0oooo0`3o0004
0?ooo`80o`000`3oool00`3o0000oooo0?l000040?ooo`80o`000`3oool30?l000@0oooo0P3o0003
0?ooo`070?l0003oool0o`000?l0003oool0o`000?ooo`030?l001`0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`020?l000030?ooo`3o0000o`0000X0oooo00<0o`000?ooo`3oool0
7@3oool00`3o0000oooo0?ooo`0:0?ooo`80o`000P3oool00`3o0000oooo0?l0000@0?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?l000030?ooo`80o`00
403oool20?l000@0oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o00040?ooo`05
0?l0003oool0oooo0?ooo`3o00003`3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo
02T0oooo00@0o`000?ooo`3oool0o`000P3oool0103o0000oooo0?ooo`3oool30?l000@0oooo0P3o
00001@3oool0o`000?ooo`3oool0o`000400oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo
0?ooo`0G0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?l0000;0?ooo`030?l0003oool0oooo00L0oooo0`3o00030?ooo`80o`00103oool00`3o0000oooo
0?ooo`020?ooo`80o`004P3oool0103o0000oooo0?ooo`3o000=0?ooo`030000003oool0oooo02L0
oooo00160?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0<0?ooo`80o`00103oool0103o0000oooo0?ooo`3oool30?l000<0oooo0`3o00040?oo
o`80o`000`3oool30?l000@0oooo0P3o00040?ooo`80o`00103oool20?l000<0oooo00L0o`000?oo
o`3o0000o`000?ooo`3o0000oooo00<0o`006`3oool00`3o0000oooo0?l000040?ooo`030?l0003o
ool0oooo0080o`0000<0oooo0?l0003o00002P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo01H0oooo00<0o`000?ooo`3oool02P3oool20?l00080oooo00<0o`000?ooo`3o0000403o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00000`3o
ool00`3o0000oooo0?l0000?0?ooo`80o`00103oool00`3o0000oooo0?l000020?ooo`040?l0003o
ool0oooo0?l000<0oooo0P3o00030?ooo`040?l0003oool0oooo0?l000`0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo02T0oooo00@0o`000?ooo`3o
ool0o`000`3oool00`3o0000oooo0?ooo`030?l000@0oooo0P3o00001@3oool0o`000?ooo`3oool0
o`0002`0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0[0?ooo`030?l0003oool0
oooo01L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
o`0000/0oooo00<0o`000?ooo`3oool01`3oool30?l000<0oooo0P3o00040?ooo`070?l0003oool0
oooo0?ooo`3o0000oooo0?l0000B0?ooo`040?l0003oool0oooo0?l000d0oooo00<000000?ooo`3o
ool09`3oool004H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00`0oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo0P3o00030?ooo`<0
o`00103oool20?l000@0oooo0P3o00040?ooo`80o`00103oool20?l000@0oooo0P3o00030?ooo`07
0?l0003oool0o`000?l0003oool0o`000?ooo`030?l001H0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?l000040?ooo`030?l0003oool0oooo0080o`0000<0oooo0?l0003o00002P3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool02P3oool0
1`3o0000oooo0?l0003oool0o`000?ooo`3o0000403oool00`3o0000oooo0?ooo`080?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l0000?0?ooo`80o`00
0`3oool0103o0000oooo0?ooo`3o00020?ooo`040?l0003oool0oooo0?l000<0oooo0P3o00030?oo
o`040?l0003oool0oooo0?l000`0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0:
0?ooo`030?l0003oool0oooo02P0oooo0P3o00000`3oool0o`000?l000030?ooo`040?l0003oool0
o`000?ooo`80o`000`3oool30?l000050?ooo`3o0000oooo0?ooo`3o0000;03oool20?l00180oooo
00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0080oooo
0`3o00030?ooo`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool00`3oool20?l000T0oooo
00<0o`000?ooo`3o00000`3oool20?l000@0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`00
0180oooo00@0o`000?ooo`3oool0o`003@3oool00`000000oooo0?ooo`0W0?ooo`00@@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0<0?ooo`80o`00103oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool3
0?l000D0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo0P3o00040?ooo`80o`00103oool2
0?l000<0oooo00L0o`000?ooo`3o0000o`000?ooo`3o0000oooo00<0o`00103oool00`3o0000oooo
0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?l000030?ooo`80o`000P3oool20?l000030?ooo`3o0000o`0000X0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`0F0?ooo`050?l0003oool0oooo0?ooo`3o0000203oool01`3o0000
oooo0?l0003oool0o`000?ooo`3o0000403oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l0000?0?ooo`80o`000`3oool0
103o0000oooo0?ooo`3o00020?ooo`040?l0003oool0oooo0?l000<0oooo00<0o`000?ooo`3o0000
0P3oool0103o0000oooo0?ooo`3o000<0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0240oooo0P3o00000`3oool0
o`000?l000030?ooo`040?l0003oool0o`000?ooo`80o`000`3oool30?l000050?ooo`3o0000oooo
0?ooo`3o0000;03oool20?l00180oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0G
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00000`3oool01@3o0000oooo0?l0003o
ool0o`000080oooo00<0o`000?ooo`3oool00`3oool20?l000T0oooo00<0o`000?ooo`3o00000`3o
ool20?l000@0oooo0P3o00020?ooo`040?l0003oool0o`000?l00140oooo00@0o`000?ooo`3oool0
o`003@3oool00`000000oooo0?ooo`0W0?ooo`00@@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`80
o`00103oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool00`3o0000oooo0?l000050?ooo`03
0?l0003oool0oooo0080oooo0P3o00040?ooo`80o`00103oool20?l000@0oooo0P3o00040?ooo`<0
o`0000<0oooo0?l0003oool00`3o00040?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0o`000?l00080oooo0P3o00020?oo
o`80o`0000<0oooo0?l0003o00002P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
01H0oooo00D0o`000?ooo`3oool0oooo0?l000080?ooo`070?l0003oool0o`000?ooo`3o0000oooo
0?l0000@0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?l000030?ooo`030?l0003oool0o`0000l0oooo0P3o00030?ooo`040?l0003oool0oooo0?l00080
oooo00@0o`000?ooo`3oool0o`000`3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0oooo
0?l000`0oooo00<0o`000?ooo`3oool00`3oool20?l000`0oooo0P3o00050?ooo`030?l0003oool0
oooo0240oooo0P3o00000`3oool0o`000?l000030?ooo`<0o`000P3oool0103o0000oooo0?ooo`3o
ool30?l000050?ooo`3o0000oooo0?ooo`3o0000;03oool20?l00180oooo00<0o`000?ooo`3oool0
:`3oool0103o0000oooo0?ooo`3o000F0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
00000`3oool01P3o0000oooo0?l0003oool0o`000?ooo`80o`001@3oool20?l000T0oooo00<0o`00
0?ooo`3o00000`3oool00`3o0000oooo0?l000030?ooo`80o`000P3oool0103o0000oooo0?l0003o
000A0?ooo`040?l0003oool0oooo0?l000d0oooo00<000000?ooo`3oool09`3oool002`0oooo2P00
000<0?ooo`@00000103oool4000000/0oooo00<000000?ooo`3oool0303oool20?l000@0oooo00<0
o`000?ooo`3oool00`3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o00001@3oool00`3o0000
oooo0?ooo`020?ooo`80o`001@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool30?l000040?ooo`3o0000o`000?ooo`80o`00103oool00`3o
0000oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0103o
0000oooo0?l0003o00020?ooo`80o`000P3oool20?l000050?ooo`3o0000o`000?ooo`3o0000203o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01H0oooo00D0o`000?ooo`3oool0oooo
0?l000080?ooo`070?l0003oool0o`000?ooo`3o0000oooo0?l0000@0?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?l000030?ooo`040?l0003oool0oooo
0?l000h0oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o00020?ooo`040?l0003o
ool0oooo0?l000<0oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o000<0?ooo`03
0?l0003oool0oooo00<0oooo0P3o000<0?ooo`80o`001@3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo01/0oooo0P3o00000`3oool0o`000?l000030?ooo`<0o`000P3oool0103o0000
oooo0?ooo`3oool30?l000050?ooo`3o0000oooo0?ooo`3o0000;03oool20?l00180oooo00<0o`00
0?ooo`3oool0:`3oool0103o0000oooo0?ooo`3o000F0?ooo`030?l0003oool0oooo0080oooo00@0
o`000?ooo`3oool0o`000P3oool01P3o0000oooo0?l0003oool0o`000?ooo`80o`00103oool00`3o
0000oooo0?l000030?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3o0000o`000P3oool0
0`3o0000oooo0?l000030?ooo`80o`000P3oool0103o0000oooo0?ooo`3o000A0?ooo`040?l0003o
ool0oooo0?l000d0oooo00<000000?ooo`3oool09`3oool002`0oooo2P00000S0?ooo`<00000303o
ool20?l000@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`<0o`0000@0
oooo0?l0003o0000oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
103oool20?l000@0oooo0P3o00030?ooo`040?l0003oool0o`000?l00080oooo0P3o00020?ooo`03
0?l0003oool0oooo0080o`0000H0oooo0?l0003oool0o`000?ooo`3o00040?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool05P3oool01@3o0000oooo0?ooo`3oool0o`0000P0oooo00L0
o`000?ooo`3o0000oooo0?l0003oool0o`000100oooo00<0o`000?ooo`3oool0203oool20?l000<0
oooo00<0o`000?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000>0?ooo`030?l0003oool0o`00
0080oooo00@0o`000?ooo`3oool0o`000P3oool0103o0000oooo0?ooo`3o00030?ooo`030?l0003o
ool0o`000080oooo0P3o00000`3oool0o`000?ooo`0;0?ooo`030?l0003oool0oooo00<0oooo0P3o
000<0?ooo`80o`00103oool20?l000D0oooo00<0o`000?ooo`3oool06`3oool20?l000030?ooo`3o
0000o`0000<0oooo0`3o00020?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0P3o00030?ooo`03
0?l0003oool0oooo02X0oooo0P3o00040?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3o
ool0:`3oool0103o0000oooo0?ooo`3o000E0?ooo`030?l0003oool0o`0000<0oooo00@0o`000?oo
o`3oool0o`000P3oool01P3o0000oooo0?l0003oool0o`000?ooo`80o`00103oool00`3o0000oooo
0?l000030?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3o0000o`000P3oool01P3o0000
oooo0?l0003oool0o`000?ooo`80o`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?ooo`0?
0?ooo`040?l0003oool0oooo0?l000d0oooo00<000000?ooo`3oool09`3oool002`0oooo2P00000S
0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080oooo0`3o00000`3oool0o`000?l000020?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool20?l000D0oooo0P3o00040?ooo`80o`000`3oool0
103o0000oooo0?l0003o00020?ooo`80o`000P3oool0203o0000oooo0?ooo`3oool0o`000?ooo`3o
0000oooo0`3o00040?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool05P3oool01@3o
0000oooo0?ooo`3oool0o`0000P0oooo00L0o`000?ooo`3o0000oooo0?l0003oool0o`0000l0oooo
0P3o00030?ooo`030?l0003oool0oooo00@0oooo0P3o00030?ooo`030?l0003oool0o`0000<0oooo
00@0o`000?ooo`3oool0o`003P3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?oo
o`80o`000`3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o00000P3oool20?l000030?ooo`3o
0000oooo00/0oooo00<0o`000?ooo`3oool00`3oool20?l000/0oooo00<0o`000?ooo`3o0000103o
ool20?l000D0oooo00<0o`000?ooo`3oool0603oool01@3o0000oooo0?ooo`3o0000oooo00<0o`00
0`3oool00`3o0000oooo0?l000020?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0P3o00030?oo
o`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?ooo`0;0?oo
o`030?l0003oool0oooo02/0oooo00@0o`000?ooo`3oool0o`005@3oool00`3o0000oooo0?l00003
0?ooo`060?l0003oool0oooo0?l0003oool0o`000P3oool01`3o0000oooo0?l0003oool0o`000?oo
o`3o00000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0oooo00<0oooo00@0o`000?oo
o`3o0000o`000P3oool0103o0000oooo0?l0003oool20?l000040?ooo`3o0000oooo0?l000<0oooo
00<0o`000?ooo`3oool03`3oool0103o0000oooo0?ooo`3o000=0?ooo`030000003oool0oooo02L0
oooo000/0?ooo`X000008`3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`<0o`0000<0oooo0?l0003o0000
0P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo0P3o00050?ooo`80o`00
103oool30?l00080oooo00H0o`000?ooo`3o0000oooo0?l0003oool20?l00080oooo00H0o`000?oo
o`3oool0oooo0?l0003oool20?l00080oooo00<0o`000?ooo`3oool00P3oooli0000o`X0oooo0P3o
00030?ooo`030?l0003oool0oooo00@0oooo0P3o00030?ooo`030?l0003oool0o`0000<0oooo00@0
o`000?ooo`3oool0o`003P3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?ooo`80
o`000`3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o00000P3oool20?l000030?ooo`3o0000
oooo00/0oooo00<0o`000?ooo`3oool00`3oool20?l000030?ooo`3o0000oooo00P0oooo00<0o`00
0?ooo`3o0000103oool20?l00080oooo00@0o`000?ooo`3oool0o`006P3oool01@3o0000oooo0?oo
o`3o0000oooo00<0o`000`3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0o`000?l00080
oooo0P3o00030?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool0503oool00`3o0000
oooo0?l000030?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0:`3oool0103o0000
oooo0?ooo`3o000E0?ooo`030?l0003oool0o`0000<0oooo00@0o`000?ooo`3oool0oooo0P3o0002
0?ooo`070?l0003oool0o`000?ooo`3o0000oooo0?l000030?ooo`040?l0003oool0oooo0?l00080
oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?l0003o00020?ooo`040?l0003oool0o`00
0?ooo`80o`0000@0oooo0?l0003oool0o`000`3oool00`3o0000oooo0?ooo`0<0?ooo`040?l0003o
ool0oooo0?l00080oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`0W0?ooo`00;03o
ool:000002<0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`<0o`0000<0
oooo0?l0003o00000P3oool0103o0000oooo0?ooo`3oool20?l000@0oooo0P3o00050?ooo`80o`00
103oool00`3o0000oooo0?l000020?ooo`040?l0003oool0o`000?ooo`80o`0000@0oooo0?l0003o
ool0o`00E`000?l00`3o0000oooo0?ooo`040?ooo`80o`000`3oool00`3o0000oooo0?l000030?oo
o`040?l0003oool0oooo0?l000h0oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o
ool20?l000<0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`000080oooo103o000<0?ooo`03
0?l0003oool0o`0000<0oooo0P3o00000`3oool0o`000?ooo`080?ooo`040?l0003oool0oooo0?l0
00<0oooo0P3o00020?ooo`040?l0003oool0oooo0?l001X0oooo00D0o`000?ooo`3oool0o`000?oo
o`020?l000@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?l000030?ooo`80o`00103o
ool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3o00000`3o
ool20?l000`0oooo00<0o`000?ooo`3oool0:`3oool0103o0000oooo0?ooo`3o000E0?ooo`030?l0
003oool0o`000080oooo0P3o00030?ooo`80o`000P3oool01`3o0000oooo0?l0003oool0o`000?oo
o`3o00000`3oool0103o0000oooo0?ooo`3o00020?ooo`<0o`000`3oool01P3o0000oooo0?ooo`3o
0000oooo0?l000<0oooo0`3o0000103oool0o`000?ooo`3o00030?ooo`030?l0003oool0oooo00`0
oooo00@0o`000?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo
02L0oooo000/0?ooo`X000008`3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00l0
oooo00<0o`000?ooo`3oool00P3o00030?ooo`030?l0003oool0oooo0080o`00103oool20?l000@0
oooo00<0o`000?ooo`3o00000`3oool0103o0000oooo0?ooo`3o00020?oooaX0003o00@0oooo0?l0
003oool0oooo0P3o00001@3oool0o`000?l0003oool0o`0001@0oooo00D0o`000?ooo`3oool0oooo
0?l000070?ooo`0<0?l0003oool0oooo0?l0003oool0o`000?ooo`3o0000oooo0?l0003oool0o`00
6`000?l0103oool0o`000?ooo`3o00030?ooo`040?l0003oool0oooo0?l000/0oooo00H0o`000?oo
o`3oool0o`000?ooo`3o00020?ooo`040?l0003oool0oooo0?ooo`80o`000`3oool01`3o0000oooo
0?ooo`3oool0o`000?ooo`3o00000P3oool40?l000`0oooo00<0o`000?ooo`3o00000`3oool20?l0
00030?ooo`3o0000oooo00P0oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?l0003o
ool0o`000080oooo00@0o`000?ooo`3oool0o`001P3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00P0oooo00D0o`000?ooo`3oool0o`000?ooo`020?l000@0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`020?ooo`80o`00103oool01@3o0000oooo0?ooo`3oool0o`00
0100oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0o`00
00<0oooo0P3o000<0?ooo`030?l0003oool0oooo02/0oooo0P3o00000`3oool0o`000?ooo`0D0?oo
o`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool00P3oool20?l00080oooo00L0o`000?oo
o`3o0000oooo0?l0003oool0o`0000<0oooo00@0o`000?ooo`3oool0o`000P3oool30?l000<0oooo
00@0o`000?ooo`3oool0oooo0P3o00030?ooo`070?l0003oool0o`000?ooo`3o0000oooo0?l00004
0?ooo`030?l0003oool0oooo00/0oooo00@0o`000?ooo`3oool0o`000P3oool00`3o0000oooo0?oo
o`0;0?ooo`030000003oool0oooo02L0oooo001I0?ooo`030000003oool0oooo00d0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01D0oooo00<0o`00
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`020?l000<0oooo0P3o0000103oool0o`000?ooo`3o
00030?ooo`80o`00103oool00`3o0000oooo0?l0000D0000o`@0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0o`000080oooo0P3o00001@3oool0o`000?l0
003oool0o`000140oooo00@0o`000?ooo`3oool0o`000P3oool20?l000L0oooo00@0o`000?ooo`3o
ool0oooo0P3o00020?ooo`80o`0000<0oooo0?l0003oool02P3oool20?l00080oooo5@000?l00`3o
ool0o`000?ooo`0:0?ooo`040?l0003oool0oooo0?l00080oooo00<0o`000?ooo`3o0000103oool0
1@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3o00000P3oool30?l000030?ooo`3o
0000oooo00X0oooo00<0o`000?ooo`3o00000P3oool01@3o0000oooo0?l0003oool0o`0000T0oooo
00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?l0003oool0o`000080oooo0P3o00000`3o
ool0o`000?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool20?l0
00030?ooo`3o0000oooo0080o`00103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo0P3o00040?ooo`050?l0003oool0oooo0?ooo`3o0000403oool20?l000@0oooo00<0o`00
0?ooo`3oool03@3oool0103o0000oooo0?ooo`3o00030?ooo`80o`00303oool00`3o0000oooo0?oo
o`0[0?ooo`80o`0000<0oooo0?l0003oool03@3oool00`3o0000oooo0?ooo`040?ooo`060?l0003o
ool0o`000?l0003oool0o`00103oool20?l00080oooo0`3o0000103oool0o`000?ooo`3o00030?oo
o`040?l0003oool0oooo0?l00080oooo0`3o00030?ooo`040?l0003oool0oooo0?ooo`80o`000`3o
ool01`3o0000oooo0?l0003oool0o`000?ooo`3o0000103oool0103o0000oooo0?ooo`3o000:0?oo
o`040?l0003oool0oooo0?l00080oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`0W
0?ooo`00=P3oool300000200oooo0`00000=0?ooo`030?l0003oool0oooo0380oooo00<0o`000?oo
o`3oool01@3oool20?l000040?ooo`3o0000oooo0?l000<0oooo4`000?l30?ooo`060?l0003oool0
oooo0?l0003oool0o`001@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3o00000P3oool20?l000050?ooo`3o0000o`000?ooo`3o00004@3oool0103o0000
oooo0?ooo`3o00020?ooo`030?l0003oool0o`0000H0oooo00@0o`000?ooo`3oool0oooo0P3o0002
0?ooo`80o`0000<0oooo0?l0003oool02P3oool20?l00080oooo0P3o00050?ooo`040?l0003oool0
o`000?oooa80003o1@3oool0103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0o`0000@0oooo
00<0o`000?ooo`3oool00P3oool30?l00080oooo00<0o`000?ooo`3oool00`3o00000`3oool0o`00
0?ooo`0:0?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool00P3o00090?ooo`040?l0
003oool0oooo0?l000<0oooo00D0o`000?ooo`3o0000oooo0?l000020?ooo`80o`0000<0oooo0?l0
003oool01@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool20?l000040?ooo`3o0000oooo0?l00140oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?l000/0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo00<0o`00
0?ooo`3oool03@3oool01`3o0000oooo0?ooo`3o0000oooo0?l0003oool00P3o000<0?ooo`030?l0
003oool0oooo02/0oooo0P3o00000`3oool0o`000?ooo`0=0?ooo`030?l0003oool0oooo00@0oooo
00H0o`000?ooo`3o0000o`000?ooo`3o00040?ooo`80o`000P3oool30?l000040?ooo`3o0000oooo
0?l000<0oooo00@0o`000?ooo`3oool0o`000P3oool30?l000<0oooo00@0o`000?ooo`3oool0oooo
0P3o00030?ooo`040?l0003oool0o`000?ooo`80o`001@3oool0103o0000oooo0?ooo`3o000:0?oo
o`040?l0003oool0oooo0?l00080oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`0W
0?ooo`00<`3oool3000002<0oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`050?oo
o`80o`004@000?l20?ooo`060?l0003oool0oooo0?l0003oool0o`001`3oool00`3o0000oooo0?l0
000:0?ooo`030?l0003oool0oooo0080oooo00P0o`000?ooo`3o0000oooo0?l0003oool0o`000?oo
o`80o`0000<0oooo0?l0003oool03P3oool00`3o0000oooo0?l000020?ooo`80o`0000@0oooo0?l0
003oool0o`001P3oool0103o0000oooo0?ooo`3oool20?l00080oooo0P3o00000`3oool0o`000?oo
o`0:0?ooo`040?l0003oool0o`000?ooo`80o`001@3oool00`3o0000oooo0?l000020?ooo`040?l0
003oool0oooo0?l00080oooo00<0o`000?ooo`000?l040000?l30?ooo`030?l0003oool0o`0000@0
oooo00<0o`000?ooo`3oool00P3oool30?l00080oooo00<0o`000?ooo`3oool00`3o00000`3oool0
o`000?ooo`0:0?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool00P3o00040?ooo`03
0?l0003oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0o`00
0?ooo`3o00000P3oool20?l000030?ooo`3o0000oooo00D0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P3o0000103oool0o`000?ooo`3o
000A0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3o000;0?ooo`80o`000`3o
ool20?l000@0oooo00<0o`000?ooo`3oool03@3oool01`3o0000oooo0?ooo`3o0000oooo0?l0003o
ool00P3o00040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0:`3oool20?l00003
0?ooo`3o0000oooo00d0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?l000030?l000D0
oooo00@0o`000?ooo`3oool0oooo0P3o0000103oool0o`000?ooo`3o00030?ooo`040?l0003oool0
oooo0?l00080oooo00@0o`000?ooo`3oool0o`000P3oool0103o0000oooo0?ooo`3oool20?l000D0
oooo00@0o`000?ooo`3o0000o`001@3oool0103o0000oooo0?ooo`3o000:0?ooo`040?l0003oool0
oooo0?l00100oooo00<000000?ooo`3oool09`3oool00300oooo0`00000V0?ooo`030000003oool0
oooo04D0oooo3`000?l0103oool0o`000?ooo`3oool20?l00080oooo00@0o`000?ooo`3oool0o`00
0`3oool20?l000P0oooo0P3o000:0?ooo`030?l0003oool0oooo0080oooo00X0o`000?ooo`3o0000
oooo0?l0003oool0o`000?ooo`3o0000oooo0P3o00050?ooo`030?l0003oool0oooo00L0oooo00H0
o`000?ooo`3o0000oooo0?l0003oool30?l000030?ooo`3o0000oooo00D0oooo00@0o`000?ooo`3o
ool0oooo0P3o00020?ooo`80o`0000<0oooo0?l0003oool02P3oool0103o0000oooo0?l0003oool2
0?l000D0oooo00H0o`000?ooo`3oool0o`000?ooo`3o00030?ooo`030?l0003oool0o`0000<0oooo
00<0o`000?ooo`3oool00`3oool@0000o`P0oooo0`3o00020?ooo`030?l0003oool0oooo00<0o`00
00<0oooo0?l0003oool02P3oool01P3o0000oooo0?l0003o0000oooo0?l00080oooo0P3o00001`3o
ool0o`000?ooo`3oool0o`000?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`000080oooo
00D0o`000?ooo`3o0000oooo0?l000020?ooo`80o`0000<0oooo0?l0003oool0103oool20?l000D0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`<0o`000P3oool00`3o0000
oooo0?ooo`0?0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3o000;0?ooo`80
o`000`3oool20?l000@0oooo00<0o`000?ooo`3oool02P3oool0103o0000oooo0?ooo`3o00020?oo
o`040?l0003oool0o`000?ooo`80o`00103oool00`3o0000oooo0?ooo`050?ooo`80o`00;03oool2
0?l000030?ooo`3o0000oooo00d0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?l00003
0?l000D0oooo00@0o`000?ooo`3oool0oooo0P3o0000103oool0o`000?ooo`3o00030?ooo`040?l0
003oool0oooo0?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`3o00040?ooo`80o`001`3oool2
0?l000D0oooo00@0o`000?ooo`3oool0o`002P3oool0103o0000oooo0?ooo`3o000@0?ooo`030000
003oool0oooo02L0oooo000]0?ooo`<00000:@3oool00`000000oooo0?ooo`0m0?oooa00003o00<0
o`000?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`80o`000P3oool0103o0000oooo0?l0
003o00030?ooo`80o`00203oool20?l000X0oooo00<0o`000?ooo`3oool00P3oool02P3o0000oooo
0?l0003oool0o`000?ooo`3o0000oooo0?l0003oool20?l000D0oooo00<0o`000?ooo`3oool01`3o
ool01P3o0000oooo0?l0003oool0o`000?ooo`<0o`0000<0oooo0?l0003oool01@3oool0103o0000
oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3o00002`3oool0103o0000oooo0?l0003oool3
0?l000@0oooo00H0o`000?ooo`3oool0o`000?ooo`3o00030?ooo`030?l0003oool0o`0000<0oooo
00<0o`000?ooo`3oool02@3oool20?l000h0003o0P3oool30?l00080oooo00<0o`000?ooo`3oool0
0`3o00000`3oool0o`000?ooo`0:0?ooo`060?l0003oool0o`000?l0003oool0o`000P3oool00`3o
0000oooo0?l000020?l000040?ooo`3o0000oooo0?l00080oooo00D0o`000?ooo`3oool0oooo0?l0
00020?ooo`050?l0003oool0o`000?ooo`3o00000P3oool20?l000030?ooo`3o0000oooo00@0oooo
0P3o00050?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool30?l00080oooo
00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0o`000?ooo`3o
00002`3oool20?l000<0oooo0P3o00030?ooo`<0o`00103oool00`3o0000oooo0?ooo`040?ooo`04
0?l0003oool0oooo0?l00080oooo00L0o`000?ooo`3o0000oooo0?l0003oool0o`0000<0oooo00<0
o`000?ooo`3oool01@3oool20?l002`0oooo0P3o00000`3oool0o`000?ooo`0=0?ooo`030?l0003o
ool0oooo00@0oooo00@0o`000?ooo`3o0000oooo0P3o00050?ooo`040?l0003oool0oooo0?ooo`80
o`0000<0oooo0?l0003oool00P3o00020?ooo`040?l0003oool0oooo0?l00080oooo00H0o`000?oo
o`3oool0o`000?ooo`3o00040?ooo`80o`00203oool00`3o0000oooo0?ooo`030?ooo`040?l0003o
ool0oooo0?l000T0oooo0P3o00020?ooo`030?l0003oool0oooo00h0oooo00<000000?ooo`3oool0
9`3oool002`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0g0?ooo`l0003o103o
ool20?l000040?ooo`3o0000oooo0?l000<0oooo00<0o`000?ooo`3o00000P3oool20?l00080oooo
00@0o`000?ooo`3o0000o`000`3oool20?l000P0oooo0P3o000:0?ooo`030?l0003oool0o`0000<0
o`0000T0oooo0?l0003o0000o`000?ooo`3o0000oooo0?l0003oool00P3o00050?ooo`030?l0003o
ool0oooo00<0oooo00X0o`000?ooo`3oool0oooo0?l0003oool0o`000?ooo`3o0000oooo0`3o0000
0`3oool0o`000?ooo`050?ooo`040?l0003oool0oooo0?ooo`80o`000`3oool00`3o0000oooo0?l0
000;0?ooo`070?l0003oool0o`000?ooo`3o0000oooo0?l000040?ooo`060?l0003oool0oooo0?l0
003oool0o`000`3oool00`3o0000oooo0?l000030?ooo`030?l0003oool0oooo00T0oooo0`3o0004
0?ooo`80o`003P000?l0203o0000oooo0?ooo`3o0000oooo0?l0003oool0o`002`3oool01P3o0000
oooo0?l0003o0000oooo0?l00080oooo00<0o`000?ooo`3o00000P3o0000103oool0o`000?ooo`3o
00020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?l0003oool0o`000080
oooo0P3o00000`3oool0o`000?ooo`040?ooo`80o`001@3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo0`3o00020?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3o
ool00P3oool01@3o0000oooo0?l0003oool0o`0000/0oooo0P3o00020?ooo`<0o`000`3oool30?l0
00@0oooo00<0o`000?ooo`3oool0103oool20?l0000;0?ooo`3o0000oooo0?ooo`3o0000oooo0?l0
003oool0o`000?ooo`3o00000`3oool00`3o0000oooo0?ooo`050?ooo`80o`00;03oool20?l00003
0?ooo`3o0000oooo00d0oooo00<0o`000?ooo`3oool0103oool0103o0000oooo0?ooo`3oool20?l0
00D0oooo00@0o`000?ooo`3oool0oooo0P3o00000`3oool0o`000?ooo`020?l00080oooo00H0o`00
0?ooo`3oool0o`000?ooo`3o00030?ooo`030?l0003oool0o`0000@0oooo0P3o000>0?ooo`040?l0
003oool0o`000?l000T0oooo0P3o00020?ooo`030?l0003oool0oooo00h0oooo00<000000?ooo`3o
ool09`3oool005T0oooo0`00000a0?ooo`d0003o303oool20?l000030?ooo`3o0000oooo0080o`00
0P3oool00`3o0000oooo0?l000020?ooo`80o`000P3oool0103o0000oooo0?l0003o00030?ooo`80
o`00203oool20?l000X0oooo00<0o`000?ooo`3o00000`3o0000103oool0o`000?l0003o00030?oo
o`050?l0003oool0o`000?ooo`3o0000103oool00`3o0000oooo0?ooo`030?ooo`0:0?l0003oool0
oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`<0o`0000<0oooo0?l0003oool01@3oool0103o
0000oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3o00002`3oool01P3o0000oooo0?l0003o
ool0o`000?ooo`80o`000`3oool01P3o0000oooo0?ooo`3o0000oooo0?l000<0oooo00<0o`000?oo
o`3o00000`3oool0103o0000oooo0?ooo`3o00070?ooo`040?l0003oool0o`000?l000@0oooo0P3o
00050?ooo`l0003o00<0oooo0?l0003oool01P3oool01P3o0000oooo0?ooo`3oool0o`000?ooo`@0
o`000P3oool00`3o0000oooo0?l000020?l000040?ooo`3o0000oooo0?l00080oooo00D0o`000?oo
o`3oool0oooo0?l000020?ooo`040?l0003oool0o`000?ooo`80o`0000D0oooo0?l0003o0000oooo
0?l000020?ooo`060?l0003oool0oooo0?l0003oool0o`00103oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo0`3o00020?ooo`030?l0003oool0oooo00l0oooo00<0o`000?oo
o`3oool00P3oool01@3o0000oooo0?l0003oool0o`0000/0oooo0P3o00020?ooo`<0o`000`3oool0
0`3o0000oooo0?l000040?ooo`80o`001@3oool20?l0000;0?ooo`3o0000oooo0?ooo`3o0000oooo
0?l0003oool0o`000?ooo`3o00000`3oool00`3o0000oooo0?ooo`050?ooo`80o`00;03oool20?l0
00030?ooo`3o0000oooo00d0oooo00<0o`000?ooo`3oool0103oool0103o0000oooo0?ooo`3oool2
0?l000D0oooo00@0o`000?ooo`3oool0oooo0P3o00000`3oool0o`000?ooo`030?l000070?ooo`3o
0000oooo0?ooo`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000@0oooo0P3o000>0?ooo`04
0?l0003oool0o`000?l000T0oooo0P3o00000`3oool0o`000?l0000@0?ooo`030000003oool0oooo
02L0oooo000/0?ooo`X000008`3oool00`000000oooo0?ooo`0[0?ooo`h0003o4@3oool20?l00005
0?ooo`3o0000oooo0?ooo`3o00000P3oool00`3o0000oooo0?l000020?ooo`070?l0003oool0oooo
0?ooo`3o0000oooo0?l000040?ooo`80o`00203oool20?l000X0oooo00@0o`000?ooo`3o0000oooo
0P3o0000103oool0o`000?l0003o00030?ooo`050?l0003oool0o`000?ooo`3o0000103oool00`3o
0000oooo0?ooo`030?ooo`0:0?l0003oool0oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`<0
o`0000<0oooo0?l0003oool01@3oool0103o0000oooo0?ooo`3oool20?l000<0oooo0`3o000;0?oo
o`060?l0003oool0o`000?ooo`3o0000oooo0P3o00030?ooo`060?l0003oool0oooo0?l0003oool0
o`000`3oool00`3o0000oooo0?l000030?ooo`040?l0003oool0oooo0?l000L0oooo00@0o`000?oo
o`3o0000o`00103oool20?l000T0oooo0`3o00000`3oool0003o0000o`090000o`D0oooo00P0o`00
0?ooo`3oool0oooo0?l0003oool0o`000?ooo`80o`000P3oool00`3o0000oooo0?l000020?l00004
0?ooo`3o0000oooo0?l00080oooo00<0o`000?ooo`3oool00P3oool01P3o0000oooo0?l0003oool0
o`000?ooo`80o`0000D0oooo0?l0003o0000oooo0?l000020?ooo`060?l0003oool0oooo0?l0003o
ool0o`00103oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo0?ooo`80o`0000D0oooo
0?l0003oool0oooo0?l0000A0?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3o0000oooo
0P3o000:0?ooo`80o`000P3oool30?l000<0oooo00<0o`000?ooo`3o0000103oool20?l000D0oooo
0P3o00001P3oool0o`000?ooo`3oool0o`000?ooo`80o`000P3oool0103o0000oooo0?ooo`3oool2
0?l000H0oooo0P3o000/0?ooo`@0o`003P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`3oool20?l000030?ooo`3o
0000oooo00<0o`0000L0oooo0?l0003oool0oooo0?l0003oool0o`0000<0oooo00<0o`000?ooo`3o
0000103oool20?l000l0oooo0`3o00090?ooo`80o`0000<0oooo0?l0003o0000403oool00`000000
oooo0?ooo`0W0?ooo`00;@3oool2000002X0oooo00<000000?ooo`3oool09@3oool=0000oaT0oooo
0P3o00030?ooo`060?l0003oool0oooo0?l0003oool0o`000P3oool01`3o0000oooo0?ooo`3oool0
o`000?ooo`3o0000103oool00`3o0000oooo0?ooo`070?ooo`80o`002P3oool0103o0000oooo0?l0
003oool20?l000030?ooo`3o0000o`0000P0oooo00H0o`000?ooo`3oool0o`000?ooo`3o00040?oo
o`80o`000`3oool30?l000030?ooo`3o0000oooo0080o`000P3oool20?l000D0oooo00@0o`000?oo
o`3oool0oooo0P3o00040?ooo`030?l0003oool0o`0000X0oooo00<0o`000?ooo`3o00000P3o0000
103oool0o`000?ooo`3o00020?ooo`040?l0003oool0oooo0?ooo`80o`000`3oool30?l000<0oooo
00@0o`000?ooo`3oool0o`001`3oool0103o0000oooo0?l0003o00040?ooo`80o`002@3oool00`3o
0000oooo0?l000030?ooo`040?l0003oool0o`000?ooo`/0003o0`3oool0103o0000oooo0?l0003o
ool20?l00080oooo00<0o`000?ooo`3o0000103o00001@3oool0o`000?ooo`3oool0o`0000@0oooo
00H0o`000?ooo`3o0000oooo0?l0003oool20?l000040?ooo`3o0000o`000?ooo`@0o`000P3oool0
0`3o0000oooo0?l000040?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0oooo0P3o
00001@3oool0o`000?ooo`3oool0o`000140oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo
0?l0003oool20?l000@0oooo00<0o`000?ooo`3oool00`3oool01@3o0000oooo0?l0003o0000oooo
0080o`000`3oool00`3o0000oooo0?l000040?ooo`80o`001@3oool0103o0000oooo0?l0003o0002
0?ooo`040?l0003oool0o`000?l00080oooo00@0o`000?ooo`3oool0oooo0P3o00060?ooo`80o`00
;03oool40?l000h0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20?l00080oooo0`3o0000103oool0o`00
0?ooo`3oool30?l000@0oooo0P3o00050?ooo`030?l0003oool0oooo00d0oooo0`3o00090?ooo`80
o`0000<0oooo0?l0003oool0403oool00`000000oooo0?ooo`0W0?ooo`00;`3oool2000002P0oooo
00<000000?ooo`3oool07`3oool=0000ob00oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`03
0?l0003oool0o`000080oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`0000@0oooo00<0o`00
0?ooo`3oool01`3oool20?l000X0oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?l0003o
00080?ooo`050?l0003oool0oooo0?l0003oool00P3o00030?ooo`030?l0003oool0o`000080oooo
0`3o00000`3oool0o`000?ooo`020?l00080oooo0P3o00050?ooo`040?l0003oool0oooo0?ooo`80
o`00103oool00`3o0000oooo0?l0000:0?ooo`030?l0003oool0o`000080o`0000@0oooo0?l0003o
ool0o`000P3oool0103o0000oooo0?ooo`3oool20?l000<0oooo0`3o00030?ooo`040?l0003oool0
oooo0?l000D0oooo00@0o`000?ooo`3o0000oooo0P3o00050?ooo`030?l0003oool0oooo00T0oooo
00L0o`000?ooo`3oool0oooo0?l0003oool0o`0000<0oooo00<0o`000?ooo`000?l02`000?l0103o
0000oooo0?l0003o00020?ooo`030?l0003oool0o`0000H0o`000P3oool00`3o0000oooo0?ooo`02
0?ooo`060?l0003oool0o`000?ooo`3o0000oooo0P3o0000103oool0o`000?l0003oool40?l00080
oooo00<0o`000?ooo`3o0000103oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0o`000?oo
o`80o`0000D0oooo0?l0003oool0oooo0?l0000A0?ooo`030?l0003oool0oooo0080oooo00@0o`00
0?ooo`3o0000oooo0P3o00040?ooo`080?l0003oool0oooo0?ooo`3o0000oooo0?l0003oool20?l0
00030?ooo`3o0000o`0000<0oooo00<0o`000?ooo`3o0000103oool20?l000030?ooo`3o0000o`00
0080oooo00@0o`000?ooo`3o0000o`000P3oool0103o0000oooo0?l0003o00030?ooo`030?l0003o
ool0oooo0080o`001P3oool20?l001P0oooo00<0o`000?ooo`3oool04@3oool40?l000h0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool20?l000<0oooo0P3o0000103oool0o`000?ooo`3oool30?l000@0oooo
0P3o00050?ooo`030?l0003oool0oooo00d0oooo0`3o00090?ooo`80o`0000<0oooo0?l0003oool0
403oool00`000000oooo0?ooo`0W0?ooo`00<@3oool3000002D0oooo00<000000?ooo`3oool06@3o
ool=0000obH0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0o`000080oooo
00L0o`000?ooo`3oool0oooo0?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool01`3oool20?l0
00/0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`0000T0oooo00D0o`000?ooo`3oool0o`00
0?ooo`020?l000<0oooo00@0o`000?ooo`3o0000oooo103o00000`3oool0o`000?ooo`020?l00080
oooo0P3o00050?ooo`040?l0003oool0oooo0?ooo`80o`00103oool00`3o0000oooo0?l0000:0?oo
o`030?l0003oool0o`000080o`0000@0oooo0?l0003oool0o`000P3oool0103o0000oooo0?ooo`3o
ool20?l000<0oooo0`3o00030?ooo`040?l0003oool0oooo0?l000D0oooo00@0o`000?ooo`3o0000
oooo0P3o00050?ooo`030?l0003oool0oooo00T0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0
o`0000<0oooo00<0o`000?ooo`3oool01@3oool<0000o`070?l0003oool0oooo0?l0003oool0o`00
0?ooo`020?l00080oooo00<0o`000?ooo`3oool00P3oool01P3o0000oooo0?l0003oool0o`000?oo
o`80o`0000@0oooo0?l0003o0000oooo103o00001@3oool0o`000?ooo`3oool0o`0000@0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?l000030?l000050?ooo`3o0000oooo0?ooo`3o0000
4@3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0o`000?ooo`80o`00103oool0203o0000
oooo0?ooo`3oool0o`000?ooo`3o0000oooo0P3o00000`3oool0o`000?l000030?ooo`040?l0003o
ool0oooo0?l000<0oooo0P3o00000`3oool0o`000?l000020?ooo`040?l0003oool0oooo0?l000<0
oooo0`3o00030?ooo`030?l0003oool0oooo0080o`001@3oool00`3o0000oooo0?l0000H0?ooo`03
0?l0003oool0oooo0140oooo103o000>0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool30?l000<0oooo0`3o00040?ooo`80
o`001@3oool00`3o0000oooo0?ooo`0?0?ooo`060?l0003oool0oooo0?l0003oool0o`00103oool2
0?l000030?ooo`3o0000oooo0100oooo00<000000?ooo`3oool09`3oool003@0oooo0P00000S0?oo
o`030000003oool0oooo01<0oooo3@000?l/0?ooo`030?l0003oool0oooo0080oooo0P3o00030?oo
o`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o00003P3oool20?l000/0oooo00L0o`000?oo
o`3oool0oooo0?l0003oool0o`0000T0oooo00D0o`000?ooo`3oool0o`000?ooo`020?l000<0oooo
00@0o`000?ooo`3o0000oooo103o00000`3oool0o`000?ooo`020?l00080oooo0P3o00050?ooo`04
0?l0003oool0oooo0?ooo`80o`00103oool00`3o0000oooo0?l0000:0?ooo`030?l0003oool0o`00
0080o`000`3oool0103o0000oooo0?ooo`3o00030?ooo`80o`000`3oool30?l000<0oooo00@0o`00
0?ooo`3oool0o`001@3oool0103o0000oooo0?l0003oool20?l000D0oooo00<0o`000?ooo`3oool0
2@3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o0000103oool20?l000D0oooo0P3o00020?oo
o`030?l000000?l0003o00/0003o00<0oooo0?l0003o00000P3oool00`3o0000oooo0?ooo`020?oo
o`060?l0003oool0o`000?ooo`3o0000oooo0P3o0000103oool0o`000?l0003oool40?l000050?oo
o`3o0000oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0o`0000<0
o`0000D0oooo0?l0003oool0oooo0?l0000A0?ooo`030?l0003oool0oooo0080oooo00@0o`000?oo
o`3o0000oooo0P3o00040?ooo`030?l0003oool0oooo0080o`0000<0oooo0?l0003oool00P3o0002
0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool0103o0000oooo0?ooo`3oool20?l000030?oo
o`3o0000o`000080oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?l000030?ooo`030?l0
003oool0oooo0080o`001@3oool00`3o0000oooo0?l0000H0?ooo`030?l0003oool0oooo0100oooo
00<0o`000?ooo`3o00000P3o000>0?ooo`80o`00103oool20?l000X0oooo00<0o`000?ooo`3oool0
0P3oool20?l000<0oooo0`3o00030?ooo`<0o`00103oool20?l000D0oooo00<0o`000?ooo`3oool0
3`3oool01P3o0000oooo0?ooo`3o0000oooo0?l000@0oooo0P3o00000`3oool0o`000?ooo`0@0?oo
o`030000003oool0oooo02L0oooo000a0?ooo`<000009@3oool3000000l0oooo2`000?lb0?ooo`03
0?l0003oool0oooo0080oooo0P3o00030?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o
00003P3oool20?l000/0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`0000T0oooo00D0o`00
0?ooo`3oool0o`000?ooo`020?l000<0oooo00@0o`000?ooo`3o0000oooo103o0000103oool0o`00
0?ooo`3o00030?ooo`80o`001@3oool0103o0000oooo0?ooo`3oool20?l000@0oooo00<0o`000?oo
o`3o00002P3oool00`3o0000oooo0?l000020?l000<0oooo00@0o`000?ooo`3oool0o`000`3oool2
0?l000<0oooo0`3o00030?ooo`040?l0003oool0oooo0?l000D0oooo00<0o`000?ooo`3o00000P3o
ool00`3o0000oooo0?ooo`0?0?ooo`040?l0003oool0oooo0?ooo`<0o`00103oool20?l000D0oooo
0P3o00020?ooo`040?l0003oool0o`000?ooo`80o`0000<0oooo0000o`000?l02P000?l00`3o0000
oooo0?ooo`020?ooo`060?l0003oool0o`000?ooo`3o0000oooo0P3o0000103oool0o`000?l0003o
ool40?l000050?ooo`3o0000oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`020?ooo`80o`00
00D0oooo0?l0003o0000oooo0?l0000F0?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3o
0000oooo0P3o00040?ooo`050?l0003oool0oooo0?l0003oool00P3o00000`3oool0o`000?ooo`02
0?ooo`050?l0003oool0o`000?ooo`3o00000P3oool01P3o0000oooo0?l0003oool0o`000?ooo`<0
o`000P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o
ool00P3o00050?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3oool04P3oool00`3o0000
oooo0?ooo`0@0?ooo`030?l0003oool0o`000080o`003P3oool20?l000@0oooo0P3o000:0?ooo`03
0?l0003oool0oooo0080oooo0P3o00030?ooo`<0o`000`3oool30?l000@0oooo0P3o00050?ooo`03
0?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool00`3o00040?ooo`80o`0000<0oooo0?l0003o
ool0403oool00`000000oooo0?ooo`0W0?ooo`00;`3oool2000002P0oooo00<000000?ooo`3oool0
2`3oool90000ocP0oooo00<0o`000?ooo`3oool00P3oool20?l000<0oooo00<0o`000?ooo`3o0000
0`3oool00`3o0000oooo0?l0000>0?ooo`030?l0003oool0oooo00X0oooo00L0o`000?ooo`3oool0
oooo0?l0003oool0o`0000T0oooo00D0o`000?ooo`3oool0o`000?ooo`020?l000<0oooo00@0o`00
0?ooo`3o0000oooo103o0000103oool0o`000?ooo`3o00030?ooo`<0o`000`3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00002@3oool00`3o0000oooo
0?ooo`030?l000<0oooo00@0o`000?ooo`3oool0o`000`3oool20?l000<0oooo00<0o`000?ooo`3o
00000`3oool0103o0000oooo0?l0003o00050?ooo`030?l0003oool0o`000080oooo00<0o`000?oo
o`3oool03`3oool0103o0000oooo0?ooo`3oool30?l000@0oooo0P3o00050?ooo`80o`0000D0oooo
0?l0003o0000oooo0?l000020?ooo`030?l0003oool0oooo00D0oooo2`000?l20?l00080oooo00D0
o`000?ooo`3o0000o`000?ooo`020?l000030?ooo`3o0000o`000080o`0000L0oooo0?l0003oool0
oooo0?l0003oool0o`000080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?l000020?l0
00030?ooo`3o0000oooo01X0oooo00@0o`000?ooo`3o0000oooo0P3o00040?ooo`050?l0003oool0
oooo0?l0003oool00P3o00000`3oool0o`000?ooo`030?ooo`80o`0000<0oooo0?l0003oool00P3o
ool20?l000030?ooo`3o0000oooo00<0o`000P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0o`0000<0oooo0P3o00000`3oool0o`000?l000050?ooo`030?l0003oool0o`0000<0oooo00<0
o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0o`000080o`003P3o
ool20?l000040?ooo`3o0000oooo0?ooo`80o`002P3oool00`3o0000oooo0?ooo`020?ooo`80o`00
0`3oool30?l000<0oooo0`3o00040?ooo`80o`005`3oool00`3o0000oooo0?ooo`030?l000@0oooo
0P3o00000`3oool0o`000?ooo`020?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool0
9`3oool002d0oooo0P00000C0?ooo`@00000103oool4000000/0oooo00<000000?ooo`3oool02`3o
ool50000oc`0oooo00<0o`000?ooo`3oool00P3oool20?l000<0oooo00<0o`000?ooo`3o00000`3o
ool00`3o0000oooo0?l0000>0?ooo`030?l0003oool0oooo00X0oooo00L0o`000?ooo`3oool0oooo
0?l0003oool0o`0000T0oooo00D0o`000?ooo`3oool0o`000?ooo`020?l000<0oooo00@0o`000?oo
o`3o0000oooo103o0000103oool0o`000?ooo`3o00030?ooo`<0o`000`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00002@3oool00`3o0000oooo0?oo
o`030?l000<0oooo00@0o`000?ooo`3oool0o`00103oool01`3o0000oooo0?ooo`3oool0o`000?oo
o`3o00000`3oool0103o0000oooo0?l0003o00050?ooo`80o`000`3oool00`3o0000oooo0?ooo`0?
0?ooo`030?l0003oool0oooo0080oooo0P3o00050?ooo`030?l0003oool0oooo0080oooo00@0o`00
0?ooo`3o0000oooo0P3o00001@3oool0o`000?ooo`3oool0o`0000L0oooo00D0o`000?ooo`3o0000
o`000?ooo`0;0000o`040?ooo`3o0000o`000?ooo`80o`0000<0oooo0?l0003o00000P3o00001`3o
ool0o`000?ooo`3oool0o`000?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?ooo`040?l0003o
ool0o`000?l00080oooo00<0o`000?ooo`3oool06@3oool0103o0000oooo0?l0003oool20?l000@0
oooo00H0o`000?ooo`3oool0o`000?ooo`3o00070?ooo`80o`0000<0oooo0?l0003oool00P3oool3
0?l00080oooo00<0o`000?ooo`3o00000P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
o`0000<0oooo0`3o00000`3oool0o`000?ooo`040?ooo`030?l0003oool0o`0000<0oooo00<0o`00
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0o`000080o`003P3oool4
0?l00080oooo0P3o000:0?ooo`030?l0003oool0oooo0080oooo0P3o00030?ooo`<0o`000`3oool3
0?l000@0oooo0P3o000G0?ooo`060?l0003oool0oooo0?l0003oool0o`00103oool20?l000040?oo
o`3o0000oooo0?ooo`<0003o303oool00`000000oooo0?ooo`0W0?ooo`00;03oool:000000/0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0C03oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool00`3o0000
oooo0?l000030?ooo`030?l0003oool0o`0000h0oooo00<0o`000?ooo`3oool03P3oool00`3o0000
oooo0?l0000:0?ooo`060?l0003oool0o`000?l0003oool0o`000`3oool0103o0000oooo0?l0003o
ool40?l000040?ooo`3o0000oooo0?l000<0oooo0`3o00030?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3o00080?ooo`030?l0003oool0oooo0080
o`00103oool0103o0000oooo0?ooo`3o00040?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l0
00030?ooo`040?l0003oool0o`000?l000@0oooo0`3o00030?ooo`030?l0003oool0oooo01D0oooo
00<0o`000?ooo`3oool00`3oool02@3o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`04
0?l00080oooo00<0o`000?ooo`3oool01`3oool20?l000030?ooo`3o0000oooo00<0oooo2`000?l0
0`3o0000oooo0?l000030?l000070?ooo`3o0000oooo0?ooo`3o0000oooo0?l000020?ooo`030?l0
003oool0oooo0080oooo00@0o`000?ooo`3o0000o`000P3oool00`3o0000oooo0?ooo`0I0?ooo`04
0?l0003oool0o`000?ooo`80o`000P3oool30?l00080oooo00<0o`000?ooo`3o00001`3oool20?l0
00030?ooo`3o0000oooo0080oooo0`3o00020?ooo`030?l0003oool0o`000080oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?l000030?ooo`<0o`0000<0oooo0?l0003oool0103oool00`3o
0000oooo0?l000020?ooo`80o`00503oool20?l00140oooo00<0o`000?ooo`3o00000P3o000>0?oo
o`80o`0000@0oooo0?l0003oool0oooo0P3o000?0?ooo`80o`000`3oool30?l000<0oooo0`3o0004
0?ooo`80o`00603oool01@3o0000oooo0?l0003oool0003o00@0oooo20000?l=0?ooo`030000003o
ool0oooo02L0oooo00110?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04`0oooo00<0o`000?ooo`3oool00P3o
ool20?l000<0oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l0000>0?ooo`030?l0003o
ool0oooo00l0oooo0P3o000:0?ooo`060?l0003oool0o`000?l0003oool0o`000`3oool0103o0000
oooo0?l0003oool30?l000050?ooo`3o0000o`000?ooo`3o00000`3oool30?l000<0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`80o`000P3oool00`3o0000oooo0?ooo`02
0?ooo`040?l0003oool0oooo0?l000D0oooo00@0o`000?ooo`3oool0o`00103oool00`3o0000oooo
0?ooo`030?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0P3o00040?ooo`<0o`006`3oool00`3o
0000oooo0?ooo`030?ooo`090?l0003oool0oooo0?l0003oool0o`000?ooo`3o0000oooo00@0o`00
0P3oool00`3o0000oooo0?ooo`070?ooo`80o`0000<0oooo0?l0003oool0103oool20?l00080oooo
2`000?l00`3oool0o`000?l000020?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool0
0P3oool0103o0000oooo0?l0003o000N0?ooo`040?l0003oool0o`000?ooo`80o`000P3oool30?l0
0080oooo00<0o`000?ooo`3o00001`3oool20?l000030?ooo`3o0000oooo0080oooo0`3o00040?oo
o`80o`0000<0oooo0?l0003oool01@3oool00`3o0000oooo0?l000030?ooo`<0o`000P3oool20?l0
00<0oooo00<0o`000?ooo`3o00000P3oool20?l001@0oooo0P3o000A0?ooo`030?l0003oool0oooo
0080o`003P3oool20?l000060?ooo`3o0000oooo0?l0003oool0o`003`3oool20?l000<0oooo00<0
o`000?ooo`3o00000`3oool30?l000@0oooo0P3o000H0?ooo`030?l0003oool0o`0000d0003o3P3o
ool00`000000oooo0?ooo`0W0?ooo`00AP3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0C03oool00`3o0000oooo0?ooo`020?ooo`80o`000`3o
ool00`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000h0oooo00<0o`000?ooo`3oool03`3o
ool20?l000X0oooo0P3o00001@3oool0o`000?ooo`3o0000oooo0080o`000P3oool00`3o0000oooo
0?l000020?l000050?ooo`3o0000o`000?ooo`3o00000`3oool30?l000<0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3o
ool01P3oool0103o0000oooo0?ooo`3o000:0?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0P3o
00040?ooo`<0o`008@3oool02@3o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`040?l0
0080oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?l000050?ooo`80o`000P3oool20?l0
00030?ooo`3o0000003o00`0003o00D0oooo0?l0003oool0oooo0?l000040?ooo`030?l0003oool0
o`0001l0oooo0P3o00020?ooo`80o`000P3oool30?l00080oooo00<0o`000?ooo`3o00001`3oool2
0?l000030?ooo`3o0000oooo0080oooo0`3o00040?ooo`80o`0000<0oooo0?l0003oool01@3oool0
0`3o0000oooo0?l000030?ooo`<0o`000P3oool20?l000<0oooo00<0o`000?ooo`3o00000P3oool2
0?l000@0oooo00<0o`000?ooo`3oool03@3oool20?l00140oooo00<0o`000?ooo`3oool00P3o000>
0?ooo`80o`000P3oool20?l000030?ooo`3o0000oooo00h0oooo0P3o00030?ooo`030?l0003oool0
o`0000<0oooo0P3o00060?ooo`030?l0003oool0oooo01<0oooo3@000?l20?l00180oooo00<00000
0?ooo`3oool09`3oool002`0oooo0P00000H0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0203oool400000500oooo0P3o00030?ooo`030?l0003oool0o`0000<0oooo00<0o`00
0?ooo`3o0000803oool20?l000X0oooo0P3o00001@3oool0o`000?ooo`3o0000oooo0080o`000P3o
ool0103o0000oooo0?l0003o00020?ooo`80o`0000<0oooo0?l0003oool00`3oool20?l000<0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`<0o`0000<0oooo0?l0003oool0
0P3o00080?ooo`<0o`003`3oool01@3o0000oooo0?l0003oool0o`0000<0oooo0`3o000Q0?ooo`09
0?l0003oool0oooo0?l0003oool0o`000?ooo`3o0000oooo00@0o`000P3oool00`3o0000oooo0?oo
o`080?ooo`030?l0003oool0o`0000D0oooo0P3o00020?ooo`80o`0000L0oooo0?l0003o0000oooo
0?l0003oool0o`0000h0003o00H0o`000?ooo`3oool0o`000?ooo`3o000O0?ooo`80o`000P3oool2
0?l00080oooo00D0o`000?ooo`3o0000oooo0?l000020?ooo`030?l0003oool0oooo00D0oooo0P3o
00000`3oool0o`000?ooo`020?ooo`<0o`00103oool20?l000030?ooo`3o0000oooo00D0oooo00<0
o`000?ooo`3o00000`3oool30?l00080oooo0P3o00030?ooo`030?l0003oool0o`000080oooo0P3o
00040?ooo`030?l0003oool0oooo00d0oooo0P3o000A0?ooo`030?l0003oool0oooo0080o`003P3o
ool20?l00080oooo0P3o00000`3oool0o`000?ooo`0>0?ooo`80o`001@3oool0103o0000oooo0?oo
o`3oool20?l000H0oooo00<0o`000?ooo`3oool03P3oool<0000o`060?l0003oool0oooo0?ooo`3o
0000oooo0P3o000B0?ooo`030000003oool0oooo02L0oooo000^0?ooo`<000004P3oool3000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0540
oooo0P3o00030?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o0000803oool20?l000X0
oooo0P3o0000103oool0o`000?ooo`3oool30?l00080oooo00@0o`000?ooo`3o0000o`000P3oool2
0?l000030?ooo`3o0000oooo00<0oooo0P3o00030?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool01`3oool30?l000030?ooo`3o0000oooo0080o`00203oool30?l000l0oooo00D0o`00
0?ooo`3o0000oooo0?l000030?ooo`<0o`008@3oool02@3o0000oooo0?ooo`3o0000oooo0?l0003o
ool0o`000?ooo`030?l000<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?l000050?oo
o`80o`000`3oool0303o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l0
00<0oooo3@000?lO0?ooo`80o`000P3oool20?l00080oooo00D0o`000?ooo`3o0000oooo0?l00002
0?ooo`030?l0003oool0oooo00D0oooo0P3o00000`3oool0o`000?ooo`020?ooo`<0o`001@3oool0
0`3o0000oooo0?l000060?ooo`030?l0003oool0o`0000<0oooo0`3o00020?ooo`<0o`000P3oool0
0`3o0000oooo0?l000020?ooo`80o`00103oool00`3o0000oooo0?ooo`0=0?ooo`80o`004@3oool0
0`3o0000oooo0?ooo`020?l000h0oooo0P3o00020?ooo`80o`0000<0oooo0?l0003oool03P3oool2
0?l000D0oooo00@0o`000?ooo`3oool0oooo0P3o00060?ooo`030?l0003oool0oooo00T0oooo2`00
0?l20?ooo`80o`000P3oool00`3o0000oooo0?ooo`020?l00080oooo00<0o`000?ooo`3oool0403o
ool00`000000oooo0?ooo`0W0?ooo`00<@3oool300000180oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0540oooo0P3o00030?ooo`030?l0003o
ool0o`0000<0oooo00<0o`000?ooo`3o0000803oool20?l000X0oooo0P3o00001`3oool0o`000?oo
o`3oool0o`000?ooo`3o00000P3oool0103o0000oooo0?l0003o00020?ooo`80o`0000<0oooo0?l0
003oool00`3oool20?l000<0oooo00<0o`000?ooo`3oool03@3oool30?l000030?ooo`3o0000oooo
0080o`00203oool30?l000l0oooo0P3o00020?ooo`80o`000P3oool30?l00240oooo00T0o`000?oo
o`3oool0o`000?ooo`3o0000oooo0?l0003oool00`3o000?0?ooo`80o`001P3oool01@3o0000oooo
0?ooo`3oool0o`000080oooo00T0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o00000`3o
ool0103o0000oooo0?l0003oool20?l000d0003o6@3oool20?l00080oooo0P3o00020?ooo`050?l0
003oool0o`000?ooo`3o00000P3oool00`3o0000oooo0?ooo`050?ooo`80o`0000<0oooo0?l0003o
ool00`3oool20?l000D0oooo00<0o`000?ooo`3o00003P3oool00`3o0000oooo0?ooo`040?l00004
0?ooo`3o0000oooo0?l00080oooo0P3o00030?ooo`80o`003P3oool00`3o0000oooo0?l0000A0?oo
o`030?l0003oool0oooo0080o`003P3oool20?l000<0oooo00<0o`000?ooo`3o00003`3oool20?l0
00D0oooo00@0o`000?ooo`3oool0oooo0P3o00060?ooo`030?l0003oool0oooo00<0oooo30000?l7
0?ooo`80o`000P3oool00`3o0000oooo0?ooo`020?l00080oooo00<0o`000?ooo`3oool0403oool0
0`000000oooo0?ooo`0W0?ooo`00=03oool2000000/0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0DP3oool0
1`3o0000oooo0?ooo`3oool0o`000?ooo`3o00000`3oool00`3o0000oooo0?l0000P0?ooo`80o`00
2P3oool20?l000070?ooo`3o0000oooo0?ooo`3o0000oooo0?l000020?ooo`040?l0003oool0o`00
0?l00080oooo0P3o00060?ooo`80o`000`3oool00`3o0000oooo0?ooo`0=0?ooo`<0o`0000<0oooo
0?l0003oool00P3o00080?ooo`<0o`00403oool00`3o0000oooo0?ooo`020?l00080oooo0`3o000Q
0?ooo`030?l0003oool0oooo00<0o`0000H0oooo0?l0003oool0o`000?ooo`3o000?0?ooo`80o`00
1P3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00@0o`000?ooo`3o0000o`00103oool00`3o
0000oooo0?ooo`020?ooo`80o`0000@0oooo0?l0003o0000oooo0P3o00000`3oool0o`000?ooo`0=
0000oa<0oooo0P3o00020?ooo`80o`000P3oool01@3o0000oooo0?l0003oool0o`000080oooo00<0
o`000?ooo`3oool01@3oool20?l000030?ooo`3o0000oooo00<0oooo0P3o00050?ooo`80o`003`3o
ool00`3o0000oooo0?ooo`040?l000040?ooo`3o0000oooo0?ooo`80o`0000<0oooo0?l0003oool0
0P3oool20?l000X0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`000140oooo00D0o`000?oo
o`3oool0oooo0?l0000>0?ooo`030?l0003oool0oooo01@0oooo0P3o00050?ooo`050?l0003oool0
oooo0?ooo`3o00001P3oool>0000o``0oooo0P3o00030?ooo`80o`0000D0oooo0?l0003oool0oooo
0?l0000B0?ooo`030000003oool0oooo02L0oooo000a0?ooo`<000003@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1B0?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l000040?ooo`80o`00803oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3o00000P3oool00`3o
0000oooo0?l000030?ooo`80o`001P3oool20?l000<0oooo00<0o`000?ooo`3oool03@3oool30?l0
00040?ooo`3o0000oooo0?l000T0oooo0`3o000C0?ooo`80o`000P3oool00`3o0000oooo0?l0000Q
0?ooo`040?l0003oool0o`000?ooo`80o`0000H0oooo0?l0003oool0o`000?ooo`3o000?0?ooo`80
o`001P3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00@0o`000?ooo`3o0000o`00103oool0
0`3o0000oooo0?ooo`020?ooo`80o`0000@0oooo0?l0003o0000oooo0P3o0000103oool0o`000?oo
o`3o00050?ooo`h0003o303oool20?l00080oooo00@0o`000?ooo`3o0000o`000P3oool00`3o0000
oooo0?l000020?ooo`030?l0003oool0oooo00D0oooo0P3o00000`3oool0o`000?ooo`030?ooo`80
o`001@3oool20?l000l0oooo00<0o`000?ooo`3oool00P3o0000103oool0o`000?ooo`3o00020?oo
o`80o`0000<0oooo0?l0003oool00P3oool20?l000X0oooo00T0o`000?ooo`3oool0oooo0?l0003o
ool0o`000?ooo`3o00003`3oool01@3o0000oooo0?ooo`3oool0o`0000h0oooo00<0o`000?ooo`3o
ool0503oool20?l000D0oooo00@0o`000?ooo`3oool0oooo3`000?lB0?ooo`80o`000`3oool20?l0
00@0oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`0W0?ooo`00;@3oool400000140
oooo100000040?ooo`@000002`3oool00`000000oooo0?ooo`1B0?ooo`070?l0003oool0oooo0?oo
o`3o0000oooo0?l000040?ooo`80o`00803oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0
o`0000L0oooo00<0o`000?ooo`3o00000`3oool20?l000H0oooo00<0o`000?ooo`3o00000P3oool0
0`3o0000oooo0?ooo`0>0?ooo`060?l0003oool0o`000?l0003oool0o`002@3oool30?l001<0oooo
0P3o00020?ooo`030?l0003oool0o`000240oooo00@0o`000?ooo`3o0000oooo0P3o00001P3oool0
o`000?ooo`3o0000oooo0?l000l0oooo00<0o`000?ooo`3oool01@3oool01@3o0000oooo0?ooo`3o
ool0o`000080oooo00@0o`000?ooo`3o0000o`00103oool00`3o0000oooo0?ooo`020?ooo`80o`00
00<0oooo0?l0003oool00`3o0000103oool0o`000?ooo`3o000;0?ooo`h0003o1`3oool01@3o0000
oooo0?ooo`3o0000oooo0080o`000P3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0oooo
00D0oooo0`3o00050?ooo`80o`001@3oool20?l000l0oooo00<0o`000?ooo`3oool00P3o0000103o
ool0o`000?ooo`3o00030?ooo`040?l0003oool0oooo0?l00080oooo0P3o000:0?ooo`080?l0003o
ool0oooo0?ooo`3o0000oooo0?l0003oool20?l000h0oooo00D0o`000?ooo`3oool0oooo0?l0000=
0?ooo`030?l0003oool0oooo01D0oooo00@0o`000?ooo`3oool0oooo3`000?lI0?ooo`80o`000`3o
ool20?l000@0oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`0W0?ooo`00;03oool0
0`000000oooo0?ooo`0Z0?ooo`<00000DP3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`3o0000
103oool20?l00200oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`80o`00
0`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3oool0
3P3oool01P3o0000oooo0?l0003o0000oooo0?l000X0oooo0P3o000C0?ooo`80o`0000D0oooo0?l0
003oool0oooo0?l0000Q0?ooo`040?l0003oool0o`000?ooo`80o`0000H0oooo0?l0003oool0o`00
0?ooo`3o000G0?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo0P3o00000`3oool0o`000?ooo`030?l000040?ooo`3o0000oooo
0?l00180oooo3`000?l40?ooo`80o`000P3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0
oooo00H0oooo0P3o00050?ooo`030?l0003oool0oooo00@0oooo0P3o000?0?ooo`030?l0003oool0
oooo0080o`0000@0oooo0?l0003oool0o`000`3oool0203o0000oooo0?ooo`3o0000oooo0?l0003o
ool0o`002P3oool0203o0000oooo0?ooo`3oool0o`000?ooo`3o0000oooo0P3o000>0?ooo`050?l0
003oool0oooo0?ooo`3o00003@3oool00`3o0000oooo0?ooo`0B0?ooo`l0003o803oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0403oool00`000000
oooo0?ooo`0W0?ooo`00;@3oool4000002P0oooo00<000000?ooo`3oool0DP3oool01`3o0000oooo
0?ooo`3oool0o`000?ooo`3o0000103oool20?l00200oooo00<0o`000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`080?ooo`80o`000`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0o`00
0080oooo00<0o`000?ooo`3oool03P3oool01P3o0000oooo0?l0003o0000oooo0?l000X0oooo0P3o
000C0?ooo`@0o`000P3oool00`3o0000oooo0?ooo`0O0?ooo`040?l0003oool0o`000?ooo`80o`00
00H0oooo0?l0003oool0o`000?ooo`3o000G0?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo0P3o00000`3oool0o`000?ooo`03
0?l000030?ooo`3o0000oooo01P0oooo4`000?l01@3oool0o`000?ooo`3oool0o`0000P0oooo0P3o
00050?ooo`030?l0003oool0oooo00@0oooo0P3o000?0?ooo`090?l0003oool0oooo0?ooo`3o0000
oooo0?l0003oool0o`0000H0oooo00D0o`000?ooo`3o0000oooo0?l0000:0?ooo`080?l0003oool0
oooo0?ooo`3o0000oooo0?l0003oool20?l000h0oooo00D0o`000?ooo`3oool0oooo0?l0000=0?oo
o`030?l0003oool0oooo00X0oooo4@000?l50?ooo`030?l0003oool0oooo01h0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0100oooo00<000000?oo
o`3oool09`3oool00340oooo0`00000U0?ooo`030000003oool0oooo0580oooo00L0o`000?ooo`3o
ool0oooo0?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00P0oooo0P3o00030?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3o00000P3oool00`3o0000oooo0?ooo`0>0?ooo`060?l0003oool0o`000?l0003oool0o`00
2P3oool00`3o0000oooo0?ooo`0B0?ooo`@0o`000P3oool00`3o0000oooo0?ooo`0O0?ooo`040?l0
003oool0o`000?ooo`80o`0000H0oooo0?l0003oool0o`000?ooo`3o000G0?ooo`050?l0003oool0
oooo0?ooo`3o00001@3oool00`3o0000oooo0?ooo`070?ooo`80o`0000<0oooo0?l0003oool00`3o
00000`3oool0o`000?ooo`0Q0?oooa80003o1@3oool20?l000`0oooo0P3o000?0?ooo`090?l0003o
ool0oooo0?ooo`3o0000oooo0?l0003oool0o`0000H0oooo00D0o`000?ooo`3o0000oooo0?l0000:
0?ooo`080?l0003oool0oooo0?ooo`3o0000oooo0?l0003oool20?l000h0oooo00D0o`000?ooo`3o
ool0oooo0?l0000=0?ooo`040?l0003oool0oooo0?oooa80003o3@3oool00`3o0000oooo0?ooo`0S
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`0W
0?ooo`00=03oool2000002<0oooo00<000000?ooo`3oool0EP3oool00`3o0000oooo0?l000040?oo
o`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo00L0oooo00@0o`000?ooo`3oool0o`00403oool01P3o0000oooo0?l0003o
0000oooo0?l000X0oooo00<0o`000?ooo`3oool04P3oool30?l000<0oooo00<0o`000?ooo`3oool0
7`3oool0103o0000oooo0?l0003oool20?l000060?ooo`3o0000oooo0?l0003oool0o`005`3oool0
1@3o0000oooo0?ooo`3oool0o`0000D0oooo00<0o`000?ooo`3oool01`3oool20?l000030?ooo`3o
0000oooo00<0o`0000<0oooo0?l0003oool08@3oool00`3o0000oooo0?ooo`020?ooo`80o`000P3o
oolC0000o`T0oooo0P3o000C0?ooo`050?l0003oool0o`000?ooo`3o00001P3oool01@3o0000oooo
0?l0003oool0o`0000T0oooo0P3o00030?ooo`040?l0003oool0o`000?ooo`80o`003P3oool01@3o
0000oooo0?ooo`3oool0o`0000L0oooo50000?lE0?ooo`030?l0003oool0oooo02<0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0oooo02L0oooo000a0?oo
o`<000009@3oool00`000000oooo0?ooo`1G0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool07`3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool01`3oool0103o0000oooo0?ooo`3o000@0?ooo`060?l0003oool0o`000?l0003oool0o`00
2P3oool00`3o0000oooo0?ooo`0B0?ooo`<0o`000`3oool00`3o0000oooo0?ooo`0O0?ooo`040?l0
003oool0o`000?ooo`80o`0000H0oooo0?l0003oool0o`000?ooo`3o000K0?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool01`3oool20?l000030?ooo`3o0000oooo00<0o`0000<0oooo
0?l0003oool08@3oool00`3o0000oooo0?ooo`020?ooo`80o`000P3oool00`3o0000oooo0?l00005
0?oooaP0003o4@3oool0103o0000oooo0?l0003o00070?ooo`050?l0003oool0o`000?ooo`3o0000
2@3oool20?l000<0oooo00@0o`000?ooo`3o0000oooo0P3o000>0?oooaL0003o7P3oool00`3o0000
oooo0?ooo`0S0?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool002h0oooo
0`00000X0?ooo`030000003oool0oooo05L0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`0O0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`070?ooo`040?l0003oool0oooo0?l00180oooo0`3o000;0?ooo`030?l0003oool0oooo0180
oooo0`3o00030?ooo`030?l0003oool0oooo01l0oooo00@0o`000?ooo`3o0000oooo0P3o00001P3o
ool0o`000?ooo`3o0000oooo0?l001/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`070?ooo`80o`0000<0oooo0?l0003oool00`3o00000`3oool0o`000?ooo`0V0?ooo`80o`000P3o
ool00`3o0000oooo0?l0000<0?ooo`030?l0003oool0oooo0240003o0P3o00070?ooo`050?l0003o
ool0o`000?ooo`3o00002@3oool20?l000<0oooo00<0o`000?ooo`000?l07P000?l20?ooo`040?l0
003oool0oooo0?l00280oooo00<0o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0F0?ooo`03
0000003oool0oooo02L0oooo000/0?ooo`800000:`3oool3000005L0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0o`0001D0oooo00<0o`000?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0C0?ooo`80o`000`3oool00`3o0000oooo0?ooo`0O0?ooo`040?l0
003oool0o`000?ooo`80o`000P3oool20?l000030?ooo`3o0000oooo01X0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`070?ooo`80o`0000<0oooo0?l0003oool00`3o00000`3oool0
o`000?ooo`0V0?ooo`80o`000P3oool00`3o0000oooo0?l0000<0?ooo`030?l0003oool0oooo00X0
oooo0P3o00000`3oool0003o0000o`130000o`<0oooo00<0o`000?ooo`3oool0203oool0103o0000
oooo0?ooo`3o000R0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0W0?ooo`00F@3oool00`000000oooo0?ooo`1G0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00`0
oooo00<0o`000?ooo`3o00005@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo01<0
oooo0P3o00030?ooo`030?l0003oool0oooo01l0oooo00@0o`000?ooo`3o0000oooo0P3o00020?oo
o`040?l0003oool0oooo0?l001/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`07
0?ooo`80o`0000<0oooo0?l0003oool00`3o00000`3oool0o`000?ooo`0V0?ooo`80o`000P3oool0
0`3o0000oooo0?l0000<0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool04P3ooolP
0000o`030?ooo`3o0000o`0000h0oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`040?l0003o
ool0oooo0?l00280oooo00<0o`000?ooo`3oool0?03oool00`000000oooo0?ooo`0W0?ooo`00;03o
ool:000002<0oooo00<000000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo01l0oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003o
ool0o`0001D0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0C0?ooo`80o`000`3o
ool00`3o0000oooo0?ooo`0O0?ooo`040?l0003oool0o`000?ooo`80o`000P3oool0103o0000oooo
0?ooo`3o000K0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01`3oool20?l00008
0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o000W0?ooo`070?l0003oool0oooo0?ooo`3o0000
oooo0?l0000<0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0503oool00`3o0000
oooo0?ooo`050?ooo`050?l0003oool0o`000?ooo`3o00002@3oool20?l000<0oooo00H0o`000?oo
o`3o0000oooo0?l0003oool30?l000/0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`030?l0
003oool0oooo00@0oooo00@0o`000?ooo`3oool0o`008P3oool00`3o0000oooo0?ooo`0l0?ooo`03
0000003oool0oooo02L0oooo000_0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
E`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool0
5@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0o`0001D0oooo00<0o`000?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0C0?ooo`80o`000`3oool00`3o0000oooo0?ooo`0O0?ooo`040?l0
003oool0o`000?ooo`80o`000P3oool0103o0000oooo0?ooo`3o000Q0?ooo`030?l0003oool0oooo
00L0oooo00X0o`000?ooo`3o0000o`000?ooo`3o0000oooo0?l0003oool0o`009`3oool01`3o0000
oooo0?ooo`3oool0o`000?ooo`3o0000303oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0
oooo01@0oooo00<0o`000?ooo`3oool01@3oool20?l00080oooo00<0o`000?ooo`3oool01`3oool2
0?l000<0oooo00@0o`000?ooo`3o0000o`000P3oool30?l000/0oooo00D0o`000?ooo`3oool0oooo
0?l000030?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0o`008P3oool00`3o0000
oooo0?ooo`0l0?ooo`030000003oool0oooo02L0oooo000^0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01l0oooo
00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0o`0001D0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0C0?ooo`80o`009@3oool0103o0000oooo
0?l0003oool20?l00080oooo00@0o`000?ooo`3oool0o`008@3oool00`3o0000oooo0?ooo`090?oo
o`80o`0000H0oooo0?l0003oool0o`000?ooo`3o000W0?ooo`070?l0003oool0oooo0?ooo`3o0000
oooo0?l0000<0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0503oool00`3o0000
oooo0?ooo`060?ooo`040?l0003oool0oooo0?l000T0oooo00<0o`000?ooo`3o00000P3oool0103o
0000oooo0?l0003o00020?ooo`<0o`002`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0
o`000?ooo`3oool0103oool0103o0000oooo0?ooo`3o001Q0?ooo`030000003oool0oooo02L0oooo
000^0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0E`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?oo
o`0<0?ooo`030?l0003oool0o`0001D0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0C0?ooo`80o`009@3oool0103o0000oooo0?l0003oool20?l00080oooo00@0o`000?ooo`3oool0
o`008@3oool00`3o0000oooo0?ooo`090?ooo`80o`0000H0oooo0?l0003oool0o`000?ooo`3o000W
0?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l0000<0?ooo`030?l0003oool0oooo00/0oooo
00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`060?ooo`040?l0003oool0oooo0?l000T0
oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?l0003o00020?ooo`<0o`002@3oool00`3o
0000oooo0?l000030?ooo`030?l0003oool0oooo0080o`001P3oool0103o0000oooo0?ooo`3o001Q
0?ooo`030000003oool0oooo02L0oooo000^0?ooo`030000003oool0oooo02P0oooo0`00001G0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0T0?oo
o`030?l0003oool0o`0001D0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0C0?oo
o`80o`009@3oool0103o0000oooo0?l0003oool20?l00080oooo00@0o`000?ooo`3oool0o`008@3o
ool00`3o0000oooo0?ooo`090?ooo`80o`0000@0oooo0?l0003oool0oooo0P3o000[0?ooo`030?l0
003oool0o`0000`0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0
003oool0oooo00H0oooo00@0o`000?ooo`3oool0o`002@3oool01@3o0000oooo0?l0003oool0o`00
0080oooo0P3o00020?ooo`030?l0003oool0o`0000T0oooo00<0o`000?ooo`3o0000103oool0103o
0000oooo0?l0003o00060?ooo`80o`0000<0oooo0?l0003oool0H03oool00`000000oooo0?ooo`0W
0?ooo`00;`3oool7000002<0oooo00<000000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?l0000E0?oo
o`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool04`3oool20?l002D0oooo00<0o`000?oo
o`3o00000P3oool0103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0oooo01l0oooo00<0o`00
0?ooo`3oool02@3oool20?l000040?ooo`3o0000oooo0?ooo`80o`00:`3oool00`3o0000oooo0?l0
000<0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?oo
o`060?ooo`040?l0003oool0oooo0?l000T0oooo00D0o`000?ooo`3o0000oooo0?l000020?ooo`80
o`000P3oool00`3o0000oooo0?l000090?ooo`80o`001@3oool0103o0000oooo0?l0003o00060?oo
o`80o`0000<0oooo0?l0003oool0H03oool00`000000oooo0?ooo`0W0?ooo`00F@3oool00`000000
oooo0?ooo`1G0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool07`3oool00`3o0000
oooo0?ooo`0T0?ooo`030?l0003oool0o`0001D0oooo00<0o`000?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0C0?ooo`80o`009@3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?l0
0080oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`090?ooo`80o`0000@0oooo0?l0
003oool0oooo0P3o000[0?ooo`030?l0003oool0o`0000`0oooo00<0o`000?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0o`002@3o
ool01@3o0000oooo0?l0003oool0o`000080oooo0P3o00020?ooo`030?l0003oool0o`0000T0oooo
0P3o00050?ooo`040?l0003oool0o`000?l000H0oooo0P3o00000`3oool0o`000?ooo`1P0?ooo`03
0000003oool0oooo02L0oooo001I0?ooo`030000003oool0oooo05L0oooo00<0o`000?ooo`3oool0
9@3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0o`0001D0oooo00<0o`000?ooo`3oool0
7`3oool20?l002D0oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o00020?ooo`03
0?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool02@3oool20?l000040?ooo`3o0000oooo0?oo
o`80o`00:`3oool00`3o0000oooo0?l0000<0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?oo
o`3oool0503oool00`3o0000oooo0?ooo`060?ooo`040?l0003oool0oooo0?l000T0oooo00<0o`00
0?ooo`3o00000P3o00020?ooo`80o`000P3oool00`3o0000oooo0?l000090?ooo`80o`001@3oool0
103o0000oooo0?l0003o00060?ooo`80o`0000<0oooo0?l0003oool0H03oool00`000000oooo0?oo
o`0W0?ooo`00F@3oool00`000000oooo0?ooo`1G0?ooo`030?l0003oool0oooo02D0oooo00<0o`00
0?ooo`3oool09@3oool20?l001D0oooo00<0o`000?ooo`3oool07`3oool20?l002D0oooo00<0o`00
0?ooo`3o00000P3oool0103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0oooo01l0oooo00<0
o`000?ooo`3oool02@3oool20?l000040?ooo`3o0000oooo0?ooo`80o`00:`3oool00`3o0000oooo
0?l0000<0?ooo`030?l0003oool0oooo02/0oooo00@0o`000?ooo`3oool0o`002@3oool01@3o0000
oooo0?l0003oool0o`000080oooo0P3o00020?ooo`030?l0003oool0o`0000T0oooo0P3o00050?oo
o`040?l0003oool0o`000?l000H0oooo0P3o00000`3oool0o`000?ooo`1P0?ooo`030000003oool0
oooo02L0oooo001I0?ooo`030000003oool0oooo05L0oooo00<0o`000?ooo`3oool09@3oool00`3o
0000oooo0?ooo`0U0?ooo`80o`00=`3oool20?l002D0oooo00<0o`000?ooo`3o00000P3oool0103o
0000oooo0?ooo`3o000T0?ooo`030?l0003oool0oooo00T0oooo0P3o00001@3oool0o`000?ooo`3o
ool0o`0002d0oooo0P3o000<0?ooo`030?l0003oool0oooo02/0oooo00@0o`000?ooo`3oool0o`00
2@3oool00`3o0000oooo0?l000040?ooo`80o`00103oool00`3o0000oooo0?ooo`070?ooo`80o`00
1@3oool0103o0000oooo0?l0003o00060?ooo`80o`0000<0oooo0?l0003oool0H03oool00`000000
oooo0?ooo`0W0?ooo`00F@3oool3000005L0oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo
0?ooo`0U0?ooo`80o`00=`3oool20?l002D0oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo
0?ooo`3o000T0?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3oool0o`000P3oool00`3o
0000oooo0?ooo`0[0?ooo`80o`00303oool00`3o0000oooo0?ooo`0[0?ooo`040?l0003oool0oooo
0?l000T0oooo00<0o`000?ooo`3o0000103oool20?l000@0oooo00<0o`000?ooo`3oool01`3oool2
0?l000D0oooo0P3o00000`3oool0o`000?ooo`050?ooo`80o`0000<0oooo0?l0003oool0H03oool0
0`000000oooo0?ooo`0W0?ooo`00F@3oool00`000000oooo0?ooo`1o0?ooo`030?l0003oool0oooo
02D0oooo0P3o000g0?ooo`80o`009P3oool20?l00080oooo00@0o`000?ooo`3oool0o`00<03oool0
103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0oooo02/0oooo0P3o000m0?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3o0000103oool20?l000@0oooo00<0o`000?ooo`3oool01`3o
ool20?l000D0oooo0P3o00000`3oool0o`000?ooo`050?ooo`@0o`00H@3oool00`000000oooo0?oo
o`0W0?ooo`00A@3oool00`000000oooo0?ooo`020?ooo`@000002`3oool00`000000oooo0?ooo`1o
0?ooo`030?l0003oool0oooo02D0oooo0P3o000g0?ooo`80o`009P3oool20?l00080oooo00@0o`00
0?ooo`3oool0o`00<03oool0103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0oooo02/0oooo
0P3o000m0?ooo`030?l0003oool0oooo00D0oooo00D0o`000?ooo`3o0000oooo0?l000040?ooo`80
o`00103oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo0P3o00000`3oool0
o`000?ooo`050?ooo`040?l0003oool0o`000?l00640oooo00<000000?ooo`3oool09`3oool004D0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0Y`3oool20?l003L0oooo0P3o000V0?ooo`80o`000P3oool0103o0000oooo0?ooo`3o000`
0?ooo`040?l0003oool0oooo0?l00080oooo00<0o`000?ooo`3oool0:`3oool20?l003d0oooo00<0
o`000?ooo`3oool00`3oool01`3o0000oooo0?l0003oool0o`000?ooo`3o0000103oool20?l000@0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3o00001P3oool0103o0000oooo0?ooo`3o001Q0?ooo`030000003oool0oooo
02L0oooo00100?ooo`L000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0Y`3oool20?l003L0oooo0P3o000V0?ooo`80o`000P3oool0103o0000
oooo0?ooo`3o000`0?ooo`040?l0003oool0oooo0?l00080oooo00<0o`000?ooo`3oool0:`3oool2
0?l003d0oooo00<0o`000?ooo`3oool00P3oool20?l000040?ooo`3o0000oooo0?l000H0oooo0P3o
00040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0o`0000H0oooo00<0o`000?ooo`3oool0HP3oool00`000000oooo0?oo
o`0W0?ooo`00@03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`080?ooo`@00000YP3oool00`3o0000oooo0?ooo`0f0?ooo`80o`009P3o
ool20?l00080oooo00@0o`000?ooo`3oool0o`00<03oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo02/0oooo0P3o000m0?ooo`030?l0003oool0oooo0080oooo0P3o0000103oool0o`00
0?ooo`3o00060?ooo`80o`00103oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0680
oooo00<000000?ooo`3oool09`3oool00440oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2W0?ooo`03
0?l0003oool0oooo03H0oooo0P3o000V0?ooo`80o`001@3oool00`3o0000oooo0?ooo`0^0?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0:`3oool20?l003d0oooo00<0o`000?ooo`3o
ool00P3oool40?l000030?ooo`3o0000oooo00D0oooo0P3o00040?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool0HP3oool00`000000oooo0?ooo`0W0?ooo`00@P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`2W0?ooo`030?l0003oool0oooo03H0oooo00<0o`000?ooo`3oool09@3oool20?l003H0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0[0?ooo`80o`00?@3oool00`3o0000
oooo0?ooo`020?ooo`@0o`0000<0oooo0?l0003oool01@3oool20?l000@0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`1R0?ooo`030000003oool0oooo02L0oooo00120?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0:L0oooo00<0o`000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0U0?ooo`80
o`00=P3oool00`3o0000oooo0?ooo`0a0?ooo`80o`00?@3oool00`3o0000oooo0?ooo`020?ooo`@0
o`0000<0oooo0?l0003oool01@3oool20?l000@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?ooo`1R0?ooo`030000003oool0oooo02L0oooo00130?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0:L0oooo
00<0o`000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo03D0oooo
00<0o`000?ooo`3oool0<@3oool20?l003d0oooo00<0o`000?ooo`3oool00P3oool40?l000030?oo
o`3o0000oooo00D0oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
HP3oool00`000000oooo0?ooo`0W0?ooo`00A03oool2000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0>00oooo00<0o`000?ooo`3oool09@3o
ool00`3o0000oooo0?ooo`1Y0?ooo`80o`00?@3oool01P3o0000oooo0?ooo`3oool0o`000?ooo`@0
o`001`3oool20?l000@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`1R0?ooo`03
0000003oool0oooo02L0oooo00150?ooo`030000003oool0oooo0080oooo1000000;0?ooo`<00000
h03oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo06T0oooo0P3o000m0?ooo`060?l0
003oool0oooo0?ooo`3o0000oooo103o00070?ooo`80o`00103oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo0680oooo00<000000?ooo`3oool09`3oool005T0oooo00<000000?ooo`3o
ool0h03oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo06T0oooo0P3o000m0?ooo`08
0?l0003oool0oooo0?ooo`3o0000oooo0?l0003oool20?l000L0oooo0P3o00040?ooo`030?l0003o
ool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`030?l0003oool0oooo00<0oooo
0P3o001T0?ooo`030000003oool0oooo02L0oooo001I0?ooo`030000003oool0oooo0>00oooo00<0
o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`1Y0?ooo`80o`00?@3oool0203o0000oooo0?oo
o`3oool0o`000?ooo`3o0000oooo0P3o00070?ooo`80o`00103oool00`3o0000oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`3o00002P3oool00`3o0000oooo0?ooo`030?ooo`80o`00I03oool0
0`000000oooo0?ooo`0W0?ooo`00F@3oool00`000000oooo0?ooo`3P0?ooo`030?l0003oool0oooo
02D0oooo00<0o`000?ooo`3oool0J@3oool20?l003d0oooo00D0o`000?ooo`3oool0oooo0?l00003
0?ooo`80o`001`3oool20?l000@0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0o`0000X0oooo00<0o`000?ooo`3oool00`3oool20?l006@0oooo00<000000?ooo`3oool09`3o
ool005T0oooo00<000000?ooo`3oool0h03oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0
oooo06T0oooo0P3o000m0?ooo`050?l0003oool0o`000?ooo`3o00000`3oool20?l000L0oooo0P3o
00040?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`030?l0
003oool0oooo00<0oooo0P3o001T0?ooo`030000003oool0oooo02L0oooo001I0?ooo`030000003o
ool0oooo0>00oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`1Y0?ooo`80o`00?@3o
ool01@3o0000oooo0?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3o0000I03oool00`000000oooo0?ooo`0W0?ooo`00
F@3oool300000>00oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`1Y0?ooo`80o`00
?@3oool01@3o0000oooo0?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0000:0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o0000I03oool00`000000oooo0?ooo`0W0?oo
o`00F@3oool00`000000oooo0?ooo`3P0?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3o
ool0J@3oool20?l003d0oooo00D0o`000?ooo`3o0000oooo0?l000040?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`3o00002P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo06@0oooo00<00000
0?ooo`3oool09`3oool005T0oooo00<000000?ooo`3oool0h03oool00`3o0000oooo0?ooo`0U0?oo
o`030?l0003oool0oooo06T0oooo0P3o000m0?ooo`050?l0003oool0o`000?ooo`3o0000103oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0o`0000X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`1T0?ooo`030000003oool0oooo02L0oooo001I0?ooo`030000003oool0oooo0>00oooo00<0o`00
0?ooo`3oool09@3oool00`3o0000oooo0?ooo`1Y0?ooo`80o`00?@3oool01@3o0000oooo0?l0003o
ool0o`0000@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool0I03oool00`000000oooo0?ooo`0W0?ooo`00F@3oool00`000000oooo0?oo
o`3P0?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool0J@3oool20?l003d0oooo00D0
o`000?ooo`3o0000oooo0?l000040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo06@0oooo00<000000?ooo`3oool09`3oool005T0oooo
00<000000?ooo`3oool0h03oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo06T0oooo
0P3o000m0?ooo`050?l0003oool0o`000?ooo`3o0000103oool00`3o0000oooo0?ooo`050?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`00
00X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`1T0?ooo`030000003oool0oooo
02L0oooo001I0?ooo`<00000h03oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo06T0
oooo0P3o000m0?ooo`040?l0003oool0o`000?l000D0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l0000:
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0I03oool00`000000oooo0?ooo`0W
0?ooo`00F@3oool00`000000oooo0?ooo`3P0?ooo`030?l0003oool0oooo02D0oooo00<0o`000?oo
o`3oool0J@3oool20?l003d0oooo00@0o`000?ooo`3o0000o`001@3oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0o`0000X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`1T0?ooo`030000003o
ool0oooo02L0oooo001I0?ooo`030000003oool0oooo0>00oooo00<0o`000?ooo`3oool09@3oool0
0`3o0000oooo0?ooo`1Y0?ooo`80o`00?@3oool0103o0000oooo0?l0003o00050?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`3o00002P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo06@0oooo
00<000000?ooo`3oool09`3oool005T0oooo00<000000?ooo`3oool0h03oool00`3o0000oooo0?oo
o`0U0?ooo`030?l0003oool0oooo06T0oooo0P3o000m0?ooo`040?l0003oool0o`000?l000D0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`050?l0003oool0oooo0?ooo`3o0000I`3oool00`00
0000oooo0?ooo`0W0?ooo`00F@3oool00`000000oooo0?ooo`3P0?ooo`030?l0003oool0oooo02D0
oooo00<0o`000?ooo`3oool0J@3oool20?l003d0oooo00@0o`000?ooo`3o0000o`001@3oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0o`0000X0oooo00D0o`000?ooo`3oool0oooo0?l0001W0?ooo`030000003o
ool0oooo02L0oooo001I0?ooo`030000003oool0oooo0>00oooo00<0o`000?ooo`3oool09@3oool0
0`3o0000oooo0?ooo`1Y0?ooo`80o`00?@3oool0103o0000oooo0?l0003o00050?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`3o00002P3oool01@3o0000oooo0?ooo`3oool0o`0006L0oooo00<000000?ooo`3o
ool09`3oool005T0oooo0`00003P0?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool0
J@3oool20?l003d0oooo00@0o`000?ooo`3o0000o`001@3oool00`3o0000oooo0?ooo`050?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?l000X0
oooo00D0o`000?ooo`3oool0oooo0?l0001W0?ooo`030000003oool0oooo02L0oooo001I0?ooo`03
0000003oool0oooo0>00oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`1Y0?ooo`80
o`00?@3oool0103o0000oooo0?l0003o000=0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?l000X0oooo00D0o`000?ooo`3oool0oooo0?l0001W
0?ooo`030000003oool0oooo02L0oooo001I0?ooool00000300000000`3o000000000000001Y0000
0080o`00?@000000103o000000000?l0003o000C000000030?l00000000000000080000000<0o`00
0000000000000P3o000:000000050?l00000000000000000003o0000J000000Y0?ooo`00\
\>"],
  ImageRangeCache->{{{96, 815}, {338.875, 196}} -> {-235.932, 67.0178, \
1.18407, 0.341273}}]
}, Open  ]],

Cell["\<\
Fur further analysis (not shown in this notebook) the estimated function for \
seasonality is used to further adjust the observed prices.\
\>", "Text"],

Cell[BoxData[
    \(\(peak3\  = \ peak2\  - Map[yfkt, t];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructing the forward curve", "Subsection"],

Cell["\<\
Using the results of the previous analysis a forward curve can be constructed \
for the valuation date. It is assumed that the valuation date is the next to \
the last observed date. The forward curve should start at the last observed \
price, assuming that the last price together with the above estimated \
corrections is the best estimation for the future prices.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(valdate\  = DaysPlus[Last[dates2], 1]\), "\[IndentingNewLine]", 
    \(DayOfWeek[%]\), "\[IndentingNewLine]", 
    \(S\_0 = \ Last[peak3]\)}], "Input"],

Cell[BoxData[
    \({2002, 4, 30}\)], "Output"],

Cell[BoxData[
    \("Tuesday"\)], "Output"],

Cell[BoxData[
    \(23.46685744597664`\)], "Output"]
}, Open  ]],

Cell["\<\
The dates for the coming 365 days are constructed and the day of the week and \
the year fraction for each day are calculated.\
\>", "Text"],

Cell[BoxData[{
    \(\(dates3\  = 
        Map[DaysPlus[Last[dates2], #] &, 
          Range[1, 365]];\)\), "\[IndentingNewLine]", 
    \(\(week\  = Mod[Range[365], 7] + 1;\)\), "\[IndentingNewLine]", 
    \(\(year\  = \ YearsBetween[{2000, 1, 1}, dates3];\)\)}], "Input"],

Cell["\<\
Together with the above estimated curves a forward curve can be \
constructed.\
\>", "Text"],

Cell[BoxData[
    \(\(forwards\  = \ 
        Transpose[{dates3, year, 
            S\_0 + Map[wfkt, week] + Map[yfkt, year]}];\)\)], "Input"],

Cell["\<\
To visualize the estimated forward curve it is added to the plot of \
historical prices.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\  = \ Length[peak];\)\), "\n", 
    \(\(ticks3\  = \ 
        Map[{n + #, 
              StringForm["\<`3`/`2`/`1`\>", Sequence @@ dates3[\([#]\)]]} &, 
          Range[1, Length[dates3], 100]];\)\), "\[IndentingNewLine]", 
    \(\(plforwd\  = 
        ListPlot[Transpose[{Range[n + 1, n + 365], forwards[\([All, 3]\)]}], 
          PlotStyle \[Rule] Green, \[IndentingNewLine]Frame \[Rule] True, 
          FrameTicks \[Rule] {ticks3, Automatic, None, None}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[plpeak, %, PlotRange \[Rule] Automatic, 
        FrameTicks \[Rule] {Join[ticks, ticks3], Automatic, None, 
            None}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14  scalefont  setfont
% Scaling calculations
0.0238095 0.00090876 0.0047619 0.00369277 [
[.02472 -0.0125 -33.7813 -17.75 ]
[.02472 -0.0125 33.7813 0 ]
[.11559 -0.0125 -33.7813 -17.75 ]
[.11559 -0.0125 33.7813 0 ]
[.20647 -0.0125 -29.875 -17.75 ]
[.20647 -0.0125 29.875 0 ]
[.29735 -0.0125 -33.7813 -17.75 ]
[.29735 -0.0125 33.7813 0 ]
[.38822 -0.0125 -33.7813 -17.75 ]
[.38822 -0.0125 33.7813 0 ]
[.4791 -0.0125 -37.6875 -17.75 ]
[.4791 -0.0125 37.6875 0 ]
[.56997 -0.0125 -29.875 -17.75 ]
[.56997 -0.0125 29.875 0 ]
[.6454 -0.0125 -33.7813 -17.75 ]
[.6454 -0.0125 33.7813 0 ]
[.73628 -0.0125 -29.875 -17.75 ]
[.73628 -0.0125 29.875 0 ]
[.82715 -0.0125 -37.6875 -17.75 ]
[.82715 -0.0125 37.6875 0 ]
[.91803 -0.0125 -33.7813 -17.75 ]
[.91803 -0.0125 33.7813 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00476 -11.8125 -8.875 ]
[-0.0125 .00476 0 8.875 ]
[-0.0125 .04169 -19.625 -8.875 ]
[-0.0125 .04169 0 8.875 ]
[-0.0125 .07862 -19.625 -8.875 ]
[-0.0125 .07862 0 8.875 ]
[-0.0125 .11555 -19.625 -8.875 ]
[-0.0125 .11555 0 8.875 ]
[-0.0125 .15247 -19.625 -8.875 ]
[-0.0125 .15247 0 8.875 ]
[-0.0125 .1894 -19.625 -8.875 ]
[-0.0125 .1894 0 8.875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .1 -37.375 -24.8125 ]
[-0.01875 .1 -19.625 24.8125 ]
[ 0 .2 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02472 0 m
.02472 .00625 L
s
gsave
.02472 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11559 0 m
.11559 .00625 L
s
gsave
.11559 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20647 0 m
.20647 .00625 L
s
gsave
.20647 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.29735 0 m
.29735 .00625 L
s
gsave
.29735 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.38822 0 m
.38822 .00625 L
s
gsave
.38822 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4791 0 m
.4791 .00625 L
s
gsave
.4791 -0.0125 -98.6875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.688 17.625 moveto
(\\220) show
103.125 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2001) show
134.375 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.56997 0 m
.56997 .00625 L
s
gsave
.56997 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2002) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6454 0 m
.6454 .00625 L
s
gsave
.6454 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2002) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.73628 0 m
.73628 .00625 L
s
gsave
.73628 -0.0125 -90.875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.813 17.625 moveto
(\\220) show
75.250 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.063 17.625 moveto
(\\220) show
87.500 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2002) show
118.750 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.82715 0 m
.82715 .00625 L
s
gsave
.82715 -0.0125 -98.6875 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.688 17.625 moveto
(\\220) show
103.125 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2002) show
134.375 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91803 0 m
.91803 .00625 L
s
gsave
.91803 -0.0125 -94.7813 -21.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.625 17.625 moveto
(\\220) show
83.063 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.875 17.625 moveto
(\\220) show
95.313 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2003) show
126.563 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .00476 m
.00625 .00476 L
s
gsave
-0.0125 .00476 -72.8125 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .04169 m
.00625 .04169 L
s
gsave
-0.0125 .04169 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .07862 m
.00625 .07862 L
s
gsave
-0.0125 .07862 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .11555 m
.00625 .11555 L
s
gsave
-0.0125 .11555 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .15247 m
.00625 .15247 L
s
gsave
-0.0125 .15247 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .1894 m
.00625 .1894 L
s
gsave
-0.0125 .1894 -80.625 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.75 translate 1 -1 scale
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
/Arial findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01215 m
.00375 .01215 L
s
0 .01953 m
.00375 .01953 L
s
0 .02692 m
.00375 .02692 L
s
0 .0343 m
.00375 .0343 L
s
0 .04908 m
.00375 .04908 L
s
0 .05646 m
.00375 .05646 L
s
0 .06385 m
.00375 .06385 L
s
0 .07123 m
.00375 .07123 L
s
0 .086 m
.00375 .086 L
s
0 .09339 m
.00375 .09339 L
s
0 .10077 m
.00375 .10077 L
s
0 .10816 m
.00375 .10816 L
s
0 .12293 m
.00375 .12293 L
s
0 .13032 m
.00375 .13032 L
s
0 .1377 m
.00375 .1377 L
s
0 .14509 m
.00375 .14509 L
s
0 .15986 m
.00375 .15986 L
s
0 .16724 m
.00375 .16724 L
s
0 .17463 m
.00375 .17463 L
s
0 .18201 m
.00375 .18201 L
s
0 .19679 m
.00375 .19679 L
s
.25 Mabswid
0 0 m
0 .2 L
s
gsave
-0.01875 .1 -114.313 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.8125 12.875 translate
90 rotate
-85.8125 -12.875 translate
0 25.75 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.625 moveto
%%IncludeResource: font Arial
%%IncludeFont: Arial
%%BeginResource: font Arial-MISO
%%BeginFont: Arial-MISO
/Arial /Arial-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
currentpoint currentpoint
newpath
 moveto
 0.813 0.000 rmoveto
 0 -10.063 rlineto
 6.688 0 rlineto
 0 10.063 rlineto
 -6.688 0 rlineto
closepath
fill moveto
8.313 0.000 rmoveto
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.313 17.625 moveto
(\\220) show
75.750 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MWh) show
108.625 17.625 moveto
%%IncludeResource: font Arial-MISO
%%IncludeFont: Arial-MISO
/Arial-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
1 .2 L
s
1 0 m
1 .2 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02472 .08048 m
.02563 .06082 L
.02654 .05121 L
.02744 .0857 L
.02835 .08917 L
.02926 .08727 L
.03017 .05949 L
.03108 .0674 L
.03199 .05626 L
.0329 .04954 L
.03381 .0879 L
.03471 .07763 L
.03562 .07698 L
.03653 .08786 L
.03744 .07453 L
.03835 .05596 L
.03926 .05027 L
.04017 .07991 L
.04108 .08612 L
.04198 .0817 L
.04289 .08759 L
.0438 .08139 L
.04471 .05803 L
.04562 .04623 L
.04653 .08518 L
.04744 .08895 L
.04835 .08832 L
.04925 .07892 L
.05016 .07251 L
.05107 .05479 L
.05198 .04668 L
.05289 .07413 L
.0538 .06903 L
.05471 .06941 L
.05562 .06992 L
.05652 .07606 L
.05743 .06103 L
.05834 .04801 L
.05925 .074 L
.06016 .06856 L
.06107 .07707 L
.06198 .06973 L
.06289 .07056 L
.06379 .05695 L
.0647 .05017 L
.06561 .07475 L
.06652 .07066 L
.06743 .06614 L
.06834 .07406 L
.06925 .07475 L
Mistroke
.07016 .05967 L
.07107 .04721 L
.07197 .06417 L
.07288 .06883 L
.07379 .0657 L
.0747 .07023 L
.07561 .06625 L
.07652 .05926 L
.07743 .04741 L
.07834 .07206 L
.07924 .06364 L
.08015 .07937 L
.08106 .08062 L
.08197 .07591 L
.08288 .06679 L
.08379 .05215 L
.0847 .09248 L
.08561 .10999 L
.08651 .0781 L
.08742 .10039 L
.08833 .08919 L
.08924 .05837 L
.09015 .04362 L
.09106 .09529 L
.09197 .09927 L
.09288 .11597 L
.09378 .09993 L
.09469 .11003 L
.0956 .06993 L
.09651 .05868 L
.09742 .10655 L
.09833 .12064 L
.09924 .11507 L
.10015 .11918 L
.10105 .12202 L
.10196 .06686 L
.10287 .04964 L
.10378 .111 L
.10469 .1222 L
.1056 .12341 L
.10651 .15222 L
.10742 .10616 L
.10832 .07434 L
.10923 .05714 L
.11014 .10688 L
.11105 .10881 L
.11196 .1138 L
.11287 .14738 L
.11378 .10681 L
.11469 .0782 L
Mistroke
.11559 .05708 L
.1165 .10509 L
.11741 .10871 L
.11832 .10403 L
.11923 .10904 L
.12014 .10127 L
.12105 .07921 L
.12196 .04872 L
.12286 .09188 L
.12377 .07817 L
.12468 .10472 L
.12559 .09114 L
.1265 .08825 L
.12741 .07429 L
.12832 .05019 L
.12923 .10955 L
.13013 .09741 L
.13104 .12938 L
.13195 .11176 L
.13286 .10191 L
.13377 .05564 L
.13468 .04238 L
.13559 .08015 L
.1365 .10661 L
.1374 .09201 L
.13831 .09441 L
.13922 .08996 L
.14013 .06594 L
.14104 .04846 L
.14195 .10958 L
.14286 .10736 L
.14377 .10063 L
.14467 .10512 L
.14558 .10594 L
.14649 .07881 L
.1474 .05694 L
.14831 .12678 L
.14922 .11344 L
.15013 .09036 L
.15104 .15588 L
.15194 .08776 L
.15285 .08405 L
.15376 .05728 L
.15467 .11326 L
.15558 .11648 L
.15649 .11393 L
.1574 .08772 L
.15831 .09739 L
.15921 .07073 L
.16012 .05903 L
Mistroke
.16103 .11889 L
.16194 .11006 L
.16285 .12308 L
.16376 .12093 L
.16467 .12164 L
.16558 .08325 L
.16648 .07961 L
.16739 .12362 L
.1683 .11652 L
.16921 .12494 L
.17012 .12755 L
.17103 .11057 L
.17194 .10118 L
.17285 .06433 L
.17375 .1303 L
.17466 .11875 L
.17557 .12113 L
.17648 .1441 L
.17739 .11194 L
.1783 .07558 L
.17921 .07617 L
.18012 .13492 L
.18103 .11215 L
.18193 .14494 L
.18284 .12114 L
.18375 .0752 L
.18466 .09102 L
.18557 .07476 L
.18648 .12035 L
.18739 .12106 L
.1883 .09768 L
.1892 .11056 L
.19011 .12127 L
.19102 .08337 L
.19193 .07189 L
.19284 .15203 L
.19375 .17722 L
.19466 .16071 L
.19557 .1224 L
.19647 .09912 L
.19738 .08196 L
.19829 .07089 L
.1992 .06268 L
.20011 .06242 L
.20102 .09443 L
.20193 .08464 L
.20284 .07937 L
.20374 .0804 L
.20465 .07346 L
.20556 .04829 L
Mistroke
.20647 .08519 L
.20738 .08044 L
.20829 .09481 L
.2092 .09288 L
.21011 .07232 L
.21101 .06877 L
.21192 .11437 L
.21283 .11643 L
.21374 .12207 L
.21465 .11981 L
.21556 .10888 L
.21647 .09502 L
.21738 .08592 L
.21828 .1412 L
.21919 .13325 L
.2201 .14391 L
.22101 .12312 L
.22192 .1392 L
.22283 .09584 L
.22374 .07636 L
.22465 .14328 L
.22555 .11889 L
.22646 .09073 L
.22737 .12043 L
.22828 .10844 L
.22919 .07475 L
.2301 .06799 L
.23101 .11123 L
.23192 .12485 L
.23282 .11546 L
.23373 .10969 L
.23464 .13724 L
.23555 .09559 L
.23646 .0812 L
.23737 .13025 L
.23828 .09799 L
.23919 .1088 L
.24009 .10458 L
.241 .10281 L
.24191 .0872 L
.24282 .0701 L
.24373 .10116 L
.24464 .09469 L
.24555 .09481 L
.24646 .11912 L
.24736 .10059 L
.24827 .08282 L
.24918 .07113 L
.25009 .09677 L
.251 .0983 L
Mistroke
.25191 .09551 L
.25282 .09499 L
.25373 .11281 L
.25463 .0996 L
.25554 .07405 L
.25645 .12349 L
.25736 .14879 L
.25827 .13267 L
.25918 .19119 L
.26009 .12015 L
.261 .10643 L
.2619 .07701 L
.26281 .12816 L
.26372 .15409 L
.26463 .12495 L
.26554 .11631 L
.26645 .08718 L
.26736 .08222 L
.26827 .06862 L
.26917 .10286 L
.27008 .07393 L
.27099 .09403 L
.2719 .09576 L
.27281 .09088 L
.27372 .07906 L
.27463 .0641 L
.27554 .0803 L
.27644 .09802 L
.27735 .08237 L
.27826 .09342 L
.27917 .08388 L
.28008 .07584 L
.28099 .0379 L
.2819 .08624 L
.28281 .09636 L
.28372 .07718 L
.28462 .08983 L
.28553 .09838 L
.28644 .07475 L
.28735 .06747 L
.28826 .12125 L
.28917 .11002 L
.29008 .08541 L
.29099 .10087 L
.29189 .10573 L
.2928 .08801 L
.29371 .0701 L
.29462 .09869 L
.29553 .11557 L
.29644 .1155 L
Mistroke
.29735 .0871 L
.29826 .06563 L
.29916 .08494 L
.30007 .0654 L
.30098 .05093 L
.30189 .12856 L
.3028 .12148 L
.30371 .1978 L
.30462 .1252 L
.30553 .09183 L
.30643 .08213 L
.30734 .17531 L
.30825 .14004 L
.30916 .11502 L
.31007 .11354 L
.31098 .14948 L
.31189 .0896 L
.3128 .07545 L
.3137 .10078 L
.31461 .05862 L
.31552 .15734 L
.31643 .09751 L
.31734 .09667 L
.31825 .08087 L
.31916 .07442 L
.32007 .12206 L
.32097 .10684 L
.32188 .09501 L
.32279 .11222 L
.3237 .08453 L
.32461 .0847 L
.32552 .06251 L
.32643 .12023 L
.32734 .11814 L
.32824 .12554 L
.32915 .10211 L
.33006 .10905 L
.33097 .07618 L
.33188 .06968 L
.33279 .14595 L
.3337 .1406 L
.33461 .11133 L
.33551 .06218 L
.33642 .07494 L
.33733 .06712 L
.33824 .05019 L
.33915 .11805 L
.34006 .11482 L
.34097 .12173 L
.34188 .13409 L
Mistroke
.34278 .08626 L
.34369 .06323 L
.3446 .04105 L
.34551 .0515 L
.34642 .11835 L
.34733 .14773 L
.34824 .09563 L
.34915 .10579 L
.35005 .1023 L
.35096 .06461 L
.35187 .10865 L
.35278 .11887 L
.35369 .16041 L
.3546 .09062 L
.35551 .08809 L
.35642 .09367 L
.35732 .05997 L
.35823 .14183 L
.35914 .12085 L
.36005 .13884 L
.36096 .11647 L
.36187 .09796 L
.36278 .07185 L
.36369 .05425 L
.36459 .12488 L
.3655 .15377 L
.36641 .12376 L
.36732 .16382 L
.36823 .12922 L
.36914 .0773 L
.37005 .04852 L
.37096 .17394 L
.37186 .13531 L
.37277 .13443 L
.37368 .16152 L
.37459 .12987 L
.3755 .10054 L
.37641 .05095 L
.37732 .1468 L
.37823 .12455 L
.37913 .12402 L
.38004 .10861 L
.38095 .10831 L
.38186 .06805 L
.38277 .05284 L
.38368 .13079 L
.38459 .10541 L
.3855 .09174 L
.3864 .10491 L
.38731 .10306 L
Mistroke
.38822 .06193 L
.38913 .04571 L
.39004 .09276 L
.39095 .09571 L
.39186 .08142 L
.39277 .09944 L
.39368 .08188 L
.39458 .06471 L
.39549 .04623 L
.3964 .09809 L
.39731 .10287 L
.39822 .08313 L
.39913 .09466 L
.40004 .08942 L
.40095 .06923 L
.40185 .04583 L
.40276 .11086 L
.40367 .09427 L
.40458 .09936 L
.40549 .0846 L
.4064 .1046 L
.40731 .04524 L
.40822 .0299 L
.40912 .08263 L
.41003 .08934 L
.41094 .08043 L
.41185 .12181 L
.41276 .12415 L
.41367 .0798 L
.41458 .05369 L
.41549 .11543 L
.41639 .1414 L
.4173 .11694 L
.41821 .14383 L
.41912 .12551 L
.42003 .09217 L
.42094 .07169 L
.42185 .13205 L
.42276 .123 L
Mfstroke
.42276 .123 m
.42328 .2 L
s
.42406 .2 m
.42457 .12719 L
.42548 .10518 L
.42639 .08381 L
.4273 .06799 L
.42821 .15013 L
.42912 .11463 L
.43003 .10958 L
.43093 .11611 L
.43184 .10334 L
.43275 .07945 L
.43366 .06319 L
.43457 .11265 L
.43548 .11443 L
.43639 .13701 L
.4373 .11515 L
.4382 .14248 L
.43911 .07868 L
.44002 .06578 L
.44093 .11555 L
.44184 .12215 L
.44275 .1216 L
.44366 .11747 L
.44457 .12019 L
.44547 .08852 L
.44638 .0789 L
.44729 .12201 L
.4482 .12221 L
.44911 .12634 L
.45002 .1107 L
.45093 .11104 L
.45184 .08497 L
.45274 .07652 L
.45365 .16548 L
.45456 .11689 L
.45547 .09052 L
.45638 .10672 L
.45729 .09977 L
.4582 .08355 L
.45911 .0626 L
.46001 .10333 L
.46092 .10149 L
.46183 .10586 L
.46274 .12356 L
.46365 .09018 L
.46456 .07595 L
.46547 .07415 L
.46638 .11066 L
.46728 .11217 L
.46819 .1158 L
Mistroke
.4691 .11164 L
.47001 .1123 L
.47092 .08922 L
.47183 .08329 L
.47274 .11943 L
.47365 .12695 L
.47455 .13223 L
.47546 .13587 L
.47637 .10858 L
.47728 .09888 L
.47819 .07574 L
.4791 .1657 L
.48001 .13464 L
.48092 .10953 L
.48182 .07987 L
.48273 .11378 L
.48364 .0993 L
.48455 .07998 L
.48546 .13806 L
.48637 .1278 L
.48728 .13294 L
.48819 .13176 L
.48909 .14244 L
.49 .1028 L
.49091 .07893 L
.49182 .13843 L
Mfstroke
.49182 .13843 m
.49235 .2 L
s
.49393 .2 m
.49455 .17175 L
.49546 .19085 L
.49636 .14335 L
.49727 .10867 L
.49818 .17333 L
.49909 .18206 L
.5 .17285 L
.50091 .15507 L
.50182 .17833 L
.50273 .11278 L
.50364 .0763 L
.50454 .17318 L
.50545 .16169 L
.50636 .15608 L
.50727 .15017 L
.50818 .12798 L
.50909 .08424 L
.51 .07436 L
s
.51 .07436 m
.51085 .2 L
s
.51107 .2 m
.51181 .16649 L
.51272 .13494 L
.51363 .12895 L
.51454 .13919 L
.51545 .11348 L
.51636 .09085 L
s
.51636 .09085 m
.51669 .2 L
s
.52155 .2 m
.52181 .15774 L
.52272 .10651 L
s
.52272 .10651 m
.52277 .2 L
s
.52544 .2 m
.52545 .19722 L
s
.52545 .19722 m
.52548 .2 L
s
.52682 .2 m
.52726 .1335 L
.52817 .13334 L
.52908 .09968 L
.52999 .10455 L
.5309 .06815 L
.53181 .07941 L
.53272 .14445 L
.53362 .07118 L
.53453 .08584 L
.53544 .0758 L
.53635 .10734 L
.53726 .05924 L
.53817 .14331 L
.53908 .15238 L
.53999 .14672 L
.54089 .11968 L
.5418 .09022 L
s
.5418 .09022 m
.54243 .2 L
s
.54618 .2 m
.54635 .18933 L
.54726 .15151 L
.54816 .11875 L
.54907 .19138 L
.54998 .14702 L
.55089 .16146 L
.5518 .15406 L
.55271 .14549 L
.55362 .07281 L
.55453 .07555 L
.55543 .13603 L
.55634 .13098 L
.55725 .12341 L
.55816 .12371 L
.55907 .11443 L
.55998 .08666 L
.56089 .07486 L
.5618 .12263 L
.5627 .09244 L
.56361 .11293 L
.56452 .09959 L
.56543 .09614 L
.56634 .07008 L
.56725 .06178 L
.56816 .10219 L
.56907 .10114 L
.56997 .09584 L
.57088 .09336 L
.57179 .08633 L
.5727 .0779 L
.57361 .06731 L
.57452 .08894 L
.57543 .07428 L
.57634 .10211 L
.57724 .10873 L
.57815 .07928 L
.57906 .10264 L
.57997 .07834 L
.58088 .10841 L
.58179 .10094 L
.5827 .10638 L
.58361 .12139 L
.58451 .09417 L
.58542 .08092 L
.58633 .07992 L
.58724 .11056 L
.58815 .10447 L
.58906 .09327 L
.58997 .10372 L
Mistroke
.59088 .12996 L
.59178 .0826 L
.59269 .07049 L
.5936 .10878 L
.59451 .11446 L
.59542 .1045 L
.59633 .0986 L
.59724 .09242 L
.59815 .08844 L
.59905 .07587 L
.59996 .09755 L
.60087 .09981 L
.60178 .08755 L
.60269 .09586 L
.6036 .08155 L
.60451 .07635 L
.60542 .06516 L
.60632 .09544 L
.60723 .09358 L
.60814 .09743 L
.60905 .09131 L
.60996 .08961 L
.61087 .06679 L
.61178 .05245 L
.61269 .10212 L
.6136 .10538 L
.6145 .11097 L
.61541 .10458 L
.61632 .06347 L
.61723 .06925 L
.61814 .04106 L
.61905 .03081 L
.61996 .09607 L
.62087 .08388 L
.62177 .09117 L
.62268 .07917 L
.62359 .07861 L
.6245 .06189 L
.62541 .12804 L
.62632 .1124 L
.62723 .11268 L
.62814 .13139 L
.62904 .11844 L
.62995 .08571 L
.63086 .06647 L
.63177 .12941 L
.63268 .15009 L
.63359 .13381 L
.6345 .12834 L
.63541 .11242 L
Mistroke
.63631 .09902 L
.63722 .06242 L
.63813 .11293 L
.63904 .12536 L
.63995 .14139 L
.64086 .10774 L
.64177 .0972 L
.64268 .06916 L
.64358 .05576 L
.64449 .10139 L
Mfstroke
0 1 0 r
.6454 .11407 m
.64631 .10862 L
.64722 .10083 L
.64813 .08965 L
.64904 .07358 L
.64995 .05042 L
.65085 .11659 L
.65176 .11277 L
.65267 .10732 L
.65358 .09953 L
.65449 .08835 L
.6554 .07228 L
.65631 .04912 L
.65722 .11529 L
.65812 .11147 L
.65903 .10603 L
.65994 .09824 L
.66085 .08706 L
.66176 .07099 L
.66267 .04783 L
.66358 .11401 L
.66449 .11018 L
.66539 .10474 L
.6663 .09695 L
.66721 .08578 L
.66812 .06971 L
.66903 .04656 L
.66994 .11273 L
.67085 .10891 L
.67176 .10347 L
.67266 .09569 L
.67357 .08451 L
.67448 .06845 L
.67539 .0453 L
.6763 .11147 L
.67721 .10766 L
.67812 .10222 L
.67903 .09444 L
.67993 .08327 L
.68084 .06721 L
.68175 .04406 L
.68266 .11024 L
.68357 .10643 L
.68448 .101 L
.68539 .09322 L
.6863 .08206 L
.6872 .06599 L
.68811 .04285 L
.68902 .10904 L
.68993 .10523 L
Mistroke
.69084 .0998 L
.69175 .09203 L
.69266 .08087 L
.69357 .06482 L
.69447 .04168 L
.69538 .10787 L
.69629 .10407 L
.6972 .09865 L
.69811 .09088 L
.69902 .07973 L
.69993 .06368 L
.70084 .04055 L
.70174 .10674 L
.70265 .10295 L
.70356 .09753 L
.70447 .08977 L
.70538 .07862 L
.70629 .06258 L
.7072 .03946 L
.70811 .10566 L
.70901 .10187 L
.70992 .09646 L
.71083 .0887 L
.71174 .07756 L
.71265 .06153 L
.71356 .03841 L
.71447 .10462 L
.71538 .10084 L
.71628 .09544 L
.71719 .08769 L
.7181 .07656 L
.71901 .06053 L
.71992 .03742 L
.72083 .10364 L
.72174 .09986 L
.72265 .09447 L
.72356 .08673 L
.72446 .07561 L
.72537 .05959 L
.72628 .03649 L
.72719 .10271 L
.7281 .09895 L
.72901 .09356 L
.72992 .08583 L
.73083 .07472 L
.73173 .0587 L
.73264 .03561 L
.73355 .10185 L
.73446 .09809 L
.73537 .09272 L
Mistroke
.73628 .085 L
.73719 .07389 L
.7381 .05789 L
.739 .03481 L
.73991 .10105 L
.74082 .0973 L
.74173 .09193 L
.74264 .08422 L
.74355 .07313 L
.74446 .05714 L
.74537 .03406 L
.74627 .10032 L
.74718 .09658 L
.74809 .09122 L
.749 .08352 L
.74991 .07244 L
.75082 .05645 L
.75173 .03339 L
.75264 .09966 L
.75354 .09593 L
.75445 .09058 L
.75536 .0829 L
.75627 .07182 L
.75718 .05585 L
.75809 .0328 L
.759 .09907 L
.75991 .09536 L
.76081 .09002 L
.76172 .08234 L
.76263 .07128 L
.76354 .05532 L
.76445 .03228 L
.76536 .09856 L
.76627 .09486 L
.76718 .08953 L
.76808 .08187 L
.76899 .07081 L
.7699 .05486 L
.77081 .03184 L
.77172 .09813 L
.77263 .09444 L
.77354 .08913 L
.77445 .08147 L
.77535 .07043 L
.77626 .05449 L
.77717 .03147 L
.77808 .09778 L
.77899 .0941 L
.7799 .0888 L
.78081 .08116 L
Mistroke
.78172 .07012 L
.78262 .0542 L
.78353 .03119 L
.78444 .09752 L
.78535 .09385 L
.78626 .08856 L
.78717 .08092 L
.78808 .0699 L
.78899 .05399 L
.78989 .031 L
.7908 .09733 L
.79171 .09367 L
.79262 .0884 L
.79353 .08078 L
.79444 .06977 L
.79535 .05387 L
.79626 .03089 L
.79716 .09723 L
.79807 .09359 L
.79898 .08832 L
.79989 .08071 L
.8008 .06972 L
.80171 .05383 L
.80262 .03086 L
.80353 .09722 L
.80443 .09358 L
.80534 .08833 L
.80625 .08073 L
.80716 .06975 L
.80807 .05387 L
.80898 .03092 L
.80989 .09729 L
.8108 .09366 L
.8117 .08842 L
.81261 .08084 L
.81352 .06987 L
.81443 .054 L
.81534 .03106 L
.81625 .09744 L
.81716 .09383 L
.81807 .0886 L
.81897 .08103 L
.81988 .07007 L
.82079 .05422 L
.8217 .03128 L
.82261 .09768 L
.82352 .09408 L
.82443 .08886 L
.82534 .0813 L
.82625 .07036 L
Mistroke
.82715 .05451 L
.82806 .03159 L
.82897 .098 L
.82988 .09441 L
.83079 .08921 L
.8317 .08166 L
.83261 .07073 L
.83352 .05489 L
.83442 .03199 L
.83533 .0984 L
.83624 .09483 L
.83715 .08963 L
.83806 .0821 L
.83897 .07117 L
.83988 .05536 L
.84079 .03246 L
.84169 .09889 L
.8426 .09532 L
.84351 .09014 L
.84442 .08262 L
.84533 .0717 L
.84624 .0559 L
.84715 .03301 L
.84806 .09945 L
.84896 .0959 L
.84987 .09072 L
.85078 .08321 L
.85169 .07231 L
.8526 .05651 L
.85351 .03364 L
.85442 .10009 L
.85533 .09655 L
.85623 .09138 L
.85714 .08388 L
.85805 .07299 L
.85896 .0572 L
.85987 .03434 L
.86078 .1008 L
.86169 .09727 L
.8626 .09212 L
.8635 .08462 L
.86441 .07374 L
.86532 .05796 L
.86623 .03511 L
.86714 .10158 L
.86805 .09806 L
.86896 .09292 L
.86987 .08543 L
.87077 .07456 L
.87168 .0588 L
Mistroke
.87259 .03595 L
.8735 .10243 L
.87441 .09892 L
.87532 .09379 L
.87623 .08631 L
.87714 .07545 L
.87804 .05969 L
.87895 .03685 L
.87986 .10334 L
.88077 .09984 L
.88168 .09472 L
.88259 .08725 L
.8835 .0764 L
.88441 .06065 L
.88531 .03782 L
.88622 .10432 L
.88713 .10082 L
.88804 .09571 L
.88895 .08825 L
.88986 .0774 L
.89077 .06166 L
.89168 .03884 L
.89258 .10535 L
.89349 .10186 L
.8944 .09675 L
.89531 .0893 L
.89622 .07846 L
.89713 .06273 L
.89804 .03992 L
.89895 .10643 L
.89985 .10295 L
.90076 .09785 L
.90167 .0904 L
.90258 .07957 L
.90349 .06385 L
.9044 .04104 L
.90531 .10756 L
.90622 .10408 L
.90712 .09899 L
.90803 .09155 L
.90894 .08073 L
.90985 .06501 L
.91076 .04221 L
.91167 .10873 L
.91258 .10526 L
.91349 .10017 L
.91439 .09274 L
.9153 .08192 L
.91621 .06621 L
.91712 .04341 L
Mistroke
.91803 .10994 L
.91894 .10648 L
.91985 .10139 L
.92076 .09397 L
.92166 .08315 L
.92257 .06744 L
.92348 .04465 L
.92439 .11118 L
.9253 .10773 L
.92621 .10265 L
.92712 .09522 L
.92803 .08441 L
.92893 .06871 L
.92984 .04592 L
.93075 .11246 L
.93166 .109 L
.93257 .10393 L
.93348 .09651 L
.93439 .0857 L
.9353 .06999 L
.93621 .04721 L
.93711 .11375 L
.93802 .1103 L
.93893 .10523 L
.93984 .09781 L
.94075 .087 L
.94166 .0713 L
.94257 .04852 L
.94348 .11506 L
.94438 .11161 L
.94529 .10654 L
.9462 .09913 L
.94711 .08832 L
.94802 .07262 L
.94893 .04984 L
.94984 .11639 L
.95075 .11294 L
.95165 .10787 L
.95256 .10045 L
.95347 .08965 L
.95438 .07395 L
.95529 .05117 L
.9562 .11772 L
.95711 .11427 L
.95802 .1092 L
.95892 .10179 L
.95983 .09099 L
.96074 .07529 L
.96165 .05251 L
.96256 .11905 L
Mistroke
.96347 .1156 L
.96438 .11053 L
.96529 .10312 L
.96619 .09232 L
.9671 .07662 L
.96801 .05384 L
.96892 .12038 L
.96983 .11693 L
.97074 .11186 L
.97165 .10444 L
.97256 .09364 L
.97346 .07794 L
.97437 .05516 L
.97528 .1217 L
.97619 .11825 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{801, 160},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<Q0000X2000`400?l00000o`00003oo`3ooooo
0?ooool0oooo903oool00?l0ooooo`3ooooo0?ooob@0oooo003o0?ooool0ooooo`3ooolT0?ooo`00
H@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`1X0?ooo`00H@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1X0?ooo`00H@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`1X0?ooo`00E@3oool00`000000oooo0?ooo`030?ooo`@000000`3oool00`00
0000oooo0?ooo`020?ooo`@000000`3oool010000000oooo0?ooo`3oool6000000<0oooo10000004
0?ooo`@00000103oool8000000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`<000000`3o
ool00`000000oooo0?ooo`020?ooo`H000000`3oool4000000@0oooo100000040?ooo`@000000P3o
ool600000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo0?ooo`H000000`3oool4000000@0oooo100000060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool6000000030?ooo`000000oooo00L0oooo00D000000?ooo`3oool0
oooo000000030?ooo`H000000`3oool4000000@0oooo100000060?ooo`H000001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`H000000`3oool4000000@0oooo100000020?ooo`H000000`3oool3000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`@000000`3oool010000000
oooo0?ooo`3oool6000000<0oooo100000040?ooo`@000001P3oool5000000<0oooo00<000000?oo
o`3oool00P3oool6000000030?ooo`000000oooo00<0oooo1P0000030?ooo`@00000103oool40000
00030?ooo`000000000000X000000P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000000`3oool6000000<0oooo100000040?ooo`@000000`3oool600000080oooo10000003
0?ooo`030000003oool0oooo00<0oooo100000020?ooo`030000003oool0oooo0080oooo1P000003
0?ooo`@00000103oool4000000<0oooo1`0000050?ooo`@000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3o
ool6000000<0oooo100000040?ooo`@000000`3oool6000000H0oooo00@000000?ooo`3oool00000
103oool6000000030?ooo`000000oooo00<0oooo1P0000030?ooo`@00000103oool4000000@0oooo
100000180?ooo`00E@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool000000`3oool2000000T0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo0P0000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000080?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0A@3oool005D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool700000080oooo00<000000?ooo`3oool01`3oool00`000000oooo000000060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo1`0000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0000000<0oooo
1`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool700000003
0?ooo`000000oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0A@3oool005D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000007
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000P0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`00
0000oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0A@3oool005D0oooo
00<000000?ooo`3oool00P3oool2000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`80
00000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`<0
000000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool3000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`050000
003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00<0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3o
ool0000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000040?ooo`040000003oool0oooo
000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo
000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo000000040?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`05
0000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04D0oooo001E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P0000040?ooo`050000003oool0
oooo0000003oool00`0000040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000
0`3oool200000080oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`05
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooo`8000000P3oool010000000oooo0?ooo`3oool2000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000070?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000800000103oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool00000008000000`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@00000103oool00`000000oooo0?ooo`02
0?ooo`@000000`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000@0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`800000103oool00`000000oooo
00000002000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000080?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080oooo0`0000180?ooo`00E@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000040?oo
o`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`0000001`3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`00
00000`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00D000000?ooo`3oool0oooo000000070?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`050?ooo`800000103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
00L0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0A@3oool005<0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0000000T0oooo00<000000?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00001@3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000040?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool00P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00<000000?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool0
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`070000
003oool0oooo0?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool01P00
0000oooo0000003oool000000?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool01`000000oooo0?ooo`3oool000000?ooo`000000
2@3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103o
ool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000030?ooo`<00000103oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo0000003o
ool000001@3oool00`000000oooo000000060?ooo`030000003oool0000000@0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0A@3oool005@0oooo0P0000050?ooo`050000003oool0oooo0?ooo`000000
103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
0000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo0P00
00050?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000oooo000000040?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oo
o`8000001P3oool2000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000D0oooo0P0000050?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000
003oool0oooo0080oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo000000020?ooo`<000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`<0
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`060000003oool0oooo0000003oool000000P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000D0oooo00<00000
0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo000000040?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool2000000D0oooo00D000000?ooo`3oool0oooo000000040?oo
o`040000003oool0oooo0?ooo`8000001P3oool2000000H0oooo00<000000?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`800000103oool010000000oooo0?ooo`0000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo04D0oooo001E0?ooo`030000003oool0oooo00@0oooo0`0000060?ooo`030000
003oool0oooo00<000001P3oool00`000000oooo00000003000000@0oooo100000040?ooo`@00000
103oool7000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04000000D0oooo
00<000000?ooo`3oool0100000040?ooo`@00000103oool4000000@0oooo100000030?ooo`@00000
1P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`0000000`0000040?ooo`@0
0000103oool4000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`@0
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
00000`0000040?ooo`@00000103oool4000000H0oooo1@0000060?ooo`030000003oool0oooo00D0
oooo1`0000050?ooo`030000003oool0oooo00@00000103oool4000000@0oooo100000030?ooo`@0
0000103oool4000000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`@000001P3oool00`00
0000oooo00000003000000@0oooo100000040?ooo`@000001P3oool00`000000oooo000000020000
00H0oooo00<000000?ooo`3oool0100000050?ooo`030000003oool0oooo00@00000103oool40000
00@0oooo100000000`3oool0000000000005000000030?ooo`0000000000008000001@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`0000040?oo
o`@00000103oool4000000@0oooo100000030?ooo`@000001P3oool00`000000oooo0?ooo`040000
00D0oooo00<000000?ooo`3oool0100000040?ooo`@00000103oool4000000@0oooo100000000`3o
ool000000?ooo`050?ooo`<000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo00000003000000@0oooo100000040?ooo`@00000103oool4
000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04000000D0oooo00<00000
0?ooo`3oool0100000040?ooo`@00000103oool4000000@0oooo100000180?ooo`00o`3ooooo0?oo
ool0oooo903oool00?l0ooooo`3ooooo0?ooob@0oooo003o0?ooool0ooooo`3ooolT0?ooo`00o`3o
oooo0?ooool0oooo903oool00?l0ooooo`3ooooo0?ooob@0oooo003o0?ooool0ooooo`3ooolT0?oo
o`00o`3ooooo0?ooool0oooo903oool00?l0ooooo`3ooooo0?ooob@0oooo003o0?ooool0ooooo`3o
oolT0?ooo`00o`3ooooo0?ooool0oooo903oool00500oooo1000000<0?ooool00000o`00002C0000
0300oooo001?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0^0?ooo`00C`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0;P3oool004l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo02h0oooo001?0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool6000000/0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo02h0oooo001?0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0^0?ooo`00C`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooooo0?ooohl0oooo00<000000?ooo`3o
ool0;P3oool004l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0?l0ooooo`3ooon?0?ooo`030000003oool0oooo02h0oooo001?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02@3oool400000?l0ooooo`3ooon>0?ooo`030000003o
ool0oooo02h0oooo001@0?ooo`@00000303oool00`000000oooo0?ooo`3o0?ooool0ooooS`3oool0
0`000000oooo0?ooo`0^0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0ooooS`3oool00`00
0000oooo0?ooo`0^0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0ooooS`3oool00`000000
oooo0?ooo`0^0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0ooooS`3oool00`000000oooo
0?ooo`0^0?ooo`00H03oool400000?l0ooooo`3ooon>0?ooo`030000003oool0oooo02h0oooo001P
0?ooo`030000003oool0oooo0?l0ooooo`3ooon?0?ooo`030000003oool0oooo02h0oooo001P0?oo
o`030000003oool0oooo0?l0ooooo`3ooon?0?ooo`030000003oool0oooo02h0oooo001P0?ooo`03
0000003oool0oooo0?l0ooooo`3ooon?0?ooo`030000003oool0oooo02h0oooo001P0?ooo`030000
003oool0oooo0?l0ooooo`3ooon?0?ooo`030000003oool0oooo02h0oooo001P0?ooo`@00000o`3o
oooo0?ooohh0oooo00<000000?ooo`3oool0;P3oool00600oooo00<000000?ooo`3oool0o`3ooooo
0?ooohl0oooo00<000000?ooo`3oool0;P3oool00600oooo00<000000?ooo`3oool0o`3oool:0?oo
o`030?l0003oool0oooo0?l0ooooPP3oool00`000000oooo0?ooo`0^0?ooo`00H03oool00`000000
oooo0?ooo`3o0?ooo`X0oooo00<0o`000?ooo`3oool0Q`3oool00`3o0000oooo0?ooo`1Q0?ooo`05
003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00D00?l0
0?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo
0?ooo`3oool00?l000@0oooo00<00?l00?ooo`3oool0J@3oool00`000000oooo0?ooo`0^0?ooo`00
H03oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<0o`000?ooo`3oool0Q`3oool00`3o0000oooo
0?ooo`1D0?ooo`05003o003oool0oooo0?ooo`00o`00103oool01@00o`00oooo0?ooo`3oool00?l0
00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`03003o003oool0oooo0080oooo00D00?l0
0?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo
0?ooo`3oool00?l000@0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo
0?ooo`00o`00G`3oool00`000000oooo0?ooo`0^0?ooo`00H03oool400000?l0oooo2@3oool00`3o
0000oooo0?ooo`270?ooo`030?l0003oool0oooo04`0oooo00D00?l00?ooo`3oool0oooo003o0003
0?ooo`05003o003oool0oooo0?ooo`00o`00103oool01@00o`00oooo0?ooo`3oool00?l000<0oooo
00D00?l00?ooo`3oool0oooo003o00030?ooo`03003o003oool0oooo0080oooo00D00?l00?ooo`3o
ool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3o
ool00?l000@0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00
o`000`3oool01@00o`00oooo0?ooo`3oool00?l005L0oooo00<000000?ooo`3oool0;P3oool004/0
oooo00<000000?ooo`3oool00`3oool4000000/0oooo00<000000?ooo`3oool0o`3oool:0?ooo`03
0?l0003oool0oooo08L0oooo00<0o`000?ooo`3oool0A03oool01@00o`00oooo0?ooo`3oool00?l0
00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`00103o
ool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`03
003o003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo
0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00D00?l00?ooo`3oool0oooo
003o00030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l0
00@0oooo00<00?l00?ooo`3oool0D03oool00`000000oooo0?ooo`0^0?ooo`00B`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`2f0?ooo`030?l0003oool0oooo0500oooo00<0o`000?ooo`3oool0Q`3oool00`3o0000
oooo0?ooo`0o0?ooo`03003o003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo003o00030?oo
o`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00D0
0?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`00o`00
oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool0
0?l000<0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`05003o003oool0oooo0?ooo`00o`00
0`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00040?oo
o`05003o003oool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`180?ooo`030000003oool0
oooo02h0oooo001;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0;H0oooo00<0o`000?ooo`3oool0D03oool00`3o
0000oooo0?ooo`270?ooo`030?l0003oool0oooo03L0oooo00D00?l00?ooo`3oool0oooo003o0003
0?ooo`03003o003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003o
ool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00D00?l00?ooo`3o
ool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`02
0?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo
00D00?l00?ooo`3oool0oooo003o00040?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00
o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`05003o003o
ool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l004H0oooo00<000000?ooo`3o
ool0;P3oool004/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0]P3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0
003oool0oooo02L0oooo00<0o`000?ooo`3oool0Q`3oool00`3o0000oooo0?ooo`0c0?ooo`05003o
003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00D00?l00?oo
o`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?oo
o`3oool00?l000@0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?oo
o`00o`000`3oool00`00o`00oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool0
1@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`05003o
003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?oo
o`3oool0oooo003o00040?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?oo
o`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o000n0?ooo`030000003oool0oooo02h0
oooo001;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`H00000D`3oool00`3o0000oooo0?ooo`1M0?ooo`030?l0003oool0oooo02H0oooo
00<0o`000?ooo`3oool09`3oool00`3o0000oooo0?ooo`270?ooo`030?l0003oool0oooo02l0oooo
00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`00
o`00oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3o
ool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`05003o003oool0oooo0?ooo`00
o`000`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool00P3oool01@00
o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003o
ool0oooo0?ooo`00o`00103oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3o
ool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`00103oool01@00o`00oooo0?ooo`3o
ool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00
o`00103oool00`00o`00oooo0?ooo`0g0?ooo`030000003oool0oooo02h0oooo001;0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo03T0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`1M0?ooo`030?l0
003oool0oooo02H0oooo00<0o`000?ooo`3oool09`3oool00`3o0000oooo0?ooo`270?ooo`030?l0
003oool0oooo02H0oooo00<00?l00?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool00?l000<0
oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`00103oool0
1@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o
003oool0oooo0?ooo`00o`00103oool00`00o`00oooo0?ooo`02003o0080oooo0P00o`030?ooo`05
003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o
00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00`3oool01@00o`00oooo0?ooo`3o
ool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`03003o003oool0oooo0080oooo
00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00
o`00oooo0?ooo`3oool00?l000@0oooo00D00?l00?ooo`3oool0oooo003o000e0?ooo`030000003o
ool0oooo02h0oooo001;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo03T0oooo00<0o`000?ooo`3oool06P3oool0
0`3o0000oooo0?ooo`1M0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool06`3oool0
0`3o0000oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`3o0000R@3oool00`3o0000oooo0?oo
o`0R0?ooo`05003o003oool0oooo0?ooo`00o`00103oool01@00o`00oooo0?ooo`3oool00?l000<0
oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`00103oool0
1@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o
003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00
oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`030?oo
o`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2
003o00<0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`05003o003oool0oooo0?ooo`00o`00
0`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00040?oo
o`05003o003oool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`0_0?ooo`030000003oool0
oooo02h0oooo00190?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool06P3oool00`3o
0000oooo0?ooo`1M0?ooo`030?l0003oool0oooo02H0oooo0P3o000L0?ooo`050?l0003oool0oooo
0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0008T0oooo00<0o`000?ooo`3oool07P3o
ool01@00o`00oooo0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool00P3oool01@00o`00oooo
0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo
0?ooo`00o`00103oool01@00o`00oooo0?ooo`3oool00?l00080oooo0P00o`030?ooo`05003o003o
ool0oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`020?ooo`80
0?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o
0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`02
0?ooo`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`05003o003o
ool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3o
ool0oooo003o00040?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3o
ool00?l000<0oooo00<00?l00?ooo`3oool09`3oool00`000000oooo0?ooo`0^0?ooo`00BP3oool2
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01/0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000L0oooo00D0
o`000?ooo`3oool0oooo0?l000080?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0
1P3oool01@3o0000oooo0?ooo`3oool0o`0002T0oooo00<0o`000?ooo`3oool0;`3oool00`3o0000
oooo0?ooo`0V0?ooo`80o`003`3oool00`3o0000oooo0?ooo`0:0?ooo`050?l0003oool0oooo0?oo
o`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0008T0oooo00<0o`000?ooo`3oool06P3oool0
1@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`05003o
003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?oo
o`3oool0oooo003o00030?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0
oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`020?ooo`800?l0
0`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o0080
oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?oo
o`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00`3oool0
1@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`03003o
003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?oo
o`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l002D0oooo00<000000?ooo`3oool0;P3oool0
04/0oooo00<000000?ooo`3oool00`3oool4000000/0oooo1000000B0?ooo`050?l0003oool0oooo
0?ooo`3o00000`3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00000`3o
ool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?l000<0oooo00<0o`000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0_0?ooo`030?l0
003oool0oooo0280oooo00@0o`000?ooo`3oool0oooo0P3o000?0?ooo`030?l0003oool0oooo00X0
oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o0000R@3oool0
0`3o0000oooo0?ooo`0F0?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?oo
o`3oool00?l000<0oooo00<00?l00?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool00?l000<0
oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2
003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00@0
0?l00?ooo`3oool0oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0
oooo003o00030?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00
oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`030?oo
o`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool0
1@00o`00oooo0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool00P3oool01@00o`00oooo0?oo
o`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?oo
o`00o`00103oool00`00o`00oooo0?ooo`0N0?ooo`030000003oool0oooo02h0oooo001P0?ooo`03
0000003oool0oooo00l0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo
0?ooo`3o00000`3oool20?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003o
ool0oooo0?ooo`3o00001`3oool20?l000L0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo0080o`000`3oool00`3o0000oooo0?ooo`0W0?ooo`030?l0
003oool0oooo02l0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0E0?ooo`040?l0
003oool0oooo0?ooo`80o`003`3oool01@3o0000oooo0?ooo`3oool0o`0000P0oooo00D0o`000?oo
o`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o0000R@3oool00`3o0000oooo0?oo
o`0B0?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000<0
oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`05003o003oool0oooo0?ooo`00o`000`3oool0
1@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l0
0P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01000o`00
oooo0?ooo`3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool0
0?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0
oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D0
0?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`800?l0
0`3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00D00?l00?ooo`3oool0oooo003o00030?oo
o`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000@0oooo00D0
0?l00?ooo`3oool0oooo003o000L0?ooo`030000003oool0oooo02h0oooo001P0?ooo`030000003o
ool0oooo00l0oooo00<0o`000?ooo`3oool00P3o00030?ooo`050?l0003oool0oooo0?ooo`3o0000
0`3oool20?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?oo
o`3o00000`3oool0103o0000oooo0?ooo`3oool20?l000L0oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080o`000`3oool00`3o0000oooo0?ooo`0W
0?ooo`030?l0003oool0oooo02l0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0E
0?ooo`040?l0003oool0oooo0?ooo`80o`003`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo
00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3o
ool0oooo0?l000250?ooo`050?l0003oool0oooo0?ooo`3o0000503oool01@00o`00oooo0?ooo`3o
ool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00
o`00103oool01@00o`00oooo0?ooo`3oool00?l00080oooo0P00o`030?ooo`05003o003oool0oooo
0?ooo`00o`000`3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`020?ooo`800?l00`3o
ool01@00o`00oooo0?ooo`3oool00?l000<0oooo00@00?l00?ooo`3oool0oooo0P00o`020?ooo`80
0?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o
0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`02
0?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3o
ool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo
003o00040?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l0
00<0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`05003o003oool0oooo0?ooo`00o`000`3o
ool00`00o`00oooo0?ooo`0F0?ooo`030000003oool0oooo02h0oooo001P0?ooo`030000003oool0
oooo00l0oooo00<0o`000?ooo`3oool00P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000`3o
ool20?l00080oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo00D0o`000?ooo`3oool0oooo
0?l000030?ooo`80o`001`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool00P3o00030?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool0
;`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01D0oooo00@0o`000?ooo`3oool0
oooo0P3o000;0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0
o`0000<0oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?oo
o`3oool0o`000840oooo00D0o`000?ooo`3oool0oooo0?l0000D0?ooo`05003o003oool0oooo0?oo
o`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o
00040?ooo`03003o003oool0oooo00800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo
003o00030?ooo`04003o003oool0oooo0?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05
003o003oool0oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`02
0?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3o
ool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo
0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`80
0?l00P3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l0
00<0oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3o
ool00?l000<0oooo00<00?l00?ooo`3oool00P3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo
00D00?l00?ooo`3oool0oooo003o000D0?ooo`030000003oool0oooo02h0oooo001P0?ooo`@00000
3@3oool20?l00080oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool20?l00080
oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000030?oo
o`80o`001`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool00P3o00030?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool0;`3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01D0oooo00@0o`000?ooo`3oool0oooo0P3o000;
0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo
0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3o
ool0O`3oool00`3o0000oooo0?ooo`020?l000l0oooo00<0o`000?ooo`3oool00P3oool01@00o`00
oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0
oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?oo
o`3oool00?l000<0oooo00@00?l00?ooo`3oool0oooo0P00o`020?ooo`800?l00P3oool2003o00<0
oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`04003o003oool0oooo0?ooo`800?l00P3oool2
003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00
o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l0
0P3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0
oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?oo
o`00o`000`3oool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool0
1@00o`00oooo0?ooo`3oool00?l000@0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o
003oool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`0>0?ooo`030000003oool0oooo02h0
oooo001P0?ooo`030000003oool0oooo00h0oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo
0?ooo`3oool0o`0000<0oooo0P3o00020?ooo`80o`000P3oool20?l00080oooo00<0o`000?ooo`3o
00000P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo0P3o00070?ooo`050?l0003oool0oooo
0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`3oool00P3o
00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`000240oooo00<0o`000?ooo`3oool0
;P3oool20?l000`0oooo00<0o`000?ooo`3oool05@3oool0103o0000oooo0?ooo`3oool20?l000/0
oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool2
0?l00080oooo0P3o00020?ooo`80o`000`3oool20?l00080oooo00<0o`000?ooo`3oool0O`3oool0
0`3o0000oooo0?ooo`020?l000l0oooo00<0o`000?ooo`3oool00P3oool01@00o`00oooo0?ooo`3o
ool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00
o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l0
00<0oooo00@00?l00?ooo`3oool0oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l0
0?ooo`3oool0oooo003o00030?ooo`04003o003oool0oooo0?ooo`800?l00P3oool2003o0080oooo
0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`80
0?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o
0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`02
0?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3o
ool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo
003o00040?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l0
00<0oooo00<00?l00?ooo`3oool03P3oool00`000000oooo0?ooo`0^0?ooo`00H03oool00`000000
oooo0?ooo`0>0?ooo`80o`0000@0oooo0?l0003o0000o`000`3oool01@3o0000oooo0?ooo`3oool0
o`0000<0oooo0P3o00020?ooo`80o`000P3oool20?l00080oooo00<0o`000?ooo`3o00000P3oool0
1@3o0000oooo0?ooo`3oool0o`0000<0oooo0P3o00030?ooo`030?l0003oool0oooo0080o`000`3o
ool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?l00080oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool00`3o0000
oooo0?ooo`0K0?ooo`030?l0003oool0oooo02h0oooo0P3o000;0?ooo`80o`00203oool00`3o0000
oooo0?ooo`0<0?ooo`040?l0003oool0oooo0?ooo`80o`002`3oool01@3o0000oooo0?ooo`3oool0
o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`80o`000P3oool20?l00080oooo0P3o
00030?ooo`80o`000P3oool00`3o0000oooo0?ooo`1>0?ooo`030?l0003oool0oooo02h0oooo00<0
o`000?ooo`3oool00P3o000?0?ooo`030?l0003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo
003o00030?ooo`03003o003oool0oooo00800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0
oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?oo
o`04003o003oool0oooo0?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0
oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`020?ooo`800?l0
0`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o0080
oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?oo
o`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2
003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00
o`020?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`00
103oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?oo
o`03003o003oool0oooo00h0oooo00<000000?ooo`3oool0;P3oool00600oooo00<000000?ooo`3o
ool03P3oool20?l000040?ooo`3o0000o`000?l000<0oooo00D0o`000?ooo`3oool0oooo0?l00003
0?ooo`80o`000P3oool20?l00080oooo0P3o00020?ooo`030?l0003oool0o`000080oooo00D0o`00
0?ooo`3oool0oooo0?l000030?ooo`80o`000`3oool00`3o0000oooo0?ooo`020?l000<0oooo00D0
o`000?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3o
ool06`3oool00`3o0000oooo0?ooo`0^0?ooo`80o`002`3oool20?l000P0oooo00<0o`000?ooo`3o
ool0303oool0103o0000oooo0?ooo`3oool20?l000L0oooo00D0o`000?ooo`3oool0oooo0?l00003
0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3oool20?l00080oooo
0P3o00020?ooo`80o`000`3oool20?l00080oooo00<0o`000?ooo`3oool0CP3oool00`3o0000oooo
0?ooo`0]0?ooo`80o`000P3oool20?l000l0oooo00<0o`000?ooo`3oool00P3oool01@00o`00oooo
0?ooo`3oool00?l00080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l0
00<0oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o0003
0?ooo`04003o003oool0oooo0?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003o
ool0oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`020?ooo`80
0?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o
0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`02
0?ooo`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3o
ool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo
0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00
o`00103oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o0003
0?ooo`03003o003oool0oooo00h0oooo00<000000?ooo`3oool0;P3oool00600oooo00<000000?oo
o`3oool03P3oool20?l000040?ooo`3o0000o`000?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0
00030?ooo`80o`000P3oool20?l00080oooo0P3o00020?ooo`030?l0003oool0o`000080oooo0P3o
00020?ooo`040?l0003oool0oooo0?ooo`80o`000`3oool00`3o0000oooo0?ooo`020?l000<0oooo
00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool20?l0
0080oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool00`3o0000oooo0?ooo`0H
0?ooo`040?l0003oool0oooo0?l00300oooo0P3o000;0?ooo`80o`00203oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o00000`3oool20?l000L0oooo00D0
o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000
oooo0?ooo`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool20?l00080oooo00<0o`000?oo
o`3oool06P3oool00`3o0000oooo0?ooo`0a0?ooo`030?l0003oool0oooo0100oooo00<0o`000?oo
o`3oool06P3oool20?l00080oooo0P3o00030?ooo`030?l0003oool0oooo00D0oooo00D0o`000?oo
o`3oool0oooo0?l000040?ooo`03003o003oool0oooo00800?l00P3oool2003o0080oooo0P00o`03
0?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00`3o
ool01@00o`00oooo0?ooo`3oool00?l000<0oooo00@00?l00?ooo`3oool0oooo0P00o`020?ooo`80
0?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`04003o003oool0oooo
0?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo00L00?l0
0?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo
00@00?l00?ooo`3oool0oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05
003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o
00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o0080oooo0P00o`02
0?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`030?ooo`05003o003o
ool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l00100oooo00<000000?ooo`3o
ool0;P3oool00600oooo1000000=0?ooo`80o`0000@0oooo0?l0003o0000o`000`3oool01@3o0000
oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3o00000P3oool20?l00080oooo0P3o00020?oo
o`070?l0003oool0o`000?ooo`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?ooo`80o`00
0`3oool00`3o0000oooo0?ooo`020?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`04
0?l0003oool0oooo0?ooo`80o`000P3oool20?l00080oooo0P3o00030?ooo`050?l0003oool0oooo
0?ooo`3o00000`3oool00`3o0000oooo0?ooo`0G0?ooo`80o`000P3oool00`3o0000oooo0?ooo`0[
0?ooo`030?l0003oool0oooo0080o`002`3oool20?l000P0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0o`0000<0oooo0P3o00070?ooo`030?l0003oool0
oooo0080o`000P3oool20?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`80o`000P3o
ool20?l00080oooo0P3o00030?ooo`80o`000P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00d0oooo00<0o`000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo01X0oooo0P3o00020?ooo`80o`000`3oool00`3o0000oooo0?ooo`050?ooo`050?l0003o
ool0oooo0?ooo`3o00000`3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo
00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05
003o003oool0oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`02
0?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00H00?l00?ooo`3oool00?l0
0?ooo`00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool01`00o`00
oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2
003o0080oooo00<00?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool0
1@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00
o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l0
0P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o00<0
oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`03003o003oool0oooo00h0oooo00<000000?oo
o`3oool0;P3oool00600oooo00<000000?ooo`3oool03P3oool20?l000040?ooo`3o0000o`000?l0
0080oooo0P3o00030?ooo`060?l0003oool0oooo0?l0003oool0o`000P3oool20?l00080oooo0P3o
00020?ooo`070?l0003oool0o`000?ooo`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?oo
o`80o`000P3oool20?l00080oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0
103o0000oooo0?ooo`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?oo
o`3oool0o`0000<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?ooo`80o`00
0P3oool00`3o0000oooo0?ooo`0[0?ooo`030?l0003oool0oooo0080o`002P3oool30?l000P0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0o`0000<0oooo
0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool20?l00080oooo0P3o00030?ooo`05
0?l0003oool0oooo0?ooo`3o00000`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool20?l0
0080oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo
0340oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0F0?ooo`040?l0003oool0oooo
0?ooo`80o`000P3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0oooo00D0oooo00D0o`00
0?ooo`3oool0oooo0?l000030?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`800?l00`3o
ool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo
00D00?l00?ooo`3oool0oooo003o00030?ooo`04003o003oool0oooo0?ooo`800?l00P3oool2003o
0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`03003o003oool00?l0
0080oooo0P00o`020?ooo`800?l00P3oool03`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool02000o`00oooo003o003o
ool00?l00?ooo`00o`00oooo0P00o`020?ooo`03003o003oool00?l00080oooo0P00o`020?ooo`80
0?l00P3oool2003o0080oooo0P00o`030?ooo`04003o003oool0oooo0?ooo`800?l00P3oool2003o
0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`02
0?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3o
ool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l00100oooo
00<000000?ooo`3oool0;P3oool00600oooo00<000000?ooo`3oool03P3oool20?l000040?ooo`3o
0000o`000?l00080oooo00<0o`000?ooo`3o00000P3oool20?l000040?ooo`3o0000oooo0?l00080
oooo0P3o00020?ooo`80o`0000@0oooo0?l0003o0000oooo0`3o00001@3oool0o`000?ooo`3oool0
o`0000<0oooo0P3o00020?ooo`80o`000P3oool20?l00080oooo0P3o00030?ooo`050?l0003oool0
oooo0?ooo`3o00000`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?oo
o`3oool0o`0000<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?ooo`80o`00
0P3oool00`3o0000oooo0?ooo`0[0?ooo`030?l0003oool0oooo0080o`002P3oool30?l000P0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0o`0000<0oooo
0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool20?l00080oooo0P3o00030?ooo`05
0?l0003oool0oooo0?ooo`3o00000`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool20?l0
0080oooo00<0o`000?ooo`3oool02P3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00<0o`00
0?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo01H0oooo00@0o`00
0?ooo`3oool0oooo0P3o00020?ooo`030?l0003oool0o`000080oooo00D0o`000?ooo`3oool0oooo
0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool2003o0080oooo0P00o`020?ooo`80
0?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o
0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`3o
ool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`07003o003o
ool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool04`00o`00oooo003o003oool00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3o
ool2003o0080oooo00l00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo
0P00o`020?ooo`03003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo
00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`80
0?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o
00<0oooo00D00?l00?ooo`3oool0oooo003o000@0?ooo`030000003oool0oooo02h0oooo000b0?oo
o`X00000903oool00`000000oooo0?ooo`0>0?ooo`80o`0000@0oooo0?l0003o0000o`000P3oool0
0`3o0000oooo0?l000020?ooo`80o`0000@0oooo0?l0003oool0o`000P3oool30?l000040?ooo`3o
0000o`000?ooo`80o`0000<0oooo0?l0003o00000P3oool0103o0000oooo0?ooo`3o00030?ooo`80
o`000P3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`00
00<0oooo0P3o00020?ooo`80o`000P3oool20?l00080oooo0P3o00030?ooo`050?l0003oool0oooo
0?ooo`3o0000203oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0o`000080oooo0P3o000>
0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?l000<0oooo00<0o`000?ooo`3oool0103oool30?l000P0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0o`0000<0oooo0P3o00030?ooo`050?l0003oool0
oooo0?ooo`3o00000P3oool20?l00080oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o0000
0`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool20?l00080oooo00<0o`000?ooo`3oool0
1P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0]0?ooo`050?l0003oool0oooo0?ooo`3o00004P3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo0140oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`030?l0003oool0
o`000080oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o0000
0`3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0
oooo003o00030?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?oo
o`00o`000`3oool01P00o`00oooo0?ooo`00o`00oooo003o0080oooo0P00o`020?ooo`800?l00P3o
ool03`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o00020?ooo`800?l00P3oool04`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo00l00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3o
ool2003o0080oooo0P00o`020?ooo`04003o003oool00?l00?ooo`800?l00P3oool2003o0080oooo
00<00?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo
0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05
003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00
o`00oooo0?ooo`3oool00?l00100oooo00<000000?ooo`3oool0;P3oool00380oooo2P00000T0?oo
o`030000003oool0oooo00h0oooo0P3o0000403oool0o`000?ooo`3oool0o`000?ooo`3o0000oooo
0?l0003oool0o`000?ooo`3o0000oooo0?l0003oool<0?l000030?ooo`3o0000o`000080oooo00@0
o`000?ooo`3oool0o`000`3oool20?l00080oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo
00D0o`000?ooo`3oool0oooo0?l000030?ooo`80o`000P3oool20?l00080oooo0P3o00020?ooo`80
o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000P0oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?l000020?ooo`80o`000P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
0080o`000`3oool01@3o0000oooo0?ooo`3oool0o`000080oooo0`3o00080?ooo`030?l0003oool0
oooo00@0oooo00H0o`000?ooo`3oool0oooo0?l0003oool30?l000<0oooo0P3o00030?ooo`050?l0
003oool0oooo0?ooo`3o00000P3oool20?l00080oooo0P3o00030?ooo`050?l0003oool0oooo0?oo
o`3o00000`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool20?l00080oooo00<0o`000?oo
o`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0]0?ooo`050?l0003oool0oooo0?ooo`3o00004P3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo0140oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`030?l0
003oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?oo
o`3o00000`3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l00?oo
o`3oool0oooo003o00030?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`03003o003oool0
oooo00800?l00P3oool2003o0080oooo00<00?l00?ooo`00o`000P3oool2003o0080oooo01<00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00080oooo0P00o`020?ooo`0C003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3o
ool03`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o00020?ooo`800?l00P3oool2003o0080oooo00l00?l00?ooo`00o`00oooo003o003oool00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`80
0?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o
0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`02
0?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l00100oooo00<000000?ooo`3oool0;P3o
ool00380oooo2P00000T0?ooo`@000003@3oool20?l0000@0?ooo`3o0000oooo0?ooo`3o0000oooo
0?l0003oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo``0o`001@3oool0103o0000oooo
0?l0003o00030?ooo`80o`000P3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool0103o0000
oooo0?ooo`3oool20?l00080oooo0P3o00020?ooo`80o`000P3oool20?l00080oooo0P3o00030?oo
o`050?l0003oool0oooo0?ooo`3o0000203oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0
o`000080oooo0P3o00000`3oool0o`000?l0000;0?ooo`030?l0003oool0oooo00H0oooo00D0o`00
0?ooo`3oool0oooo0?l0000;0?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool20?l00080oooo
0P3o00030?ooo`030?l0003oool0oooo00<0o`00203oool00`3o0000oooo0?ooo`040?ooo`060?l0
003oool0oooo0?ooo`3o0000oooo0`3o00030?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0
o`000080oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo0P3o
00020?ooo`80o`000P3oool20?l000<0oooo0P3o00020?ooo`050?l0003oool0oooo0?ooo`3o0000
103oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0]0?ooo`80o`000P3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0oooo0?oo
o`80o`000P3oool0103o0000oooo0?l0003oool20?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0
00030?ooo`040?l0003oool0oooo0?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`800?l0
0`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o0080
oooo0P00o`020?ooo`800?l00P3oool01`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2
003o0080oooo01<00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool0
0?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`0C003o003oool00?l00?oo
o`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o
00020?ooo`800?l00P3oool03`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool0
0?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool2003o0080oooo00l00?l00?ooo`00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080
oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00@00?l00?ooo`3oool0oooo0P00o`020?oo
o`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2
003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l00100oooo00<0
00000?ooo`3oool0;P3oool00380oooo2P00000<0?ooo`H000000`3oool4000000/0oooo00<00000
0?ooo`3oool03P3oool20?l0000B0?ooo`3o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000?oo
o`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo1@3o00000`3oool0o`000?ooo`020?l000D0
oooo103o00030?ooo`80o`000P3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool0103o0000
oooo0?ooo`3oool20?l00080oooo0P3o00020?ooo`80o`000P3oool20?l00080oooo0P3o00030?oo
o`050?l0003oool0oooo0?ooo`3o0000203oool00`3o0000oooo0?ooo`090?ooo`070?l0003oool0
oooo0?ooo`3o0000oooo0?l000020?ooo`80o`0000<0oooo0?l0003o00002`3oool00`3o0000oooo
0?ooo`060?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool0103o0000oooo0?ooo`3oool20?l0
0080oooo0P3o00020?ooo`80o`000`3oool00`3o0000oooo0?ooo`030?l000P0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`020?l000040?ooo`3o0000o`000?l000<0oooo0P3o0003
0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool20?l00080oooo0P3o00030?ooo`050?l0003o
ool0oooo0?ooo`3o00000`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool20?l00080oooo
00D0o`000?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0oooo0080o`000P3oool20?l000/0
oooo00<0o`000?ooo`3oool0;@3oool20?l00080oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool00`3o0000
oooo0?ooo`050?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool0103o0000oooo0?l0003oool2
0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0oooo0?ooo`800?l0
0P3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0
oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`0;003o003oool00?l00?oo
o`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo01<00?l00?ooo`00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool0
0?l00080oooo0P00o`020?ooo`0C003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?oo
o`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool03`00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o00020?oo
o`800?l00P3oool2003o0080oooo00l00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00
oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2
003o0080oooo0P00o`020?ooo`03003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool2
003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o0080oooo0P00
o`030?ooo`05003o003oool0oooo0?ooo`00o`00403oool00`000000oooo0?ooo`0^0?ooo`00<P3o
ool:000000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03P3oool20?l0000A0?ooo`3o0000oooo0?ooo`3o0000
oooo0?l0003oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o00000P3oool30?l00080
oooo00@0o`000?ooo`3o0000o`001P3oool20?l000060?ooo`3o0000oooo0?l0003oool0o`000P3o
ool20?l00080oooo0P3o00020?ooo`80o`000`3oool0103o0000oooo0?ooo`3oool20?l00080oooo
0P3o00020?ooo`80o`000P3oool20?l00080oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o
0000203oool00`3o0000oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool00`3o
0000oooo0?l000020?ooo`80o`0000<0oooo0?l0003o00002`3oool00`3o0000oooo0?ooo`060?oo
o`050?l0003oool0oooo0?ooo`3o00000`3oool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0
o`000?ooo`80o`000P3oool20?l00080oooo0P3o00030?ooo`030?l0003oool0oooo00<0o`00203o
ool0103o0000oooo0?ooo`3o00020?ooo`80o`000P3oool20?l000040?ooo`3o0000o`000?l000<0
oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool20?l00080oooo0P3o00030?oo
o`050?l0003oool0oooo0?ooo`3o00000`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool2
0?l00080oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0oooo0080o`000P3o
ool20?l000/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003o
ool0oooo00/0oooo0P3o00020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool0103o0000oooo0?ooo`3oool30?l000X0oooo00<0o`000?ooo`3oool01@3oool0103o0000oooo
0?ooo`3oool20?l00080oooo00@0o`000?ooo`3o0000oooo0P3o00030?ooo`050?l0003oool0oooo
0?ooo`3o00000`3oool0103o0000oooo0?ooo`3oool2003o0080oooo0P00o`020?ooo`800?l00P3o
ool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00020?ooo`03003o003oool00?l00080oooo
0P00o`020?ooo`0C003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool04`00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00
o`000P3oool2003o0080oooo01<00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`0?003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo
0P00o`020?ooo`800?l00P3oool03`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool2003o0080oooo00P00?l00?ooo`00
o`00oooo003o003oool00?l00?ooo`800?l00P3oool00`00o`00oooo003o00020?ooo`800?l00P3o
ool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo
0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l00100oooo00<000000?ooo`3o
ool0;P3oool00380oooo2P00000>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo0P3o00003`3oool0o`00
0?ooo`3oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l000040?ooo`03
0?l0003oool0o`0000`0oooo0P3o00001P3oool0o`000?ooo`3o0000oooo0?l00080oooo0P3o0002
0?ooo`80o`000P3oool20?l000<0oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`000P3o
ool20?l00080oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000P0oooo
00<0o`000?ooo`3oool00P3o00020?ooo`80o`000`3oool01`3o0000oooo0?ooo`3oool0o`000?oo
o`3o00000P3oool20?l000030?ooo`3o0000o`0000/0oooo00<0o`000?ooo`3oool01P3oool01@3o
0000oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool01@3oool0103o0000oooo0?l0003o
ool20?l00080oooo0P3o00020?ooo`80o`000`3oool00`3o0000oooo0?ooo`030?l000L0oooo0P3o
00020?ooo`030?l0003oool0oooo0080o`000P3oool20?l000040?ooo`3o0000o`000?l00080oooo
00<0o`000?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`000080oooo0P3o00020?ooo`80
o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo0P3o00020?ooo`80o`000P3oool20?l0
0080oooo00<0o`000?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo0P3o0002
0?ooo`80o`000P3oool20?l000/0oooo00@0o`000?ooo`3oool0oooo0P3o00070?ooo`030?l0003o
ool0oooo00h0oooo00D0o`000?ooo`3oool0oooo0?l0000=0?ooo`80o`0000<0oooo0?l0003o0000
2@3oool20?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`<0o`002P3oool01@3o0000
oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`040?l0003oool0
o`000?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0
oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`03003o003oool0oooo0080
0?l00P3oool00`00o`00oooo003o00020?ooo`800?l00P3oool04`00o`00oooo003o003oool00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3o
ool2003o0080oooo01<00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`04003o003oool00?l0
003o0080oooo01<00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool0
0?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`09003o003oool00?l00?oo
o`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool03`00o`00oooo003o
003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l0
0P3oool2003o0080oooo00l00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o
003oool00?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00
oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l00?oo
o`3oool0oooo003o000@0?ooo`030000003oool0oooo02h0oooo000b0?ooo`X000003`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0>0?ooo`80o`0000@0oooo0?l0003oool0oooo0`3o0000203oool0o`000?ooo`3o
0000oooo0?l0003oool0o`001P3oool00`3o0000oooo0?ooo`0:0?ooo`80o`0000H0oooo0?l0003o
ool0o`000?ooo`3o00020?ooo`80o`000P3oool20?l00080oooo0P3o00030?ooo`040?l0003oool0
oooo0?ooo`80o`000P3oool20?l00080oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo00D0
o`000?ooo`3oool0oooo0?l000080?ooo`030?l0003oool0oooo0080o`000P3oool20?l000<0oooo
00`0o`000?ooo`3oool0oooo0?l0003oool0o`000?ooo`3o0000oooo0?l0003oool20?l000L0oooo
00D0o`000?ooo`3oool0oooo0?l000080?ooo`030?l0003oool0oooo0080o`000`3oool01@3o0000
oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3o0000oooo0P3o00020?ooo`<0o`0000<0oooo
0?l0003o00000`3oool0103o0000oooo0?l0003oool20?l000L0oooo0P3o00000`3oool0o`000?l0
00020?ooo`80o`000P3oool20?l000040?ooo`3o0000oooo0?l00080oooo00<0o`000?ooo`3o0000
0`3oool00`3o0000oooo0?ooo`020?l00080oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo
0?ooo`3oool0o`0000<0oooo0P3o00020?ooo`80o`000P3oool20?l00080oooo00<0o`000?ooo`3o
00000P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo0P3o00020?ooo`80o`000P3oool20?l0
00L0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`80o`001`3oool00`3o0000oooo0?ooo`0>
0?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool20?l000030?ooo`3o0000o`0000T0oooo0P3o
00030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool30?l000T0oooo0P3o00030?ooo`050?l0
003oool0oooo0?ooo`3o00000`3oool20?l00080oooo00@0o`000?ooo`3o0000oooo0P3o00020?oo
o`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo0P00o`020?ooo`800?l00P3oool2
003o0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo00<00?l00?ooo`00o`000P3oool2
003o0080oooo01<00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool0
0?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`0I003o003oool00?l00?oo
o`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o
003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool04`00o`00oooo003o003oool0
0?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00
0P3oool2003o0080oooo01400?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o
003oool00?l00?ooo`00o`00oooo003o00020?ooo`0?003o003oool00?l00?ooo`00o`00oooo003o
003oool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool0
3`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o
00020?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`00
0`3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l00100
oooo00<000000?ooo`3oool0;P3oool004`0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00P0oooo1P00000;0?ooo`80o`0000@0oooo0?l0003oool0oooo0`3o0000203o
ool0o`000?ooo`3o0000oooo0?l0003oool0o`004`3oool20?l000060?ooo`3o0000o`000?l0003o
ool0o`000P3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool0103o0000oooo0?ooo`3oool3
0?l000030?ooo`3o0000o`000080oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo00D0o`00
0?ooo`3oool0oooo0?l000080?ooo`030?l0003oool0oooo0080o`000P3oool20?l000<0oooo00H0
o`000?ooo`3oool0oooo0?l0003oool30?l000030?ooo`3o0000oooo0080o`001`3oool01@3o0000
oooo0?ooo`3oool0o`0000L0oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0
o`0000<0oooo00@0o`000?ooo`3o0000oooo0P3o00020?ooo`<0o`0000<0oooo0?l0003o00000P3o
ool20?l000030?ooo`3o0000oooo0080o`001`3oool20?l000030?ooo`3o0000o`000080oooo0P3o
00020?ooo`80o`0000@0oooo0?l0003oool0o`000P3oool00`3o0000oooo0?l000030?ooo`030?l0
003oool0oooo0080o`000P3oool20?l00080oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o
00000`3oool20?l00080oooo0P3o00020?ooo`070?l0003oool0o`000?ooo`3o0000oooo0?l00002
0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool20?l00080oooo0P3o00020?ooo`80o`000`3o
ool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0oooo0P3o00070?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`00
00d0oooo0P3o00000`3oool0o`000?l000090?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0
o`0000<0oooo0`3o00000`3oool0o`000?l000060?ooo`80o`000`3oool01@3o0000oooo0?ooo`3o
ool0o`000080oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?l0003oool20?l00080oooo
0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool2003o0080oooo0P00o`020?ooo`80
0?l00P3oool2003o0080oooo0P00o`020?ooo`07003o003oool00?l00?ooo`00o`00oooo003o0002
0?ooo`800?l00P3oool04`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo00@00?l00?ooo`00
o`000?l00P3oool04`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?oo
o`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo01<00?l00?ooo`00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool0
0?l00080oooo0P00o`020?ooo`0C003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?oo
o`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool02@00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool2003o0080oooo00l0
0?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00
0P3oool2003o0080oooo00@00?l00?ooo`00o`00oooo0P00o`020?ooo`800?l00P3oool2003o00<0
oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o000@0?oo
o`030000003oool0oooo02h0oooo000l0?ooo`<000003P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool20?l000040?ooo`3o0000oooo
0?ooo`<0o`0000P0oooo0?l0003oool0o`000?ooo`3o0000oooo0?l001@0oooo00<0o`000?ooo`3o
00000P3o0000103oool0o`000?ooo`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool0103o
0000oooo0?ooo`3oool30?l000030?ooo`3o0000o`000080oooo0P3o00020?ooo`040?l0003oool0
o`000?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00D0o`000?ooo`3oool0
oooo0?l000020?ooo`80o`000P3oool20?l000<0oooo00H0o`000?ooo`3oool0oooo0?l0003oool3
0?l000030?ooo`3o0000oooo0080o`001`3oool01@3o0000oooo0?ooo`3oool0o`0000L0oooo0P3o
00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3o0000
oooo0P3o00000`3oool0o`000?ooo`020?l000030?ooo`3o0000o`000080oooo0P3o00000`3oool0
o`000?ooo`020?l000L0oooo0P3o00000`3oool0o`000?l000020?ooo`80o`000P3oool20?l00004
0?ooo`3o0000oooo0?l00080oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?ooo`020?l0
0080oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo0P3o0002
0?ooo`80o`000P3oool01P3o0000oooo0?l0003oool0o`000?ooo`80o`0000<0oooo0?l0003oool0
0P3oool0103o0000oooo0?ooo`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool01@3o0000
oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0oooo0P3o00070?ooo`050?l0003oool0
o`000?ooo`3o00000`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080o`003@3o
ool50?l000T0oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool30?l000030?oo
o`3o0000o`000080oooo0P3o00020?ooo`80o`000`3oool00`3o0000oooo0?ooo`020?l00080oooo
00<0o`000?ooo`3o00000P3oool0103o0000oooo0?l0003oool20?l00080oooo0P3o00030?ooo`04
0?l0003oool0oooo0?ooo`80o`000P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool03`00
o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o0002
0?ooo`800?l00P3oool06@00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3o
ool2003o0080oooo01<00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`0C003o003oool00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o00020?ooo`800?l00P3oool04`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo00T00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`0?
003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l0
0080oooo0P00o`020?ooo`08003o003oool00?l00?ooo`00o`00oooo003o003oool2003o0080oooo
0P00o`020?ooo`03003o003oool00?l00080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo
0?ooo`3oool00?l00100oooo00<000000?ooo`3oool0;P3oool003T0oooo0`00000A0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`03
0?l0003oool0o`000080oooo0P3o00020?ooo`<0o`0000@0oooo0?l0003oool0o`005P3oool30?l0
00040?ooo`3o0000oooo0?ooo`80o`000P3oool20?l00080oooo0P3o00030?ooo`80o`000P3oool4
0?l000040?ooo`3o0000oooo0?ooo`80o`000P3oool0103o0000oooo0?l0003oool20?l000<0oooo
00D0o`000?ooo`3oool0oooo0?l000030?ooo`80o`000`3oool00`3o0000oooo0?ooo`020?l00080
oooo0P3o00030?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0P3o00020?ooo`040?l0003oool0
o`000?l000L0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0oooo0?ooo`80
o`000P3oool20?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0o`00
0?ooo`@0o`0000@0oooo0?l0003o0000oooo0P3o00020?ooo`80o`0000<0oooo0?l0003oool00P3o
00020?ooo`030?l0003oool0oooo0080oooo0P3o00000`3oool0o`000?l000020?ooo`80o`000P3o
ool20?l000040?ooo`3o0000oooo0?l00080oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo
0?ooo`020?l00080oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0
oooo0`3o00000`3oool0o`000?l000020?ooo`060?l0003oool0o`000?ooo`3o0000oooo0P3o0000
0`3oool0o`000?ooo`020?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool20?l00080oooo0P3o
00030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3oool20?l000L0
oooo00D0o`000?ooo`3o0000oooo0?l000030?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool00P3o000=0?ooo`D0o`002@3oool20?l000<0oooo00D0o`000?ooo`3oool0oooo0?l00003
0?ooo`<0o`0000<0oooo0?l0003o00000P3oool20?l00080oooo0P3o00030?ooo`0:0?l0003oool0
oooo0?l0003oool0o`000?ooo`3o0000oooo0?l00080oooo00@0o`000?ooo`3o0000oooo0P3o0002
0?ooo`80o`000`3oool0103o0000oooo0?ooo`3oool20?l000040?ooo`00o`00oooo003o0080oooo
0P00o`020?ooo`0C003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool06@00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00
o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo01<00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l0
0080oooo0P00o`020?ooo`0C003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00
o`00oooo003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool04`00o`00oooo
003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l0
0?ooo`00o`000P3oool2003o0080oooo00d00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00
o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`0?003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`0<003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo0P00o`020?ooo`03003o003o
ool00?l00080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l00100oooo
00<000000?ooo`3oool0;P3oool003H0oooo0`00000?0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo
00<0o`000?ooo`3o00000P3oool20?l00080oooo0`3o00000`3oool0o`000?l0000G0?ooo`<0o`00
00@0oooo0?l0003oool0oooo0P3o00020?ooo`80o`000P3oool00`3o0000oooo0?l000020?ooo`80
o`000P3oool40?l000040?ooo`3o0000oooo0?ooo`80o`000P3oool0103o0000oooo0?l0003oool2
0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`80o`000P3oool20?l00080oooo0P3o
00020?ooo`80o`000`3oool01P3o0000oooo0?ooo`3oool0o`000?ooo`80o`000P3oool0103o0000
oooo0?l0003o00070?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o
ool20?l00080oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo
0?l0003oool40?l000040?ooo`3o0000o`000?ooo`80o`000P3oool20?l000030?ooo`3o0000oooo
0080o`000P3oool0103o0000oooo0?ooo`3oool30?l000030?ooo`3o0000o`000080oooo0P3o0002
0?ooo`80o`0000@0oooo0?l0003oool0o`000P3oool00`3o0000oooo0?l000030?ooo`030?l0003o
ool0oooo0080o`000P3oool20?l00080oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o0000
0P3oool01@3o0000oooo0?l0003o0000oooo0080o`0000P0oooo0?l0003o0000oooo0?l0003oool0
o`000?ooo`80o`0000<0oooo0?l0003oool00P3oool0103o0000oooo0?ooo`3oool20?l00080oooo
0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo0P3o0000103oool0
o`000?ooo`3o00030?ooo`090?l0003oool0oooo0?ooo`3o0000oooo0?l0003oool0o`0000<0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?l000d0oooo1@3o00090?ooo`80o`00
0`3oool02@3o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`020?l000030?ooo`3o0000
o`000080oooo0P3o00020?ooo`80o`000`3oool02P3o0000oooo0?ooo`3o0000oooo0?l0003oool0
o`000?ooo`3o00020?ooo`030?l0003oool0o`0000<0o`000P3oool20?l000<0oooo00X0o`000?oo
o`3oool0o`000?ooo`3o0000oooo003o003oool00?l00P3oool2003o0080oooo01<00?l00?ooo`00
o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00080oooo0P00o`020?ooo`0I003o003oool00?l00?ooo`00o`00oooo003o003oool00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o00020?ooo`800?l00P3oool04`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo01<00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00080oooo0P00o`020?ooo`0C003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3o
ool04`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`000P3oool03@00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo01<00?l00?ooo`00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo
0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l00100oooo00<000000?ooo`3o
ool0;P3oool003<0oooo0`00000B0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3o
00000P3oool20?l00080oooo0`3o00000`3oool0o`000?l0000G0?ooo`<0o`0000@0oooo0?l0003o
ool0oooo0P3o00020?ooo`80o`000P3oool00`3o0000oooo0?l000020?ooo`80o`000P3oool40?l0
00040?ooo`3o0000oooo0?ooo`80o`000P3oool0103o0000oooo0?l0003oool20?l000<0oooo00<0
o`000?ooo`3oool00P3o00030?ooo`80o`000P3oool20?l00080oooo0P3o00020?ooo`80o`000`3o
ool01P3o0000oooo0?ooo`3oool0o`000?ooo`80o`000P3oool0103o0000oooo0?l0003o00070?oo
o`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3oool20?l00080oooo0P3o
00030?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool20?l000040?ooo`3o0000o`000?ooo`<0
o`0000<0oooo0?l0003o00000`3o0000103oool0o`000?l0003oool20?l000030?ooo`3o0000o`00
0080oooo00@0o`000?ooo`3oool0oooo0`3o00000`3oool0o`000?l000020?ooo`80o`000P3oool2
0?l000090?ooo`3o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000080oooo0P3o00020?ooo`80
o`000P3oool20?l00080oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o
0000oooo0?l0003o0000oooo0080o`0000@0oooo0?l0003o0000oooo0`3o00001@3oool0o`000?l0
003oool0o`0000<0oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`000P3oool20?l000<0
oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`80o`0000@0oooo0?l0003oool0o`000`3oool0
2@3o0000oooo0?ooo`3oool0o`000?ooo`3o0000oooo0?l000030?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool00P3o000=0?ooo`D0o`002@3oool20?l000<0oooo00T0o`000?ooo`3o
ool0o`000?ooo`3o0000oooo0?l0003oool00P3o00000`3oool0o`000?l000020?ooo`80o`000P3o
ool20?l000<0oooo00`0o`000?ooo`3oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o
00020?ooo`80o`0000@0oooo0?l0003oool0oooo0P3o00030?ooo`0:0?l0003oool0oooo0?l0003o
ool0o`000?ooo`00o`00oooo003o0080oooo0P00o`020?ooo`0C003o003oool00?l00?ooo`00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o00020?oo
o`800?l00P3oool01000o`00oooo003o0000o`020?ooo`0C003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`80
0?l00P3oool04`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00
o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`800?l00P3o
ool2003o0080oooo0P00o`020?ooo`03003o003oool00?l00080oooo0P00o`020?ooo`0C003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00
o`00oooo003o00020?ooo`800?l00P3oool04`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo
00T00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo01<00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00<00?l00?ooo`3o
ool03P3oool00`000000oooo0?ooo`0^0?ooo`00<P3oool00`000000oooo0?ooo`0D0?ooo`@00000
103oool4000000/0oooo1000000>0?ooo`030?l0003oool0o`000080oooo0P3o00020?ooo`040?l0
003oool0o`000?ooo`80o`005`3oool30?l000040?ooo`3o0000oooo0?ooo`80o`000P3oool20?l0
0080oooo00<0o`000?ooo`3o00000P3oool20?l00080oooo103o0000103oool0o`000?ooo`3oool2
0?l00080oooo00@0o`000?ooo`3o0000oooo0P3o00020?ooo`040?l0003oool0o`000?ooo`80o`00
0`3oool20?l00080oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo00H0o`000?ooo`3oool0
oooo0?l0003oool20?l00080oooo00@0o`000?ooo`3o0000o`000`3oool01@3o0000oooo0?ooo`3o
ool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`80o`000P3oool20?l000<0oooo
00D0o`000?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0o`000080o`0000D0oooo0?l0003o
0000o`000?ooo`050?l000040?ooo`3o0000o`000?ooo`80o`000P3oool0103o0000oooo0?ooo`3o
00030?ooo`<0o`0000<0oooo0?l0003o00000P3oool20?l00080oooo0P3o00001`3oool0o`000?oo
o`3oool0o`000?ooo`3o00000P3oool0103o0000oooo0?l0003o00020?ooo`80o`000P3oool20?l0
0080oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?l0003o
0000oooo0080o`0000@0oooo0?l0003o0000oooo0`3o0000103oool0o`000?l0003oool20?l00080
oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo00D0o`000?oo
o`3oool0oooo0?l000030?ooo`80o`0000@0oooo0?l0003oool0o`000P3oool20?l000<0oooo00D0
o`000?ooo`3o0000oooo0?l000030?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
0P3o000<0?ooo`H0o`002@3oool20?l000<0oooo00T0o`000?ooo`3oool0o`000?ooo`3o0000oooo
0?l0003oool00P3o00000`3oool0o`000?l000020?ooo`80o`000P3oool20?l000<0oooo00`0o`00
0?ooo`3oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o00020?ooo`80o`0000@0oooo
0?l0003oool0oooo0P3o00030?ooo`0:0?l0003oool0oooo0?l0003oool0o`000?ooo`00o`00oooo
003o0080oooo0P00o`020?ooo`0I003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?oo
o`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o
00020?ooo`800?l00P3oool04`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool0
0?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo00P00?l00?oo
o`00o`00oooo003o003oool00?l00?ooo`800?l00P3oool2003o0080oooo00<00?l00?ooo`00o`00
0P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`03003o
003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`07003o
003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool04`00o`00oooo003o003oool0
0?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00
0P3oool2003o0080oooo00T00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2
003o0080oooo01<00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool0
0?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`04003o003oool00?l00?oo
o`800?l00P3oool2003o0100oooo00<000000?ooo`3oool0;P3oool00380oooo2P00000T0?ooo`03
0000003oool0oooo00l0oooo00<0o`000?ooo`3o00000P3oool20?l000@0oooo00@0o`000?ooo`3o
ool0o`005`3oool30?l000040?ooo`3o0000oooo0?ooo`80o`000P3oool20?l00080oooo00<0o`00
0?ooo`3o00000P3oool20?l00080oooo103o0000103oool0o`000?ooo`3oool20?l00080oooo00@0
o`000?ooo`3o0000oooo0P3o00020?ooo`040?l0003oool0o`000?ooo`80o`000`3oool20?l00080
oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo00H0o`000?ooo`3oool0oooo0?l0003oool2
0?l00080oooo00@0o`000?ooo`3o0000o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo
00D0o`000?ooo`3oool0oooo0?l000030?ooo`80o`000P3oool20?l00080oooo0P3o00030?ooo`05
0?l0003oool0oooo0?l0003oool00`3o00001@3oool0o`000?l0003o0000oooo00D0o`0000@0oooo
0?l0003o0000oooo0P3o00020?ooo`040?l0003oool0oooo0?l000<0oooo0`3o00000`3oool0o`00
0?l000020?ooo`80o`000P3oool20?l000070?ooo`3o0000oooo0?ooo`3o0000oooo0?l000020?oo
o`040?l0003oool0o`000?l00080oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo00<0o`00
0?ooo`3oool00P3o00020?ooo`050?l0003oool0o`000?l0003oool00P3o0000103oool0o`000?l0
003oool30?l000040?ooo`3o0000o`000?ooo`80o`000P3oool0103o0000oooo0?ooo`3oool20?l0
0080oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo0P3o0000
103oool0o`000?ooo`3o00020?ooo`80o`000P3oool20?l000040?ooo`3o0000oooo0?l000<0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?l000`0oooo0`3o00000`3oool0o`00
0?l000090?ooo`80o`000`3oool02@3o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`02
0?l000030?ooo`3o0000o`000080oooo0P3o00020?ooo`80o`000`3oool40?l000080?ooo`3o0000
oooo0?l0003oool0o`000?ooo`3o00020?ooo`80o`0000@0oooo0?l0003oool0oooo0P3o00030?oo
o`80o`0000P0oooo0?l0003oool0o`000?ooo`00o`00oooo003o0080oooo0P00o`020?ooo`0I003o
003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?oo
o`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool04`00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool0
0?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00
o`020?ooo`03003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00
o`020?ooo`800?l00P3oool00`00o`00oooo003o00020?ooo`800?l00P3oool2003o0080oooo0P00
o`020?ooo`800?l00P3oool2003o0080oooo00<00?l00?ooo`00o`000P3oool2003o0080oooo01<0
0?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00
oooo003o003oool00?l00080oooo0P00o`020?ooo`0=003o003oool00?l00?ooo`00o`00oooo003o
003oool00?l00?ooo`00o`00oooo003o00020?ooo`0C003o003oool00?l00?ooo`00o`00oooo003o
003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l0
0P3oool02000o`00oooo003o003oool00?l00?ooo`00o`00oooo0P00o`0@0?ooo`030000003oool0
oooo02h0oooo000c0?ooo`800000:`3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo
00X0oooo00<0o`000?ooo`3oool05@3oool30?l000040?ooo`3o0000oooo0?ooo`80o`000P3oool2
0?l00080oooo00<0o`000?ooo`3o00000P3oool20?l00080oooo103o0000103oool0o`000?ooo`3o
ool20?l00080oooo00@0o`000?ooo`3o0000oooo0P3o00020?ooo`070?l0003oool0o`000?ooo`3o
0000oooo0?l000020?ooo`80o`000P3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool01`3o
0000oooo0?ooo`3oool0o`000?ooo`3o0000103oool30?l000<0oooo00D0o`000?ooo`3oool0oooo
0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool20?l00080oooo0P3o00020?ooo`80
o`000`3oool01@3o0000oooo0?ooo`3o0000oooo00<0o`0000D0oooo0?l0003o0000o`000?ooo`05
0?l000040?ooo`3o0000o`000?ooo`80o`000P3oool0103o0000oooo0?ooo`3o00030?ooo`<0o`00
00<0oooo0?l0003o00000P3oool20?l00080oooo0P3o00001`3oool0o`000?ooo`3oool0o`000?oo
o`3o00000P3oool01@3o0000oooo0?l0003o0000oooo00<0o`000P3oool20?l00080oooo0P3o0003
0?ooo`030?l0003oool0oooo0080o`000P3oool01@3o0000oooo0?l0003o0000oooo0080o`0000@0
oooo0?l0003o0000oooo0`3o0000103oool0o`000?l0003oool20?l00080oooo00@0o`000?ooo`3o
ool0oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo00D0o`000?ooo`3oool0oooo0?l00003
0?ooo`80o`0000@0oooo0?l0003oool0o`000P3oool20?l00080oooo0P3o0000103oool0o`000?oo
o`3o00030?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3o000<0?ooo`<0o`00
00<0oooo0?l0003o00002@3oool20?l000<0oooo00T0o`000?ooo`3oool0o`000?ooo`3o0000oooo
0?l0003oool00P3o00000`3oool0o`000?l000020?ooo`80o`000P3oool20?l000<0oooo103o0000
203oool0o`000?ooo`3o0000oooo0?l0003oool0o`000P3oool20?l000040?ooo`3o0000oooo0?oo
o`80o`000`3oool20?l000080?ooo`3o0000oooo0?l0003oool00?l00?ooo`00o`020?ooo`800?l0
0P3oool06@00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080
oooo01<00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?oo
o`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00
o`020?ooo`800?l00P3oool00`00o`00oooo003o00020?ooo`800?l00P3oool2003o0080oooo0P00
o`020?ooo`800?l00P3oool2003o0080oooo00<00?l00?ooo`00o`000P3oool2003o0080oooo0P00
o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`03003o003oool00?l00080oooo0P00
o`020?ooo`800?l00P3oool2003o0080oooo00/00?l00?ooo`00o`00oooo003o003oool00?l00?oo
o`00o`00oooo003o00020?ooo`800?l00P3oool03`00o`00oooo003o003oool00?l00?ooo`00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`0A003o003oool00?l00?ooo`00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080
oooo00/00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o000?0?ooo`030000
003oool0oooo02h0oooo000e0?ooo`800000:@3oool00`000000oooo0?ooo`0e0?ooo`<0o`0000@0
oooo0?l0003oool0oooo0P3o00020?ooo`80o`000P3oool00`3o0000oooo0?l000020?ooo`80o`00
00<0oooo0?l0003oool00`3o0000103oool0o`000?ooo`3oool20?l00080oooo00@0o`000?ooo`3o
0000oooo0P3o00002@3oool0o`000?l0003oool0o`000?ooo`3o0000oooo0?l000020?ooo`80o`00
0P3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool0103o0000oooo0?ooo`3o00020?ooo`03
0?l0003oool0oooo0080oooo0`3o00020?ooo`80o`000`3oool0103o0000oooo0?l0003oool20?l0
0080oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo00D0o`00
0?ooo`3oool0o`000?ooo`030?l00080oooo0P3o00000`3oool0o`000?l000030?l000040?ooo`3o
0000o`000?ooo`80o`000P3oool0103o0000oooo0?ooo`3o00030?ooo`<0o`0000<0oooo0?l0003o
00000P3oool20?l00080oooo0P3o00001`3oool0o`000?ooo`3oool0o`000?ooo`3o00000P3oool0
1@3o0000oooo0?l0003o0000oooo00<0o`000P3oool20?l00080oooo0P3o00030?ooo`030?l0003o
ool0oooo0080o`000P3oool00`3o0000oooo0?l000020?l000030?ooo`3o0000oooo0080o`0000@0
oooo0?l0003o0000o`000P3oool0103o0000oooo0?l0003o00020?ooo`040?l0003oool0oooo0?oo
o`80o`000P3oool20?l00080oooo0P3o00030?ooo`080?l0003oool0oooo0?ooo`3o0000oooo0?l0
003oool20?l000040?ooo`3o0000oooo0?l00080oooo0P3o00020?ooo`80o`0000@0oooo0?l0003o
ool0o`000`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0080o`000`3oool00`3o
0000oooo0?ooo`060?ooo`<0o`0000<0oooo0?l0003o00000P3oool00`3o0000oooo0?ooo`040?oo
o`80o`000`3oool0203o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000P3oool0103o0000oooo
0?l0003o00020?ooo`80o`000P3oool01P3o0000oooo0?l0003oool0o`000?ooo`<0o`0000P0oooo
0?l0003oool0o`000?ooo`3o0000oooo0?l00080oooo0P3o0000103oool0o`000?ooo`3oool20?l0
00<0oooo0P3o0000203oool0o`000?ooo`3o0000oooo003o003oool00?l00P3oool2003o0080oooo
00H00?l00?ooo`00o`00oooo003o003oool2003o0080oooo00l00?l00?ooo`00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo00P00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`800?l00P3oool2003o0080oooo00<00?l00?ooo`00
o`000P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`03
003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`80
0?l00P3oool2003o00<0oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`80
0?l00P3oool00`00o`00oooo003o00020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`80
0?l00P3oool01`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo00l00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3o
ool2003o0080oooo00d00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00080oooo0P00o`020?ooo`0;003o003oool00?l00?ooo`00o`00oooo003o003oool00?l0
0?ooo`00o`003`3oool00`000000oooo0?ooo`0^0?ooo`00=`3oool3000002H0oooo00<000000?oo
o`3oool0=@3oool30?l000040?ooo`3o0000oooo0?ooo`80o`000P3oool20?l00080oooo00X0o`00
0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0`3o0000103oool0o`000?ooo`3oool2
0?l000060?ooo`3o0000oooo0?ooo`3o0000oooo0P3o00002@3oool0o`000?l0003oool0o`000?oo
o`3o0000oooo0?l000020?ooo`80o`000P3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool0
103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0oooo0080oooo0`3o00020?ooo`80o`000`3o
ool01P3o0000oooo0?l0003o0000oooo0?l00080oooo00@0o`000?ooo`3oool0oooo0P3o00020?oo
o`80o`000P3oool20?l000<0oooo00D0o`000?ooo`3oool0o`000?ooo`030?l00080oooo0P3o0002
0?ooo`@0o`0000@0oooo0?l0003o0000oooo0P3o00020?ooo`040?l0003oool0oooo0?l000<0oooo
0`3o00000`3oool0o`000?l000020?ooo`80o`000P3oool20?l000070?ooo`3o0000oooo0?ooo`3o
0000oooo0?l000020?ooo`050?l0003oool0o`000?l0003oool00`3o00020?ooo`80o`000P3oool2
0?l000<0oooo00D0o`000?ooo`3oool0o`000?ooo`030?l000080?ooo`3o0000o`000?l0003oool0
o`000?ooo`3o00020?ooo`<0o`000P3oool0103o0000oooo0?l0003o00020?ooo`040?l0003oool0
oooo0?ooo`80o`000P3oool20?l00080oooo00<0o`000?ooo`3o00000P3oool01P3o0000oooo0?oo
o`3oool0o`000?ooo`80o`0000H0oooo0?l0003oool0o`000?ooo`3o00020?ooo`80o`000P3oool2
0?l000040?ooo`3o0000oooo0?l000<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`020?l000<0oooo00<0o`000?ooo`3oool01P3oool30?l000030?ooo`3o0000o`000080oooo00<0
o`000?ooo`3oool0103oool20?l000<0oooo0P3o00001P3oool0o`000?ooo`3o0000oooo0?l00080
oooo00@0o`000?ooo`3o0000o`000P3oool20?l00080oooo00H0o`000?ooo`3o0000oooo0?l0003o
ool30?l000080?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o00020?ooo`040?l0003oool0oooo
0?l00080oooo0P3o00030?ooo`80o`0000P0oooo0?l0003oool0o`000?ooo`00o`00oooo003o0080
oooo0P00o`020?ooo`04003o003oool00?l0003o0080oooo0P00o`020?ooo`0?003o003oool00?l0
0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`02
0?ooo`04003o003oool00?l00?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`03003o003o
ool00?l00080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`800?l00P3o
ool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o0080oooo
0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`020?ooo`80
0?l00P3oool2003o0080oooo00<00?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`80
0?l00P3oool2003o0080oooo00L00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`02
0?ooo`0?003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00080oooo0P00o`020?ooo`800?l00P3oool02@00o`00oooo003o003oool00?l00?ooo`00
o`00oooo003o00020?ooo`800?l00P3oool02`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l000l0oooo00<000000?ooo`3oool0;P3oool003X0oooo0P00000T0?ooo`@00000
=03oool30?l000040?ooo`3o0000oooo0?ooo`80o`000P3oool20?l00080oooo00T0o`000?ooo`3o
0000oooo0?l0003oool0o`000?ooo`3o00000P3oool20?l000060?ooo`3o0000oooo0?ooo`3o0000
oooo0P3o00020?ooo`040?l0003oool0o`000?ooo`<0o`0000H0oooo0?l0003oool0o`000?ooo`3o
00020?ooo`80o`000P3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool0103o0000oooo0?oo
o`3o00020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00000P3oool20?l000<0oooo
00H0o`000?ooo`3o0000o`000?ooo`3o00020?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool2
0?l00080oooo0P3o00030?ooo`050?l0003oool0oooo0?l0003oool00`3o00020?ooo`80o`000P3o
ool40?l000040?ooo`3o0000o`000?ooo`80o`000P3oool0103o0000oooo0?ooo`3o00030?ooo`<0
o`0000<0oooo0?l0003o00000P3oool20?l00080oooo0P3o00001`3oool0o`000?ooo`3oool0o`00
0?ooo`3o00000P3oool01@3o0000oooo0?l0003o0000oooo00<0o`000P3oool20?l00080oooo0P3o
00030?ooo`050?l0003oool0oooo0?l0003oool00`3o00001@3oool0o`000?l0003o0000oooo00<0
o`000P3oool30?l00080oooo00@0o`000?ooo`3o0000o`000P3oool01P3o0000oooo0?ooo`3o0000
oooo0?l00080oooo0P3o00020?ooo`030?l0003oool0o`000080oooo00H0o`000?ooo`3oool0oooo
0?l0003oool20?l000060?ooo`3o0000oooo0?l0003oool0o`000P3oool20?l00080oooo0P3o0000
103oool0o`000?ooo`3o00030?ooo`030?l0003oool0oooo00D0oooo0P3o00020?ooo`80o`000`3o
ool00`3o0000oooo0?ooo`060?ooo`<0o`0000<0oooo0?l0003o00000P3oool00`3o0000oooo0?oo
o`040?ooo`80o`000`3oool20?l000060?ooo`3o0000oooo0?l0003oool0o`000P3oool40?l00080
oooo0P3o0000303oool0o`000?l0003oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`80
o`000P3oool00`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?l00080oooo0P3o00030?oo
o`80o`0000h0oooo0?l0003oool0o`000?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o0080oooo0P00o`020?ooo`800?l00P3oool03`00o`00oooo003o003oool00?l00?ooo`00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool2003o0080oooo0P00
o`020?ooo`800?l00P3oool2003o0080oooo00<00?l00?ooo`00o`000P3oool2003o0080oooo00@0
0?l00?ooo`3oool0oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o
003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o00<0
oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o0080oooo0P00o`020?oo
o`800?l00`3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool0
1`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo00l00?l00?ooo`00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool2003o0080
oooo0P00o`020?ooo`09003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00
o`020?ooo`0;003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`003`3oool0
0`000000oooo0?ooo`0^0?ooo`00=`3oool3000002H0oooo00<000000?ooo`3oool0=@3oool30?l0
00040?ooo`3o0000oooo0?ooo`80o`000P3oool20?l00080oooo00T0o`000?ooo`3o0000oooo0?l0
003oool0o`000?ooo`3o00000P3oool20?l000060?ooo`3o0000oooo0?ooo`3o0000oooo0P3o0002
0?ooo`040?l0003oool0o`000?ooo`<0o`0000H0oooo0?l0003oool0o`000?ooo`3o00020?ooo`80
o`000P3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool0103o0000oooo0?ooo`3o00070?oo
o`030?l0003oool0o`000080oooo0P3o00030?ooo`060?l0003oool0o`000?l0003oool0o`000P3o
ool01@3o0000oooo0?ooo`3o0000oooo0080o`0000@0oooo0?l0003o0000oooo0`3o00030?ooo`08
0?l0003oool0oooo0?l0003oool0o`000?ooo`3o00020?ooo`060?l0003oool0oooo0?ooo`3o0000
oooo0P3o0000103oool0o`000?l0003oool20?l00080oooo00@0o`000?ooo`3oool0o`000`3oool3
0?l000050?ooo`3o0000o`000?l0003oool00P3o00020?ooo`80o`0000L0oooo0?l0003oool0oooo
0?l0003oool0o`000080oooo103o0000103oool0o`000?ooo`3o00020?ooo`80o`000P3oool20?l0
00<0oooo00D0o`000?ooo`3oool0o`000?ooo`030?l00080oooo0P3o0000103oool0o`000?l0003o
00020?ooo`<0o`000P3oool0103o0000oooo0?l0003o00020?ooo`060?l0003oool0oooo0?l0003o
ool0o`000P3oool20?l00080oooo00<0o`000?ooo`3o00000P3oool01P3o0000oooo0?ooo`3oool0
o`000?ooo`80o`0000H0oooo0?l0003oool0o`000?ooo`3o00020?ooo`80o`000P3oool20?l00004
0?ooo`3o0000oooo0?l000<0oooo00<0o`000?ooo`3oool01@3oool20?l00080oooo0P3o00030?oo
o`030?l0003oool0oooo00H0oooo0`3o00000`3oool0o`000?l000020?ooo`030?l0003oool0oooo
00@0oooo0P3o00030?ooo`80o`0000<0oooo0?l0003oool00P3o00030?ooo`@0o`000P3oool20?l0
00040?ooo`3o0000o`000?ooo`80o`000P3oool0103o0000oooo0?l0003oool20?l00080oooo00<0
o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3o00020?ooo`80o`000`3oool20?l0000>0?oo
o`3o0000oooo0?l0003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`020?ooo`80
0?l00P3oool2003o0080oooo00l00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o
0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`02
0?ooo`800?l00P3oool2003o0080oooo0P00o`030?ooo`05003o003oool0oooo0?ooo`00o`000`3o
ool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`05
003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o
00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o0080oooo00L00?l0
0?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo
00L00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool03@00
o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool02`00
o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l000l0oooo00<000000?ooo`3o
ool0;P3oool003D0oooo0P00000Y0?ooo`030000003oool0oooo03D0oooo0`3o0000103oool0o`00
0?ooo`3oool20?l00080oooo0P3o00020?ooo`090?l0003oool0o`000?ooo`3o0000oooo0?l0003o
ool0o`000080oooo0P3o00001P3oool0o`000?l0003oool0o`000?ooo`80o`000P3oool0103o0000
oooo0?l0003oool30?l000060?ooo`3o0000oooo0?l0003oool0o`000P3oool20?l00080oooo0P3o
00020?ooo`80o`000P3oool20?l000040?ooo`3o0000oooo0?l00080oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`020?l000<0oooo00H0o`000?ooo`3o0000o`000?ooo`3o00020?oo
o`050?l0003oool0oooo0?l0003oool00P3o00000`3oool0o`000?l000040?l000<0oooo00H0o`00
0?ooo`3oool0o`000?ooo`3o00040?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0P3o0000103o
ool0o`000?l0003oool20?l00080oooo00@0o`000?ooo`3oool0o`000`3oool70?l000030?ooo`3o
0000o`000080oooo0P3o00001`3oool0o`000?ooo`3oool0o`000?ooo`3o00000P3oool40?l00004
0?ooo`3o0000oooo0?l00080oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3o0000
oooo00<0o`000`3oool0103o0000oooo0?l0003o00030?ooo`<0o`000P3oool0103o0000oooo0?l0
003o00020?ooo`060?l0003oool0oooo0?l0003oool0o`000P3oool20?l00080oooo00<0o`000?oo
o`3o00000P3oool01P3o0000oooo0?ooo`3oool0o`000?ooo`80o`0000H0oooo0?l0003oool0o`00
0?ooo`3o00020?ooo`80o`000P3oool20?l000040?ooo`3o0000oooo0?l000<0oooo00<0o`000?oo
o`3oool01@3oool20?l00080oooo0P3o00030?ooo`030?l0003oool0oooo00H0oooo0`3o00000`3o
ool0o`000?l000020?ooo`030?l0003oool0oooo00@0oooo0P3o00030?ooo`80o`0000<0oooo0?l0
003oool00P3o00030?ooo`@0o`000P3oool20?l000040?ooo`3o0000o`000?ooo`80o`000P3oool0
0`3o0000oooo0?ooo`020?ooo`060?l0003oool0oooo0?l0003oool0o`001@3oool00`3o0000oooo
0?ooo`020?l000<0oooo0P3o00003P3oool0o`000?ooo`3o0000oooo003o003oool00?l00?ooo`00
o`00oooo003o003oool00?l00P3oool2003o0080oooo0P00o`020?ooo`08003o003oool00?l00?oo
o`00o`00oooo003o003oool2003o0080oooo00<00?l00?ooo`00o`000P3oool2003o0080oooo0P00
o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?oo
o`3oool00?l000<0oooo0P00o`020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`00o`00
oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool0
0?l000<0oooo00D00?l00?ooo`3oool0oooo003o00040?ooo`05003o003oool0oooo0?ooo`00o`00
0`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00@00?l00?ooo`3oool0oooo0P00o`030?oo
o`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`07003o003oool0
0?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`800?l0
0P3oool00`00o`00oooo003o00020?ooo`800?l00P3oool2003o0080oooo00l00?l00?ooo`00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`000P3oool02@00o`00
oooo003o003oool00?l00?ooo`00o`00oooo003o000?0?ooo`030000003oool0oooo02h0oooo000c
0?ooo`800000:`3oool00`000000oooo0?ooo`0e0?ooo`<0o`000P3oool0103o0000oooo0?l0003o
00020?ooo`80o`000P3oool02@3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l000020?oo
o`030?l0003oool0oooo0080o`0000<0oooo0?l0003oool00P3o00020?ooo`040?l0003oool0o`00
0?ooo`<0o`0000H0oooo0?l0003oool0o`000?ooo`3o00020?ooo`80o`000P3oool20?l00080oooo
0P3o0000103oool0o`000?ooo`3oool20?l000050?ooo`3o0000oooo0?ooo`3o00002@3oool00`3o
0000oooo0?ooo`020?l000<0oooo00H0o`000?ooo`3o0000o`000?ooo`3o00020?ooo`050?l0003o
ool0o`000?l0003oool00P3o00000`3oool0o`000?ooo`040?l000<0oooo00H0o`000?ooo`3oool0
o`000?ooo`3o00040?ooo`030?l0003oool0oooo00<0oooo1@3o00000`3oool0o`000?l000020?oo
o`040?l0003oool0oooo0?l000<0oooo103o00001P3oool0o`000?l0003o0000oooo0?l00080oooo
0P3o00001`3oool0o`000?ooo`3oool0o`000?ooo`3o00000P3oool40?l000040?ooo`3o0000oooo
0?l00080oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3o0000oooo00<0o`000`3o
ool0103o0000oooo0?l0003o00030?ooo`<0o`000P3oool0103o0000oooo0?l0003o00020?ooo`06
0?l0003oool0oooo0?l0003oool0o`000P3oool20?l00080oooo00<0o`000?ooo`3o00000P3oool0
0`3o0000oooo0?ooo`020?l000090?ooo`3o0000o`000?ooo`3o0000oooo0?l0003oool0o`000080
oooo0P3o00020?ooo`80o`0000@0oooo0?l0003o0000o`000`3oool00`3o0000oooo0?ooo`050?oo
o`80o`000P3oool20?l000<0oooo00<0o`000?ooo`3oool01P3oool30?l000030?ooo`3o0000o`00
0080oooo00<0o`000?ooo`3oool0103oool20?l000<0oooo0P3o00000`3oool0o`000?ooo`020?l0
00<0oooo103o00020?ooo`80o`0000@0oooo0?l0003o0000oooo0P3o00020?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3o00001@3oool01P3o0000oooo0?ooo`3o0000oooo0?l00080oooo
0P3o00003P3oool0o`000?ooo`3o0000oooo003o003oool00?l00?ooo`00o`00oooo003o003oool0
0?l00P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`03
003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool01000o`00oooo0?ooo`3oool2003o
0080oooo0P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l0
0?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`00103oool00`00o`00oooo
0?ooo`0N0?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l0
00@0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`800?l00P3oool2003o0080oooo0P00o`02
0?ooo`800?l00`3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo00<00?l0
0?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`0?003o003oool00?l00?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`05003o003o
ool00?l00?ooo`00o`003`3oool00`000000oooo0?ooo`0^0?ooo`00<P3oool:000002@0oooo00<0
00000?ooo`3oool0=@3oool30?l00080oooo103o00020?ooo`80o`000P3oool02@3o0000oooo0?l0
003oool0o`000?ooo`3o0000oooo0?l000020?ooo`030?l0003oool0oooo0080o`0000@0oooo0?l0
003oool0o`000`3oool30?l0000:0?ooo`3o0000o`000?l0003oool0o`000?ooo`3o0000oooo0?l0
0080oooo0P3o00020?ooo`80o`000P3oool20?l000040?ooo`3o0000oooo0?ooo`80o`0000D0oooo
0?l0003oool0oooo0?l000090?ooo`030?l0003oool0oooo0080o`000`3oool01P3o0000oooo0?l0
003o0000oooo0?l00080oooo00D0o`000?ooo`3o0000o`000?ooo`020?l000040?ooo`3o0000oooo
0?ooo`80o`0000D0oooo0?l0003oool0oooo0?l000020?ooo`030?l0003oool0o`0000/0oooo103o
00000`3oool0o`000?l000020?ooo`040?l0003oool0oooo0?l000<0oooo103o00001P3oool0o`00
0?l0003o0000oooo0?l00080oooo0P3o00001`3oool0o`000?ooo`3oool0o`000?ooo`3o00000P3o
ool40?l000040?ooo`3o0000oooo0?l00080oooo0P3o00020?ooo`80o`000`3oool20?l000030?oo
o`3o0000oooo00<0o`000`3oool0103o0000oooo0?l0003o00030?ooo`<0o`000P3oool0103o0000
oooo0?l0003o00020?ooo`060?l0003oool0oooo0?l0003oool0o`000P3oool20?l00080oooo00<0
o`000?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?l000090?ooo`3o0000o`000?ooo`3o0000
oooo0?l0003oool0o`000080oooo0P3o00020?ooo`80o`0000@0oooo0?l0003o0000o`000`3oool0
0`3o0000oooo0?ooo`050?ooo`80o`000P3oool20?l000<0oooo00<0o`000?ooo`3oool01@3oool4
0?l000030?ooo`3o0000o`000080oooo00<0o`000?ooo`3oool0103oool20?l00080oooo00H0o`00
0?ooo`3o0000oooo0?l0003oool20?l000<0oooo103o00020?ooo`D0o`0000<0oooo0?l0003o0000
0P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0o`0000D0oooo00H0o`000?ooo`3oool0
o`000?ooo`3o00020?ooo`80o`0000h0oooo0?l0003oool0o`000?ooo`00o`00oooo003o003oool0
0?l00?ooo`00o`00oooo003o0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`02
0?ooo`800?l00P3oool00`00o`00oooo003o00020?ooo`05003o003oool0oooo0?ooo`00o`000`3o
ool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`020?ooo`03003o003oool0oooo0080oooo
00D00?l00?ooo`3oool0oooo003o00030?ooo`03003o003oool0oooo03/0oooo00<00?l00?ooo`3o
ool00P3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00@00?l00?ooo`3oool0oooo0P00o`02
0?ooo`800?l00P3oool2003o00<0oooo00@00?l00?ooo`3oool0oooo0P00o`020?ooo`800?l00P3o
ool2003o0080oooo00<00?l00?ooo`00o`000P3oool2003o0080oooo0P00o`020?ooo`0?003o003o
ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo
0P00o`020?ooo`05003o003oool00?l00?ooo`00o`003`3oool00`000000oooo0?ooo`0^0?ooo`00
H03oool4000003@0oooo0P3o00030?ooo`@0o`000P3oool20?l00080oooo00T0o`000?ooo`3o0000
oooo0?l0003oool0o`000?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?l000040?ooo`3o0000
oooo0?l000<0oooo0`3o00001@3oool0o`000?l0003o0000oooo0080o`000P3oool00`3o0000oooo
0?ooo`020?l00080oooo0P3o00020?ooo`80o`0000@0oooo0?l0003oool0oooo0P3o00001@3oool0
o`000?ooo`3oool0o`0000T0oooo00<0o`000?ooo`3oool00P3o00030?ooo`060?l0003oool0o`00
0?l0003oool0o`000P3oool01@3o0000oooo0?l0003o0000oooo0080o`0000@0oooo0?l0003oool0
oooo0P3o00001@3oool0o`000?ooo`3oool0o`000080oooo00<0o`000?ooo`3o00002`3oool40?l0
00030?ooo`3o0000o`000080oooo00@0o`000?ooo`3oool0o`000`3oool40?l000070?ooo`3o0000
o`000?l0003oool0o`000?ooo`030?l000070?ooo`3o0000oooo0?ooo`3o0000oooo0?l000020?oo
o`@0o`0000@0oooo0?l0003oool0o`000P3oool20?l00080oooo0P3o00030?ooo`80o`0000<0oooo
0?l0003oool00`3o00060?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l000020?ooo`040?l0
003oool0o`000?l00080oooo00H0o`000?ooo`3oool0o`000?ooo`3o00020?ooo`80o`000P3oool0
0`3o0000oooo0?l000020?ooo`80o`0000@0oooo0?l0003o0000oooo0P3o00001P3oool0o`000?l0
003o0000oooo0?l00080oooo0P3o00020?ooo`80o`0000@0oooo0?l0003o0000o`000`3oool00`3o
0000oooo0?ooo`050?ooo`80o`000P3oool20?l000<0oooo00<0o`000?ooo`3oool01@3oool40?l0
00030?ooo`3o0000o`000080oooo00<0o`000?ooo`3oool0103oool20?l00080oooo00H0o`000?oo
o`3o0000oooo0?l0003oool20?l000<0oooo1@3o00000`3oool0o`000?l000030?l000030?ooo`3o
0000o`0000X0oooo00<0o`000?ooo`3o00001@3oool01P3o0000oooo0?ooo`3o0000oooo0?l00080
oooo0P3o00003P3oool0o`000?ooo`3o0000oooo003o003oool00?l00?ooo`00o`00oooo003o003o
ool00?l00P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?oo
o`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo00D00?l00?ooo`3oool0oooo003o
00030?ooo`05003o003oool0oooo0?ooo`00o`00103oool00`00o`00oooo0?ooo`1<0?ooo`05003o
003oool0oooo0?ooo`00o`000`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`030?oo
o`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`03003o003oool0
0?l00080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo00/00?l00?ooo`00o`00oooo003o
003oool00?l00?ooo`00o`00oooo003o00020?ooo`800?l00P3oool01@00o`00oooo003o003oool0
0?l000l0oooo00<000000?ooo`3oool0;P3oool00600oooo00<000000?ooo`3oool0=P3oool0103o
0000oooo0?ooo`3oool40?l00080oooo0P3o00020?ooo`090?l0003oool0o`000?ooo`3o0000oooo
0?l0003oool0o`000080oooo00<0o`000?ooo`3oool00P3o0000103oool0o`000?ooo`3o00030?oo
o`<0o`0000D0oooo0?l0003o0000o`000?ooo`020?l00080oooo00D0o`000?ooo`3o0000oooo0?l0
00020?ooo`80o`000P3oool20?l000040?ooo`3o0000oooo0?ooo`@0o`000P3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo0080o`000`3oool01P3o0000oooo0?l0003o0000oooo0?l0
0080oooo00@0o`000?ooo`3o0000o`000P3oool00`3o0000oooo0?l000020?ooo`80o`0000@0oooo
0?l0003oool0oooo0P3o0000103oool0o`000?ooo`3o000;0?ooo`@0o`0000<0oooo0?l0003o0000
0P3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0003oool0o`000?l0003oool00`3o00000`3o
ool0o`000?ooo`030?l000070?ooo`3o0000oooo0?ooo`3o0000oooo0?l000020?ooo`@0o`0000@0
oooo0?l0003oool0o`000P3oool20?l00080oooo0P3o00030?ooo`80o`0000<0oooo0?l0003oool0
0`3o00060?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l000020?ooo`80o`0000@0oooo0?l0
003oool0oooo0P3o0000103oool0o`000?ooo`3o00020?ooo`80o`000P3oool00`3o0000oooo0?l0
00020?ooo`80o`0000@0oooo0?l0003o0000oooo0P3o00001P3oool0o`000?l0003o0000oooo0?l0
0080oooo0P3o00020?ooo`80o`0000@0oooo0?l0003o0000o`000`3oool00`3o0000oooo0?ooo`05
0?ooo`80o`000P3oool20?l00080oooo0P3o00070?ooo`@0o`0000<0oooo0?l0003o00000P3oool0
0`3o0000oooo0?ooo`040?ooo`80o`000P3oool00`3o0000oooo0?l000020?l000H0oooo1@3o0000
0`3oool0o`000?l000030?l000030?ooo`3o0000o`0000X0oooo00<0o`000?ooo`3o00001@3oool0
1P3o0000oooo0?ooo`3o0000oooo0?l00080oooo0P3o00000`3oool0o`000?ooo`020?ooo`09003o
003oool00?l00?ooo`00o`00oooo003o003oool00?l00080oooo0P00o`020?ooo`800?l00P3oool2
003o0080oooo0P00o`020?ooo`800?l00P3oool2003o00<0oooo00D00?l00?ooo`3oool0oooo003o
00030?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`1M0?ooo`05003o
003oool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`020?ooo`05003o003oool0oooo0?oo
o`00o`000`3oool2003o0080oooo0P00o`020?ooo`03003o003oool00?l00080oooo0P00o`020?oo
o`800?l00P3oool2003o0080oooo0P00o`020?ooo`07003o003oool00?l00?ooo`00o`00oooo003o
00020?ooo`800?l00P3oool01@00o`00oooo003o003oool00?l000l0oooo00<000000?ooo`3oool0
;P3oool00380oooo0P00000/0?ooo`030000003oool0oooo03H0oooo00@0o`000?ooo`3oool0oooo
103o00020?ooo`80o`000P3oool01P3o0000oooo0?l0003oool0o`000?ooo`<0o`000P3oool00`3o
0000oooo0?ooo`020?l000040?ooo`3o0000oooo0?l000<0oooo0`3o00001@3oool0o`000?l0003o
0000oooo0080o`000P3oool01@3o0000oooo0?l0003oool0o`000080oooo0P3o00020?ooo`80o`00
00@0oooo0?l0003oool0oooo103o00020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool00P3o00030?ooo`@0o`0000H0oooo0?l0003oool0oooo0?l0003oool20?l00080oooo00<0o`00
0?ooo`3o00000`3oool00`3o0000oooo0?l000020?ooo`80o`0000<0oooo0?l0003oool0303oool2
0?l000030?ooo`3o0000oooo0080o`000P3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0003o
ool0o`000?l0003oool00`3o00000`3oool0o`000?ooo`030?l000070?ooo`3o0000oooo0?ooo`3o
0000oooo0?l000020?ooo`80o`0000H0oooo0?l0003oool0o`000?ooo`3o00020?ooo`80o`000P3o
ool20?l000<0oooo0P3o00000`3oool0o`000?ooo`030?l000X0oooo00<0o`000?ooo`3o00000P3o
ool20?l000040?ooo`3o0000oooo0?ooo`80o`0000@0oooo0?l0003oool0o`000P3oool20?l00080
oooo00P0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`<0o`0000@0oooo0?l0003oool0oooo
0P3o0000103oool0o`000?ooo`3oool20?l00080oooo0P3o0000103oool0o`000?l0003o00030?oo
o`030?l0003oool0oooo00D0oooo0P3o00020?ooo`80o`000P3oool20?l000L0oooo103o00000`3o
ool0o`000?l000020?ooo`030?l0003oool0oooo00@0oooo0P3o00020?ooo`030?l0003oool0o`00
0080o`001P3oool20?l000040?ooo`3o0000o`000?ooo`D0o`0000<0oooo0?l0003o00002`3oool2
0?l000D0oooo00H0o`000?ooo`3oool0o`000?ooo`3o00020?ooo`80o`0000<0oooo0?l0003oool0
0P3oool01000o`00oooo003o0000o`020?ooo`03003o003oool00?l00080oooo0P00o`020?ooo`80
0?l00P3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`020?ooo`800?l00`3oool01@00
o`00oooo0?ooo`3oool00?l000<0oooo00<00?l00?ooo`3oool0K@3oool00`00o`00oooo0?ooo`02
0?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`020?ooo`800?l00`3o
ool2003o0080oooo0P00o`020?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`03003o003o
ool00?l00080oooo0P00o`020?ooo`05003o003oool00?l00?ooo`00o`003`3oool00`000000oooo
0?ooo`0^0?ooo`00=03oool3000002T0oooo00<000000?ooo`3oool0=P3oool0103o0000oooo0?oo
o`3oool40?l00080oooo0P3o00020?ooo`060?l0003oool0o`000?ooo`3o0000oooo0`3o00050?oo
o`80o`0000@0oooo0?l0003oool0o`000`3oool0103o0000oooo0?l0003oool30?l000030?ooo`3o
0000o`000080oooo00D0o`000?ooo`3o0000oooo0?l000020?ooo`80o`000P3oool0103o0000oooo
0?l0003o00020?ooo`@0o`000P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0080
o`000`3oool20?l000040?ooo`3o0000oooo0?l00080oooo00@0o`000?ooo`3o0000o`000P3oool0
0`3o0000oooo0?l000030?ooo`030?l0003oool0o`000080oooo0P3o00000`3oool0o`000?ooo`0<
0?ooo`80o`0000<0oooo0?l0003oool00P3o00020?ooo`040?l0003oool0oooo0?l000<0oooo00D0
o`000?ooo`3o0000o`000?ooo`030?l000030?ooo`3o0000oooo00<0o`0000L0oooo0?l0003oool0
oooo0?l0003oool0o`000080oooo0P3o00001P3oool0o`000?ooo`3o0000oooo0?l00080oooo0P3o
00020?ooo`80o`000`3oool20?l000030?ooo`3o0000oooo0080o`002`3oool00`3o0000oooo0?oo
o`020?ooo`80o`0000@0oooo0?l0003oool0oooo0P3o0000103oool0o`000?ooo`3o00020?ooo`80
o`000P3oool0203o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0`3o0000103oool0o`000?oo
o`3oool20?l000040?ooo`3o0000oooo0?ooo`80o`000P3oool20?l000040?ooo`3o0000o`000?l0
00<0oooo00<0o`000?ooo`3oool01@3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool01P3o
0000oooo0?ooo`3oool0o`000?ooo`80o`0000@0oooo0?l0003o0000oooo0P3o00060?ooo`80o`00
0P3oool0103o0000oooo0?l0003o00080?ooo`050?l0003oool0o`000?l0003oool01@3o00000`3o
ool0o`000?l0000;0?ooo`80o`001@3oool0303o0000oooo0?ooo`3o0000oooo0?l0003oool0o`00
0?ooo`3o0000oooo0?l00080oooo00<00?l00?ooo`3oool00P00o`020?ooo`03003o003oool00?l0
0080oooo0P00o`020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool2003o0080oooo0P00o`02
0?ooo`03003o003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo003o001h0?ooo`05003o003o
ool0oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`030?ooo`04
003o003oool0oooo0?ooo`800?l00P3oool2003o0080oooo0P00o`020?ooo`800?l00P3oool00`00
o`00oooo003o00020?ooo`800?l00P3oool01@00o`00oooo003o003oool00?l000l0oooo00<00000
0?ooo`3oool0;P3oool003L0oooo0`00000V0?ooo`@00000=@3oool01P3o0000oooo0?ooo`3oool0
o`000?ooo`80o`000P3oool20?l00080oooo00T0o`000?ooo`3o0000oooo0?l0003oool0o`000?oo
o`3o00001@3oool30?l000H0oooo00@0o`000?ooo`3oool0oooo0`3o00000`3oool0o`000?l00002
0?ooo`050?l0003oool0o`000?ooo`3o00000P3oool20?l00080oooo00@0o`000?ooo`3o0000o`00
0P3oool40?l00080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?l000<0oooo
0P3o0000103oool0o`000?ooo`3o00020?ooo`<0o`000`3oool00`3o0000oooo0?l000030?ooo`03
0?l0003oool0o`000080oooo0P3o00000`3oool0o`000?ooo`0<0?ooo`80o`000`3oool20?l00080
oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?l0003o0000oooo00<0o`0000<0oooo
0?l0003oool00`3o00001`3oool0o`000?ooo`3oool0o`000?ooo`3o00000P3oool20?l0000:0?oo
o`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l00080oooo0P3o00030?ooo`80o`0000<0
oooo0?l0003oool00P3o000;0?ooo`030?l0003oool0oooo0080oooo0P3o0000103oool0o`000?oo
o`3oool20?l000040?ooo`3o0000oooo0?l00080oooo0P3o00020?ooo`080?l0003oool0o`000?oo
o`3o0000oooo0?l0003oool30?l000@0oooo0P3o0000103oool0o`000?ooo`3oool20?l00080oooo
0P3o0000103oool0o`000?l0003o00030?ooo`030?l0003oool0oooo00D0oooo0P3o00020?ooo`80
o`000P3oool20?l000<0oooo00H0o`000?ooo`3oool0oooo0?l0003oool20?l000040?ooo`3o0000
o`000?ooo`80o`001P3oool01P3o0000oooo0?l0003oool0o`000?ooo`80o`00203oool00`3o0000
oooo0?l000020?l000030?ooo`3o0000oooo0080o`0000<0oooo0?l0003o00002`3oool00`3o0000
oooo0?ooo`040?ooo`0<0?l0003oool0oooo0?l0003oool0o`000?ooo`3o0000oooo0?l0003oool0
o`000P3oool00`00o`00oooo0?ooo`02003o0080oooo00<00?l00?ooo`00o`000P3oool01@00o`00
oooo0?ooo`3oool00?l000<0oooo00@00?l00?ooo`3oool0oooo0P00o`020?ooo`05003o003oool0
oooo0?ooo`00o`00R@3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`030?ooo`05003o
003oool0oooo0?ooo`00o`000`3oool01000o`00oooo0?ooo`3oool2003o0080oooo0P00o`020?oo
o`03003o003oool00?l00080oooo0P00o`020?ooo`05003o003oool00?l00?ooo`00o`003`3oool0
0`000000oooo0?ooo`0^0?ooo`00>P3oool2000000d0oooo100000040?ooo`@000002`3oool00`00
0000oooo0?ooo`0f0?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0P3o00020?ooo`80o`000P3o
ool02@3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l000050?ooo`<0o`001P3oool0103o
0000oooo0?ooo`3oool30?l000030?ooo`3o0000o`000080oooo00D0o`000?ooo`3o0000oooo0?l0
00020?ooo`80o`000P3oool0103o0000oooo0?l0003o00020?ooo`040?l0003oool0o`000?l00080
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?l000<0oooo0P3o00001@3oool0
o`000?ooo`3o0000oooo00@0o`00103oool20?l000<0oooo00<0o`000?ooo`3o00000P3oool20?l0
00030?ooo`3o0000oooo00`0oooo0P3o00030?ooo`80o`000P3oool0103o0000oooo0?l0003o0003
0?ooo`050?l0003oool0o`000?l0003oool00`3o00000`3oool0o`000?ooo`020?l000030?ooo`3o
0000o`000080oooo00<0o`000?ooo`3o00000P3oool20?l0000:0?ooo`3o0000oooo0?l0003oool0
o`000?ooo`3o0000oooo0?l00080oooo0P3o00030?ooo`80o`0000<0oooo0?l0003oool00P3o000;
0?ooo`030?l0003oool0oooo0080oooo0P3o00002@3oool0o`000?ooo`3o0000oooo0?l0003oool0
o`000?ooo`020?l000030?ooo`3o0000o`000080oooo00P0o`000?ooo`3o0000oooo0?l0003oool0
o`000?ooo`<0o`00103oool20?l000040?ooo`3o0000oooo0?ooo`80o`000P3oool20?l000040?oo
o`3o0000o`000?l000<0oooo0P3o00020?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool20?l0
0080oooo0P3o00030?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0P3o00020?ooo`040?l0003o
ool0o`000?l000H0oooo00H0o`000?ooo`3o0000oooo0?l0003oool20?l000P0oooo00<0o`000?oo
o`3o00000P3o00000`3oool0o`000?ooo`020?l000030?ooo`3o0000oooo00/0oooo00<0o`000?oo
o`3oool0103oool0303o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l0
0080oooo00<00?l00?ooo`3oool00P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool0
0?l000<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`03003o003oool0oooo08l0oooo00D0
0?l00?ooo`3oool0oooo003o00040?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01000o`00
oooo0?ooo`3oool2003o0080oooo0P00o`020?ooo`03003o003oool00?l00080oooo0P00o`020?oo
o`800?l00P3oool00`00o`00oooo0?ooo`0=0?ooo`030000003oool0oooo02h0oooo000g0?ooo`<0
00003P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0f0?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0P3o
00020?ooo`80o`000P3oool01@3o0000oooo0?l0003oool0o`0000X0oooo0P3o000:0?ooo`<0o`00
00<0oooo0?l0003o00000P3oool30?l000040?ooo`3o0000oooo0?ooo`80o`000P3oool0103o0000
oooo0?l0003o00020?ooo`040?l0003oool0o`000?l00080oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`020?l000<0oooo0P3o00001@3oool0o`000?ooo`3o0000oooo00@0o`00103o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0o`000080oooo0P3o00000`3oool0o`000?oo
o`0<0?ooo`80o`000`3oool20?l00080oooo00@0o`000?ooo`3o0000o`000`3oool01@3o0000oooo
0?l0003o0000oooo00<0o`0000@0oooo0?l0003oool0o`000P3oool20?l00080oooo00<0o`000?oo
o`3o00000P3oool20?l0000:0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l00080
oooo0P3o00030?ooo`80o`0000<0oooo0?l0003oool00P3o000;0?ooo`030?l0003oool0oooo0080
oooo0P3o00002@3oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`030?l0000<0?ooo`3o
0000oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0`3o00040?ooo`80o`0000@0
oooo0?l0003oool0oooo0P3o00020?ooo`80o`0000D0oooo0?l0003o0000oooo0?l000020?ooo`80
o`000P3oool0103o0000oooo0?ooo`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool01P3o
0000oooo0?ooo`3oool0o`000?ooo`80o`000P3oool0103o0000oooo0?l0003o00060?ooo`060?l0
003oool0o`000?ooo`3o0000oooo0P3o000;0?ooo`80o`0000<0oooo0?l0003oool00P3o00000`3o
ool0o`000?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo00`0o`000?ooo`3oool0o`000?ooo`3o
0000oooo0?l0003oool0o`000?ooo`3o00020?ooo`03003o003oool0oooo00800?l00P3oool2003o
00<0oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`05003o003oool0oooo0?ooo`00o`00V@3o
ool00`00o`00oooo0?ooo`020?ooo`05003o003oool0oooo0?ooo`00o`000`3oool01000o`00oooo
0?ooo`3oool2003o0080oooo0P00o`020?ooo`03003o003oool00?l00080oooo0P00o`020?ooo`80
0?l00P3oool00`00o`00oooo0?ooo`0=0?ooo`030000003oool0oooo02h0oooo000c0?ooo`@00000
4@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0j0?ooo`040?l0003oool0oooo0?l00080oooo0P3o00020?oo
o`030?l0003oool0oooo0080o`002P3oool20?l000X0oooo0`3o00000`3oool0o`000?l000020?oo
o`<0o`0000@0oooo0?l0003oool0oooo0P3o00020?ooo`040?l0003oool0o`000?l00080oooo00@0
o`000?ooo`3o0000o`000P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0080o`00
0`3oool20?l000030?ooo`3o0000oooo00H0o`00103oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0o`000080oooo0P3o00000`3oool0o`000?ooo`0<0?ooo`80o`000`3oool20?l00080oooo
00@0o`000?ooo`3o0000o`000`3oool01@3o0000oooo0?l0003o0000oooo00<0o`0000@0oooo0?l0
003oool0o`000P3oool20?l00080oooo00<0o`000?ooo`3o00000P3oool20?l0000:0?ooo`3o0000
oooo0?l0003oool0o`000?ooo`3o0000oooo0?l00080oooo00<0o`000?ooo`3o00000P3oool20?l0
00030?ooo`3o0000oooo0080o`00403oool20?l000090?ooo`3o0000oooo0?l0003oool0o`000?oo
o`3o0000oooo00<0o`0000`0oooo0?l0003oool0oooo0?l0003oool0o`000?ooo`3o0000oooo0?l0
003oool30?l000@0oooo0P3o00020?ooo`@0o`000P3oool20?l000050?ooo`3o0000o`000?ooo`3o
00000P3oool20?l00080oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`000P3oool20?l0
00<0oooo00H0o`000?ooo`3oool0oooo0?l0003oool20?l00080oooo00@0o`000?ooo`3o0000o`00
1P3oool01P3o0000oooo0?l0003oool0o`000?ooo`80o`002`3oool20?l000<0oooo0P3o00000`3o
ool0o`000?ooo`0B0?ooo`@0o`0000P0oooo0?l0003oool0o`000?ooo`3o0000oooo0?l00080oooo
00<00?l00?ooo`3oool00P00o`020?ooo`800?l00`3oool01@00o`00oooo0?ooo`3oool00?l000<0
oooo00<00?l00?ooo`3oool0Y03oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`020?oo
o`800?l00P3oool2003o00<0oooo0P00o`020?ooo`800?l00P3oool00`00o`00oooo0?ooo`0=0?oo
o`030000003oool0oooo02h0oooo000b0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03X0oooo00@0o`000?oo
o`3oool0o`000P3oool20?l00080oooo00<0o`000?ooo`3oool00P3o000:0?ooo`80o`002P3oool3
0?l000030?ooo`3o0000o`000080oooo0`3o0000103oool0o`000?ooo`3oool20?l00080oooo00@0
o`000?ooo`3o0000o`000P3oool01`3o0000oooo0?l0003oool0o`000?ooo`3o00002@3oool00`3o
0000oooo0?ooo`020?l000<0oooo0P3o00000`3oool0o`000?ooo`060?l000@0oooo00<0o`000?oo
o`3oool0103oool01`3o0000oooo0?l0003oool0o`000?ooo`3o00003@3oool20?l000<0oooo0P3o
00020?ooo`040?l0003oool0o`000?l00080oooo0P3o00001@3oool0o`000?l0003oool0o`0000<0
oooo00<0o`000?ooo`3o00000P3oool20?l00080oooo00<0o`000?ooo`3o00000P3oool20?l0000:
0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l00080oooo00<0o`000?ooo`3o0000
0P3oool20?l000030?ooo`3o0000oooo0080o`00403oool20?l000090?ooo`3o0000oooo0?l0003o
ool0o`000?ooo`3o0000oooo00<0o`000P3oool02P3o0000oooo0?l0003oool0o`000?ooo`3o0000
oooo0?l0003oool30?l000@0oooo0P3o00020?ooo`040?l0003oool0oooo0?l00080oooo0P3o0000
1@3oool0o`000?l0003oool0o`000080oooo0P3o00020?ooo`040?l0003oool0oooo0?ooo`80o`00
0P3oool20?l00080oooo0P3o00030?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000
oooo0?ooo`3o0000oooo0080o`001P3oool01`3o0000oooo0?l0003oool0o`000?ooo`3o0000303o
ool20?l000<0oooo0P3o00000`3oool0o`000?ooo`0B0?ooo`@0o`0000P0oooo0?l0003oool0o`00
0?ooo`3o0000oooo0?l00080oooo00<00?l00?ooo`3oool00P00o`020?ooo`03003o003oool0oooo
0080oooo00<00?l00?ooo`3oool0/03oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`02
0?ooo`800?l00`3oool01000o`00oooo0?ooo`3oool2003o0080oooo00<00?l00?ooo`3oool03@3o
ool00`000000oooo0?ooo`0^0?ooo`00<`3oool4000001H0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`080?ooo`H00000=`3oool0103o0000oooo0?ooo`3oool40?l00080oooo
00<0o`000?ooo`3oool00P3o000:0?ooo`80o`002P3oool30?l000030?ooo`3o0000oooo0080oooo
0`3o0000103oool0o`000?ooo`3oool20?l00080oooo00@0o`000?ooo`3o0000o`000P3oool01`3o
0000oooo0?l0003oool0o`000?ooo`3o00002@3oool00`3o0000oooo0?l000020?ooo`030?l0003o
ool0oooo0080o`0000<0oooo0?l0003oool01@3o00050?ooo`030?l0003oool0oooo00@0oooo00L0
o`000?ooo`3o0000oooo0?l0003oool0o`0000d0oooo0P3o00030?ooo`80o`000P3oool01@3o0000
oooo0?l0003o0000oooo00<0o`0000D0oooo0?l0003o0000oooo0?l000030?ooo`030?l0003oool0
o`000080oooo0P3o00020?ooo`030?l0003oool0o`000080oooo0P3o00020?ooo`80o`0000H0oooo
0?l0003oool0o`000?ooo`3o00020?ooo`0:0?l0003oool0o`000?ooo`3o0000oooo0?l0003oool0
o`000?ooo`80o`00403oool20?l000090?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo
00<0o`000P3oool30?l000070?ooo`3o0000oooo0?l0003oool0o`000?ooo`030?l000D0oooo00@0
o`000?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`020?l000050?ooo`3o0000oooo0?ooo`3o
00000P3oool20?l00080oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`000P3oool20?l0
00<0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?l0003oool00P3o
00060?ooo`070?l0003oool0o`000?ooo`3o0000oooo0?l0000=0?ooo`040?l0003oool0oooo0?oo
o`80o`005@3oool40?l000080?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o00050?ooo`05003o
003oool0oooo0?ooo`00o`00^`3oool01@00o`00oooo0?ooo`3oool00?l000<0oooo0P00o`030?oo
o`05003o003oool0oooo0?ooo`00o`000`3oool00`00o`00oooo0?ooo`0=0?ooo`030000003oool0
oooo02h0oooo000g0?ooo`<00000403oool3000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo03h0oooo103o00020?ooo`030?l0003oool0oooo
0080o`002P3oool20?l000X0oooo0`3o00000`3oool0o`000?ooo`020?ooo`<0o`0000@0oooo0?l0
003o0000oooo0P3o00020?ooo`040?l0003oool0o`000?l00080oooo00L0o`000?ooo`3o0000oooo
0?l0003oool0o`0000X0oooo0P3o00020?ooo`030?l0003oool0oooo0080o`0000<0oooo0?l0003o
ool00`3o00000`3oool0o`000?ooo`040?ooo`030?l0003oool0oooo00@0oooo00L0o`000?ooo`3o
0000oooo0?l0003oool0o`0000d0oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0?l0003o
0000oooo00<0o`0000D0oooo0?l0003o0000oooo0?l000030?ooo`030?l0003oool0o`000080oooo
0P3o00020?ooo`030?l0003oool0o`000080oooo0P3o00020?ooo`80o`0000H0oooo0?l0003oool0
o`000?ooo`3o00020?ooo`060?l0003oool0o`000?ooo`3o0000oooo0P3o00020?ooo`80o`00403o
ool20?l000090?ooo`3o0000o`000?l0003oool0o`000?ooo`3o0000oooo00<0o`000P3oool30?l0
00070?ooo`3o0000o`000?l0003oool0o`000?ooo`030?l000D0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?l000050?ooo`3o0000oooo0?ooo`3o00000P3oool20?l00080oooo
00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo00D0o`000?ooo`3o
ool0oooo0?l000020?ooo`050?l0003oool0oooo0?l0003oool00P3o00060?ooo`070?l0003oool0
o`000?ooo`3o0000oooo0?l0000=0?ooo`040?l0003oool0oooo0?ooo`80o`005@3oool40?l00008
0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o00050?ooo`03003o003oool0oooo0<40oooo00D0
0?l00?ooo`3oool0oooo003o00040?ooo`05003o003oool0oooo0?ooo`00o`000`3oool00`00o`00
oooo0?ooo`0=0?ooo`030000003oool0oooo02h0oooo000j0?ooo`8000004@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0?P3oool30?l00004
0?ooo`3o0000oooo0?l00080oooo0P3o000:0?ooo`80o`002P3oool30?l000D0oooo0`3o0000103o
ool0o`000?l0003oool30?l000030?ooo`3o0000oooo0080o`000P3oool01`3o0000oooo0?l0003o
ool0o`000?ooo`3o00002P3oool20?l00080oooo00L0o`000?ooo`3o0000oooo0?l0003oool0o`00
0080oooo0P3o00000`3oool0o`000?ooo`040?ooo`030?l0003oool0oooo00@0oooo00L0o`000?oo
o`3o0000oooo0?l0003oool0o`0000d0oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0?l0
003o0000oooo00<0o`0000D0oooo0?l0003o0000oooo0?l000030?ooo`<0o`000P3oool20?l00080
oooo00<0o`000?ooo`3o00000P3oool20?l00080oooo0P3o00001P3oool0o`000?ooo`3o0000oooo
0?l00080oooo00H0o`000?ooo`3o0000oooo0?l0003oool20?l00080oooo00<0o`000?ooo`3oool0
3`3oool20?l000090?ooo`3o0000o`000?l0003oool0o`000?ooo`3o0000oooo0080o`000`3oool3
0?l000050?ooo`3o0000o`000?l0003oool00P3o00000`3oool0o`000?l000050?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3o00001@3oool0o`000?ooo`3oool0o`000080oooo
0P3o00020?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool20?l00080oooo0P3o00030?ooo`05
0?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3o0000oooo0080o`000`3oool0
2P3o0000oooo0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o000=0?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool04`3oool40?l000080?ooo`3o0000oooo0?l0003oool0o`000?oo
o`3o003=0?ooo`03003o003oool0oooo0080oooo00D00?l00?ooo`3oool0oooo003o00030?ooo`03
003o003oool0oooo00d0oooo00<000000?ooo`3oool0;P3oool003L0oooo0`00000>0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo03h0oooo0`3o0000103oool0o`000?ooo`3o00020?ooo`80o`002P3oool20?l0
00X0oooo0`3o00060?ooo`80o`0000D0oooo0?l0003o0000o`000?ooo`020?l000030?ooo`3o0000
oooo0080o`000P3oool01`3o0000oooo0?l0003oool0o`000?ooo`3o00002`3oool02P3o0000oooo
0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o00020?ooo`80o`0000<0oooo0?l0003oool0103o
ool00`3o0000oooo0?ooo`040?ooo`070?l0003oool0o`000?ooo`3o0000oooo0?l0000=0?ooo`03
0?l0003oool0oooo00H0oooo00D0o`000?ooo`3o0000o`000?ooo`020?l00080oooo0P3o00000`3o
ool0o`000?ooo`020?ooo`<0o`000P3oool20?l000<0oooo0P3o00020?ooo`80o`000P3oool20?l0
00060?ooo`3o0000oooo0?l0003oool0o`000P3oool01P3o0000oooo0?l0003oool0o`000?ooo`80
o`000P3oool00`3o0000oooo0?ooo`0?0?ooo`80o`0000T0oooo0?l0003o0000o`000?ooo`3o0000
oooo0?l0003oool00P3o00030?ooo`<0o`0000D0oooo0?l0003o0000o`000?ooo`020?l000030?oo
o`3o0000o`0000D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?l000050?oo
o`3o0000oooo0?ooo`3o00000P3oool20?l00080oooo00@0o`000?ooo`3oool0oooo0P3o00020?oo
o`80o`000P3oool20?l000<0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0
oooo0?l0003oool00P3o00030?ooo`050?l0003oool0oooo0?l0003oool00P3o00020?ooo`030?l0
003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0C0?ooo`0<0?l0
003oool0o`000?l0003oool0o`000?ooo`3o0000oooo0?l0003oool0o`00eP3oool01@00o`00oooo
0?ooo`3oool00?l000l0oooo00<000000?ooo`3oool0;P3oool003@0oooo0`00000A0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo03h0oooo00L0o`000?ooo`3o0000oooo0?l0003oool0o`000080oooo0P3o000:
0?ooo`030?l0003oool0oooo00T0oooo0`3o00060?ooo`80o`0000D0oooo0?l0003o0000o`000?oo
o`040?l000030?ooo`3o0000o`000080oooo00L0o`000?ooo`3o0000oooo0?l0003oool0o`0000/0
oooo00P0o`000?ooo`3oool0o`000?ooo`3o0000oooo0?l000@0oooo0P3o00000`3oool0o`000?oo
o`0;0?ooo`040?l0003oool0o`000?ooo`80o`003P3oool00`3o0000oooo0?ooo`060?ooo`@0o`00
00<0oooo0?l0003o00000P3oool20?l000030?ooo`3o0000oooo00<0oooo0P3o00020?ooo`80o`00
0`3oool20?l00080oooo00@0o`000?ooo`3oool0oooo0P3o00001P3oool0o`000?l0003o0000oooo
0?l00080oooo00H0o`000?ooo`3o0000oooo0?l0003oool20?l00080oooo00<0o`000?ooo`3oool0
3`3oool20?l000090?ooo`3o0000o`000?l0003oool0o`000?ooo`3o0000oooo0080o`000`3oool3
0?l000030?ooo`3o0000o`000080oooo0P3o00000`3oool0o`000?l000050?ooo`030?l0003oool0
oooo00<0oooo00D0o`000?ooo`3oool0o`000?ooo`020?l00080oooo00<0o`000?ooo`3oool00P3o
00020?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool20?l00080oooo0P3o00030?ooo`050?l0
003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3o0000oooo0080o`000`3oool01@3o
0000oooo0?ooo`3o0000oooo0080o`000P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool04`3oool01@3o0000oooo0?l0003o0000oooo0080o`000P3o
ool00`3o0000oooo0?l0003J0?ooo`03003o003oool0oooo00d0oooo00<000000?ooo`3oool0;P3o
ool00380oooo0P00000E0?ooo`@00000103oool4000000/0oooo100000110?ooo`<0o`000P3oool2
0?l000X0oooo00<0o`000?ooo`3oool02@3oool20?l000L0oooo00<0o`000?ooo`3oool00`3o0000
0`3oool0o`000?l000020?l000030?ooo`3o0000o`0000H0oooo00<0o`000?ooo`3o00003P3oool3
0?l000030?ooo`3o0000oooo00<0oooo0P3o00000`3oool0o`000?ooo`0;0?ooo`040?l0003oool0
o`000?ooo`80o`005`3oool40?l000030?ooo`3o0000o`000080oooo0P3o00070?ooo`030?l0003o
ool0oooo0080o`000`3oool20?l00080oooo00@0o`000?ooo`3oool0oooo0P3o00001P3oool0o`00
0?l0003o0000oooo0?l00080oooo00H0o`000?ooo`3o0000oooo0?l0003oool20?l00080oooo00<0
o`000?ooo`3oool03`3oool20?l000050?ooo`3o0000o`000?l0003oool00`3o00000`3oool0o`00
0?l000030?ooo`<0o`0000<0oooo0?l0003oool00P3oool20?l00080oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0o`000080oooo00T0o`000?ooo`3oool0
oooo0?l0003oool0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3oool20?l00080oooo0P3o
00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3oool0
o`000?ooo`020?l000<0oooo00D0o`000?ooo`3oool0o`000?ooo`020?l00080oooo00<0o`000?oo
o`3oool0403oool00`3o0000oooo0?ooo`0C0?ooo`050?l0003oool0o`000?l0003oool00P3o0002
0?ooo`030?l0003oool0o`000>X0oooo00<000000?ooo`3oool0;P3oool00600oooo00<000000?oo
o`3oool0@`3oool20?l00080oooo0P3o000:0?ooo`030?l0003oool0oooo00T0oooo0P3o000;0?oo
o`80o`0000<0oooo0?l0003oool00P3o00000`3oool0o`000?l000060?ooo`030?l0003oool0o`00
00h0oooo0`3o00000`3oool0o`000?ooo`030?ooo`80o`0000<0oooo0?l0003oool02`3oool0103o
0000oooo0?l0003oool20?l001L0oooo103o00000`3oool0o`000?l000020?ooo`80o`001`3oool0
0`3o0000oooo0?ooo`020?l000<0oooo0P3o00020?ooo`040?l0003oool0oooo0?ooo`80o`0000L0
oooo0?l0003o0000o`000?ooo`3o0000oooo0080o`0000D0oooo0?l0003oool0o`000?ooo`020?l0
0080oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?l000020?l000050?ooo`3o0000o`00
0?l0003oool00P3o00030?ooo`<0o`001@3oool20?l00080oooo00<0o`000?ooo`3oool02P3oool2
0?l00080oooo00T0o`000?ooo`3oool0oooo0?l0003oool0o`000?ooo`3o00000P3oool0103o0000
oooo0?ooo`3oool20?l00080oooo0P3o00020?ooo`80o`000`3oool01@3o0000oooo0?ooo`3oool0
o`000080oooo00D0o`000?ooo`3oool0o`000?ooo`020?l000<0oooo00D0o`000?ooo`3oool0o`00
0?ooo`020?l001D0oooo00<0o`000?ooo`3oool04`3oool01@3o0000oooo0?l0003o0000oooo0080
o`000P3oool20?l00>/0oooo00<000000?ooo`3oool0;P3oool00380oooo2P00000T0?ooo`030000
003oool0oooo04<0oooo0P3o00020?ooo`80o`002P3oool00`3o0000oooo0?ooo`090?ooo`80o`00
2`3oool20?l000030?ooo`3o0000oooo0080o`0000<0oooo0?l0003o00001P3oool00`3o0000oooo
0?l0000>0?ooo`<0o`0000<0oooo0?l0003oool0103oool00`3o0000oooo0?l0000<0?ooo`040?l0
003oool0o`000?ooo`80o`005`3oool40?l000030?ooo`3o0000o`000080oooo0P3o00070?ooo`04
0?l0003oool0oooo0?l000@0oooo0P3o00020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool3
0?l000030?ooo`3o0000oooo0080o`0000H0oooo0?l0003oool0o`000?ooo`3o00030?ooo`030?l0
003oool0oooo0180oooo0`3o00001@3oool0o`000?l0003o0000oooo0080o`00103oool20?l000H0
oooo00@0o`000?ooo`3oool0o`00303oool20?l00080oooo00T0o`000?ooo`3oool0oooo0?l0003o
ool0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3oool20?l00080oooo0P3o00020?ooo`80
o`000`3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3oool0o`000?ooo`02
0?l000<0oooo00D0o`000?ooo`3oool0o`000?ooo`020?l001D0oooo00<0o`000?ooo`3oool04`3o
ool00`3o0000oooo0?l000020?ooo`80o`000P3oool20?l00>/0oooo00<000000?ooo`3oool0;P3o
ool003D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`130?ooo`80o`000P3oool0
0`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo0P3o000<0?ooo`040?l0003oool0
o`000?ooo`80o`0000<0oooo0?l0003o00001P3oool00`3o0000oooo0?l0000>0?ooo`<0o`0000<0
oooo0?l0003oool0103oool00`3o0000oooo0?l0000<0?ooo`040?l0003oool0o`000?ooo`80o`00
5`3oool40?l000030?ooo`3o0000o`000080oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`020?ooo`80o`000P3oool01@3o0000oooo0?ooo`3oool0o`000080oooo0`3o00000`3oool0
o`000?ooo`020?l000060?ooo`3o0000oooo0?l0003oool0o`000`3oool00`3o0000oooo0?ooo`0B
0?ooo`<0o`0000D0oooo0?l0003o0000o`000?ooo`020?l000@0oooo0P3o00090?ooo`030?l0003o
ool0oooo00X0oooo0P3o00020?ooo`090?l0003oool0oooo0?ooo`3o0000oooo0?l0003oool0o`00
0080oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`000P3oool20?l000<0oooo00D0o`00
0?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?l0003oool00P3o00030?ooo`060?l0
003oool0oooo0?l0003oool0o`005P3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0o`00
0080oooo0P3o00020?ooo`80o`00j`3oool00`000000oooo0?ooo`0^0?ooo`00=03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo04<0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?oo
o`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?l000020?oo
o`80o`001P3oool00`3o0000oooo0?l0000>0?ooo`<0o`0000<0oooo0?l0003oool0103oool00`3o
0000oooo0?l0000<0?ooo`040?l0003oool0o`000?ooo`80o`005`3oool30?l000040?ooo`3o0000
o`000?l00080oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`040?l0003o
ool0oooo0?l000<0oooo00<0o`000?ooo`3oool00`3o00000`3oool0o`000?ooo`020?l000060?oo
o`3o0000oooo0?l0003oool0o`000`3oool00`3o0000oooo0?ooo`0B0?ooo`<0o`0000D0oooo0?l0
003o0000o`000?ooo`020?l000@0oooo0P3o00090?ooo`030?l0003oool0oooo00X0oooo0P3o0002
0?ooo`090?l0003oool0oooo0?ooo`3o0000oooo0?l0003oool0o`000080oooo00@0o`000?ooo`3o
ool0oooo0P3o00020?ooo`80o`0000@0oooo0?l0003o0000o`000`3oool01@3o0000oooo0?ooo`3o
ool0o`000080oooo00D0o`000?ooo`3oool0o`000?ooo`020?l000<0oooo00H0o`000?ooo`3oool0
o`000?ooo`3o000F0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool00P3o00020?oo
o`80o`00j`3oool00`000000oooo0?ooo`0^0?ooo`00=03oool00`000000oooo0?ooo`0Y0?ooo`@0
0000@P3oool01@3o0000oooo0?ooo`3oool0o`0001P0oooo00<0o`000?ooo`3oool0303oool00`3o
0000oooo0?l000020?ooo`80o`001P3oool00`3o0000oooo0?l0000>0?ooo`<0o`0000<0oooo0?l0
003oool0103oool00`3o0000oooo0?l0000<0?ooo`040?l0003oool0o`000?ooo`80o`00603oool2
0?l000040?ooo`3o0000o`000?l00080oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?oo
o`030?ooo`040?l0003oool0oooo0?l000<0oooo00<0o`000?ooo`3oool00`3o00000`3oool0o`00
0?ooo`020?l000060?ooo`3o0000oooo0?l0003oool0o`000`3oool00`3o0000oooo0?ooo`0B0?oo
o`<0o`0000D0oooo0?l0003o0000o`000?ooo`020?l000@0oooo0P3o00090?ooo`030?l0003oool0
oooo00/0oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?l0003oool0o`000080oooo
00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`0000@0oooo0?l0003o0000o`000`3oool01@3o
0000oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3oool0o`000?ooo`020?l000<0oooo00H0
o`000?ooo`3oool0o`000?ooo`3o000F0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3o
ool00P3o00020?ooo`80o`00j`3oool00`000000oooo0?ooo`0^0?ooo`00=03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo04<0oooo00D0o`000?ooo`3oool0oooo0?l0000H0?ooo`03
0?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool00P3o00060?ooo`030?l0003oool0o`0000h0
oooo0`3o00000`3oool0o`000?ooo`040?ooo`030?l0003oool0oooo00`0oooo0`3o00000`3oool0
o`000?l0000H0?ooo`80o`0000@0oooo0?l0003o0000o`000P3oool00`3o0000oooo0?ooo`090?oo
o`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0o`000`3oool02@3o0000oooo0?ooo`3o
0000oooo0?l0003oool0o`000?ooo`020?l000060?ooo`3o0000oooo0?l0003oool0o`00603oool0
103o0000oooo0?l0003oool30?l000030?ooo`3o0000o`0000@0oooo0P3o00090?ooo`030?l0003o
ool0oooo00/0oooo00@0o`000?ooo`3oool0o`000`3oool30?l000050?ooo`3o0000oooo0?ooo`3o
00000`3oool20?l00080oooo0P3o0000103oool0o`000?l0003o00030?ooo`050?l0003oool0oooo
0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3o0000oooo0080o`000`3oool01P3o0000oooo0?oo
o`3o0000oooo0?l002h0oooo00<0o`000?ooo`3oool00P3o00020?ooo`80o`00j`3oool00`000000
oooo0?ooo`0^0?ooo`00=@3oool7000002@0oooo00<000000?ooo`3oool0@`3oool01@3o0000oooo
0?ooo`3oool0o`0001P0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`020?l000H0
oooo00<0o`000?ooo`3o00003P3oool30?l000030?ooo`3o0000oooo00@0oooo00<0o`000?ooo`3o
ool0303oool30?l000030?ooo`3o0000o`0001P0oooo0P3o0000103oool0o`000?l0003o00020?oo
o`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`3o0003
0?ooo`090?l0003oool0oooo0?l0003oool0o`000?ooo`3o0000oooo0080o`0000H0oooo0?l0003o
ool0o`000?ooo`3o000H0?ooo`030?l0003oool0o`000080oooo0P3o00000`3oool0o`000?ooo`04
0?ooo`80o`002@3oool00`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?l000<0oooo0`3o
00001@3oool0o`000?ooo`3oool0o`0000<0oooo0P3o00020?ooo`80o`0000@0oooo0?l0003o0000
o`000`3oool00`3o0000oooo0?ooo`020?l00080oooo00<0o`000?ooo`3oool00P3o00000`3oool0
o`000?ooo`020?ooo`060?l0003oool0oooo0?l0003oool0o`00<@3oool20?l00080oooo0P3o003[
0?ooo`030000003oool0oooo02h0oooo001P0?ooo`030000003oool0oooo04<0oooo00D0o`000?oo
o`3oool0oooo0?l0000H0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool00P3o0006
0?ooo`030?l0003oool0o`0000h0oooo0`3o00000`3oool0o`000?ooo`040?ooo`030?l0003oool0
oooo00`0oooo0`3o00000`3oool0o`000?l0000H0?ooo`80o`0000@0oooo0?l0003o0000o`000P3o
ool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo
0?l000020?ooo`060?l0003oool0o`000?ooo`3o0000oooo0P3o00001P3oool0o`000?l0003o0000
oooo0?l001P0oooo00<0o`000?ooo`3o00000P3oool20?l000030?ooo`3o0000oooo00@0oooo0P3o
00090?ooo`030?l0003oool0oooo00/0oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo
0?l0003oool0o`000080oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`80o`0000@0oooo0?l0
003o0000o`000`3oool0103o0000oooo0?ooo`3o00030?ooo`030?l0003oool0oooo0080o`0000@0
oooo0?l0003oool0oooo0P3o00020?ooo`030?l0003oool0o`000340oooo0P3o00030?ooo`030?l0
003oool0oooo0>T0oooo00<000000?ooo`3oool0;P3oool00600oooo00<000000?ooo`3oool0@`3o
ool01@3o0000oooo0?ooo`3oool0o`0001P0oooo00<0o`000?ooo`3oool03P3oool01@3o0000oooo
0?ooo`3oool0o`0000H0oooo00<0o`000?ooo`3o00003P3oool30?l000030?ooo`3o0000oooo00@0
oooo00<0o`000?ooo`3oool0303oool30?l000030?ooo`3o0000o`0001P0oooo0P3o0000103oool0
o`000?l0003o00020?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool01P3oool01@3o
0000oooo0?ooo`3oool0o`000080oooo00H0o`000?ooo`3o0000oooo0?l0003oool20?l000060?oo
o`3o0000o`000?l0003oool0o`00603oool00`3o0000oooo0?l000020?ooo`80o`0000<0oooo0?l0
003oool0103oool20?l000T0oooo00<0o`000?ooo`3oool02`3oool0103o0000oooo0?ooo`3o0003
0?ooo`050?l0003oool0o`000?ooo`3o00000P3oool0103o0000oooo0?ooo`3oool20?l00080oooo
0P3o0000103oool0o`000?l0003o00030?ooo`040?l0003oool0oooo0?l000<0oooo00<0o`000?oo
o`3oool00P3o0000103oool0o`000?ooo`3oool20?l00080oooo00<0o`000?ooo`3o0000<@3oool2
0?l000<0oooo00<0o`000?ooo`3oool0j@3oool00`000000oooo0?ooo`0^0?ooo`00H03oool40000
0480oooo00D0o`000?ooo`3oool0oooo0?l0000H0?ooo`030?l0003oool0oooo00h0oooo00D0o`00
0?ooo`3oool0oooo0?l000060?ooo`030?l0003oool0o`0000h0oooo0`3o00000`3oool0o`000?oo
o`0C0?ooo`<0o`0000<0oooo0?l0003o0000603oool20?l000040?ooo`3o0000o`000?l00080oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`050?l0003oool0oooo0?ooo`3o
00000P3oool01P3o0000oooo0?l0003oool0o`000?ooo`80o`0000H0oooo0?l0003o0000o`000?oo
o`3o000H0?ooo`030?l0003oool0o`000080oooo0P3o00000`3oool0o`000?ooo`050?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool03P3oool02@3o0000oooo0?ooo`3oool0o`000?oo
o`3o0000oooo0?l000020?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool20?l000040?ooo`3o
0000o`000?l000<0oooo00@0o`000?ooo`3oool0o`000`3oool00`3o0000oooo0?ooo`020?l00004
0?ooo`3o0000oooo0?ooo`80o`000P3oool00`3o0000oooo0?ooo`0a0?ooo`80o`000`3oool00`3o
0000oooo0?ooo`3Y0?ooo`030000003oool0oooo02h0oooo001P0?ooo`030000003oool0oooo04<0
oooo00D0o`000?ooo`3oool0oooo0?l0000H0?ooo`030?l0003oool0oooo00h0oooo00D0o`000?oo
o`3oool0oooo0?l000060?ooo`030?l0003oool0o`0000h0oooo0`3o00000`3oool0o`000?ooo`0C
0?ooo`<0o`0000<0oooo0?l0003oool0603oool20?l000040?ooo`3o0000o`000?l00080oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`050?l0003oool0oooo0?ooo`3o0000
0P3oool00`3o0000oooo0?ooo`020?ooo`<0o`0000H0oooo0?l0003o0000o`000?ooo`3o000H0?oo
o`030?l0003oool0o`000080oooo0P3o00000`3oool0o`000?ooo`050?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0o`00
0080oooo00@0o`000?ooo`3oool0oooo0P3o00001@3oool0o`000?ooo`3o0000oooo00<0o`000`3o
ool0103o0000oooo0?ooo`3o00030?ooo`030?l0003oool0oooo0080o`0000@0oooo0?l0003oool0
oooo0P3o00020?ooo`030?l0003oool0oooo0340oooo0P3o00030?ooo`030?l0003oool0oooo0>T0
oooo00<000000?ooo`3oool0;P3oool00600oooo00<000000?ooo`3oool0@`3oool01@3o0000oooo
0?ooo`3oool0o`0001P0oooo00<0o`000?ooo`3oool03P3oool01@3o0000oooo0?ooo`3oool0o`00
00H0oooo00<0o`000?ooo`3o00003P3oool20?l00080oooo00<0o`000?ooo`3oool04P3oool30?l0
00030?ooo`3o0000oooo01P0oooo0P3o0000103oool0o`000?l0003o00020?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00<0
o`000?ooo`3oool00P3oool30?l000060?ooo`3o0000o`000?l0003oool0o`00603oool00`3o0000
oooo0?l000020?ooo`80o`0000<0oooo0?l0003oool01@3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?l000020?ooo`04
0?l0003oool0oooo0?ooo`80o`0000P0oooo0?l0003oool0o`000?ooo`3o0000oooo0?l000<0oooo
00@0o`000?ooo`3oool0o`000`3oool00`3o0000oooo0?ooo`020?l000040?ooo`3o0000oooo0?oo
o`80o`000P3oool00`3o0000oooo0?ooo`0a0?ooo`80o`000`3oool00`3o0000oooo0?ooo`3Y0?oo
o`030000003oool0oooo02h0oooo001P0?ooo`030000003oool0oooo04<0oooo00D0o`000?ooo`3o
ool0oooo0?l0000H0?ooo`030?l0003oool0oooo00h0oooo00D0o`000?ooo`3oool0oooo0?l00006
0?ooo`80o`00403oool0103o0000oooo0?ooo`3o000D0?ooo`<0o`0000<0oooo0?l0003oool0603o
ool20?l000040?ooo`3o0000o`000?l00080oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`060?ooo`050?l0003oool0oooo0?ooo`3o00001`3oool30?l000060?ooo`3o0000o`000?l0
003oool0o`006P3oool00`3o0000oooo0?ooo`020?l000030?ooo`3o0000oooo00D0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3o00000P3oool20?l00080oooo0P3o0000203oool0o`000?ooo`3o0000oooo0?l0003oool0
o`000`3oool0103o0000oooo0?ooo`3o00030?ooo`030?l0003oool0oooo0080o`0000@0oooo0?l0
003oool0oooo0P3o00020?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`3oool0kP3oool0
0`000000oooo0?ooo`0^0?ooo`00H03oool00`000000oooo0?ooo`130?ooo`050?l0003oool0oooo
0?ooo`3o0000603oool00`3o0000oooo0?ooo`0>0?ooo`050?l0003oool0oooo0?ooo`3o00001P3o
ool20?l00100oooo00<0o`000?ooo`3oool05@3oool30?l000030?ooo`3o0000oooo01P0oooo0P3o
0000103oool0o`000?l0003o00020?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0
1P3oool01@3o0000oooo0?ooo`3oool0o`0000L0oooo0`3o00001P3oool0o`000?l0003o0000oooo
0?l001X0oooo00<0o`000?ooo`3oool00P3o00000`3oool0o`000?ooo`0?0?ooo`030?l0003oool0
oooo00h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?l00080oooo0P3o0000
203oool0o`000?ooo`3o0000oooo0?l0003oool0o`000`3oool0103o0000oooo0?ooo`3o00030?oo
o`030?l0003oool0oooo0080o`0000@0oooo0?l0003oool0oooo0P3o00020?ooo`030?l0003oool0
oooo0340oooo00<0o`000?ooo`3oool0kP3oool00`000000oooo0?ooo`0^0?ooo`00H03oool40000
0480oooo00D0o`000?ooo`3oool0oooo0?l0000H0?ooo`030?l0003oool0oooo01T0oooo0P3o000X
0?ooo`<0o`0000<0oooo0?l0003oool0603oool20?l000040?ooo`3o0000o`000?l00080oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`050?l0003oool0oooo0?ooo`3o0000
1`3oool30?l000030?ooo`3o0000o`000080oooo00<0o`000?ooo`3oool06`3oool20?l000030?oo
o`3o0000oooo00l0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo0080o`0000`0oooo0?l0003oool0o`000?ooo`3o0000oooo0?l0003oool0o`000?oo
o`3o00030?ooo`040?l0003oool0oooo0?l000H0oooo0P3o0000103oool0o`000?ooo`3oool20?l0
0080oooo00<0o`000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`3^0?ooo`030000003oool0oooo
02h0oooo001<0?ooo`030000003oool0oooo0080oooo1000000;0?ooo`030000003oool0oooo04<0
oooo00D0o`000?ooo`3oool0oooo0?l0000H0?ooo`030?l0003oool0oooo01T0oooo0P3o000X0?oo
o`<0o`0000<0oooo0?l0003oool0603oool20?l000040?ooo`3o0000o`000?l00080oooo00<0o`00
0?ooo`3oool04P3oool01@3o0000oooo0?ooo`3oool0o`0000L0oooo0P3o00020?ooo`80o`000P3o
ool00`3o0000oooo0?ooo`0K0?ooo`80o`0000<0oooo0?l0003oool03`3oool00`3o0000oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3o0000303oool0o`000?oo
o`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l000<0oooo00@0o`000?ooo`3oool0o`00
1P3oool20?l000040?ooo`3o0000oooo0?ooo`<0o`0000<0oooo0?l0003oool0<P3oool00`3o0000
oooo0?ooo`3^0?ooo`030000003oool0oooo02h0oooo001<0?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04<0oooo00<0o`000?ooo`3o
ool06P3oool00`3o0000oooo0?ooo`0I0?ooo`80o`00:03oool30?l000030?ooo`3o0000oooo01P0
oooo0P3o0000103oool0o`000?l0003o00020?ooo`030?l0003oool0oooo01H0oooo00<0o`000?oo
o`3oool01@3oool20?l00080oooo0P3o000P0?ooo`80o`0000<0oooo0?l0003oool03`3oool00`3o
0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3o0000303o
ool0o`000?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l000<0oooo00@0o`000?oo
o`3oool0o`001`3oool00`3o0000oooo0?l000020?ooo`<0o`0000<0oooo0?l0003oool0<P3oool0
0`3o0000oooo0?ooo`3^0?ooo`030000003oool0oooo02h0oooo00170?ooo`L000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0@`3oool00`3o
0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo01T0oooo0P3o000Y0?ooo`80o`0000<0oooo0?l0
003oool0603oool20?l000030?ooo`3o0000o`0000<0oooo00<0o`000?ooo`3oool05P3oool00`3o
0000oooo0?ooo`050?ooo`80o`000P3oool20?l00200oooo0P3o00000`3oool0o`000?ooo`0?0?oo
o`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?l0
000<0?ooo`3o0000oooo0?l0003oool0o`000?ooo`3o0000oooo0?l0003oool0o`000`3oool0103o
0000oooo0?ooo`3o00070?ooo`030?l0003oool0o`000080oooo103o000d0?ooo`030?l0003oool0
oooo0>h0oooo00<000000?ooo`3oool0;P3oool004L0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0203oool600000400oooo00<0o`00
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0I0?ooo`80o`00:@3oool20?l000030?ooo`3o0000
oooo01P0oooo0P3o00000`3oool0o`000?l000030?ooo`030?l0003oool0oooo01H0oooo00<0o`00
0?ooo`3oool01@3oool20?l00080oooo0P3o000P0?ooo`80o`004P3oool00`3o0000oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3o00001`3oool0o`000?ooo`3o
0000oooo0?l0003oool00P3o00020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`3o0000
oooo0?ooo`050?ooo`030?l0003oool0o`000080oooo103o003o0?ooobH0oooo00<000000?ooo`3o
ool0;P3oool004P0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1P0?ooo`030?l0003oool0oooo01T0
oooo0P3o000Y0?ooo`80o`0000<0oooo0?l0003oool0603oool20?l000030?ooo`3o0000o`0000<0
oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`050?ooo`80o`000P3oool20?l00200
oooo0P3o000B0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`020?l000030?ooo`3o0000oooo0080o`000P3oool20?l00080oooo00D0o`000?ooo`3o
ool0oooo0?l000020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0103o003o0?oo
obH0oooo00<000000?ooo`3oool0;P3oool004T0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0H03oool00`3o
0000oooo0?ooo`0I0?ooo`80o`00:@3oool20?l001/0oooo0P3o00000`3oool0o`000?l000030?oo
o`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?l0
0200oooo0P3o000B0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`020?l000030?ooo`3o0000oooo0080o`000P3oool20?l00080oooo00D0o`000?oo
o`3oool0oooo0?l000020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0103o003o
0?ooobH0oooo00<000000?ooo`3oool0;P3oool004T0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0H03oool0
0`3o0000oooo0?ooo`0I0?ooo`80o`00:@3oool00`3o0000oooo0?ooo`0J0?ooo`80o`0000<0oooo
0?l0003o00000`3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool00P3o000P0?ooo`80o`004P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool00P3o00000`3oool0o`000?ooo`020?l00080oooo0P3o0002
0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00@0o`00o`3ooolV0?ooo`030000003oool0oooo02h0oooo001:0?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo07`0oooo0P3o000Y0?ooo`030?l0003oool0oooo01X0oooo0P3o00000`3oool0o`000?ooo`03
0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`02
0?l00200oooo0P3o000B0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`020?l000030?ooo`3o0000oooo0080o`000P3oool20?l00080oooo00D0o`00
0?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0103o
003o0?ooobH0oooo00<000000?ooo`3oool0;P3oool004/0oooo0P0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool4000007/0oooo0P3o000Y0?ooo`030?l0003oool0
oooo01X0oooo0P3o00000`3oool0o`000?ooo`0L0?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool00P3o000P0?ooo`80o`004P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool00P3o00000`3oool0o`000?ooo`020?l00080oooo0P3o0002
0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00@0o`00o`3ooolV0?ooo`030000003oool0oooo02h0oooo001<0?ooo`030000003oool0
oooo0080oooo1000000;0?ooo`030000003oool0oooo07`0oooo0P3o000Y0?ooo`030?l0003oool0
oooo01/0oooo00<0o`000?ooo`3o00007@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo0080o`00803oool20?l00180oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo0080o`0000<0oooo0?l0003oool00P3o00020?ooo`80o`000P3oool0
1@3o0000oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`040?l00?l0oooo9P3oool00`000000oooo0?ooo`0^0?ooo`00H03oool00`000000oooo0?ooo`1l
0?ooo`80o`00:@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0o`0002H0oooo00@0o`00
0?ooo`3oool0o`008@3oool20?l00180oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo0080o`0000<0oooo0?l0003oool00P3o00020?ooo`80o`000P3o
ool01@3o0000oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`030?l00?l0oooo9`3oool00`000000oooo0?ooo`0^0?ooo`00H03oool00`000000oooo0?oo
o`1l0?ooo`80o`00:@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0o`0002H0oooo00@0
o`000?ooo`3oool0o`008@3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00h0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?l000030?ooo`3o0000o`000080oooo
0P3o00020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00<0o`00o`3ooolW0?ooo`030000003oool0oooo02h0oooo001P0?ooo`030000
003oool0oooo07`0oooo0P3o000Y0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3o0000
:@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0o`0000<0oooo0?l0003o0000
0P3oool20?l00080oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool00`3o003o0?ooobL0oooo00<000000?ooo`3oool0;P3oool00600oooo
1000001k0?ooo`80o`00:@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0o`0002T0oooo
00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0Z0?ooo`040?l0003oool0o`000?ooo`<0
o`0000<0oooo0?l0003oool00P3oool20?l00080oooo00D0o`000?ooo`3oool0oooo0?l000020?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00`3o003o0?ooobL0oooo00<000000?oo
o`3oool0;P3oool00600oooo00<000000?ooo`3oool0O03oool20?l002T0oooo00<0o`000?ooo`3o
ool06`3oool00`3o0000oooo0?l0000Y0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3o
ool0:P3oool0103o0000oooo0?l0003oool30?l000030?ooo`3o0000oooo0080oooo0P3o00020?oo
o`050?l0003oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00<0o`00o`3ooolW0?ooo`030000003oool0oooo02h0oooo001P0?ooo`030000003oool0oooo
07`0oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0o`00
02T0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0Z0?ooo`040?l0003oool0o`00
0?ooo`<0o`0000<0oooo0?l0003oool00P3oool20?l00080oooo00D0o`000?ooo`3oool0oooo0?l0
00020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3o003o0?ooobP0oooo00<0
00000?ooo`3oool0;P3oool00600oooo00<000000?ooo`3oool0O03oool00`3o0000oooo0?ooo`0X
0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3o0000:@3oool00`3o0000oooo0?ooo`0O
0?ooo`030?l0003oool0oooo02X0oooo00@0o`000?ooo`3o0000oooo0`3o00000`3oool0o`000?oo
o`020?ooo`80o`000P3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`020?l00?l0oooo:03oool00`000000oooo0?ooo`0^0?ooo`00H03o
ool00`000000oooo0?ooo`1l0?ooo`030?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool06`3o
ool00`3o0000oooo0?l0000Y0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool0:P3o
ool0103o0000oooo0?l0003oool30?l000030?ooo`3o0000oooo0080oooo0P3o00020?ooo`050?l0
003oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0080
o`00o`3ooolX0?ooo`030000003oool0oooo02h0oooo001P0?ooo`@00000N`3oool00`3o0000oooo
0?ooo`0X0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3o0000B`3oool00`3o0000oooo
0?ooo`0Z0?ooo`040?l0003oool0o`000?ooo`<0o`001@3oool20?l00080oooo00D0o`000?ooo`3o
ool0oooo0?l000020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3o003o0?oo
obP0oooo00<000000?ooo`3oool0;P3oool00600oooo00<000000?ooo`3oool0O03oool00`3o0000
oooo0?ooo`0X0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0B`3oool00`3o0000
oooo0?ooo`0Z0?ooo`040?l0003oool0o`000?ooo`<0o`001@3oool20?l00080oooo00D0o`000?oo
o`3oool0oooo0?l000020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3o003o
0?ooobP0oooo00<000000?ooo`3oool0;P3oool00600oooo00<000000?ooo`3oool0O03oool00`3o
0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0B`3oool00`3o
0000oooo0?ooo`0Z0?ooo`040?l0003oool0o`000?ooo`<0o`001@3oool20?l00080oooo00D0o`00
0?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3o
003o0?ooobP0oooo00<000000?ooo`3oool0;P3oool00600oooo00<000000?ooo`3oool0Y`3oool0
0`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo04/0oooo00<0o`000?ooo`3oool0:P3oool0
0`3o0000oooo0?l000020?ooo`030?l0003oool0oooo00@0oooo0P3o00020?ooo`030?l0003oool0
oooo0080o`000P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0080o`00o`3ooolX
0?ooo`030000003oool0oooo02h0oooo001P0?ooo`030000003oool0oooo0:L0oooo00<0o`000?oo
o`3oool06`3oool00`3o0000oooo0?ooo`1;0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?oo
o`3o00000P3oool00`3o0000oooo0?ooo`040?ooo`80o`000P3oool00`3o0000oooo0?ooo`020?l0
0080oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?l00?l0oooo:03oool00`00
0000oooo0?ooo`0^0?ooo`00H03oool400000:H0oooo00<0o`000?ooo`3oool06`3oool00`3o0000
oooo0?ooo`1;0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3o00000P3oool00`3o0000
oooo0?ooo`040?ooo`80o`000P3oool00`3o0000oooo0?ooo`020?l00080oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`020?l00?l0oooo:03oool00`000000oooo0?ooo`0^0?ooo`00
B@3oool4000000@0oooo1000000;0?ooo`030000003oool0oooo0:L0oooo00<0o`000?ooo`3oool0
6`3oool00`3o0000oooo0?ooo`1;0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3o0000
2@3oool20?l00080oooo00<0o`000?ooo`3oool00P3o00020?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool00P3o003o0?ooobP0oooo00<000000?ooo`3oool0;P3oool004P0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`2W0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0
B`3oool00`3o0000oooo0?ooo`0Z0?ooo`030?l0003oool0o`0000T0oooo0P3o00020?ooo`030?l0
003oool0oooo0080o`000P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0080o`00
o`3ooolX0?ooo`030000003oool0oooo02h0oooo00180?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0:L0oooo
00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`1;0?ooo`030?l0003oool0oooo02X0oooo
0`3o00090?ooo`80o`000P3oool00`3o0000oooo0?ooo`020?l00080oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`020?l00?l0oooo:03oool00`000000oooo0?ooo`0^0?ooo`00C@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
Y`3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo04/0oooo00<0o`000?ooo`3oool0
:P3oool30?l000T0oooo0P3o00020?ooo`030?l0003oool0oooo0080o`000P3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo0080o`00o`3ooolX0?ooo`030000003oool0oooo02h0oooo
001=0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool600000:@0oooo
00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`1;0?ooo`030?l0003oool0oooo02X0oooo
0`3o00090?ooo`80o`000P3oool00`3o0000oooo0?ooo`020?l00080oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`020?l00?l0oooo:03oool00`000000oooo0?ooo`0^0?ooo`00B03o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`2W0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0
B`3oool00`3o0000oooo0?ooo`0Z0?ooo`<0o`002@3oool20?l00080oooo00<0o`000?ooo`3oool0
0P3o00020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3o003o0?ooobP0oooo
00<000000?ooo`3oool0;P3oool004P0oooo1@0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`350?ooo`030?l0003oool0oooo04/0oooo00<0
o`000?ooo`3oool0:P3oool20?l000X0oooo0P3o00020?ooo`030?l0003oool0oooo0080o`000P3o
ool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo0?l00?l0oooo:@3oool00`000000oooo
0?ooo`0^0?ooo`00B03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`350?ooo`030?l0003oool0oooo04/0oooo00<0
o`000?ooo`3oool0:P3oool20?l000X0oooo0P3o00020?ooo`030?l0003oool0oooo0080o`000P3o
ool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo0?l00?l0oooo:@3oool00`000000oooo
0?ooo`0^0?ooo`00B@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool400000<@0oooo00<0o`000?ooo`3oool0B`3oool00`3o0000oooo0?oo
o`0Z0?ooo`80o`002P3oool20?l00080oooo00<0o`000?ooo`3oool00P3o00020?ooo`030?l0003o
ool0oooo00L0oooo00@0o`000?ooo`3oool0o`00o`3ooolY0?ooo`030000003oool0oooo02h0oooo
00190?ooo`D000000`3oool4000000/0oooo00<000000?ooo`3oool0a@3oool00`3o0000oooo0?oo
o`1;0?ooo`030?l0003oool0oooo02X0oooo0P3o000:0?ooo`80o`000P3oool00`3o0000oooo0?oo
o`020?l000030?ooo`3o0000o`0000T0oooo00@0o`000?ooo`3oool0o`00o`3ooolY0?ooo`030000
003oool0oooo02h0oooo001P0?ooo`030000003oool0oooo0?l0oooo503oool00`3o0000oooo0?oo
o`0Z0?ooo`80o`002P3oool20?l00080oooo00<0o`000?ooo`3oool00P3o00000`3oool0o`000?l0
00090?ooo`040?l0003oool0oooo0?l00?l0oooo:@3oool00`000000oooo0?ooo`0^0?ooo`00H03o
oooo000001L0000000<0o`00000000000000:P0000020?l000X000000P3o0002000000030?l00000
000000000080o`0000<000000?l0003o00002@000000103o000000000000003o003o000002X00000
<03oool00?l0ooooo`3ooooo0?ooob@0oooo0000\
\>"],
  ImageRangeCache->{{{96, 896}, {555.5, 396.5}} -> {-350.043, 151.761, \
1.67836, 0.413031}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary", "Section"],

Cell["\<\
This example for estimating forward curves are a first expedition into the \
world of electricity prices. The analysis was done in preparation for a \
project. Doing this exercise helped us to understand more sophisticated \
approaches for estimating forward curves. Several parts are missing in this \
notebook like the estimation of volatilities, adjusting the forward curve to \
trade prices, controlling for jumps etc. Eventhough we left out a lot of \
important topics  we hope that this example is usefull as a starting point \
for others.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Section"],

Cell[TextData[{
  StyleBox["Cleveland, William S.",
    FontWeight->"Bold"],
  ", (1993), Visualizing Data, New Jersey 1993."
}], "Text"],

Cell[TextData[{
  StyleBox["Clewlow, Les/Strickland, Chris",
    FontWeight->"Bold"],
  ", (2000), Energy Derivatives: Pricing and Risk Management, Lacima \
Publications."
}], "Text"],

Cell[TextData[{
  StyleBox["Pilipovic, Dragana",
    FontWeight->"Bold"],
  ", (1997), Energy Risk: Valuing and Managing Energy Derivatives, \
McGraw-Hill."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 2048}, {0, 695}},
WindowToolbars->{},
WindowSize->{896, 694},
WindowMargins->{{76, Automatic}, {Automatic, 29}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 45, 0, 67, "Title"],
Cell[1753, 52, 75, 0, 41, "Subtitle"],

Cell[CellGroupData[{
Cell[1853, 56, 30, 0, 62, "Section"],

Cell[CellGroupData[{
Cell[1908, 60, 983, 19, 210, "Input"],
Cell[2894, 81, 486, 8, 82, "Print"]
}, Open  ]],
Cell[3395, 92, 567, 15, 48, "Text"],

Cell[CellGroupData[{
Cell[3987, 111, 77, 1, 50, "Input"],
Cell[4067, 114, 35, 1, 49, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4151, 121, 43, 0, 62, "Section"],
Cell[4197, 123, 915, 20, 117, "Text"],

Cell[CellGroupData[{
Cell[5137, 147, 225, 4, 70, "Input"],
Cell[5365, 153, 238, 3, 84, "Output"]
}, Open  ]],
Cell[5618, 159, 97, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[5740, 165, 190, 3, 70, "Input"],
Cell[5933, 170, 155, 2, 65, "Output"]
}, Open  ]],
Cell[6103, 175, 166, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[6294, 182, 500, 9, 110, "Input"],
Cell[6797, 193, 81138, 2093, 166, 26686, 1416, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[87950, 2289, 174, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[88149, 2296, 322, 6, 70, "Input"],
Cell[88474, 2304, 143674, 2873, 159, 26668, 1424, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[232163, 5180, 243, 4, 48, "Text"],
Cell[232409, 5186, 97, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[232531, 5192, 458, 8, 90, "Input"],
Cell[232992, 5202, 145601, 2924, 152, 27221, 1458, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[378608, 8129, 155, 3, 29, "Text"],
Cell[378766, 8134, 71, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[378862, 8138, 343, 6, 90, "Input"],
Cell[379208, 8146, 167, 3, 25, "Message"],
Cell[379378, 8151, 167, 3, 25, "Message"],
Cell[379548, 8156, 1628433, 36775, 371, 1267165, 32310, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2007996, 44934, 409, 8, 48, "Text"],

Cell[CellGroupData[{
Cell[2008430, 44946, 277, 5, 90, "Input"],
Cell[2008710, 44953, 651, 10, 87, "Output"],
Cell[2009364, 44965, 93459, 2011, 151, 19217, 1090, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2102860, 46981, 57, 0, 52, "Subsection"],
Cell[2102920, 46983, 276, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[2103221, 46992, 207, 3, 70, "Input"],
Cell[2103431, 46997, 225750, 12191, 150, 128446, 10985, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2329196, 59191, 58, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[2329279, 59195, 64, 1, 50, "Input"],
Cell[2329346, 59198, 35, 1, 49, "Output"]
}, Open  ]],
Cell[2329396, 59202, 206, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[2329627, 59210, 327, 5, 90, "Input"],
Cell[2329957, 59217, 52045, 1755, 186, 23429, 1397, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2382005, 60974, 2265, 46, 173, "Output"]
}, Open  ]],
Cell[2384285, 61023, 89, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[2384399, 61029, 526, 10, 113, "Input"],
Cell[2384928, 61041, 44208, 1243, 186, 12137, 843, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2429151, 62287, 373, 10, 48, "Text"],
Cell[2429527, 62299, 1045, 17, 270, "Input"],
Cell[2430575, 62318, 219, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[2430819, 62326, 109, 2, 50, "Input"],
Cell[2430931, 62330, 78678, 2868, 309, 46953, 2472, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2509658, 65204, 51, 0, 52, "Subsection"],
Cell[2509712, 65206, 315, 8, 48, "Text"],
Cell[2510030, 65216, 878, 15, 190, "Input"],
Cell[2510911, 65233, 121, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[2511057, 65240, 44, 0, 45, "Subsubsection"],
Cell[2511104, 65242, 253, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[2511382, 65251, 116, 2, 50, "Input"],
Cell[2511501, 65255, 39885, 1046, 168, 11901, 696, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2551401, 66304, 320, 6, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2551758, 66315, 41, 0, 45, "Subsubsection"],
Cell[2551802, 66317, 109, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[2551936, 66324, 58, 1, 50, "Input"],
Cell[2551997, 66327, 42, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2552076, 66333, 134, 2, 50, "Input"],
Cell[2552213, 66337, 65700, 1448, 206, 13567, 800, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2617928, 67788, 281, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[2618234, 67797, 58, 1, 50, "Input"],
Cell[2618295, 67800, 45, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2618377, 67806, 134, 2, 50, "Input"],
Cell[2618514, 67810, 55143, 1310, 214, 13492, 791, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2673730, 69128, 59, 0, 62, "Section"],
Cell[2673792, 69130, 408, 6, 67, "Text"],

Cell[CellGroupData[{
Cell[2674225, 69140, 50, 0, 52, "Subsection"],
Cell[2674278, 69142, 346, 6, 48, "Text"],
Cell[2674627, 69150, 164, 3, 50, "Input"],
Cell[2674794, 69155, 213, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[2675032, 69163, 210, 4, 70, "Input"],
Cell[2675245, 69169, 45544, 1612, 186, 22499, 1323, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2720804, 70784, 245, 7, 29, "Text"],

Cell[CellGroupData[{
Cell[2721074, 70795, 103, 2, 50, "Input"],
Cell[2721180, 70799, 158, 3, 49, "Output"]
}, Open  ]],
Cell[2721353, 70805, 75, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[2721453, 70809, 245, 5, 70, "Input"],
Cell[2721701, 70816, 46651, 1649, 186, 22905, 1351, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2768367, 72468, 161, 3, 29, "Text"],
Cell[2768531, 72473, 154, 4, 50, "Input"],
Cell[2768688, 72479, 134, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[2768847, 72486, 117, 2, 50, "Input"],
Cell[2768967, 72490, 41846, 1070, 200, 11885, 696, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2810862, 73566, 46, 0, 52, "Subsection"],
Cell[2810911, 73568, 413, 8, 48, "Text"],

Cell[CellGroupData[{
Cell[2811349, 73580, 163, 4, 70, "Input"],
Cell[2811515, 73586, 356, 5, 87, "Output"]
}, Open  ]],
Cell[2811886, 73594, 147, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[2812058, 73601, 505, 9, 90, "Input"],
Cell[2812566, 73612, 115823, 2602, 160, 28147, 1515, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2928404, 76217, 87, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[2928516, 76223, 223, 4, 64, "Input"],
Cell[2928742, 76229, 54, 1, 49, "Output"]
}, Open  ]],
Cell[2928811, 76233, 64, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[2928900, 76237, 223, 4, 64, "Input"],
Cell[2929126, 76243, 53, 1, 49, "Output"]
}, Open  ]],
Cell[2929194, 76247, 124, 3, 29, "Text"],
Cell[2929321, 76252, 160, 2, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2929518, 76259, 49, 0, 52, "Subsection"],
Cell[2929570, 76261, 306, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[2929901, 76270, 113, 2, 70, "Input"],
Cell[2930017, 76274, 302, 4, 65, "Output"]
}, Open  ]],
Cell[2930334, 76281, 67, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[2930426, 76285, 208, 4, 90, "Input"],
Cell[2930637, 76291, 567, 8, 103, "Output"]
}, Open  ]],
Cell[2931219, 76302, 185, 4, 29, "Text"],

Cell[CellGroupData[{
Cell[2931429, 76310, 126, 3, 50, "Input"],
Cell[2931558, 76315, 113, 2, 49, "Output"]
}, Open  ]],
Cell[2931686, 76320, 115, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[2931826, 76327, 638, 12, 110, "Input"],
Cell[2932467, 76341, 153602, 3599, 152, 39566, 2187, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3086084, 79943, 161, 3, 29, "Text"],
Cell[3086248, 79948, 72, 1, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3086357, 79954, 52, 0, 52, "Subsection"],
Cell[3086412, 79956, 390, 6, 67, "Text"],

Cell[CellGroupData[{
Cell[3086827, 79966, 172, 3, 90, "Input"],
Cell[3087002, 79971, 47, 1, 49, "Output"],
Cell[3087052, 79974, 43, 1, 49, "Output"],
Cell[3087098, 79977, 52, 1, 49, "Output"]
}, Open  ]],
Cell[3087165, 79981, 150, 3, 29, "Text"],
Cell[3087318, 79986, 272, 5, 90, "Input"],
Cell[3087593, 79993, 102, 3, 29, "Text"],
Cell[3087698, 79998, 142, 3, 50, "Input"],
Cell[3087843, 80003, 112, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[3087980, 80010, 699, 13, 130, "Input"],
Cell[3088682, 80025, 208746, 4173, 168, 39018, 2073, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3297489, 84205, 26, 0, 62, "Section"],
Cell[3297518, 84207, 569, 9, 67, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3298124, 84221, 29, 0, 62, "Section"],
Cell[3298156, 84223, 137, 4, 29, "Text"],
Cell[3298296, 84229, 183, 5, 29, "Text"],
Cell[3298482, 84236, 168, 5, 29, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

